(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    943412,      40696]
NotebookOptionsPosition[    938066,      40519]
NotebookOutlinePosition[    938513,      40538]
CellTagsIndexPosition[    938470,      40535]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Delay Line Phase Shifter", "Title"],

Cell["\<\
T050250-01
November 10, 2005
Daniel Sigg
\
\>", "Subsubtitle",
 CellChangeTimes->{3.4428679809275*^9}],

Cell[CellGroupData[{

Cell["Theory of Operations", "Subtitle"],

Cell[TextData[{
 "The delay line phase shifter uses a variable length stripline to delay the \
input signal by a selectable amount. Eighteen RF switches are used to route \
the signal either through fixed delay taps or short bypass paths (see \
schematics D050339). The fixed delay taps are ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["1", "16"], "ns"}], TraditionalForm]]],
 ",  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["1", "8"], "ns"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["1", "4"], "ns"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["1", "2"], "ns"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "ns"}], TraditionalForm]]],
 ", 2 ns, 4 ns, 8 ns and 16 ns in length. Any delay between 0 ns and ",
 StyleBox["31.9375 ns can bee added in steps of 0.0625 ns by using \
front-panel mounted toggle switches or through a digital interface such as \
EPICS. Since insertion loss is to be kept small, the RF switches have been \
specially selected and the stripline has been constructed with as large a \
copper cross-section as possible. The RF switches are PE4220 \
silicon-on-sapphire devices from Peregrine Semiconductor and have a nominal \
insertion loss of ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  FormBox[
   RowBox[{"0.1", "-", 
    RowBox[{"0.2", " ", "dB"}]}], TraditionalForm]]],
 " between 10 MHz and 500 MHz. Their 1 dB compression point is at 22 dBm. The \
striplines are built on a 4 layer board with a total thickness of 0.125\". \
This keeps the layer separation around 30 mils and requires 30 mil traces to \
yield 50 \[CapitalOmega] transmission lines. With 3 oz. copper the \
cross-section becomes 0.87 ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["mm", "2"], TraditionalForm]]],
 ". A 16 ns delay will require a trace length around 2.2 m. With a \
conductivity of  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"59.6", "\[Times]", 
    SuperscriptBox["10", "6"]}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", "\[CapitalOmega]m"], TraditionalForm]]],
 " the resistance will be around 40 m\[CapitalOmega]. It is clear that at RF \
frequencies skin effects will play a role as well. At 25 MHz the skin depth \
in copper is about 0.5 mils.",
 StyleBox["\n",
  FontFamily->"Times New Roman"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Specifications", "Subtitle"],

Cell[BoxData[GridBox[{
   {" ", 
    RowBox[{"   ", "Minimum", "   "}], 
    RowBox[{"   ", "Nominal", "   "}], 
    RowBox[{"   ", "Maximum", "  "}]},
   {" ", " ", " ", " "},
   {
    RowBox[{
    "Supply", 
     "                                                                        \
                           "}], 
    RowBox[{"9", "V"}], " ", 
    RowBox[{" ", 
     RowBox[{"24", "V"}]}]},
   {" ", " ", " ", " "},
   {
    RowBox[{"Input", " ", "power"}], " ", " ", 
    RowBox[{"20", "dBm"}]},
   {
    RowBox[{"1", "dB", " ", "compression", " ", "point"}], " ", 
    RowBox[{"22.5", "dBm"}], " "},
   {
    RowBox[{"\[IndentingNewLine]", 
     RowBox[{"Intrinsic", " ", "delay", " "}]}], " ", 
    RowBox[{" ", "\[IndentingNewLine]", 
     RowBox[{"3.7", " ", "ns"}]}], " "},
   {"Steps", "0", " ", "511"},
   {
    RowBox[{"Delay", " ", "per", " ", "step", " ", 
     RowBox[{"(", "design", ")"}]}], " ", 
    RowBox[{"0.0625", " ", "ns"}], " "},
   {
    RowBox[{"Delay", " ", "per", " ", "step", " ", 
     RowBox[{"(", 
      RowBox[{"at", " ", "50", " ", "MHz"}], ")"}]}], 
    RowBox[{" ", 
     AdjustmentBox[
      RowBox[{"0.02", "ns"}],
      BoxMargins->{{0.123552, -0.123552}, {0, 0}}]}], 
    RowBox[{"0.0602", " ", "ns"}], 
    RowBox[{" ", 
     AdjustmentBox[
      RowBox[{"0.10", "ns"}],
      BoxMargins->{{0.123552, -0.123552}, {0, 0}}]}]},
   {
    RowBox[{"Differential", " ", "non\[Dash]linearity", " ", 
     RowBox[{"(", 
      RowBox[{"at", " ", "50", "MHz"}], ")"}]}], 
    RowBox[{
     RowBox[{"-", "0.06"}], "ns"}], " ", 
    RowBox[{
     RowBox[{"+", "0.06"}], "ns"}]},
   {" ", " ", " ", " "},
   {
    RowBox[{"Fixed", " ", "insertion", " ", "loss", " ", 
     RowBox[{"(", 
      RowBox[{"1", "MHz", " ", "to", " ", "200", " ", "MHz"}], ")"}]}], " ", 
    RowBox[{"2.7", "dB"}], " "},
   {
    RowBox[{"Variable", " ", "insertion", " ", "loss", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"phase", " ", "shift"}], " ", "<", " ", 
       RowBox[{"180", "\[Degree]"}]}], ")"}]}], 
    RowBox[{
     RowBox[{"-", "0.6"}], "dB"}], " ", 
    RowBox[{"1.2", "dB"}]},
   {
    RowBox[{"Return", " ", "loss"}], 
    RowBox[{"14", " ", "dB"}], " ", " "},
   {" ", " ", " ", " "}
  },
  GridBoxAlignment->{
   "Columns" -> {Left, {Center}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
  GridBoxDividers->{
   "Columns" -> {{True}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {True, True, {False}, True}, "RowsIndexed" -> {}}]], "Input",
 CellChangeTimes->{{3.44286804995875*^9, 3.442868092193125*^9}}],

Cell[BoxData["\[IndentingNewLine]"], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Needs", "[", "\"\<BarCharts`\>\"", "]"}], ";", 
  RowBox[{"Needs", "[", "\"\<Histograms`\>\"", "]"}], ";", 
  RowBox[{"Needs", "[", "\"\<PieCharts`\>\"", "]"}]}], "\n", 
 RowBox[{"Needs", "[", "\"\<ErrorBarPlots`\>\"", "]"}], "\n", 
 RowBox[{"Needs", "[", "\"\<PlotLegends`\>\"", "]"}], "\n", 
 RowBox[{"Needs", "[", "\"\<Controls`LinearControl`\>\"", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$TextStyle", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
     RowBox[{"FontSize", "\[Rule]", "13"}]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotopt", "=", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0", ",", "0", ",", "1"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.1", ",", "0.7", ",", "0.2"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.5", ",", "0.5", ",", "0.2"}], "]"}]}], "}"}]}], "}"}]}]}],
   ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "pathname", "=", 
   "\"\<C:/User/Daniel/Protel/DelayLinePhaseShifter/Data/\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"filename1", "=", 
   RowBox[{"pathname", "<>", "\"\<Delay_Xns.txt\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"filename2", "=", 
   RowBox[{"pathname", "<>", "\"\<Power.txt\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"filename3", "=", 
   RowBox[{"pathname", "<>", "\"\<DelayTaps.txt\>\""}]}], ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Import Data", "Subtitle"],

Cell[CellGroupData[{

Cell["Delay as function of frequency", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"filename1", ",", "\"\<Table\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x", "=", 
   RowBox[{"First", "/@", "data"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
       "+", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{
        "#", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}]}], 
      ")"}], "&"}], "/@", "data"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"y", "[", 
    RowBox[{"1", "/", "16"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"#", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
       "+", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{
        "#", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}]}]}], 
      ")"}], "&"}], "/@", "data"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"y", "[", 
    RowBox[{"1", "/", "8"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"#", "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], 
       "+", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{
        "#", "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}]}]}], 
      ")"}], "&"}], "/@", "data"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"y", "[", 
    RowBox[{"1", "/", "4"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"#", "\[LeftDoubleBracket]", "8", "\[RightDoubleBracket]"}], 
       "+", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{
        "#", "\[LeftDoubleBracket]", "9", "\[RightDoubleBracket]"}]}]}], 
      ")"}], "&"}], "/@", "data"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"y", "[", 
    RowBox[{"1", "/", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"#", "\[LeftDoubleBracket]", "10", "\[RightDoubleBracket]"}], 
       "+", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{
        "#", "\[LeftDoubleBracket]", "11", "\[RightDoubleBracket]"}]}]}], 
      ")"}], "&"}], "/@", "data"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"y", "[", "1", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"#", "\[LeftDoubleBracket]", "12", "\[RightDoubleBracket]"}], 
       "+", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{
        "#", "\[LeftDoubleBracket]", "13", "\[RightDoubleBracket]"}]}]}], 
      ")"}], "&"}], "/@", "data"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"y", "[", "2", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"#", "\[LeftDoubleBracket]", "14", "\[RightDoubleBracket]"}], 
       "+", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{
        "#", "\[LeftDoubleBracket]", "15", "\[RightDoubleBracket]"}]}]}], 
      ")"}], "&"}], "/@", "data"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"y", "[", "4", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"#", "\[LeftDoubleBracket]", "16", "\[RightDoubleBracket]"}], 
       "+", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{
        "#", "\[LeftDoubleBracket]", "17", "\[RightDoubleBracket]"}]}]}], 
      ")"}], "&"}], "/@", "data"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"y", "[", "8", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"#", "\[LeftDoubleBracket]", "18", "\[RightDoubleBracket]"}], 
       "+", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{
        "#", "\[LeftDoubleBracket]", "19", "\[RightDoubleBracket]"}]}]}], 
      ")"}], "&"}], "/@", "data"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"y", "[", "16", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"#", "\[LeftDoubleBracket]", "20", "\[RightDoubleBracket]"}], 
       "+", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{
        "#", "\[LeftDoubleBracket]", "21", "\[RightDoubleBracket]"}]}]}], 
      ")"}], "&"}], "/@", "data"}]}], ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Power sweep at 50 MHz", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"pwrdata", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"filename2", ",", "\"\<Table\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pwrx", "=", 
   RowBox[{"First", "/@", "pwrdata"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pwry", "=", 
   RowBox[{"Last", "/@", "pwrdata"}]}], ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Delay steps at 50 MHz", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dtapdata", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"filename3", ",", "\"\<Table\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dtapx", "=", 
   RowBox[{"First", "/@", "dtapdata"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dtaploss", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      ")"}], "&"}], "/@", "dtapdata"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dtapphase", "=", 
   RowBox[{"Last", "/@", "dtapdata"}]}], ";"}]}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions", "Subtitle"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"smooth", "[", 
    RowBox[{"l_List", ",", 
     RowBox[{"n_:", "5"}]}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"Plus", "@@", "#"}], "n"], "&"}], "/@", 
    RowBox[{"Partition", "[", 
     RowBox[{"l", ",", "n", ",", "1"}], "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"unwrap", "[", "l_List", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ret", "=", 
        RowBox[{"{", 
         RowBox[{"l", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
         "}"}]}], ",", 
       RowBox[{"ofs", "=", "0"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"i", "=", "2"}], ",", 
        RowBox[{"i", "<=", 
         RowBox[{"Length", "[", "l", "]"}]}], ",", 
        RowBox[{"++", "i"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"ofs", "+=", 
          RowBox[{"Which", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "l", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
              "-", 
              RowBox[{"l", "\[LeftDoubleBracket]", 
               RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]}], ">", 
             "180"}], ",", 
            RowBox[{"-", "360"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{
              "l", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
              "-", 
              RowBox[{"l", "\[LeftDoubleBracket]", 
               RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]}], "<", 
             RowBox[{"-", "180"}]}], ",", "360", ",", "True", ",", "0"}], 
           "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"ret", ",", 
           RowBox[{
            RowBox[{
            "l", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], "+", 
            "ofs"}]}], "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      "ret"}]}], "]"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot of Insertion Loss Data", "Subtitle"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"delays", "=", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "16"], ",", 
     FractionBox["1", "8"], ",", 
     FractionBox["1", "4"], ",", 
     FractionBox["1", "2"], ",", "1", ",", "2", ",", "4", ",", "8", ",", 
     "16"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "dbmag", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dbmag", "[", "0", "]"}], ":=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "/", "1*^6"}], ",", 
      RowBox[{"dB", "[", 
       RowBox[{"y", "[", "0", "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dbmag", "[", "n_", "]"}], ":=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "/", "1*^6"}], ",", 
      RowBox[{"dB", "[", 
       RowBox[{
        RowBox[{"y", "[", "n", "]"}], "/", 
        RowBox[{"y", "[", "0", "]"}]}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dbmagall", "=", 
   RowBox[{"dbmag", "/@", "delays"}]}], ";"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "dbmagsmooth", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dbmagsmooth", "[", "n_", "]"}], ":=", 
  RowBox[{"Interpolation", "[", 
   RowBox[{"smooth", "[", 
    RowBox[{
     RowBox[{"dbmag", "[", "n", "]"}], ",", "5"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dbmagsmoothall", "=", 
   RowBox[{"dbmagsmooth", "/@", "delays"}]}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell["Insertion Loss with No Delay", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"f", "=", 
   RowBox[{"dbmagsmooth", "[", "0", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "6", ",", "194"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
       RowBox[{"RGBColor", " ", "[", 
        RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "}"}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Zero Delay Insertion Loss\>\""}], ",",
    "\[IndentingNewLine]", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Frequency (MHz)\>\"", ",", "\"\<Insertion Loss (dB)\>\""}], 
     "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}]}], "]"}]}], "Input",
 CellChangeTimes->{3.44286813583375*^9}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00658566 0.00506586 2.0802 0.57351 [
[.12006 -0.0125 -9.1875 -16.375 ]
[.12006 -0.0125 9.1875 0 ]
[.24671 -0.0125 -9.1875 -16.375 ]
[.24671 -0.0125 9.1875 0 ]
[.37335 -0.0125 -9.1875 -16.375 ]
[.37335 -0.0125 9.1875 0 ]
[.5 -0.0125 -12.7813 -16.375 ]
[.5 -0.0125 12.7813 0 ]
[.62665 -0.0125 -12.7813 -16.375 ]
[.62665 -0.0125 12.7813 0 ]
[.75329 -0.0125 -12.7813 -16.375 ]
[.75329 -0.0125 12.7813 0 ]
[.87994 -0.0125 -12.7813 -16.375 ]
[.87994 -0.0125 12.7813 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -51.7188 -32.75 ]
[.5 -0.0125 51.7188 -16.375 ]
[-0.0125 .01556 -30.9375 -8.1875 ]
[-0.0125 .01556 0 8.1875 ]
[-0.0125 .13027 -30.9375 -8.1875 ]
[-0.0125 .13027 0 8.1875 ]
[-0.0125 .24497 -30.9375 -8.1875 ]
[-0.0125 .24497 0 8.1875 ]
[-0.0125 .35967 -20.1875 -8.1875 ]
[-0.0125 .35967 0 8.1875 ]
[-0.0125 .47437 -30.9375 -8.1875 ]
[-0.0125 .47437 0 8.1875 ]
[-0.0125 .58907 -30.9375 -8.1875 ]
[-0.0125 .58907 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -47.3125 -56.0313 ]
[-0.01875 .30902 -30.9375 56.0313 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -75.5313 0 ]
[.5 .63053 75.5313 16.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.12006 0 m
.12006 .61803 L
s
.24671 0 m
.24671 .61803 L
s
.37335 0 m
.37335 .61803 L
s
.5 0 m
.5 .61803 L
s
.62665 0 m
.62665 .61803 L
s
.75329 0 m
.75329 .61803 L
s
.87994 0 m
.87994 .61803 L
s
0 .13027 m
1 .13027 L
s
0 .24497 m
1 .24497 L
s
0 .35967 m
1 .35967 L
s
0 .47437 m
1 .47437 L
s
0 .58907 m
1 .58907 L
s
0 g
.12006 0 m
.12006 .00625 L
s
gsave
.12006 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.24671 0 m
.24671 .00625 L
s
gsave
.24671 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.37335 0 m
.37335 .00625 L
s
gsave
.37335 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(75) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.62665 0 m
.62665 .00625 L
s
gsave
.62665 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(125) show
1.000 setlinewidth
grestore
.75329 0 m
.75329 .00625 L
s
gsave
.75329 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.87994 0 m
.87994 .00625 L
s
gsave
.87994 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(175) show
1.000 setlinewidth
grestore
.125 Mabswid
.14539 0 m
.14539 .00375 L
s
.17072 0 m
.17072 .00375 L
s
.19605 0 m
.19605 .00375 L
s
.22138 0 m
.22138 .00375 L
s
.27204 0 m
.27204 .00375 L
s
.29737 0 m
.29737 .00375 L
s
.3227 0 m
.3227 .00375 L
s
.34802 0 m
.34802 .00375 L
s
.39868 0 m
.39868 .00375 L
s
.42401 0 m
.42401 .00375 L
s
.44934 0 m
.44934 .00375 L
s
.47467 0 m
.47467 .00375 L
s
.52533 0 m
.52533 .00375 L
s
.55066 0 m
.55066 .00375 L
s
.57599 0 m
.57599 .00375 L
s
.60132 0 m
.60132 .00375 L
s
.65198 0 m
.65198 .00375 L
s
.6773 0 m
.6773 .00375 L
s
.70263 0 m
.70263 .00375 L
s
.72796 0 m
.72796 .00375 L
s
.77862 0 m
.77862 .00375 L
s
.80395 0 m
.80395 .00375 L
s
.82928 0 m
.82928 .00375 L
s
.85461 0 m
.85461 .00375 L
s
.09473 0 m
.09473 .00375 L
s
.0694 0 m
.0694 .00375 L
s
.04407 0 m
.04407 .00375 L
s
.01874 0 m
.01874 .00375 L
s
.90527 0 m
.90527 .00375 L
s
.9306 0 m
.9306 .00375 L
s
.95593 0 m
.95593 .00375 L
s
.98126 0 m
.98126 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -112.719 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Frequency) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
127.563 16.625 moveto
(H) show
131.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(MHz) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
158.250 16.625 moveto
(L) show
162.438 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01556 m
.00625 .01556 L
s
gsave
-0.0125 .01556 -91.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.6) show
1.000 setlinewidth
grestore
0 .13027 m
.00625 .13027 L
s
gsave
-0.0125 .13027 -91.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.4) show
1.000 setlinewidth
grestore
0 .24497 m
.00625 .24497 L
s
gsave
-0.0125 .24497 -91.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.2) show
1.000 setlinewidth
grestore
0 .35967 m
.00625 .35967 L
s
gsave
-0.0125 .35967 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
0 .47437 m
.00625 .47437 L
s
gsave
-0.0125 .47437 -91.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
1.000 setlinewidth
grestore
0 .58907 m
.00625 .58907 L
s
gsave
-0.0125 .58907 -91.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04424 m
.00375 .04424 L
s
0 .07291 m
.00375 .07291 L
s
0 .10159 m
.00375 .10159 L
s
0 .15894 m
.00375 .15894 L
s
0 .18762 m
.00375 .18762 L
s
0 .21629 m
.00375 .21629 L
s
0 .27364 m
.00375 .27364 L
s
0 .30232 m
.00375 .30232 L
s
0 .33099 m
.00375 .33099 L
s
0 .38834 m
.00375 .38834 L
s
0 .41702 m
.00375 .41702 L
s
0 .4457 m
.00375 .4457 L
s
0 .50305 m
.00375 .50305 L
s
0 .53172 m
.00375 .53172 L
s
0 .5604 m
.00375 .5604 L
s
0 .61775 m
.00375 .61775 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -156.156 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
117.031 12.1875 translate
90 rotate
-117.031 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Insertion) show
116.063 16.625 moveto
(Loss) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
146.875 16.625 moveto
(H) show
151.063 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dB) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
166.875 16.625 moveto
(L) show
171.063 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.12006 .61178 m
.12006 .61803 L
s
.24671 .61178 m
.24671 .61803 L
s
.37335 .61178 m
.37335 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.62665 .61178 m
.62665 .61803 L
s
.75329 .61178 m
.75329 .61803 L
s
.87994 .61178 m
.87994 .61803 L
s
.125 Mabswid
.14539 .61428 m
.14539 .61803 L
s
.17072 .61428 m
.17072 .61803 L
s
.19605 .61428 m
.19605 .61803 L
s
.22138 .61428 m
.22138 .61803 L
s
.27204 .61428 m
.27204 .61803 L
s
.29737 .61428 m
.29737 .61803 L
s
.3227 .61428 m
.3227 .61803 L
s
.34802 .61428 m
.34802 .61803 L
s
.39868 .61428 m
.39868 .61803 L
s
.42401 .61428 m
.42401 .61803 L
s
.44934 .61428 m
.44934 .61803 L
s
.47467 .61428 m
.47467 .61803 L
s
.52533 .61428 m
.52533 .61803 L
s
.55066 .61428 m
.55066 .61803 L
s
.57599 .61428 m
.57599 .61803 L
s
.60132 .61428 m
.60132 .61803 L
s
.65198 .61428 m
.65198 .61803 L
s
.6773 .61428 m
.6773 .61803 L
s
.70263 .61428 m
.70263 .61803 L
s
.72796 .61428 m
.72796 .61803 L
s
.77862 .61428 m
.77862 .61803 L
s
.80395 .61428 m
.80395 .61803 L
s
.82928 .61428 m
.82928 .61803 L
s
.85461 .61428 m
.85461 .61803 L
s
.09473 .61428 m
.09473 .61803 L
s
.0694 .61428 m
.0694 .61803 L
s
.04407 .61428 m
.04407 .61803 L
s
.01874 .61428 m
.01874 .61803 L
s
.90527 .61428 m
.90527 .61803 L
s
.9306 .61428 m
.9306 .61803 L
s
.95593 .61428 m
.95593 .61803 L
s
.98126 .61428 m
.98126 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01556 m
1 .01556 L
s
.99375 .13027 m
1 .13027 L
s
.99375 .24497 m
1 .24497 L
s
.99375 .35967 m
1 .35967 L
s
.99375 .47437 m
1 .47437 L
s
.99375 .58907 m
1 .58907 L
s
.125 Mabswid
.99625 .04424 m
1 .04424 L
s
.99625 .07291 m
1 .07291 L
s
.99625 .10159 m
1 .10159 L
s
.99625 .15894 m
1 .15894 L
s
.99625 .18762 m
1 .18762 L
s
.99625 .21629 m
1 .21629 L
s
.99625 .27364 m
1 .27364 L
s
.99625 .30232 m
1 .30232 L
s
.99625 .33099 m
1 .33099 L
s
.99625 .38834 m
1 .38834 L
s
.99625 .41702 m
1 .41702 L
s
.99625 .4457 m
1 .4457 L
s
.99625 .50305 m
1 .50305 L
s
.99625 .53172 m
1 .53172 L
s
.99625 .5604 m
1 .5604 L
s
.99625 .61775 m
1 .61775 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.12006 0 m
.12006 .61803 L
s
gsave
.5 .63053 -136.531 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Zero) show
93.188 16.625 moveto
(Delay) show
129.750 16.625 moveto
(Insertion) show
182.813 16.625 moveto
(Loss) show
210.063 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 0 r
.007 w
.02381 .60332 m
.06244 .57486 L
.10458 .5524 L
.12507 .53976 L
.13506 .53376 L
.13979 .53106 L
.14415 .52906 L
.14868 .52749 L
.15103 .52672 L
.15227 .52632 L
.1536 .52592 L
.15477 .52562 L
.15584 .52543 L
.15794 .52517 L
.15907 .52507 L
.1603 .52497 L
.16254 .52479 L
.18221 .52272 L
.22285 .51793 L
.24165 .51503 L
.25154 .51348 L
.25694 .51232 L
.25829 .51212 L
.25958 .51191 L
.26198 .51137 L
.26455 .51062 L
.2673 .50978 L
.27009 .50882 L
.27167 .50805 L
.27313 .50723 L
.28339 .50284 L
.30357 .49095 L
.34283 .4599 L
.38058 .43381 L
.40156 .42264 L
.41074 .4165 L
.4156 .41254 L
.42079 .40845 L
.42342 .40678 L
.4259 .40554 L
.42813 .40468 L
.43055 .40397 L
.43284 .40344 L
.4341 .40319 L
.43527 .403 L
.43627 .40287 L
.43735 .40279 L
.43854 .40278 L
.43963 .40281 L
.44086 .40287 L
Mistroke
.44216 .40296 L
.4445 .40314 L
.44594 .40325 L
.44664 .4033 L
.44729 .40333 L
.4485 .40338 L
.44981 .40339 L
.45097 .40337 L
.45205 .40331 L
.45324 .40312 L
.45451 .40288 L
.45947 .40205 L
.46477 .4009 L
.46967 .39945 L
.48075 .3955 L
.48576 .39387 L
.49114 .39167 L
.49623 .38882 L
.50089 .38576 L
.50524 .38198 L
.51 .37634 L
.51959 .36454 L
.5402 .3387 L
.58082 .2735 L
.61992 .20918 L
.63987 .17613 L
.66147 .14649 L
.6716 .13545 L
.68231 .12632 L
.69234 .11901 L
.7015 .11329 L
.70636 .11108 L
.71096 .10947 L
.71352 .10833 L
.71492 .1078 L
.71623 .10742 L
.71744 .10713 L
.71855 .10692 L
.71978 .10678 L
.72043 .10674 L
.72111 .10671 L
.72216 .10671 L
.72328 .10673 L
.72434 .10679 L
.7253 .10686 L
.72643 .10695 L
.72766 .10704 L
.72882 .10711 L
.72989 .10707 L
.73103 .10694 L
Mistroke
.73209 .10681 L
.73327 .1067 L
.73452 .10667 L
.73584 .10696 L
.73709 .10729 L
.73831 .10761 L
.73944 .10787 L
.74068 .10795 L
.74134 .10796 L
.74203 .10795 L
.7432 .10787 L
.74447 .10771 L
.74561 .10749 L
.74683 .1072 L
.74903 .10655 L
.75155 .10568 L
.75288 .1052 L
.7536 .10495 L
.75429 .10472 L
.75552 .10444 L
.75687 .10417 L
.75801 .10389 L
.75926 .1035 L
.76044 .10283 L
.76168 .10193 L
.76389 .10015 L
.76888 .09658 L
.77765 .09154 L
.81823 .06847 L
.8573 .0474 L
.86755 .04308 L
.87295 .04035 L
.87866 .03745 L
.88366 .03548 L
.88649 .03462 L
.88915 .03397 L
.8904 .03372 L
.89159 .03353 L
.89266 .03339 L
.89381 .03326 L
.89505 .03316 L
.89621 .03312 L
.89691 .03311 L
.89758 .03311 L
.89882 .03311 L
.89998 .0331 L
.90124 .03302 L
.90242 .03286 L
.90349 .0327 L
.90861 .03184 L
Mistroke
.91393 .03061 L
.91895 .02924 L
.93744 .02345 L
.95608 .02056 L
.9584 .02033 L
.96061 .02009 L
.96182 .01993 L
.96315 .01971 L
.96548 .01921 L
.96682 .01881 L
.96825 .01828 L
.97083 .01719 L
.97584 .01486 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{591.375, 365.5},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{57.1875, 529.25}, {481.375, 190}} -> {-59.0091, \
-2.92036, 0.402849, 0.0035584}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Insertion Loss as Function of Delay", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
      "dbmagsmoothall", "\[LeftDoubleBracket]", "1", 
       "\[RightDoubleBracket]"}], "[", "x", "]"}], ",", 
     RowBox[{
      RowBox[{
      "dbmagsmoothall", "\[LeftDoubleBracket]", "2", 
       "\[RightDoubleBracket]"}], "[", "x", "]"}], ",", 
     RowBox[{
      RowBox[{
      "dbmagsmoothall", "\[LeftDoubleBracket]", "3", 
       "\[RightDoubleBracket]"}], "[", "x", "]"}], ",", 
     RowBox[{
      RowBox[{
      "dbmagsmoothall", "\[LeftDoubleBracket]", "4", 
       "\[RightDoubleBracket]"}], "[", "x", "]"}], ",", 
     RowBox[{
      RowBox[{
      "dbmagsmoothall", "\[LeftDoubleBracket]", "5", 
       "\[RightDoubleBracket]"}], "[", "x", "]"}], ",", 
     RowBox[{
      RowBox[{
      "dbmagsmoothall", "\[LeftDoubleBracket]", "6", 
       "\[RightDoubleBracket]"}], "[", "x", "]"}], ",", 
     RowBox[{
      RowBox[{
      "dbmagsmoothall", "\[LeftDoubleBracket]", "7", 
       "\[RightDoubleBracket]"}], "[", "x", "]"}], ",", 
     RowBox[{
      RowBox[{
      "dbmagsmoothall", "\[LeftDoubleBracket]", "8", 
       "\[RightDoubleBracket]"}], "[", "x", "]"}], ",", 
     RowBox[{
      RowBox[{
      "dbmagsmoothall", "\[LeftDoubleBracket]", "9", 
       "\[RightDoubleBracket]"}], "[", "x", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "6", ",", "194"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.9", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.8", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.7", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", "\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.6", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", "\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.5", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", "\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.4", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", "\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.3", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", "\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.2", ",", "0", ",", "0"}], "]"}]}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
   "PlotLabel", "\[Rule]", "\"\<Insertion Loss relative to Zero Delay\>\""}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Frequency (MHz)\>\"", ",", "\"\<Relative Insertion Loss (dB)\>\""}],
      "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"PlotLegend", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<1/16 ns\>\"", ",", "\"\<1/8 ns\>\"", ",", "\"\<1/4 ns\>\"", ",", 
      "\"\<1/2 ns\>\"", ",", "\"\<1 ns\>\"", ",", "\"\<2 ns\>\"", ",", 
      "\"\<4 ns\>\"", ",", "\"\<8 ns\>\"", ",", " ", "\"\<16 ns\>\""}], 
     "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"LegendPosition", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1.05", ",", 
      RowBox[{"-", "0.3"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"LegendShadow", "\[Rule]", "None"}]}], "]"}]], "Input",
 CellChangeTimes->{3.44286814558375*^9}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .53681 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.437415 0.413605 0.268403 0.413605 [
[ 0 0 0 0 ]
[ 1 .53681 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0127811 0.85102 0.524026 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00658566 0.00506586 0.52341 0.248276 [
[.12006 -0.0125 -9.1875 -16.375 ]
[.12006 -0.0125 9.1875 0 ]
[.24671 -0.0125 -9.1875 -16.375 ]
[.24671 -0.0125 9.1875 0 ]
[.37335 -0.0125 -9.1875 -16.375 ]
[.37335 -0.0125 9.1875 0 ]
[.5 -0.0125 -12.7813 -16.375 ]
[.5 -0.0125 12.7813 0 ]
[.62665 -0.0125 -12.7813 -16.375 ]
[.62665 -0.0125 12.7813 0 ]
[.75329 -0.0125 -12.7813 -16.375 ]
[.75329 -0.0125 12.7813 0 ]
[.87994 -0.0125 -12.7813 -16.375 ]
[.87994 -0.0125 12.7813 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -51.7188 -32.75 ]
[.5 -0.0125 51.7188 -16.375 ]
[-0.0125 .02686 -20.1875 -8.1875 ]
[-0.0125 .02686 0 8.1875 ]
[-0.0125 .151 -30.9375 -8.1875 ]
[-0.0125 .151 0 8.1875 ]
[-0.0125 .27513 -20.1875 -8.1875 ]
[-0.0125 .27513 0 8.1875 ]
[-0.0125 .39927 -30.9375 -8.1875 ]
[-0.0125 .39927 0 8.1875 ]
[-0.0125 .52341 -11.1875 -8.1875 ]
[-0.0125 .52341 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -47.3125 -81.125 ]
[-0.01875 .30902 -30.9375 81.125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -105.25 0 ]
[.5 .63053 105.25 16.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.12006 0 m
.12006 .61803 L
s
.24671 0 m
.24671 .61803 L
s
.37335 0 m
.37335 .61803 L
s
.5 0 m
.5 .61803 L
s
.62665 0 m
.62665 .61803 L
s
.75329 0 m
.75329 .61803 L
s
.87994 0 m
.87994 .61803 L
s
0 .151 m
1 .151 L
s
0 .27513 m
1 .27513 L
s
0 .39927 m
1 .39927 L
s
0 .52341 m
1 .52341 L
s
0 g
.12006 0 m
.12006 .00625 L
s
gsave
.12006 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.24671 0 m
.24671 .00625 L
s
gsave
.24671 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.37335 0 m
.37335 .00625 L
s
gsave
.37335 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(75) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.62665 0 m
.62665 .00625 L
s
gsave
.62665 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(125) show
1.000 setlinewidth
grestore
.75329 0 m
.75329 .00625 L
s
gsave
.75329 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.87994 0 m
.87994 .00625 L
s
gsave
.87994 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(175) show
1.000 setlinewidth
grestore
.125 Mabswid
.14539 0 m
.14539 .00375 L
s
.17072 0 m
.17072 .00375 L
s
.19605 0 m
.19605 .00375 L
s
.22138 0 m
.22138 .00375 L
s
.27204 0 m
.27204 .00375 L
s
.29737 0 m
.29737 .00375 L
s
.3227 0 m
.3227 .00375 L
s
.34802 0 m
.34802 .00375 L
s
.39868 0 m
.39868 .00375 L
s
.42401 0 m
.42401 .00375 L
s
.44934 0 m
.44934 .00375 L
s
.47467 0 m
.47467 .00375 L
s
.52533 0 m
.52533 .00375 L
s
.55066 0 m
.55066 .00375 L
s
.57599 0 m
.57599 .00375 L
s
.60132 0 m
.60132 .00375 L
s
.65198 0 m
.65198 .00375 L
s
.6773 0 m
.6773 .00375 L
s
.70263 0 m
.70263 .00375 L
s
.72796 0 m
.72796 .00375 L
s
.77862 0 m
.77862 .00375 L
s
.80395 0 m
.80395 .00375 L
s
.82928 0 m
.82928 .00375 L
s
.85461 0 m
.85461 .00375 L
s
.09473 0 m
.09473 .00375 L
s
.0694 0 m
.0694 .00375 L
s
.04407 0 m
.04407 .00375 L
s
.01874 0 m
.01874 .00375 L
s
.90527 0 m
.90527 .00375 L
s
.9306 0 m
.9306 .00375 L
s
.95593 0 m
.95593 .00375 L
s
.98126 0 m
.98126 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -112.719 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Frequency) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
127.563 16.625 moveto
(H) show
131.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(MHz) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
158.250 16.625 moveto
(L) show
162.438 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02686 m
.00625 .02686 L
s
gsave
-0.0125 .02686 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .151 m
.00625 .151 L
s
gsave
-0.0125 .151 -91.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .27513 m
.00625 .27513 L
s
gsave
-0.0125 .27513 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .39927 m
.00625 .39927 L
s
gsave
-0.0125 .39927 -91.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .52341 m
.00625 .52341 L
s
gsave
-0.0125 .52341 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05169 m
.00375 .05169 L
s
0 .07651 m
.00375 .07651 L
s
0 .10134 m
.00375 .10134 L
s
0 .12617 m
.00375 .12617 L
s
0 .17582 m
.00375 .17582 L
s
0 .20065 m
.00375 .20065 L
s
0 .22548 m
.00375 .22548 L
s
0 .25031 m
.00375 .25031 L
s
0 .29996 m
.00375 .29996 L
s
0 .32479 m
.00375 .32479 L
s
0 .34962 m
.00375 .34962 L
s
0 .37444 m
.00375 .37444 L
s
0 .4241 m
.00375 .4241 L
s
0 .44893 m
.00375 .44893 L
s
0 .47376 m
.00375 .47376 L
s
0 .49858 m
.00375 .49858 L
s
0 .00203 m
.00375 .00203 L
s
0 .54824 m
.00375 .54824 L
s
0 .57307 m
.00375 .57307 L
s
0 .59789 m
.00375 .59789 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -181.25 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
142.125 12.1875 translate
90 rotate
-142.125 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Relative) show
113.188 16.625 moveto
(Insertion) show
166.250 16.625 moveto
(Loss) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
197.063 16.625 moveto
(H) show
201.250 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dB) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
217.063 16.625 moveto
(L) show
221.250 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.12006 .61178 m
.12006 .61803 L
s
.24671 .61178 m
.24671 .61803 L
s
.37335 .61178 m
.37335 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.62665 .61178 m
.62665 .61803 L
s
.75329 .61178 m
.75329 .61803 L
s
.87994 .61178 m
.87994 .61803 L
s
.125 Mabswid
.14539 .61428 m
.14539 .61803 L
s
.17072 .61428 m
.17072 .61803 L
s
.19605 .61428 m
.19605 .61803 L
s
.22138 .61428 m
.22138 .61803 L
s
.27204 .61428 m
.27204 .61803 L
s
.29737 .61428 m
.29737 .61803 L
s
.3227 .61428 m
.3227 .61803 L
s
.34802 .61428 m
.34802 .61803 L
s
.39868 .61428 m
.39868 .61803 L
s
.42401 .61428 m
.42401 .61803 L
s
.44934 .61428 m
.44934 .61803 L
s
.47467 .61428 m
.47467 .61803 L
s
.52533 .61428 m
.52533 .61803 L
s
.55066 .61428 m
.55066 .61803 L
s
.57599 .61428 m
.57599 .61803 L
s
.60132 .61428 m
.60132 .61803 L
s
.65198 .61428 m
.65198 .61803 L
s
.6773 .61428 m
.6773 .61803 L
s
.70263 .61428 m
.70263 .61803 L
s
.72796 .61428 m
.72796 .61803 L
s
.77862 .61428 m
.77862 .61803 L
s
.80395 .61428 m
.80395 .61803 L
s
.82928 .61428 m
.82928 .61803 L
s
.85461 .61428 m
.85461 .61803 L
s
.09473 .61428 m
.09473 .61803 L
s
.0694 .61428 m
.0694 .61803 L
s
.04407 .61428 m
.04407 .61803 L
s
.01874 .61428 m
.01874 .61803 L
s
.90527 .61428 m
.90527 .61803 L
s
.9306 .61428 m
.9306 .61803 L
s
.95593 .61428 m
.95593 .61803 L
s
.98126 .61428 m
.98126 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02686 m
1 .02686 L
s
.99375 .151 m
1 .151 L
s
.99375 .27513 m
1 .27513 L
s
.99375 .39927 m
1 .39927 L
s
.99375 .52341 m
1 .52341 L
s
.125 Mabswid
.99625 .05169 m
1 .05169 L
s
.99625 .07651 m
1 .07651 L
s
.99625 .10134 m
1 .10134 L
s
.99625 .12617 m
1 .12617 L
s
.99625 .17582 m
1 .17582 L
s
.99625 .20065 m
1 .20065 L
s
.99625 .22548 m
1 .22548 L
s
.99625 .25031 m
1 .25031 L
s
.99625 .29996 m
1 .29996 L
s
.99625 .32479 m
1 .32479 L
s
.99625 .34962 m
1 .34962 L
s
.99625 .37444 m
1 .37444 L
s
.99625 .4241 m
1 .4241 L
s
.99625 .44893 m
1 .44893 L
s
.99625 .47376 m
1 .47376 L
s
.99625 .49858 m
1 .49858 L
s
.99625 .00203 m
1 .00203 L
s
.99625 .54824 m
1 .54824 L
s
.99625 .57307 m
1 .57307 L
s
.99625 .59789 m
1 .59789 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .52341 m
1 .52341 L
s
.12006 0 m
.12006 .61803 L
s
gsave
.5 .63053 -166.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Insertion) show
116.063 16.625 moveto
(Loss) show
146.875 16.625 moveto
(relative) show
192.000 16.625 moveto
(to) show
206.313 16.625 moveto
(Zero) show
236.500 16.625 moveto
(Delay) show
269.500 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 0 r
.007 w
.02381 .52341 m
.02499 .52334 L
.02605 .52328 L
.02729 .52324 L
.02846 .52322 L
.02954 .52325 L
.03053 .52331 L
.03162 .52337 L
.03279 .52343 L
.03396 .52345 L
.03506 .52337 L
.03756 .52315 L
.03821 .52309 L
.03891 .52304 L
.0402 .52303 L
.04145 .52305 L
.04262 .52309 L
.04752 .52335 L
.0501 .5235 L
.05151 .52357 L
.05283 .52362 L
.05398 .52366 L
.05521 .52366 L
.05592 .52365 L
.05659 .52365 L
.05784 .52364 L
.05898 .52364 L
.06004 .52368 L
.0612 .52373 L
.06244 .52377 L
.06372 .52381 L
.06491 .52378 L
.0656 .52375 L
.06633 .52372 L
.06763 .52365 L
.06829 .52361 L
.06899 .52358 L
.07026 .52358 L
.07104 .52359 L
.07177 .52359 L
.07242 .5236 L
.07314 .5236 L
.07432 .52359 L
.07556 .52354 L
.07779 .52341 L
.08038 .52324 L
.08284 .52309 L
.08349 .52305 L
.08419 .52302 L
.08496 .52301 L
Mistroke
.08567 .52301 L
.08637 .52301 L
.08703 .52302 L
.08825 .52304 L
.08896 .52306 L
.08971 .52308 L
.09105 .52313 L
.09407 .52325 L
.09473 .52326 L
.09543 .52326 L
.09619 .52327 L
.0969 .52327 L
.09817 .52328 L
.09889 .52329 L
.09957 .52331 L
.10083 .52338 L
.10198 .52346 L
.10333 .52355 L
.10458 .52363 L
.10565 .52369 L
.10679 .52373 L
.10806 .52377 L
.10921 .5238 L
.11042 .52381 L
.11172 .5238 L
.11295 .52378 L
.11408 .52376 L
.11642 .52365 L
.11771 .52358 L
.11893 .52352 L
.11962 .52349 L
.12037 .52347 L
.12168 .52345 L
.12426 .52341 L
.12649 .52335 L
.12758 .52332 L
.12858 .5233 L
.12963 .52328 L
.13076 .52328 L
.13194 .52329 L
.13317 .52332 L
.13439 .52336 L
.13551 .52344 L
.13807 .52367 L
.14027 .52387 L
.1426 .52403 L
.14385 .5241 L
.14451 .52414 L
.14522 .52416 L
.14647 .5242 L
Mistroke
.14764 .52423 L
.15311 .52441 L
.15577 .52451 L
.15708 .52456 L
.15829 .52459 L
.15939 .52459 L
.16056 .52453 L
.16186 .52441 L
.16304 .52428 L
.16527 .52402 L
.16763 .52382 L
.16887 .52372 L
.16952 .52368 L
.17022 .52365 L
.17146 .5236 L
.17261 .52357 L
.17698 .52353 L
.17804 .52352 L
.17918 .5235 L
.18044 .52346 L
.18162 .52339 L
.18296 .52331 L
.1837 .52327 L
.18438 .52324 L
.18559 .5232 L
.18691 .5232 L
.18815 .52321 L
.18927 .52324 L
.19057 .5233 L
.1918 .52337 L
.19314 .52345 L
.19388 .52349 L
.19457 .52352 L
.19578 .52354 L
.19642 .52355 L
.19711 .52354 L
.19785 .52353 L
.19866 .5235 L
.19942 .52347 L
.20012 .52344 L
.20082 .52338 L
.20146 .52332 L
.20287 .52318 L
.20414 .52307 L
.20477 .52302 L
.20547 .52299 L
.20671 .52299 L
.20786 .52301 L
.20856 .52303 L
.20922 .52306 L
Mistroke
.21046 .5231 L
.21181 .52315 L
.21324 .5232 L
.2144 .52323 L
.21568 .52325 L
.21683 .52325 L
.21792 .52324 L
.2192 .52323 L
.22037 .52323 L
.22101 .52324 L
.22171 .52325 L
.223 .52328 L
.22786 .52354 L
.22918 .52363 L
.23042 .52371 L
.23171 .52375 L
.23239 .52377 L
.23312 .52378 L
.23376 .52378 L
.23446 .52379 L
.23572 .52377 L
.23695 .52374 L
.23809 .5237 L
.23923 .52367 L
.24031 .52364 L
.24143 .52364 L
.24266 .52366 L
.24336 .52367 L
.24401 .52368 L
.24468 .52368 L
.24542 .52368 L
.24664 .52361 L
.24795 .52352 L
.24869 .52348 L
.24949 .52343 L
.25024 .5234 L
.25094 .5234 L
.25226 .52347 L
.25366 .52355 L
.25484 .52361 L
.25611 .52361 L
.25731 .52355 L
.25841 .52348 L
.25969 .52341 L
.26041 .52337 L
.26109 .52337 L
.26232 .5234 L
.26363 .52346 L
.26488 .52351 L
.26559 .52354 L
Mistroke
.26623 .52353 L
.26747 .52352 L
.26864 .52351 L
.26985 .52351 L
.27117 .52357 L
.27187 .52364 L
.27261 .52372 L
.27394 .52386 L
.27462 .52392 L
.27536 .52398 L
.27606 .524 L
.2767 .52397 L
.27741 .52393 L
.27818 .52388 L
.27974 .52376 L
.28043 .52371 L
.28108 .52367 L
.28182 .52366 L
.2825 .52364 L
.28507 .52361 L
.28752 .52353 L
.28887 .52347 L
.29014 .52343 L
.29133 .5234 L
.29262 .52339 L
.29379 .52339 L
.29488 .52339 L
.29602 .5234 L
.29728 .5234 L
.29982 .52339 L
.30265 .52337 L
.30389 .52337 L
.3046 .52337 L
.30525 .52336 L
.30642 .52336 L
.30767 .52335 L
.30836 .52335 L
.30901 .52335 L
.31022 .52337 L
.31087 .52338 L
.31156 .52342 L
.31279 .52351 L
.31414 .52361 L
.31488 .52366 L
.31559 .5237 L
.31683 .52371 L
.31797 .52367 L
.31904 .52362 L
.32021 .52355 L
.3253 .52324 L
Mistroke
.32644 .52317 L
.32768 .5231 L
.32885 .52305 L
.32993 .52302 L
.33119 .52301 L
.33183 .52305 L
.33252 .5231 L
.33375 .5232 L
.33487 .52329 L
.33601 .52336 L
.33709 .52333 L
.33823 .52326 L
.33947 .52317 L
.34055 .5231 L
.3417 .52308 L
.34268 .52311 L
.34376 .52317 L
.3449 .52323 L
.34611 .5233 L
.34681 .5233 L
.34744 .5233 L
.34868 .52329 L
.34996 .52327 L
.35068 .52327 L
.35134 .52327 L
.35256 .52335 L
.35386 .52344 L
.35495 .52351 L
.35613 .52356 L
.35725 .5235 L
.35826 .52342 L
.35947 .5233 L
.36061 .5232 L
.36192 .52312 L
.36311 .52312 L
.36439 .52313 L
.36511 .52315 L
.36577 .52316 L
.36697 .52315 L
.36823 .52312 L
.3689 .5231 L
.36961 .52309 L
.37089 .52307 L
.37168 .52308 L
.37242 .52313 L
.37381 .52324 L
.37504 .52334 L
.37634 .52342 L
.37746 .52341 L
.37868 .52336 L
Mistroke
.38 .5233 L
.38072 .52327 L
.38141 .52324 L
.38205 .52326 L
.38275 .52329 L
.38397 .52335 L
.38521 .52342 L
.38652 .52347 L
.3872 .52346 L
.38795 .52344 L
.38927 .52338 L
.39051 .52332 L
.39169 .52326 L
.39234 .52324 L
.39304 .52322 L
.39428 .52319 L
.39679 .52314 L
.39789 .52312 L
.39911 .52309 L
.40016 .52307 L
.4013 .52305 L
.4025 .52304 L
.40362 .52305 L
.40494 .52306 L
.40617 .52309 L
.40687 .52312 L
.40751 .52315 L
.40895 .52324 L
.41456 .52353 L
.41943 .52381 L
.42061 .52388 L
.42189 .52394 L
.42262 .52395 L
.42328 .52394 L
.42459 .52392 L
.42586 .52387 L
.42704 .52381 L
.42833 .52371 L
.4297 .5236 L
.43102 .5235 L
.43225 .52343 L
.43336 .52341 L
.43456 .5234 L
.43567 .52341 L
.43689 .52342 L
.43816 .52342 L
.43935 .52343 L
.44046 .52343 L
.44148 .52342 L
.44265 .52341 L
Mistroke
.44376 .52338 L
.44859 .52322 L
.44976 .52318 L
.45103 .52314 L
.45175 .52313 L
.45242 .52313 L
.45372 .52317 L
.45503 .5232 L
.45577 .52322 L
.45646 .52322 L
.45719 .52321 L
.45786 .52315 L
.45935 .52299 L
.46054 .52284 L
.46182 .52269 L
.46256 .52263 L
.46323 .52259 L
.46455 .52254 L
.4694 .52232 L
.4706 .52224 L
.47186 .52217 L
.47259 .52215 L
.47325 .52214 L
.47454 .52214 L
.47571 .52214 L
.47698 .52216 L
.47817 .52216 L
.47927 .52216 L
.48031 .52215 L
.48145 .52214 L
.48264 .52211 L
.48375 .52205 L
.48624 .52192 L
.4875 .52186 L
.48821 .52185 L
.48888 .52184 L
.49177 .5218 L
.49314 .52179 L
.49445 .52177 L
.49566 .52174 L
.49635 .52171 L
.49699 .52168 L
.49812 .52159 L
.49932 .52146 L
.50064 .5213 L
.50137 .52122 L
.50205 .52114 L
.50324 .52105 L
.50456 .52099 L
.50584 .52096 L
Mistroke
.50655 .52096 L
.50721 .52096 L
.50791 .52099 L
.50868 .52104 L
.51007 .52114 L
.51138 .52123 L
.51209 .52128 L
.51277 .52131 L
.51395 .52131 L
.51526 .52128 L
.51645 .52124 L
.5177 .52118 L
.51877 .5211 L
.51993 .52101 L
.5212 .52092 L
.52189 .52088 L
.52254 .52084 L
.52382 .52084 L
.52497 .52086 L
.52604 .52089 L
.52722 .52093 L
.52837 .52096 L
.52961 .52099 L
.53076 .52101 L
.53182 .52101 L
.53288 .521 L
.53388 .52096 L
.5365 .52082 L
.53895 .52068 L
.54116 .52057 L
.5424 .52053 L
.54355 .52051 L
.5447 .5205 L
.54578 .52051 L
.54696 .52053 L
.54822 .52056 L
.55059 .52067 L
.55123 .5207 L
.55192 .52072 L
.55316 .52074 L
.55446 .5207 L
.55591 .52063 L
.55716 .52057 L
.55782 .52054 L
.55851 .52051 L
.55982 .52048 L
.56103 .52047 L
.56216 .52047 L
.56339 .52051 L
.56793 .52086 L
Mistroke
.57033 .5211 L
.57153 .5212 L
.57222 .52124 L
.57286 .52127 L
.57403 .52124 L
.5751 .52116 L
.57625 .52107 L
.57751 .52098 L
.57865 .52093 L
.5797 .52095 L
.58071 .52097 L
.58179 .52101 L
.583 .52105 L
.58431 .52107 L
.58554 .52108 L
.58668 .52108 L
.58794 .52106 L
.58865 .52103 L
.58931 .52099 L
.59209 .52076 L
.59439 .52052 L
.59689 .52024 L
.59804 .52012 L
.59925 .52003 L
.60029 .51997 L
.60143 .51992 L
.60275 .51989 L
.60349 .51989 L
.60417 .51991 L
.60549 .51995 L
.60674 .52001 L
.61156 .52027 L
.61407 .52039 L
.61547 .52044 L
.61674 .52048 L
.61747 .5205 L
.61825 .52051 L
.61899 .52051 L
.61967 .5205 L
.6203 .5205 L
.621 .52049 L
.62239 .52047 L
.6237 .52046 L
.62492 .52049 L
.62619 .52052 L
.62687 .52053 L
.6276 .52053 L
.62835 .52053 L
.62913 .52049 L
.62981 .52044 L
Mistroke
.63054 .52039 L
.63197 .52026 L
.63326 .52015 L
.6339 .5201 L
.63459 .52007 L
.63584 .52001 L
.63859 .51991 L
.64355 .51969 L
.64477 .51962 L
.64607 .51954 L
.6473 .51949 L
.64843 .51946 L
.64969 .5195 L
.65088 .51957 L
.65359 .51976 L
.6547 .51983 L
.65588 .51988 L
.657 .51992 L
.65801 .51995 L
.65921 .51994 L
.6605 .51989 L
.66283 .51977 L
.66401 .51972 L
.66527 .51967 L
.66646 .51964 L
.66755 .51964 L
.66882 .51965 L
.66954 .5197 L
.6702 .51976 L
.67149 .51988 L
.67271 .51999 L
.67387 .52007 L
.67511 .52007 L
.67582 .52006 L
.6765 .52004 L
.67776 .51999 L
.6791 .51994 L
.68036 .5199 L
.68105 .51988 L
.68181 .51987 L
.68312 .51985 L
.68429 .51986 L
.68553 .51991 L
.68667 .51997 L
.68774 .52002 L
.68873 .52006 L
.68979 .52008 L
.69096 .52007 L
.69203 .52005 L
.69319 .52003 L
Mistroke
.69442 .52002 L
.69506 .52001 L
.69577 .52001 L
.69702 .52002 L
.6982 .52003 L
.69947 .52007 L
.70066 .52015 L
.70176 .52022 L
.70303 .52029 L
.70424 .52032 L
.70532 .52027 L
.70649 .52019 L
.70895 .51999 L
.71019 .51992 L
.71155 .51985 L
.71273 .51981 L
.714 .51976 L
.7152 .51975 L
.71629 .51973 L
.71737 .51971 L
.71854 .51968 L
.71964 .51961 L
.72067 .5195 L
.72315 .51919 L
.72583 .51883 L
.72706 .51869 L
.72836 .51857 L
.72947 .51852 L
.73069 .5186 L
.73209 .51873 L
.73286 .5188 L
.73359 .51888 L
.73427 .51894 L
.735 .51896 L
.73629 .51895 L
.73757 .51893 L
.73827 .51892 L
.73893 .51891 L
.74009 .51892 L
.74137 .51895 L
.74254 .519 L
.7438 .51909 L
.74499 .51923 L
.74607 .51942 L
.74737 .51966 L
.74875 .51991 L
.74992 .52009 L
.75121 .52022 L
.75185 .52026 L
.75254 .5203 L
Mistroke
.75377 .52033 L
.75452 .52033 L
.75522 .52027 L
.75655 .52013 L
.75771 .51999 L
.75895 .51985 L
.7596 .51979 L
.76031 .51979 L
.76157 .51982 L
.78009 .52042 L
.78263 .5206 L
.78386 .52068 L
.78499 .52074 L
.78618 .52078 L
.78745 .52081 L
.78812 .52083 L
.78884 .52083 L
.79016 .52084 L
.79127 .52084 L
.79249 .52082 L
.79377 .52081 L
.79496 .52078 L
.79599 .52077 L
.79708 .52076 L
.79828 .52073 L
.7994 .52069 L
.80012 .52065 L
.80081 .52059 L
.80209 .52046 L
.80342 .52034 L
.80464 .52024 L
.80576 .52023 L
.80695 .52027 L
.80814 .52032 L
.80944 .52039 L
.81016 .52042 L
.81085 .52043 L
.81214 .52045 L
.81286 .52045 L
.81352 .52046 L
.81503 .52046 L
.81633 .52047 L
.81756 .52047 L
.81883 .52049 L
.81951 .5205 L
.82024 .52052 L
.8215 .52057 L
.82264 .52063 L
.8252 .52079 L
.8276 .52099 L
Mistroke
.82865 .52107 L
.82981 .52114 L
.83107 .52115 L
.83176 .52115 L
.8324 .52114 L
.83309 .52112 L
.83375 .52112 L
.83451 .52111 L
.8352 .52111 L
.83646 .52119 L
.83763 .52128 L
.83901 .5214 L
.84028 .52151 L
.84093 .52154 L
.84161 .52157 L
.84305 .52163 L
.84565 .52173 L
.8505 .52198 L
.85343 .52219 L
.8562 .52239 L
.85741 .52247 L
.85868 .52254 L
.85935 .52257 L
.86009 .52259 L
.86138 .52259 L
.86262 .52257 L
.86375 .52254 L
.86499 .5225 L
.86629 .5225 L
.86743 .52252 L
.86849 .52254 L
.86965 .52256 L
.87089 .52257 L
.87221 .52255 L
.87363 .52252 L
.87429 .52251 L
.87498 .5225 L
.87622 .5225 L
.87742 .52252 L
.87853 .52253 L
.88106 .52259 L
.88985 .52282 L
.89448 .523 L
.89561 .52304 L
.89682 .52307 L
.89816 .5231 L
.89941 .52312 L
.90007 .52313 L
.90079 .52313 L
.90154 .52313 L
Mistroke
.90224 .52312 L
.90294 .52312 L
.9036 .52311 L
.90483 .52311 L
.90599 .52311 L
.90725 .52315 L
.90985 .52324 L
.91235 .52333 L
.91361 .52336 L
.91432 .52338 L
.91499 .52339 L
.91619 .5234 L
.91728 .52338 L
.91854 .52335 L
.91974 .52331 L
.92197 .52322 L
.92319 .52318 L
.92434 .52314 L
.92542 .52311 L
.92658 .52309 L
.92764 .5231 L
.92861 .52311 L
.93328 .52316 L
.93393 .52316 L
.93463 .52317 L
.9359 .52318 L
.93714 .52321 L
.93829 .52325 L
.93933 .52327 L
.94045 .52329 L
.94167 .52329 L
.94283 .52326 L
.94517 .52317 L
.94645 .52312 L
.94764 .52308 L
.94869 .52305 L
.94981 .52303 L
.95106 .52304 L
.95219 .52311 L
.95422 .52328 L
.95533 .52336 L
.95636 .52341 L
.95758 .52337 L
.95822 .52334 L
.95891 .5233 L
.96126 .52314 L
.96268 .52306 L
.96403 .52299 L
.96524 .52294 L
.96657 .52291 L
Mistroke
.96784 .52291 L
.96899 .52293 L
.96962 .52295 L
.97031 .52297 L
.97156 .52305 L
.97274 .52317 L
.97397 .52329 L
.97503 .52338 L
.97619 .52343 L
Mfstroke
.9 0 0 r
.02381 .52248 m
.02846 .52239 L
.03068 .52235 L
.03178 .52233 L
.03279 .52232 L
.03398 .52231 L
.03527 .52233 L
.03637 .52235 L
.03754 .52237 L
.04262 .52249 L
.04496 .52257 L
.0462 .52262 L
.04751 .52267 L
.04878 .52271 L
.04993 .52271 L
.05108 .52271 L
.05217 .5227 L
.05282 .52269 L
.05351 .52269 L
.05475 .5227 L
.05543 .52271 L
.05608 .52273 L
.05754 .52276 L
.05875 .52278 L
.0599 .5228 L
.06054 .52281 L
.06123 .52281 L
.06244 .52281 L
.06368 .5228 L
.06439 .52278 L
.06505 .52276 L
.06782 .52262 L
.07042 .52249 L
.0728 .52239 L
.07507 .52232 L
.07746 .52226 L
.0801 .52218 L
.0825 .52209 L
.08315 .52207 L
.08385 .52205 L
.08514 .52203 L
.08585 .52203 L
.08661 .52202 L
.08725 .52203 L
.08796 .52203 L
.08923 .52204 L
.08992 .52204 L
.09059 .52204 L
.09187 .52205 L
.09304 .52207 L
Mistroke
.09443 .52208 L
.09519 .52209 L
.09591 .52209 L
.09658 .5221 L
.0973 .52211 L
.09856 .52215 L
.09929 .52217 L
.10009 .52222 L
.1017 .52233 L
.1032 .52244 L
.10385 .52248 L
.10458 .52252 L
.1058 .52255 L
.1071 .52256 L
.10778 .52256 L
.10851 .52257 L
.10915 .52257 L
.10984 .52257 L
.1111 .52259 L
.11179 .52259 L
.11243 .5226 L
.11358 .52263 L
.11481 .52267 L
.11602 .52274 L
.11733 .52282 L
.11856 .52288 L
.1197 .52292 L
.12072 .52289 L
.12185 .52285 L
.12294 .52281 L
.12413 .52278 L
.12486 .52278 L
.12553 .5228 L
.12686 .52286 L
.12814 .52292 L
.12935 .52296 L
.13064 .52295 L
.13132 .52293 L
.13206 .52291 L
.13279 .5229 L
.13357 .52288 L
.13423 .52287 L
.13495 .52288 L
.1373 .52299 L
.13859 .52305 L
.1398 .5231 L
.1411 .52309 L
.14179 .52308 L
.14253 .52306 L
.14506 .523 L
Mistroke
.15033 .52289 L
.15531 .52276 L
.16464 .5225 L
.17551 .52226 L
.17823 .52216 L
.18079 .52206 L
.1831 .52198 L
.18439 .52195 L
.18558 .52194 L
.18672 .52195 L
.18797 .52196 L
.18928 .52197 L
.19048 .52198 L
.19178 .52197 L
.1925 .52197 L
.19318 .52196 L
.19439 .52194 L
.1957 .52191 L
.20673 .52167 L
.2118 .52147 L
.21303 .52142 L
.21367 .52139 L
.21435 .52137 L
.21511 .52136 L
.21581 .52138 L
.21646 .52141 L
.21717 .52144 L
.21842 .52151 L
.21959 .52159 L
.22024 .52162 L
.22095 .52164 L
.22218 .52166 L
.22683 .52175 L
.22795 .52178 L
.22917 .52182 L
.23025 .52185 L
.2314 .52187 L
.2321 .52188 L
.23273 .52189 L
.23396 .52189 L
.23517 .52189 L
.2363 .52189 L
.23696 .52188 L
.23765 .52188 L
.23889 .52186 L
.23954 .52185 L
.24023 .52184 L
.24098 .52181 L
.24169 .52179 L
.24304 .52174 L
Mistroke
.24432 .52169 L
.24547 .52167 L
.24672 .52167 L
.24802 .5217 L
.24925 .52172 L
.24993 .52173 L
.25059 .52175 L
.25134 .52175 L
.25203 .52175 L
.25271 .52176 L
.25343 .52176 L
.25472 .52175 L
.25552 .52175 L
.25626 .52174 L
.25766 .52173 L
.26252 .52167 L
.26385 .52165 L
.26457 .52164 L
.26525 .52162 L
.26645 .52158 L
.26777 .52153 L
.26903 .52148 L
.26972 .52146 L
.27037 .52144 L
.27151 .52144 L
.27277 .52147 L
.27405 .5215 L
.27474 .52152 L
.27539 .52152 L
.27609 .52151 L
.27686 .52148 L
.27821 .52142 L
.2795 .52135 L
.28072 .52129 L
.28181 .52127 L
.283 .52126 L
.28429 .52127 L
.28494 .52127 L
.28566 .52129 L
.28692 .52137 L
.28811 .52145 L
.28926 .52152 L
.29051 .52159 L
.29169 .52159 L
.29278 .52155 L
.29384 .52151 L
.29498 .52146 L
.29606 .52142 L
.29705 .52143 L
.29824 .52145 L
Mistroke
.2995 .52148 L
.30171 .52155 L
.30666 .52174 L
.30789 .52179 L
.30853 .52182 L
.30922 .52184 L
.31047 .52187 L
.31163 .52186 L
.31275 .52182 L
.31379 .52178 L
.31492 .52172 L
.31616 .52167 L
.31741 .52166 L
.31872 .52165 L
.31994 .52164 L
.32106 .52162 L
.32238 .52159 L
.32379 .52154 L
.3251 .52148 L
.32633 .52141 L
.32856 .52119 L
.32978 .52108 L
.33092 .521 L
.33189 .52101 L
.33293 .52106 L
.33408 .52111 L
.33514 .52116 L
.33636 .52118 L
.33701 .52113 L
.3377 .52107 L
.33895 .52095 L
.34012 .52084 L
.34116 .52075 L
.34229 .52072 L
.34353 .52072 L
.34468 .52073 L
.34584 .52074 L
.34711 .52073 L
.3483 .5207 L
.3494 .52068 L
.35069 .52067 L
.35134 .52066 L
.35205 .5207 L
.35331 .52077 L
.35446 .52082 L
.35562 .52084 L
.35672 .52078 L
.35789 .5206 L
.35916 .52037 L
.36027 .52017 L
Mistroke
.36145 .51999 L
.36256 .51997 L
.36357 .51998 L
.36486 .52002 L
.36557 .52005 L
.36623 .52007 L
.3674 .52009 L
.36869 .52009 L
.3694 .52008 L
.37008 .52007 L
.37136 .52004 L
.37207 .52001 L
.37273 .51997 L
.37422 .51988 L
.37905 .51947 L
.38037 .51935 L
.38109 .51929 L
.38177 .51925 L
.38296 .51921 L
.38426 .51918 L
.38551 .51916 L
.3867 .51913 L
.38776 .51907 L
.38891 .51901 L
.39133 .51888 L
.39265 .5188 L
.39389 .51874 L
.39506 .5187 L
.39613 .51866 L
.39731 .51865 L
.39859 .51867 L
.39965 .51869 L
.40081 .51873 L
.40293 .51884 L
.4085 .51924 L
.41374 .5196 L
.41845 .51982 L
.41974 .51989 L
.42044 .51992 L
.4211 .51994 L
.42226 .51996 L
.42353 .51994 L
.42476 .51988 L
.42545 .51983 L
.42609 .51978 L
.42727 .51965 L
.42851 .51944 L
.4307 .51906 L
.43193 .51887 L
.43305 .5188 L
Mistroke
.43434 .51874 L
.43556 .51871 L
.4379 .51867 L
.43923 .51864 L
.44046 .51861 L
.44115 .51859 L
.44181 .51856 L
.44256 .51853 L
.44325 .51849 L
.45345 .51799 L
.46423 .51745 L
.46885 .51719 L
.47006 .51709 L
.4707 .51704 L
.47139 .517 L
.47264 .51694 L
.47379 .51694 L
.47449 .51694 L
.47514 .51695 L
.47592 .51697 L
.47663 .51698 L
.47788 .51699 L
.47853 .51699 L
.47922 .51699 L
.48048 .51699 L
.48164 .51699 L
.48292 .51702 L
.48364 .51705 L
.48429 .51708 L
.48544 .51713 L
.48666 .51717 L
.4877 .51719 L
.48885 .51716 L
.49008 .51712 L
.4914 .51707 L
.49379 .51699 L
.49494 .51696 L
.49619 .51692 L
.49738 .51687 L
.49848 .5168 L
.50276 .51651 L
.50394 .51649 L
.50505 .51649 L
.50633 .5165 L
.5075 .5165 L
.5086 .51648 L
.50961 .51645 L
.51073 .51642 L
.51191 .51637 L
.51304 .5163 L
Mistroke
.51411 .51623 L
.51652 .51605 L
.52158 .51579 L
.52668 .5155 L
.53217 .51512 L
.53683 .5146 L
.5381 .51447 L
.53947 .51437 L
.54075 .5143 L
.54192 .51425 L
.54262 .51424 L
.54326 .51424 L
.54397 .51425 L
.54472 .51428 L
.546 .51433 L
.54737 .51438 L
.54811 .5144 L
.54878 .51441 L
.5501 .51441 L
.55084 .5144 L
.55164 .51438 L
.5524 .51436 L
.5531 .51433 L
.55375 .51429 L
.55445 .51423 L
.55571 .51413 L
.55684 .51405 L
.55807 .51398 L
.55876 .51396 L
.55941 .51395 L
.56009 .51395 L
.56082 .51396 L
.5615 .51398 L
.56215 .514 L
.56335 .51407 L
.57314 .51445 L
.57573 .51458 L
.57715 .51467 L
.57785 .51471 L
.57851 .51475 L
.57976 .51479 L
.58113 .51484 L
.58353 .51492 L
.58467 .51497 L
.5859 .51503 L
.58706 .51506 L
.58813 .51507 L
.58938 .51502 L
.5907 .51494 L
.59303 .51476 L
Mistroke
.59844 .51445 L
.60109 .51425 L
.60224 .51416 L
.6035 .51409 L
.60463 .51406 L
.60568 .51404 L
.60674 .51402 L
.60774 .514 L
.60879 .51397 L
.60994 .51392 L
.61229 .51381 L
.61455 .51371 L
.61693 .51363 L
.61818 .5136 L
.61888 .51359 L
.61954 .51358 L
.6207 .51358 L
.62194 .51358 L
.62258 .51359 L
.62327 .51359 L
.62452 .51359 L
.62583 .51359 L
.62658 .51359 L
.62726 .51358 L
.62847 .51357 L
.62978 .51355 L
.63102 .51352 L
.63218 .5135 L
.63288 .51349 L
.63364 .51349 L
.63433 .51351 L
.63497 .51352 L
.63638 .51356 L
.63713 .51358 L
.63794 .5136 L
.63864 .51362 L
.63928 .51362 L
.64054 .51361 L
.64121 .5136 L
.64195 .51358 L
.64264 .51355 L
.64328 .51352 L
.64571 .5133 L
.64698 .51317 L
.64768 .5131 L
.64832 .51305 L
.64951 .51299 L
.65079 .51298 L
.65189 .51299 L
.65306 .51302 L
Mistroke
.6537 .51304 L
.65439 .51308 L
.65564 .51317 L
.65676 .51324 L
.65799 .51331 L
.6587 .51334 L
.65937 .51332 L
.66007 .5133 L
.66082 .51326 L
.66206 .5132 L
.66272 .51316 L
.66343 .51313 L
.66475 .51313 L
.66599 .51316 L
.66668 .51319 L
.6674 .51322 L
.6687 .51328 L
.67106 .51341 L
.67236 .51347 L
.67358 .51352 L
.67427 .51352 L
.67502 .51351 L
.67632 .51347 L
.67764 .51342 L
.67886 .51337 L
.6803 .5133 L
.68185 .51324 L
.6826 .51321 L
.68331 .51319 L
.68394 .51317 L
.68464 .51317 L
.68581 .51319 L
.68705 .51321 L
.68813 .51323 L
.68929 .51324 L
.69001 .51323 L
.69067 .51322 L
.69197 .5132 L
.69316 .51319 L
.69441 .51321 L
.69564 .51328 L
.69696 .51337 L
.69934 .51359 L
.70197 .51391 L
.70329 .51404 L
.70405 .5141 L
.70475 .5141 L
.7054 .51409 L
.70608 .51406 L
.7073 .51401 L
Mistroke
.70861 .51394 L
.70935 .51392 L
.71004 .51394 L
.71256 .51402 L
.7138 .51406 L
.71494 .51408 L
.71559 .51408 L
.71628 .51408 L
.71698 .51407 L
.71774 .51406 L
.71906 .51402 L
.72029 .51398 L
.72173 .5139 L
.72305 .51381 L
.72377 .51375 L
.72456 .51367 L
.72601 .51346 L
.72737 .51327 L
.72866 .51312 L
.72982 .51308 L
.73107 .51314 L
.73172 .51319 L
.73243 .51324 L
.73313 .5133 L
.73387 .51335 L
.73457 .51338 L
.73521 .51336 L
.73645 .5133 L
.73761 .51325 L
.73884 .5132 L
.73948 .51319 L
.74018 .51323 L
.74143 .51333 L
.74385 .51359 L
.74613 .51384 L
.75109 .51442 L
.75245 .51456 L
.75319 .51462 L
.75389 .51468 L
.75455 .51472 L
.75526 .51471 L
.7565 .51468 L
.75779 .51463 L
.759 .5146 L
.76026 .51464 L
.76092 .5147 L
.76164 .51477 L
.76291 .51489 L
.76411 .515 L
.76519 .51504 L
Mistroke
.76636 .51502 L
.76752 .51498 L
.76877 .51493 L
.76995 .51489 L
.77103 .51489 L
.77217 .5149 L
.77338 .5149 L
.77462 .51491 L
.77533 .51488 L
.77598 .51485 L
.77714 .5148 L
.77824 .51477 L
.77922 .51476 L
.78029 .51483 L
.78145 .51499 L
.78268 .51518 L
.78382 .51535 L
.78489 .5155 L
.78609 .51556 L
.78741 .5156 L
.78857 .51562 L
.78981 .51563 L
.79103 .51569 L
.79217 .51573 L
.79431 .51581 L
.79496 .51583 L
.79564 .51583 L
.79688 .51582 L
.79818 .51581 L
.79892 .51581 L
.79959 .51582 L
.80079 .5159 L
.80209 .51601 L
.80445 .51626 L
.80872 .51658 L
.81105 .51676 L
.81325 .51697 L
.8156 .51726 L
.81819 .51771 L
.82276 .5186 L
.82394 .51882 L
.82519 .51902 L
.82638 .51915 L
.82746 .51924 L
.82873 .51933 L
.82945 .51937 L
.83011 .51939 L
.83132 .51942 L
.8326 .51943 L
.83384 .51944 L
Mistroke
.83516 .51945 L
.8364 .51954 L
.83754 .51962 L
.83887 .51971 L
.83963 .51975 L
.84032 .51976 L
.8416 .5197 L
.84225 .51966 L
.84297 .5196 L
.8452 .5194 L
.84755 .51919 L
.84879 .51911 L
.84949 .51908 L
.85014 .51906 L
.85128 .5191 L
.85251 .51919 L
.86148 .51972 L
.8717 .52025 L
.87708 .52078 L
.87839 .52088 L
.87979 .52097 L
.8806 .52101 L
.88134 .521 L
.88208 .52099 L
.88279 .52098 L
.88404 .52095 L
.88475 .52094 L
.88538 .52094 L
.88662 .52104 L
.88779 .52116 L
.88907 .52129 L
.88977 .52135 L
.89042 .52139 L
.89112 .52138 L
.8919 .52133 L
.89326 .52121 L
.89441 .52109 L
.89565 .52097 L
.89683 .52092 L
.89792 .5209 L
.89919 .52088 L
.89983 .52087 L
.90054 .52086 L
.90177 .52085 L
.90293 .52083 L
.9041 .52081 L
.90536 .52079 L
.90762 .52073 L
.90901 .52068 L
.91031 .52062 L
Mistroke
.91149 .52053 L
.91276 .52041 L
.91411 .52029 L
.91538 .52021 L
.91669 .52024 L
.91739 .52029 L
.91815 .52035 L
.91948 .52048 L
.92074 .5206 L
.92187 .52064 L
.92311 .52066 L
.92437 .52065 L
.92555 .52063 L
.92661 .52057 L
.92776 .52049 L
.92902 .52042 L
.92965 .52039 L
.93034 .52037 L
.93157 .52044 L
.93271 .5206 L
.93492 .52095 L
.93601 .52111 L
.93701 .5212 L
.93817 .52126 L
.93942 .5213 L
.94049 .52131 L
.94162 .52128 L
.97619 .52033 L
Mfstroke
.8 0 0 r
.02381 .52285 m
.03279 .52261 L
.04262 .52242 L
.04384 .52232 L
.04453 .52229 L
.04517 .52227 L
.04634 .52225 L
.04758 .52223 L
.0489 .52223 L
.04965 .52223 L
.05035 .52224 L
.05157 .52225 L
.05288 .52227 L
.05528 .52234 L
.0566 .52238 L
.05784 .52241 L
.059 .52244 L
.06026 .52243 L
.0614 .52241 L
.06244 .5224 L
.06369 .52238 L
.0644 .52239 L
.06507 .5224 L
.06649 .52242 L
.06719 .52243 L
.06784 .52244 L
.06855 .52245 L
.06932 .52245 L
.06998 .52243 L
.07068 .52242 L
.07373 .52233 L
.08445 .52196 L
.08561 .52195 L
.08669 .52195 L
.08782 .52195 L
.08905 .52194 L
.09031 .52189 L
.09164 .52181 L
.09278 .52176 L
.09402 .52171 L
.09478 .52172 L
.09549 .52174 L
.09687 .5218 L
.09811 .52186 L
.09881 .52188 L
.09947 .52189 L
.10066 .52185 L
.10195 .52179 L
.10458 .52164 L
.10713 .52151 L
Mistroke
.10852 .52145 L
.10984 .52141 L
.11107 .52137 L
.11239 .52135 L
.1136 .52133 L
.11471 .52132 L
.11605 .52132 L
.11681 .52133 L
.11749 .52133 L
.11813 .52133 L
.11882 .52132 L
.12008 .52128 L
.12077 .52124 L
.12149 .5212 L
.12279 .52112 L
.12347 .52108 L
.1242 .52105 L
.125 .52103 L
.12575 .52104 L
.12702 .52106 L
.1282 .52109 L
.12949 .52114 L
.13087 .52121 L
.1322 .52127 L
.13364 .52135 L
.1343 .52138 L
.135 .5214 L
.13625 .52143 L
.13749 .52145 L
.13865 .52146 L
.14003 .52148 L
.14129 .5215 L
.14242 .52152 L
.14349 .52152 L
.14462 .52152 L
.14586 .52147 L
.14818 .52137 L
.14949 .52132 L
.15069 .52131 L
.15175 .52132 L
.15291 .52134 L
.15411 .52136 L
.15524 .52137 L
.15589 .52137 L
.1566 .52137 L
.15783 .52137 L
.15854 .52136 L
.15928 .52135 L
.15991 .52133 L
.16061 .5213 L
Mistroke
.16319 .52115 L
.16561 .52098 L
.1669 .52088 L
.16759 .52083 L
.16832 .52078 L
.16902 .52075 L
.16965 .52072 L
.17089 .52075 L
.17209 .52081 L
.17338 .52088 L
.1746 .52093 L
.17573 .52092 L
.17703 .52086 L
.17825 .5208 L
.1797 .52072 L
.18102 .52066 L
.18372 .52057 L
.18661 .52048 L
.18773 .52044 L
.18891 .52042 L
.1902 .5204 L
.19139 .52041 L
.19242 .52042 L
.19353 .52042 L
.19474 .52042 L
.19587 .52038 L
.19713 .52031 L
.19832 .52023 L
.1994 .52016 L
.20055 .5201 L
.20183 .52005 L
.20302 .52002 L
.20571 .51995 L
.20699 .51992 L
.2077 .51991 L
.20836 .5199 L
.20964 .5199 L
.21084 .51992 L
.21227 .51997 L
.21378 .52003 L
.21451 .52005 L
.2152 .52007 L
.21649 .52006 L
.21769 .52003 L
.21879 .52001 L
.22127 .51995 L
.22647 .51986 L
.22763 .51982 L
.2289 .51979 L
.23009 .51976 L
Mistroke
.23119 .51978 L
.23248 .51983 L
.23318 .51985 L
.23384 .51987 L
.23498 .51988 L
.23624 .51979 L
.24535 .51926 L
.2478 .51914 L
.24915 .51906 L
.25042 .519 L
.25114 .519 L
.25192 .51901 L
.25257 .51902 L
.25329 .51902 L
.25396 .51903 L
.25467 .51902 L
.25595 .51897 L
.25727 .51883 L
.25847 .51869 L
.25976 .51854 L
.26049 .51846 L
.26116 .51843 L
.26237 .51839 L
.26366 .51838 L
.26479 .51838 L
.26603 .51837 L
.26731 .51836 L
.26795 .51835 L
.26865 .51835 L
.26989 .51835 L
.27105 .51837 L
.27251 .51843 L
.27389 .51848 L
.27513 .51852 L
.27582 .51852 L
.27647 .5185 L
.27756 .51845 L
.27877 .51838 L
.28121 .51823 L
.28247 .51817 L
.28382 .5181 L
.28627 .51802 L
.28742 .51801 L
.28867 .51799 L
.28984 .51798 L
.29092 .51795 L
.29219 .51786 L
.29352 .51776 L
.29466 .51767 L
.29588 .51759 L
Mistroke
.29703 .51753 L
.29808 .51749 L
.29913 .51746 L
.30013 .51744 L
.30129 .51743 L
.30236 .51744 L
.30362 .51746 L
.30479 .51748 L
.30592 .51748 L
.30713 .51746 L
.30778 .51744 L
.30847 .51741 L
.3097 .51736 L
.31219 .51722 L
.31492 .51704 L
.32596 .51601 L
.33637 .51532 L
.34605 .51477 L
.34722 .51473 L
.34833 .51471 L
.3496 .51472 L
.35077 .51474 L
.35306 .5148 L
.35406 .51482 L
.35517 .51483 L
.35624 .51484 L
.35737 .51479 L
.35861 .51472 L
.35977 .51463 L
.36482 .51415 L
.36991 .51372 L
.3754 .5131 L
.38514 .51168 L
.38795 .51128 L
.38932 .5111 L
.39057 .51097 L
.39189 .51087 L
.39261 .51086 L
.3933 .51086 L
.39404 .51088 L
.39473 .5109 L
.39549 .51093 L
.39629 .51097 L
.39883 .51116 L
.40023 .51127 L
.40093 .51133 L
.40157 .51138 L
.4028 .51143 L
.40415 .51147 L
.4053 .51152 L
Mistroke
.40652 .51159 L
.40776 .51174 L
.40911 .51194 L
.41155 .51237 L
.41611 .51319 L
.41879 .51359 L
.42025 .51376 L
.42096 .51383 L
.42162 .51389 L
.42278 .51397 L
.42403 .51401 L
.42468 .51403 L
.42539 .51403 L
.42668 .51402 L
.4279 .51398 L
.42901 .51393 L
.43153 .51377 L
.43389 .51363 L
.43608 .51347 L
.43725 .51335 L
.4385 .5132 L
.44114 .51276 L
.44257 .51242 L
.44392 .51203 L
.44646 .51125 L
.44901 .51063 L
.4517 .51012 L
.45401 .50981 L
.45654 .5095 L
.45922 .50904 L
.46064 .50879 L
.46142 .50865 L
.46215 .50854 L
.46284 .50846 L
.4636 .50839 L
.46491 .50829 L
.46747 .50813 L
.47005 .50794 L
.47145 .50785 L
.47277 .50779 L
.47389 .50776 L
.47509 .50774 L
.47577 .50772 L
.47642 .50771 L
.47763 .50766 L
.47876 .50758 L
.47995 .50749 L
.48209 .50727 L
.48327 .5071 L
.48439 .50692 L
Mistroke
.48692 .50653 L
.48821 .50638 L
.48894 .50633 L
.48961 .50628 L
.49085 .50621 L
.49217 .50616 L
.49347 .50615 L
.4947 .50615 L
.49579 .50615 L
.49698 .50614 L
.49829 .50604 L
.49903 .50596 L
.49972 .50588 L
.50124 .5057 L
.5019 .50562 L
.50262 .50556 L
.50391 .50552 L
.50513 .50551 L
.5058 .50552 L
.50652 .50554 L
.50781 .5056 L
.51019 .5058 L
.51139 .50587 L
.5127 .5059 L
.51382 .50577 L
.51501 .5056 L
.51614 .50542 L
.51717 .50525 L
.51848 .50512 L
.51916 .50508 L
.51989 .50504 L
.52111 .50499 L
.52246 .50494 L
.52727 .50476 L
.52944 .50472 L
.53063 .50471 L
.53175 .50468 L
.53239 .50466 L
.53308 .50461 L
.53429 .50447 L
.53541 .50433 L
.53664 .50419 L
.53781 .50408 L
.53889 .50408 L
.54004 .50411 L
.54128 .50416 L
.54242 .5042 L
.54351 .50419 L
.54448 .50416 L
.54554 .50412 L
Mistroke
.54686 .50406 L
.5481 .50402 L
.54939 .50403 L
.55008 .50404 L
.55081 .50404 L
.55205 .50405 L
.55336 .50403 L
.55447 .50397 L
.55569 .50391 L
.55691 .50386 L
.55802 .50384 L
.55929 .50391 L
.5605 .50399 L
.56263 .50417 L
.56497 .50434 L
.56619 .50441 L
.56751 .50447 L
.56823 .5045 L
.56889 .50451 L
.57019 .50452 L
.57137 .50452 L
.57266 .50451 L
.57387 .50451 L
.575 .50451 L
.57568 .50451 L
.57642 .50451 L
.57712 .5045 L
.57776 .50449 L
.57897 .50447 L
.58026 .50443 L
.58093 .5044 L
.58164 .50436 L
.58293 .50427 L
.58372 .50419 L
.58446 .50409 L
.58586 .50389 L
.59555 .50245 L
.60085 .50183 L
.60345 .50149 L
.60583 .50126 L
.61005 .50096 L
.6146 .50065 L
.61721 .50044 L
.61967 .50026 L
.62427 .50003 L
.62655 .49992 L
.62784 .49988 L
.62903 .49985 L
.63021 .49985 L
.6315 .49985 L
Mistroke
.63215 .49986 L
.63285 .49987 L
.63411 .4999 L
.63623 .49999 L
.63739 .50004 L
.63849 .50008 L
.63966 .5001 L
.64096 .50012 L
.64206 .50012 L
.64325 .50013 L
.64392 .50013 L
.64466 .50013 L
.64538 .50013 L
.64615 .50013 L
.64687 .50014 L
.64753 .50014 L
.64881 .50015 L
.65011 .50016 L
.65152 .50019 L
.65217 .5002 L
.65286 .50022 L
.65409 .50026 L
.65635 .50037 L
.6576 .50043 L
.65879 .50047 L
.65946 .50046 L
.66019 .50045 L
.66147 .50042 L
.66268 .5004 L
.66397 .50037 L
.66461 .50037 L
.6653 .50036 L
.66653 .50037 L
.66722 .50038 L
.66796 .5004 L
.66866 .50043 L
.6693 .50046 L
.67187 .50066 L
.67431 .50086 L
.67664 .501 L
.6788 .50111 L
.68368 .50135 L
.68622 .50142 L
.6875 .50147 L
.68822 .5015 L
.68889 .50154 L
.68964 .50162 L
.69031 .50171 L
.69182 .50191 L
.69322 .50208 L
Mistroke
.69451 .5022 L
.69573 .50224 L
.69702 .50227 L
.69973 .50234 L
.70095 .50241 L
.70211 .50248 L
.70275 .5025 L
.70344 .50252 L
.70466 .5025 L
.70582 .5024 L
.70705 .50228 L
.70811 .5022 L
.70927 .50214 L
.71034 .50224 L
.71149 .50238 L
.71257 .50251 L
.71357 .50264 L
.71476 .50272 L
.71606 .50272 L
.71732 .50269 L
.71803 .50265 L
.71868 .50262 L
.72095 .50246 L
.72336 .50228 L
.72462 .50221 L
.72533 .50219 L
.726 .50217 L
.72718 .50215 L
.72844 .50216 L
.72915 .50218 L
.72992 .50224 L
.73133 .50239 L
.73271 .50253 L
.73396 .50263 L
.73526 .50256 L
.73648 .50241 L
.73787 .50222 L
.73915 .50207 L
.74028 .50204 L
.74147 .50209 L
.74267 .50219 L
.74398 .50236 L
.74528 .5026 L
.74649 .50286 L
.74922 .50352 L
.75419 .50436 L
.7635 .5063 L
.78442 .5119 L
.80309 .51559 L
.80821 .5164 L
Mistroke
.81372 .51716 L
.81893 .51769 L
.8237 .51804 L
.82844 .5185 L
.83105 .51879 L
.83351 .51903 L
.83462 .51917 L
.8358 .51936 L
.8371 .51962 L
.83829 .51986 L
.83929 .52007 L
.84036 .52026 L
.84153 .52037 L
.84263 .52046 L
.84392 .52057 L
.84463 .52063 L
.84529 .5207 L
.84608 .52083 L
.84679 .52096 L
.84818 .52123 L
.85093 .52179 L
.85345 .52225 L
.85465 .52245 L
.85577 .52259 L
.85693 .5227 L
.8582 .5228 L
.8595 .52287 L
.86068 .52291 L
.86134 .52292 L
.86205 .52293 L
.86334 .52295 L
.86456 .52299 L
.86568 .52305 L
.86697 .5232 L
.86821 .52336 L
.87277 .52394 L
.87816 .52446 L
.88316 .52511 L
.88436 .52529 L
.88566 .52547 L
.88689 .52559 L
.88802 .52567 L
.88935 .52574 L
.89001 .52576 L
.89074 .52578 L
.89202 .52578 L
.89321 .52577 L
.89451 .52575 L
.8952 .52573 L
.89593 .52572 L
Mistroke
.89657 .52572 L
.89727 .52572 L
.89851 .52572 L
.89924 .52572 L
.90004 .52573 L
.90079 .52573 L
.90148 .52574 L
.90419 .52578 L
.90889 .52566 L
.91001 .52561 L
.9112 .52557 L
.91221 .52556 L
.91333 .52556 L
.9146 .52557 L
.91578 .52559 L
.91707 .52562 L
.91779 .52565 L
.91845 .52567 L
.92083 .5258 L
.9231 .52598 L
.92439 .52611 L
.92576 .52628 L
.92822 .52669 L
.93382 .52792 L
.94379 .5304 L
.95181 .53187 L
.96048 .53311 L
.97619 .53605 L
Mfstroke
.7 0 0 r
.02381 .52196 m
.02605 .52182 L
.02846 .52168 L
.03279 .52151 L
.03543 .52141 L
.03673 .52136 L
.03793 .52132 L
.03902 .52129 L
.04018 .52127 L
.04134 .52126 L
.04262 .52126 L
.04516 .52123 L
.0465 .52121 L
.04725 .5212 L
.04793 .52119 L
.04857 .52119 L
.04927 .52119 L
.05054 .52122 L
.0517 .52125 L
.05297 .52128 L
.05421 .52131 L
.05537 .52132 L
.05659 .52132 L
.05791 .52131 L
.05912 .52129 L
.06028 .52123 L
.06244 .52112 L
.07293 .52059 L
.07554 .52042 L
.07833 .52024 L
.07978 .5201 L
.08138 .51991 L
.08275 .51976 L
.0835 .51968 L
.0842 .51962 L
.08546 .51956 L
.08613 .51953 L
.08684 .51951 L
.08811 .51948 L
.08926 .51947 L
.09471 .51937 L
.09698 .51939 L
.09825 .5194 L
.09941 .5194 L
.10007 .51938 L
.10078 .51936 L
.10208 .51931 L
.10339 .51926 L
.10458 .51922 L
.1058 .51921 L
Mistroke
.1071 .51921 L
.1083 .51921 L
.10943 .51921 L
.11071 .51923 L
.1119 .51924 L
.11319 .51923 L
.11385 .51922 L
.11456 .5192 L
.11577 .51912 L
.11686 .51903 L
.11804 .51893 L
.11932 .51882 L
.12051 .51877 L
.12161 .51873 L
.12376 .51867 L
.12608 .51858 L
.12729 .51854 L
.12856 .5185 L
.12925 .51849 L
.12999 .51851 L
.1313 .51856 L
.13261 .51862 L
.13386 .51868 L
.13453 .51872 L
.13526 .51872 L
.13654 .51873 L
.13727 .51873 L
.13803 .51873 L
.13869 .51873 L
.13941 .51873 L
.14069 .51878 L
.14207 .51884 L
.14337 .51889 L
.14456 .51892 L
.14574 .51887 L
.14684 .51881 L
.14815 .51872 L
.14936 .51865 L
.15055 .51864 L
.15181 .51866 L
.15308 .51868 L
.15379 .51867 L
.15446 .51866 L
.15565 .51856 L
.15678 .51842 L
.15889 .5181 L
.16362 .51741 L
.16614 .5171 L
.16751 .51695 L
.1688 .51684 L
Mistroke
.1699 .51676 L
.17107 .51675 L
.17238 .51676 L
.17358 .51676 L
.17424 .51676 L
.17495 .51675 L
.17622 .51663 L
.17771 .51647 L
.17911 .51633 L
.17976 .51626 L
.18044 .51622 L
.18119 .51619 L
.18187 .51617 L
.18307 .51614 L
.18437 .51613 L
.18568 .51614 L
.18689 .51617 L
.18819 .5162 L
.18893 .51621 L
.18962 .51622 L
.19078 .51621 L
.19203 .51616 L
.19268 .51613 L
.19337 .51609 L
.19459 .516 L
.1957 .51587 L
.19689 .51571 L
.19904 .5154 L
.20035 .51523 L
.20159 .51512 L
.2039 .51496 L
.2052 .5149 L
.20643 .51486 L
.20785 .51483 L
.20915 .5148 L
.21037 .51476 L
.2115 .51469 L
.21406 .51452 L
.21919 .51416 L
.22482 .51375 L
.24485 .51197 L
.26331 .51025 L
.30251 .5062 L
.34416 .50225 L
.36508 .49954 L
.3843 .49694 L
.39403 .49534 L
.39878 .49467 L
.40085 .49443 L
.4031 .49421 L
Mistroke
.40432 .49412 L
.40545 .49406 L
.40653 .49403 L
.40767 .49404 L
.40887 .4941 L
.41 .49418 L
.41123 .4943 L
.41256 .49447 L
.41516 .49489 L
.41793 .49533 L
.41928 .4955 L
.42055 .49563 L
.42169 .49571 L
.42292 .49572 L
.42414 .49568 L
.42483 .49564 L
.42548 .4956 L
.42818 .49539 L
.43052 .49517 L
.43302 .49484 L
.43598 .49431 L
.43879 .49362 L
.44405 .49199 L
.45379 .48946 L
.46413 .48744 L
.47359 .48611 L
.48404 .48488 L
.49301 .48347 L
.4979 .48291 L
.50028 .48257 L
.50132 .48243 L
.50245 .48229 L
.50365 .48219 L
.50478 .48212 L
.50727 .48199 L
.51254 .4817 L
.51694 .48134 L
.51928 .48116 L
.52057 .48106 L
.52179 .48098 L
.52247 .48094 L
.52321 .48091 L
.52451 .48087 L
.52585 .48084 L
.52706 .48082 L
.52778 .4808 L
.52846 .48076 L
.52995 .48068 L
.53264 .4805 L
.53498 .4803 L
Mistroke
.53626 .48021 L
.53745 .48015 L
.53874 .48017 L
.53942 .4802 L
.54015 .48024 L
.54144 .48033 L
.54264 .48041 L
.54387 .48043 L
.54451 .48043 L
.54521 .48043 L
.54591 .48043 L
.54664 .48043 L
.54794 .48043 L
.54915 .48047 L
.55028 .48052 L
.55151 .48056 L
.55215 .48058 L
.55284 .48059 L
.55359 .48059 L
.55428 .48057 L
.55565 .48053 L
.55688 .48048 L
.5582 .48043 L
.55893 .48041 L
.5596 .4804 L
.56092 .48037 L
.56166 .48036 L
.56246 .48035 L
.56321 .48034 L
.56391 .48035 L
.56506 .48035 L
.5663 .48036 L
.56747 .48037 L
.56855 .48036 L
.56974 .48035 L
.57104 .48034 L
.5724 .48032 L
.57367 .48029 L
.5749 .48026 L
.57556 .48024 L
.57625 .48023 L
.57751 .48021 L
.57868 .48021 L
.57937 .48022 L
.58002 .48023 L
.58073 .48025 L
.58149 .48028 L
.58217 .48031 L
.58282 .48034 L
.58404 .48044 L
Mistroke
.58529 .48057 L
.58663 .4807 L
.58791 .4808 L
.58907 .48082 L
.59013 .48079 L
.59129 .48075 L
.59363 .48068 L
.59485 .4807 L
.59617 .48072 L
.59741 .48073 L
.59857 .48072 L
.59921 .48069 L
.59991 .48064 L
.60133 .48056 L
.60263 .48048 L
.60386 .48045 L
.60502 .48047 L
.60624 .48051 L
.60843 .48059 L
.61079 .48065 L
.61337 .48072 L
.61763 .48081 L
.61987 .48084 L
.6211 .48086 L
.62224 .48088 L
.62355 .48092 L
.62425 .48095 L
.625 .481 L
.62753 .48114 L
.62817 .48117 L
.62887 .4812 L
.63014 .48122 L
.63138 .48123 L
.63252 .48124 L
.63375 .48126 L
.6349 .4813 L
.63705 .48139 L
.63825 .48143 L
.63936 .48144 L
.64058 .48143 L
.64186 .48143 L
.64317 .48145 L
.64436 .48151 L
.64502 .48156 L
.64573 .48163 L
.64703 .48178 L
.64954 .48219 L
.65186 .48269 L
.66281 .48459 L
.70214 .49112 L
Mistroke
.72188 .49492 L
.73052 .49601 L
.73287 .49655 L
.73402 .49679 L
.73508 .49692 L
.73631 .49699 L
.73763 .49707 L
.73876 .49717 L
.73995 .49738 L
.74122 .49775 L
.7424 .49814 L
.7451 .49908 L
.74989 .5006 L
.75934 .5034 L
.76941 .50739 L
.78021 .51253 L
.80001 .52161 L
.81045 .5267 L
.82155 .53168 L
.83137 .53512 L
.84223 .5381 L
.86137 .54243 L
.87078 .54415 L
.8807 .5459 L
.88321 .5464 L
.88459 .54664 L
.88589 .54683 L
.88663 .5469 L
.88743 .54697 L
.8881 .54701 L
.88883 .54704 L
.88952 .54707 L
.89026 .54709 L
.89157 .54709 L
.89287 .54707 L
.89406 .54704 L
.89471 .54701 L
.89542 .54697 L
.89672 .54686 L
.89795 .54675 L
.89924 .54663 L
.90034 .54653 L
.90155 .54648 L
.90219 .54647 L
.90287 .54646 L
.90411 .54645 L
.90485 .54644 L
.90555 .54643 L
.90687 .54637 L
.90927 .54623 L
Mistroke
.91188 .54607 L
.9131 .54599 L
.91424 .54593 L
.91543 .54589 L
.91674 .54588 L
.91787 .54591 L
.91891 .54595 L
.92005 .54601 L
.92124 .54608 L
.92609 .54643 L
.92737 .54647 L
.92804 .5465 L
.92875 .54653 L
.93006 .5466 L
.93126 .54672 L
.932 .54684 L
.93268 .54696 L
.93424 .54728 L
.93694 .54795 L
.94222 .54935 L
.97619 .55741 L
Mfstroke
.6 0 0 r
.02381 .52133 m
.03279 .52055 L
.03793 .52009 L
.04262 .51977 L
.04758 .51951 L
.05288 .51929 L
.05752 .51913 L
.06006 .51906 L
.06131 .51904 L
.06244 .51901 L
.06368 .51896 L
.06437 .51892 L
.06501 .51887 L
.06785 .51862 L
.07026 .51844 L
.07283 .51828 L
.07359 .51823 L
.0743 .51816 L
.07563 .51799 L
.07822 .51761 L
.0841 .51673 L
.08889 .51612 L
.0915 .51574 L
.09278 .51556 L
.09394 .51542 L
.09522 .51531 L
.09592 .51527 L
.09658 .51523 L
.09948 .51511 L
.10458 .51491 L
.10698 .51486 L
.10823 .51484 L
.10956 .51481 L
.11072 .51478 L
.112 .51473 L
.11317 .51468 L
.11423 .51462 L
.11545 .51453 L
.11676 .51441 L
.11911 .51417 L
.12449 .5135 L
.14291 .51173 L
.18289 .50636 L
.22136 .50048 L
.26228 .4927 L
.30168 .48477 L
.33957 .47743 L
.37991 .4699 L
.41873 .46441 L
.41995 .46447 L
Mistroke
.42126 .46448 L
.4225 .46439 L
.42364 .46423 L
.42638 .46371 L
.42886 .46329 L
.43165 .46283 L
.43459 .46238 L
.43582 .46215 L
.43713 .46184 L
.43788 .4616 L
.43856 .46136 L
.43991 .46086 L
.45035 .45721 L
.45495 .45594 L
.45738 .45535 L
.46001 .45464 L
.46123 .45434 L
.46251 .45408 L
.4636 .45393 L
.4648 .45379 L
.46929 .4533 L
.47913 .4525 L
.48434 .45196 L
.4899 .45117 L
.49111 .45091 L
.49241 .45065 L
.49364 .45047 L
.49476 .45033 L
.49721 .45007 L
.4999 .4498 L
.50122 .4497 L
.50196 .44966 L
.50265 .44964 L
.50391 .44967 L
.50455 .44969 L
.50525 .44973 L
.51017 .44998 L
.52129 .45063 L
.53169 .45143 L
.53413 .45161 L
.53548 .45168 L
.53674 .45176 L
.53793 .45185 L
.53921 .45202 L
.54145 .45236 L
.54614 .45307 L
.54881 .45359 L
.55127 .45419 L
.55619 .45507 L
.5588 .45548 L
Mistroke
.56161 .45609 L
.56404 .45679 L
.56625 .45757 L
.57059 .45892 L
.58011 .46164 L
.61984 .47343 L
.65805 .48934 L
.69872 .5108 L
.73787 .53351 L
.77947 .56482 L
.80035 .58065 L
.80951 .58668 L
.81955 .59247 L
.82861 .59701 L
.8336 .59904 L
.83832 .60059 L
.84088 .60125 L
.84234 .60152 L
.84368 .60173 L
.84856 .60258 L
.84971 .60278 L
.85096 .60296 L
.85205 .60309 L
.8532 .6032 L
.85442 .60328 L
.85554 .60332 L
.85678 .60329 L
.85748 .60326 L
.85813 .60322 L
.8594 .60312 L
.86076 .60297 L
.86318 .60266 L
.86866 .60198 L
.87339 .60124 L
.8786 .60015 L
.88323 .59916 L
.88578 .59855 L
.88821 .59776 L
.8929 .59583 L
.89719 .59386 L
.90681 .58993 L
.90935 .58897 L
.91209 .58806 L
.91335 .5877 L
.91468 .58737 L
.91592 .5871 L
.91705 .58694 L
.9182 .58681 L
.91944 .58669 L
.92166 .58647 L
Mistroke
.92408 .5862 L
.92536 .58607 L
.92671 .58597 L
.92782 .58591 L
.92905 .58586 L
.93016 .58583 L
.93121 .5858 L
.93226 .58577 L
.93325 .58576 L
.9344 .58575 L
.93546 .58575 L
.9367 .58582 L
.9374 .58587 L
.93804 .58592 L
.9392 .58601 L
.94048 .58607 L
.94162 .58602 L
.94269 .58589 L
.94504 .58554 L
.94635 .58536 L
.94709 .58531 L
.94778 .58527 L
.94901 .58519 L
.94967 .58515 L
.95038 .5851 L
.9516 .58499 L
.95274 .58483 L
.95525 .58443 L
.96412 .58246 L
.96876 .58158 L
.96988 .58144 L
.97109 .58126 L
.97241 .5809 L
.97364 .5805 L
.97619 .57953 L
Mfstroke
.5 0 0 r
.02381 .51714 m
.06244 .51077 L
.10458 .50166 L
.12507 .49758 L
.14415 .49344 L
.18221 .48182 L
.2212 .46946 L
.26265 .45257 L
.28341 .4459 L
.30258 .44007 L
.31213 .43757 L
.32241 .43483 L
.32738 .43358 L
.32984 .43304 L
.33103 .43282 L
.33211 .43267 L
.33417 .43243 L
.33636 .43222 L
.34099 .43164 L
.35972 .42897 L
.38034 .42617 L
.3897 .42459 L
.39481 .42383 L
.39959 .4232 L
.40087 .42305 L
.40208 .42295 L
.40275 .42291 L
.40348 .42287 L
.40476 .42284 L
.40544 .42284 L
.40619 .42286 L
.40697 .42291 L
.4077 .423 L
.41043 .42344 L
.4152 .42403 L
.42041 .42458 L
.42287 .42489 L
.42422 .42507 L
.4255 .42522 L
.42669 .42532 L
.42798 .42533 L
.42916 .42528 L
.43024 .42521 L
.44059 .42419 L
.44283 .424 L
.44523 .42378 L
.4475 .42352 L
.44958 .42318 L
.45069 .42303 L
.4519 .42289 L
Mistroke
.45305 .42289 L
.45411 .42294 L
.45538 .42304 L
.45652 .42315 L
.45785 .42326 L
.4591 .42333 L
.46026 .4234 L
.46151 .4235 L
.46269 .42362 L
.46377 .42377 L
.46888 .42458 L
.47143 .42502 L
.47286 .42537 L
.47419 .42578 L
.47921 .42741 L
.4977 .43346 L
.50235 .43509 L
.50496 .43634 L
.50735 .43765 L
.5164 .4434 L
.53702 .45703 L
.57669 .4902 L
.61485 .52158 L
.65547 .55209 L
.69456 .57624 L
.71452 .58599 L
.72501 .59063 L
.73611 .59458 L
.74605 .59746 L
.74877 .59817 L
.75027 .59848 L
.75169 .59872 L
.75301 .5989 L
.7537 .59899 L
.75444 .59907 L
.75575 .59916 L
.75696 .59923 L
.76183 .5999 L
.76311 .60018 L
.76382 .60033 L
.76449 .60045 L
.76579 .60058 L
.76696 .60065 L
.76806 .60069 L
.76907 .6007 L
.77018 .60071 L
.77135 .6007 L
.77253 .60069 L
.77363 .60066 L
.77492 .60063 L
Mistroke
.77615 .60061 L
.77727 .60058 L
.7785 .60053 L
.77962 .60047 L
.78066 .60038 L
.783 .60012 L
.78431 .59992 L
.7855 .59971 L
.788 .59916 L
.7907 .59833 L
.79559 .59621 L
.81387 .58523 L
.81885 .58202 L
.82419 .57806 L
.83382 .56833 L
.84387 .55551 L
.85489 .54047 L
.87472 .51129 L
.89627 .4799 L
.90632 .46715 L
.91182 .46135 L
.91451 .45906 L
.91698 .45736 L
.92137 .45513 L
.92609 .45329 L
.93098 .45192 L
.93614 .45075 L
.97426 .4398 L
.97619 .4392 L
Mfstroke
.4 0 0 r
.02381 .51158 m
.06244 .49661 L
.10458 .47717 L
.14415 .4587 L
.18221 .44033 L
.20342 .4301 L
.22272 .42226 L
.24299 .4149 L
.24728 .41353 L
.24965 .41273 L
.2519 .41212 L
.25454 .41155 L
.25696 .41104 L
.26171 .41004 L
.26615 .40928 L
.26737 .40911 L
.26867 .40896 L
.26989 .40885 L
.271 .40879 L
.27229 .40878 L
.2735 .4088 L
.27476 .40881 L
.27542 .40881 L
.27614 .40878 L
.2774 .40868 L
.2786 .40857 L
.2797 .40847 L
.28086 .40837 L
.28214 .40832 L
.28332 .4083 L
.28459 .4083 L
.28532 .40831 L
.286 .40833 L
.28668 .40837 L
.28739 .40843 L
.28867 .40853 L
.29156 .40873 L
.29276 .40877 L
.29389 .40881 L
.29519 .40888 L
.29637 .40899 L
.29768 .40919 L
.2991 .40944 L
.30164 .40994 L
.32152 .41536 L
.34256 .42274 L
.38045 .43758 L
.42079 .4573 L
.45961 .47128 L
.47936 .47955 L
Mistroke
.49053 .48302 L
.50089 .48576 L
.50566 .48673 L
.51081 .48823 L
.51318 .48887 L
.51437 .4891 L
.51567 .4893 L
.51679 .48943 L
.51799 .4895 L
.51912 .48949 L
.52014 .48946 L
.52143 .48941 L
.52208 .48938 L
.52279 .48938 L
.52357 .48944 L
.52429 .48951 L
.52567 .48964 L
.52699 .48975 L
.52819 .48979 L
.52951 .48974 L
.53018 .4897 L
.5309 .48963 L
.53218 .48947 L
.53335 .48926 L
.53595 .48862 L
.54065 .48754 L
.54184 .48732 L
.54298 .48714 L
.54428 .487 L
.54548 .48686 L
.54652 .48673 L
.54764 .48655 L
.54886 .48623 L
.54999 .48587 L
.5547 .48417 L
.55987 .48246 L
.56502 .48079 L
.5707 .47837 L
.58068 .47296 L
.62085 .44629 L
.65951 .4259 L
.66987 .42106 L
.67952 .41674 L
.68959 .41354 L
.69233 .41286 L
.69492 .41233 L
.69635 .41208 L
.6979 .41187 L
.69859 .41179 L
.69931 .41173 L
Mistroke
.70061 .41169 L
.70182 .41167 L
.70314 .41165 L
.70438 .41161 L
.70554 .4115 L
.70665 .41139 L
.70785 .41127 L
.70899 .41118 L
.71004 .41115 L
.71129 .41114 L
.71261 .41117 L
.71372 .41121 L
.71494 .41127 L
.71634 .41135 L
.71767 .41143 L
.71887 .41149 L
.72016 .41149 L
.72132 .41145 L
.72254 .41141 L
.72358 .41138 L
.72474 .41137 L
.72595 .41138 L
.72726 .41143 L
.7285 .41153 L
.72963 .41169 L
.7307 .41194 L
.73169 .41221 L
.73394 .41286 L
.73613 .41333 L
.73847 .41378 L
.74106 .41443 L
.74381 .41536 L
.74615 .41647 L
.74872 .41788 L
.75408 .42039 L
.75983 .42304 L
.76528 .42658 L
.77025 .42996 L
.77999 .43712 L
.80063 .45449 L
.81977 .47078 L
.83831 .48403 L
.84866 .48932 L
.85313 .49117 L
.85803 .49293 L
.8604 .49366 L
.86172 .49396 L
.86293 .49419 L
.8656 .49465 L
.86809 .49507 L
Mistroke
.8729 .49572 L
.87733 .49622 L
.87862 .49637 L
.87983 .49647 L
.88108 .49655 L
.88175 .49657 L
.88247 .49657 L
.88318 .49656 L
.88396 .49653 L
.8847 .49649 L
.88538 .49643 L
.88667 .49626 L
.88804 .496 L
.89078 .49534 L
.89335 .49458 L
.89817 .49285 L
.90282 .49068 L
.90793 .48779 L
.91824 .48242 L
.93671 .47134 L
.97619 .43786 L
Mfstroke
.3 0 0 r
.02381 .49595 m
.06244 .46349 L
.08255 .44626 L
.10458 .431 L
.12507 .42006 L
.14415 .41274 L
.15465 .40947 L
.16457 .40723 L
.17348 .40566 L
.17592 .40534 L
.17725 .40516 L
.1785 .405 L
.17957 .40489 L
.18071 .40482 L
.18198 .40477 L
.18314 .40475 L
.18432 .40475 L
.1856 .40473 L
.1868 .4047 L
.18791 .40467 L
.18921 .40466 L
.18986 .40466 L
.19057 .40468 L
.19182 .40474 L
.19299 .4048 L
.19417 .40485 L
.1953 .40489 L
.19631 .40487 L
.1974 .40485 L
.19859 .40483 L
.19986 .40485 L
.20094 .40495 L
.20213 .40511 L
.22285 .40875 L
.24383 .41417 L
.24827 .41543 L
.25301 .41654 L
.25441 .41681 L
.25574 .41703 L
.25693 .41717 L
.25821 .4173 L
.25944 .41743 L
.26073 .41759 L
.26184 .4178 L
.26306 .41804 L
.26546 .41851 L
.26775 .41884 L
.27039 .41912 L
.27155 .41923 L
.27279 .41932 L
Mistroke
.27398 .41938 L
.27505 .41942 L
.27613 .41942 L
.27715 .4194 L
.27834 .41935 L
.27944 .41928 L
.2819 .4191 L
.28305 .41901 L
.28429 .41888 L
.28651 .41858 L
.28915 .41808 L
.29156 .41751 L
.30174 .41438 L
.31168 .41055 L
.32087 .40564 L
.34164 .39139 L
.38096 .35819 L
.39058 .34938 L
.40069 .34063 L
.40487 .33754 L
.40717 .33608 L
.40933 .33498 L
.41189 .33394 L
.4131 .33355 L
.41422 .33324 L
.41526 .333 L
.4164 .33279 L
.41755 .33267 L
.41876 .33262 L
.41995 .33261 L
.42124 .33261 L
.42247 .33259 L
.4236 .33254 L
.42631 .33238 L
.42878 .3322 L
.43332 .33179 L
.43562 .33153 L
.43815 .33111 L
.44332 .32992 L
.44604 .32925 L
.44753 .32892 L
.44891 .32866 L
.45012 .32847 L
.45143 .32833 L
.45217 .32828 L
.45287 .3283 L
.45418 .32838 L
.45539 .32849 L
.4565 .32862 L
.45772 .32873 L
Mistroke
.45902 .32882 L
.46022 .32892 L
.46154 .32908 L
.46279 .32933 L
.46394 .32966 L
.46844 .33121 L
.47857 .33586 L
.49687 .34677 L
.50745 .35527 L
.51741 .36486 L
.53602 .38016 L
.5458 .38697 L
.55113 .39051 L
.55612 .39297 L
.56037 .39449 L
.56255 .39515 L
.56493 .39573 L
.56628 .39599 L
.56752 .39617 L
.56872 .39628 L
.56998 .39633 L
.57112 .39632 L
.57218 .39628 L
.57334 .39619 L
.57459 .39604 L
.57699 .39565 L
.57956 .39521 L
.58177 .39479 L
.58302 .39449 L
.58417 .39412 L
.587 .393 L
.58966 .3917 L
.59465 .38877 L
.61575 .37285 L
.63613 .35458 L
.65518 .33748 L
.65967 .33391 L
.66203 .33197 L
.66456 .3302 L
.66918 .32789 L
.67346 .32552 L
.67623 .32387 L
.67759 .3231 L
.67884 .32245 L
.67998 .32202 L
.68118 .32164 L
.68371 .321 L
.69308 .31918 L
.69564 .31868 L
.6969 .31847 L
Mistroke
.69806 .31832 L
.69912 .31825 L
.70024 .31837 L
.70136 .31854 L
.7026 .31876 L
.70392 .31898 L
.70513 .31899 L
.7058 .31897 L
.70652 .31894 L
.70721 .31892 L
.70785 .31891 L
.7091 .31894 L
.71023 .31917 L
.71278 .31993 L
.7217 .32279 L
.72657 .32455 L
.73113 .32645 L
.7359 .32916 L
.74115 .33211 L
.75037 .33895 L
.77118 .35656 L
.78021 .36456 L
.78516 .36919 L
.78981 .37307 L
.79481 .37607 L
.80034 .37897 L
.80262 .37993 L
.80502 .38077 L
.80766 .38143 L
.81008 .38185 L
.81138 .38204 L
.81262 .38218 L
.8133 .38224 L
.81404 .38229 L
.81533 .38236 L
.81656 .38241 L
.81787 .38242 L
.81899 .38238 L
.82022 .38229 L
.82096 .3822 L
.82166 .3821 L
.82298 .38186 L
.82595 .3811 L
.82851 .38022 L
.83131 .37886 L
.83636 .37543 L
.84175 .37092 L
.85143 .36044 L
.89305 .29804 L
.90322 .2823 L
Mistroke
.91395 .26835 L
.92389 .25805 L
.93316 .2503 L
.94279 .24333 L
.94483 .2418 L
.94699 .24045 L
.94937 .23936 L
.95156 .23853 L
.95394 .23768 L
.95657 .2369 L
.95901 .23633 L
.96131 .23595 L
.96259 .23578 L
.96323 .23572 L
.96393 .23567 L
.96518 .23567 L
.96633 .23577 L
.96704 .23595 L
.96771 .23616 L
.96895 .23661 L
.97175 .23773 L
.97619 .23923 L
Mfstroke
.2 0 0 r
.02381 .47089 m
.04262 .44202 L
.0522 .42954 L
.06244 .41868 L
.07286 .41007 L
.07751 .4068 L
.08255 .40382 L
.08848 .40133 L
.09409 .39951 L
.09954 .39818 L
.10458 .39717 L
.1249 .39317 L
.13484 .39086 L
.14393 .38803 L
.15328 .38432 L
.16216 .37941 L
.17153 .37296 L
.18177 .36393 L
.20308 .34026 L
.22241 .31951 L
.23209 .31157 L
.23718 .30806 L
.23996 .30638 L
.24256 .30515 L
.24727 .30347 L
.24855 .3031 L
.24977 .3028 L
.25044 .30266 L
.25117 .30255 L
.25245 .30239 L
.25474 .3022 L
.25717 .30197 L
.25817 .30188 L
.25925 .30181 L
.26043 .30178 L
.26154 .30188 L
.2628 .30206 L
.26394 .30225 L
.2665 .3027 L
.27111 .30351 L
.27376 .30425 L
.27521 .30463 L
.27656 .3049 L
.27771 .30507 L
.27895 .30523 L
.28158 .30558 L
.28286 .3058 L
.28425 .30602 L
.28548 .30619 L
.28679 .3063 L
Mistroke
.28759 .30635 L
.28832 .30637 L
.28905 .30638 L
.28974 .30638 L
.29103 .30632 L
.29176 .30626 L
.29243 .30618 L
.29481 .30582 L
.29616 .30554 L
.29742 .30524 L
.30268 .3038 L
.30512 .30305 L
.3077 .30197 L
.31054 .30048 L
.31316 .2989 L
.32307 .29087 L
.34164 .27038 L
.36137 .24799 L
.37001 .23992 L
.37944 .23257 L
.38889 .22735 L
.39139 .22616 L
.39404 .22511 L
.39534 .22469 L
.39655 .22436 L
.39765 .22417 L
.39883 .22403 L
.40013 .22393 L
.40135 .22387 L
.40209 .22385 L
.40279 .22382 L
.40411 .22379 L
.4054 .2238 L
.40613 .22381 L
.4068 .22384 L
.40753 .22388 L
.40821 .22392 L
.40891 .22398 L
.40969 .22407 L
.41092 .22424 L
.4122 .22449 L
.4133 .22479 L
.41451 .22516 L
.4197 .2269 L
.42977 .22935 L
.43472 .23086 L
.43577 .23122 L
.43689 .23158 L
.43813 .23179 L
.43929 .23192 L
Mistroke
.43997 .23198 L
.44062 .23202 L
.44184 .23208 L
.44315 .23215 L
.44455 .23222 L
.44529 .23225 L
.44596 .23227 L
.44728 .2323 L
.44801 .23231 L
.44881 .23232 L
.44956 .23232 L
.45025 .23232 L
.45145 .23232 L
.45257 .23233 L
.45379 .23237 L
.45511 .23238 L
.45577 .23236 L
.45648 .23233 L
.45779 .23215 L
.45905 .23183 L
.46023 .2315 L
.46487 .23043 L
.46614 .23016 L
.46683 .22999 L
.46747 .22979 L
.46862 .22931 L
.46986 .22873 L
.47452 .22628 L
.47891 .22344 L
.48413 .21897 L
.48887 .21412 L
.49951 .20101 L
.51785 .17791 L
.52287 .17246 L
.52826 .16766 L
.53292 .16416 L
.53538 .16264 L
.538 .16131 L
.53945 .16073 L
.54077 .16031 L
.54209 .16 L
.54334 .15983 L
.5446 .1598 L
.54577 .15985 L
.54705 .15999 L
.5484 .16019 L
.55074 .16067 L
.55293 .1613 L
.55533 .16221 L
.55789 .16339 L
Mistroke
.56891 .17055 L
.57894 .17824 L
.58823 .185 L
.59291 .18752 L
.59561 .18867 L
.59679 .18909 L
.59808 .18948 L
.59945 .18979 L
.60076 .19 L
.60149 .19008 L
.60226 .19014 L
.60299 .19017 L
.60365 .19018 L
.60495 .19015 L
.60567 .1901 L
.60634 .19004 L
.60758 .18986 L
.60888 .18961 L
.61007 .1893 L
.61134 .18891 L
.61364 .18806 L
.61612 .18699 L
.61886 .18544 L
.62142 .18353 L
.62414 .18132 L
.62902 .17728 L
.64009 .16651 L
.65058 .15347 L
.66021 .14213 L
.66508 .13662 L
.66962 .13273 L
.67436 .12942 L
.67685 .12784 L
.67954 .12641 L
.68226 .12536 L
.68482 .12454 L
.68604 .12419 L
.68732 .12387 L
.68842 .12365 L
.68962 .12351 L
.69034 .12348 L
.69103 .12348 L
.69231 .12353 L
.69302 .12357 L
.69369 .12363 L
.69519 .12376 L
.69651 .12391 L
.69771 .12408 L
.69838 .1242 L
.69909 .12433 L
Mistroke
.7004 .12467 L
.705 .12598 L
.70753 .1266 L
.70992 .12741 L
.71128 .12803 L
.71275 .12877 L
.71532 .13005 L
.72036 .13252 L
.73039 .1374 L
.73571 .13977 L
.74144 .14177 L
.74404 .14261 L
.74677 .1433 L
.74911 .14371 L
.75043 .14388 L
.75166 .14398 L
.75291 .14404 L
.75409 .14403 L
.75515 .14394 L
.7563 .14378 L
.76124 .14282 L
.76378 .14224 L
.76522 .14179 L
.76656 .14126 L
.77218 .13818 L
.78226 .13038 L
.80087 .11126 L
.81068 .1021 L
.81607 .09807 L
.82113 .095 L
.82636 .09269 L
.83213 .0907 L
.83452 .08995 L
.83572 .08968 L
.83704 .08949 L
.83847 .08933 L
.8398 .08922 L
.84233 .08896 L
.84359 .08885 L
.84425 .0888 L
.84495 .08875 L
.84623 .08871 L
.84742 .0887 L
.84856 .08872 L
.84962 .08876 L
.85079 .08883 L
.85205 .08892 L
.85338 .08904 L
.85408 .08912 L
.85483 .08922 L
Mistroke
.8562 .08946 L
.85748 .08972 L
.85882 .08999 L
.86008 .09021 L
.86122 .0903 L
.86244 .09032 L
.86368 .0903 L
.86482 .09027 L
.86612 .09027 L
.86736 .09031 L
.86843 .09034 L
.86956 .09036 L
.8708 .09037 L
.87195 .09035 L
.87318 .0903 L
.87388 .09026 L
.87451 .09022 L
.87575 .09012 L
.87691 .09002 L
.87819 .08986 L
.87892 .08974 L
.87958 .08961 L
.88094 .08926 L
.88168 .08899 L
.88239 .08872 L
.8873 .0864 L
.8925 .08317 L
.8982 .07825 L
.90345 .07285 L
.92172 .05192 L
.93179 .04052 L
.94135 .03146 L
.95006 .02452 L
.95499 .02174 L
.95956 .0196 L
.96371 .01779 L
.9647 .01739 L
.96574 .017 L
.96664 .01674 L
.96761 .01655 L
.96978 .01619 L
.97212 .01577 L
.97422 .01525 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.871701 0.144322 0.97619 0.475206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0297619 0.297619 [
[ 0 0 0 0 ]
[ 1 3.16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 3.16667 L
0 3.16667 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0535714 0.35119 0.35119 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.2 0 0 r
.007 w
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .20238 -61 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
80.938 16.625 moveto
(ns) show
94.563 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.39881 0.35119 0.696429 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.3 0 0 r
.007 w
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .54762 -61 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
73.750 16.625 moveto
(ns) show
87.375 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.744048 0.35119 1.04167 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.4 0 0 r
.007 w
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .89286 -61 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
73.750 16.625 moveto
(ns) show
87.375 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 1.08929 0.35119 1.3869 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 0 0 r
.007 w
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 1.2381 -61 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
73.750 16.625 moveto
(ns) show
87.375 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 1.43452 0.35119 1.73214 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.6 0 0 r
.007 w
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 1.58333 -61 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
73.750 16.625 moveto
(ns) show
87.375 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 1.77976 0.35119 2.07738 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.7 0 0 r
.007 w
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 1.92857 -61 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.188 16.625 moveto
(\\220) show
74.250 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
85.000 16.625 moveto
(ns) show
98.625 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 2.125 0.35119 2.42262 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.8 0 0 r
.007 w
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 2.27381 -61 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.188 16.625 moveto
(\\220) show
74.250 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
85.000 16.625 moveto
(ns) show
98.625 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 2.47024 0.35119 2.76786 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.9 0 0 r
.007 w
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 2.61905 -61 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.188 16.625 moveto
(\\220) show
74.250 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
85.000 16.625 moveto
(ns) show
98.625 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 2.81548 0.35119 3.1131 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.007 w
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 2.96429 -61 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.188 16.625 moveto
(\\220) show
74.250 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
92.188 16.625 moveto
(ns) show
105.813 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .53681 L
0 .53681 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{617.5625, 331.5},
 ImageMargins->0,
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{57.1875, 550.188}, {611, 346.813}} -> {-1.34063, \
1.05487, 0.00393022, 0.00393022}, {{69.3125, 476.438}, {604.688, 353.125}} -> \
{-76.3204, 1.67652, 0.478409, 0.00976152}, {{486.625, 538.063}, {540, \
377.125}} -> {-31.8898, 17.9179, 0.0522615, 0.0522615}, {{489.375, 504.688}, \
{537.25, 521.938}} -> {-33.5825, 58.8947, 0.0548577, 0.177523}, {{489.375, \
504.688}, {519.5, 504.188}} -> {-33.5825, 54.9559, 0.0548577, 0.177523}, \
{{489.375, 504.688}, {501.75, 486.438}} -> {-33.5825, 51.0171, 0.0548577, \
0.177523}, {{489.375, 504.688}, {484, 468.688}} -> {-33.5825, 47.0783, \
0.0548577, 0.177523}, {{489.375, 504.688}, {466.188, 450.938}} -> {-33.5825, \
43.1326, 0.0548577, 0.177523}, {{489.375, 504.688}, {448.438, 433.125}} -> \
{-33.5825, 39.1868, 0.0548577, 0.177523}, {{489.375, 504.688}, {430.688, \
415.375}} -> {-33.5825, 35.248, 0.0548577, 0.177523}, {{489.375, 504.688}, \
{412.938, 397.625}} -> {-33.5825, 31.3093, 0.0548577, 0.177523}, {{489.375, \
504.688}, {395.188, 379.875}} -> {-33.5825, 27.3705, 0.0548577, 0.177523}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
      "dbmagsmoothall", "\[LeftDoubleBracket]", "1", 
       "\[RightDoubleBracket]"}], "[", "x", "]"}], ",", 
     RowBox[{
      RowBox[{
      "dbmagsmoothall", "\[LeftDoubleBracket]", "2", 
       "\[RightDoubleBracket]"}], "[", "x", "]"}], ",", 
     RowBox[{
      RowBox[{
      "dbmagsmoothall", "\[LeftDoubleBracket]", "3", 
       "\[RightDoubleBracket]"}], "[", "x", "]"}], ",", 
     RowBox[{
      RowBox[{
      "dbmagsmoothall", "\[LeftDoubleBracket]", "4", 
       "\[RightDoubleBracket]"}], "[", "x", "]"}], ",", 
     RowBox[{
      RowBox[{
      "dbmagsmoothall", "\[LeftDoubleBracket]", "5", 
       "\[RightDoubleBracket]"}], "[", "x", "]"}], ",", 
     RowBox[{
      RowBox[{
      "dbmagsmoothall", "\[LeftDoubleBracket]", "6", 
       "\[RightDoubleBracket]"}], "[", "x", "]"}], ",", 
     RowBox[{
      RowBox[{
      "dbmagsmoothall", "\[LeftDoubleBracket]", "7", 
       "\[RightDoubleBracket]"}], "[", "x", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "6", ",", "194"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.85", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.7", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.55", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", "\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.4", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", "\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.25", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", "\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.1", ",", "0", ",", "0"}], "]"}]}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
   "PlotLabel", "\[Rule]", "\"\<Insertion Loss relative to Zero Delay\>\""}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Frequency (MHz)\>\"", ",", "\"\<Relative Insertion Loss (dB)\>\""}],
      "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"PlotLegend", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<1/16 ns\>\"", ",", "\"\<1/8 ns\>\"", ",", "\"\<1/4 ns\>\"", ",", 
      "\"\<1/2 ns\>\"", ",", "\"\<1 ns\>\"", ",", "\"\<2 ns\>\"", ",", 
      "\"\<4 ns\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"LegendPosition", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1.05", ",", 
      RowBox[{"-", "0.3"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"LegendShadow", "\[Rule]", "None"}]}], "]"}]], "Input",
 CellChangeTimes->{3.442868155130625*^9}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .52087 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.425137 0.401327 0.260436 0.401327 [
[ 0 0 0 0 ]
[ 1 .52087 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0124017 0.826464 0.50847 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00658566 0.00506586 0.362142 0.749334 [
[.12006 -0.0125 -9.1875 -16.375 ]
[.12006 -0.0125 9.1875 0 ]
[.24671 -0.0125 -9.1875 -16.375 ]
[.24671 -0.0125 9.1875 0 ]
[.37335 -0.0125 -9.1875 -16.375 ]
[.37335 -0.0125 9.1875 0 ]
[.5 -0.0125 -12.7813 -16.375 ]
[.5 -0.0125 12.7813 0 ]
[.62665 -0.0125 -12.7813 -16.375 ]
[.62665 -0.0125 12.7813 0 ]
[.75329 -0.0125 -12.7813 -16.375 ]
[.75329 -0.0125 12.7813 0 ]
[.87994 -0.0125 -12.7813 -16.375 ]
[.87994 -0.0125 12.7813 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -51.7188 -32.75 ]
[.5 -0.0125 51.7188 -16.375 ]
[-0.0125 .06241 -30.9375 -8.1875 ]
[-0.0125 .06241 0 8.1875 ]
[-0.0125 .21228 -30.9375 -8.1875 ]
[-0.0125 .21228 0 8.1875 ]
[-0.0125 .36214 -11.1875 -8.1875 ]
[-0.0125 .36214 0 8.1875 ]
[-0.0125 .51201 -21.9375 -8.1875 ]
[-0.0125 .51201 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -47.3125 -81.125 ]
[-0.01875 .30902 -30.9375 81.125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -105.25 0 ]
[.5 .63053 105.25 16.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.12006 0 m
.12006 .61803 L
s
.24671 0 m
.24671 .61803 L
s
.37335 0 m
.37335 .61803 L
s
.5 0 m
.5 .61803 L
s
.62665 0 m
.62665 .61803 L
s
.75329 0 m
.75329 .61803 L
s
.87994 0 m
.87994 .61803 L
s
0 .06241 m
1 .06241 L
s
0 .21228 m
1 .21228 L
s
0 .36214 m
1 .36214 L
s
0 .51201 m
1 .51201 L
s
0 g
.12006 0 m
.12006 .00625 L
s
gsave
.12006 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.24671 0 m
.24671 .00625 L
s
gsave
.24671 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.37335 0 m
.37335 .00625 L
s
gsave
.37335 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(75) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.62665 0 m
.62665 .00625 L
s
gsave
.62665 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(125) show
1.000 setlinewidth
grestore
.75329 0 m
.75329 .00625 L
s
gsave
.75329 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.87994 0 m
.87994 .00625 L
s
gsave
.87994 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(175) show
1.000 setlinewidth
grestore
.125 Mabswid
.14539 0 m
.14539 .00375 L
s
.17072 0 m
.17072 .00375 L
s
.19605 0 m
.19605 .00375 L
s
.22138 0 m
.22138 .00375 L
s
.27204 0 m
.27204 .00375 L
s
.29737 0 m
.29737 .00375 L
s
.3227 0 m
.3227 .00375 L
s
.34802 0 m
.34802 .00375 L
s
.39868 0 m
.39868 .00375 L
s
.42401 0 m
.42401 .00375 L
s
.44934 0 m
.44934 .00375 L
s
.47467 0 m
.47467 .00375 L
s
.52533 0 m
.52533 .00375 L
s
.55066 0 m
.55066 .00375 L
s
.57599 0 m
.57599 .00375 L
s
.60132 0 m
.60132 .00375 L
s
.65198 0 m
.65198 .00375 L
s
.6773 0 m
.6773 .00375 L
s
.70263 0 m
.70263 .00375 L
s
.72796 0 m
.72796 .00375 L
s
.77862 0 m
.77862 .00375 L
s
.80395 0 m
.80395 .00375 L
s
.82928 0 m
.82928 .00375 L
s
.85461 0 m
.85461 .00375 L
s
.09473 0 m
.09473 .00375 L
s
.0694 0 m
.0694 .00375 L
s
.04407 0 m
.04407 .00375 L
s
.01874 0 m
.01874 .00375 L
s
.90527 0 m
.90527 .00375 L
s
.9306 0 m
.9306 .00375 L
s
.95593 0 m
.95593 .00375 L
s
.98126 0 m
.98126 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -112.719 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Frequency) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
127.563 16.625 moveto
(H) show
131.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(MHz) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
158.250 16.625 moveto
(L) show
162.438 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .06241 m
.00625 .06241 L
s
gsave
-0.0125 .06241 -91.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .21228 m
.00625 .21228 L
s
gsave
-0.0125 .21228 -91.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .36214 m
.00625 .36214 L
s
gsave
-0.0125 .36214 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .51201 m
.00625 .51201 L
s
gsave
-0.0125 .51201 -82.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .09988 m
.00375 .09988 L
s
0 .13734 m
.00375 .13734 L
s
0 .17481 m
.00375 .17481 L
s
0 .24974 m
.00375 .24974 L
s
0 .28721 m
.00375 .28721 L
s
0 .32468 m
.00375 .32468 L
s
0 .39961 m
.00375 .39961 L
s
0 .43708 m
.00375 .43708 L
s
0 .47454 m
.00375 .47454 L
s
0 .02494 m
.00375 .02494 L
s
0 .54948 m
.00375 .54948 L
s
0 .58694 m
.00375 .58694 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -181.25 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
142.125 12.1875 translate
90 rotate
-142.125 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Relative) show
113.188 16.625 moveto
(Insertion) show
166.250 16.625 moveto
(Loss) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
197.063 16.625 moveto
(H) show
201.250 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dB) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
217.063 16.625 moveto
(L) show
221.250 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.12006 .61178 m
.12006 .61803 L
s
.24671 .61178 m
.24671 .61803 L
s
.37335 .61178 m
.37335 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.62665 .61178 m
.62665 .61803 L
s
.75329 .61178 m
.75329 .61803 L
s
.87994 .61178 m
.87994 .61803 L
s
.125 Mabswid
.14539 .61428 m
.14539 .61803 L
s
.17072 .61428 m
.17072 .61803 L
s
.19605 .61428 m
.19605 .61803 L
s
.22138 .61428 m
.22138 .61803 L
s
.27204 .61428 m
.27204 .61803 L
s
.29737 .61428 m
.29737 .61803 L
s
.3227 .61428 m
.3227 .61803 L
s
.34802 .61428 m
.34802 .61803 L
s
.39868 .61428 m
.39868 .61803 L
s
.42401 .61428 m
.42401 .61803 L
s
.44934 .61428 m
.44934 .61803 L
s
.47467 .61428 m
.47467 .61803 L
s
.52533 .61428 m
.52533 .61803 L
s
.55066 .61428 m
.55066 .61803 L
s
.57599 .61428 m
.57599 .61803 L
s
.60132 .61428 m
.60132 .61803 L
s
.65198 .61428 m
.65198 .61803 L
s
.6773 .61428 m
.6773 .61803 L
s
.70263 .61428 m
.70263 .61803 L
s
.72796 .61428 m
.72796 .61803 L
s
.77862 .61428 m
.77862 .61803 L
s
.80395 .61428 m
.80395 .61803 L
s
.82928 .61428 m
.82928 .61803 L
s
.85461 .61428 m
.85461 .61803 L
s
.09473 .61428 m
.09473 .61803 L
s
.0694 .61428 m
.0694 .61803 L
s
.04407 .61428 m
.04407 .61803 L
s
.01874 .61428 m
.01874 .61803 L
s
.90527 .61428 m
.90527 .61803 L
s
.9306 .61428 m
.9306 .61803 L
s
.95593 .61428 m
.95593 .61803 L
s
.98126 .61428 m
.98126 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06241 m
1 .06241 L
s
.99375 .21228 m
1 .21228 L
s
.99375 .36214 m
1 .36214 L
s
.99375 .51201 m
1 .51201 L
s
.125 Mabswid
.99625 .09988 m
1 .09988 L
s
.99625 .13734 m
1 .13734 L
s
.99625 .17481 m
1 .17481 L
s
.99625 .24974 m
1 .24974 L
s
.99625 .28721 m
1 .28721 L
s
.99625 .32468 m
1 .32468 L
s
.99625 .39961 m
1 .39961 L
s
.99625 .43708 m
1 .43708 L
s
.99625 .47454 m
1 .47454 L
s
.99625 .02494 m
1 .02494 L
s
.99625 .54948 m
1 .54948 L
s
.99625 .58694 m
1 .58694 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .36214 m
1 .36214 L
s
.12006 0 m
.12006 .61803 L
s
gsave
.5 .63053 -166.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Insertion) show
116.063 16.625 moveto
(Loss) show
146.875 16.625 moveto
(relative) show
192.000 16.625 moveto
(to) show
206.313 16.625 moveto
(Zero) show
236.500 16.625 moveto
(Delay) show
269.500 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 0 r
.007 w
.02381 .36215 m
.02499 .36193 L
.02605 .36176 L
.02729 .36162 L
.02846 .36155 L
.02954 .36167 L
.03053 .36184 L
.03162 .36203 L
.03279 .36221 L
.03396 .36227 L
.03506 .36203 L
.03756 .36134 L
.03821 .36118 L
.03891 .36103 L
.0402 .36101 L
.04145 .36107 L
.04262 .36118 L
.04752 .36196 L
.0501 .36241 L
.05151 .36262 L
.05283 .36278 L
.05398 .36288 L
.05521 .36288 L
.05592 .36287 L
.05659 .36286 L
.05784 .36283 L
.05898 .36283 L
.06004 .36295 L
.0612 .3631 L
.06244 .36324 L
.06372 .36335 L
.06491 .36327 L
.0656 .36317 L
.06633 .36306 L
.06763 .36285 L
.06829 .36275 L
.06899 .36265 L
.07026 .36265 L
.07104 .36267 L
.07177 .36269 L
.07242 .36271 L
.07314 .36272 L
.07432 .36269 L
.07556 .36253 L
.07779 .36214 L
.08038 .36162 L
.08284 .36116 L
.08349 .36107 L
.08419 .36098 L
.08496 .36094 L
Mistroke
.08567 .36093 L
.08637 .36094 L
.08703 .36095 L
.08825 .36102 L
.08896 .36107 L
.08971 .36115 L
.09105 .3613 L
.09407 .36166 L
.09473 .36169 L
.09543 .3617 L
.09619 .36171 L
.0969 .36171 L
.09817 .36174 L
.09889 .36177 L
.09957 .36183 L
.10083 .36206 L
.10198 .36229 L
.10333 .36257 L
.10458 .36282 L
.10565 .36297 L
.10679 .36311 L
.10806 .36324 L
.10921 .36331 L
.11042 .36334 L
.11172 .36333 L
.11295 .36327 L
.11408 .36319 L
.11642 .36286 L
.11771 .36266 L
.11893 .36247 L
.11962 .36238 L
.12037 .36233 L
.12168 .36225 L
.12426 .36215 L
.12649 .36196 L
.12758 .36187 L
.12858 .3618 L
.12963 .36175 L
.13076 .36175 L
.13194 .36178 L
.13317 .36187 L
.13439 .362 L
.13551 .36224 L
.13807 .36293 L
.14027 .36352 L
.1426 .36401 L
.14385 .36423 L
.14451 .36433 L
.14522 .36441 L
.14647 .36453 L
Mistroke
.14764 .36462 L
.15311 .36515 L
.15577 .36547 L
.15708 .36563 L
.15829 .36571 L
.15939 .36572 L
.16056 .36552 L
.16186 .36515 L
.16304 .36476 L
.16527 .36399 L
.16763 .36336 L
.16887 .36309 L
.16952 .36296 L
.17022 .36285 L
.17146 .36272 L
.17261 .36263 L
.17698 .3625 L
.17804 .36247 L
.17918 .36243 L
.18044 .3623 L
.18162 .36209 L
.18296 .36185 L
.1837 .36172 L
.18438 .36161 L
.18559 .36151 L
.18691 .3615 L
.18815 .36155 L
.18927 .36164 L
.19057 .3618 L
.1918 .36202 L
.19314 .36225 L
.19388 .36237 L
.19457 .36246 L
.19578 .36255 L
.19642 .36255 L
.19711 .36253 L
.19785 .36249 L
.19866 .36242 L
.19942 .36233 L
.20012 .36222 L
.20082 .36204 L
.20146 .36186 L
.20287 .36145 L
.20414 .36111 L
.20477 .36097 L
.20547 .36088 L
.20671 .36088 L
.20786 .36094 L
.20856 .361 L
.20922 .36107 L
Mistroke
.21046 .36121 L
.21181 .36135 L
.21324 .36149 L
.2144 .36159 L
.21568 .36165 L
.21683 .36164 L
.21792 .36162 L
.2192 .3616 L
.22037 .3616 L
.22101 .36162 L
.22171 .36166 L
.223 .36174 L
.22786 .36254 L
.22918 .36282 L
.23042 .36305 L
.23171 .36317 L
.23239 .36322 L
.23312 .36325 L
.23376 .36327 L
.23446 .36327 L
.23572 .36324 L
.23695 .36314 L
.23809 .36302 L
.23923 .36291 L
.24031 .36282 L
.24143 .36284 L
.24266 .3629 L
.24336 .36292 L
.24401 .36294 L
.24468 .36295 L
.24542 .36295 L
.24664 .36274 L
.24795 .36248 L
.24869 .36234 L
.24949 .36221 L
.25024 .3621 L
.25094 .36212 L
.25226 .36232 L
.25366 .36256 L
.25484 .36274 L
.25611 .36276 L
.25731 .36257 L
.25841 .36236 L
.25969 .36213 L
.26041 .36202 L
.26109 .36202 L
.26232 .36213 L
.26363 .36228 L
.26488 .36244 L
.26559 .36252 L
Mistroke
.26623 .36251 L
.26747 .36247 L
.26864 .36244 L
.26985 .36244 L
.27117 .36262 L
.27187 .36284 L
.27261 .36308 L
.27394 .3635 L
.27462 .36369 L
.27536 .36387 L
.27606 .36391 L
.2767 .36384 L
.27741 .36372 L
.27818 .36357 L
.27974 .3632 L
.28043 .36304 L
.28108 .36294 L
.28182 .36289 L
.2825 .36285 L
.28507 .36274 L
.28752 .3625 L
.28887 .36233 L
.29014 .36219 L
.29133 .3621 L
.29262 .36208 L
.29379 .36208 L
.29488 .3621 L
.29602 .36211 L
.29728 .3621 L
.29982 .36207 L
.30265 .36203 L
.30389 .36201 L
.3046 .36201 L
.30525 .362 L
.30642 .36199 L
.30767 .36197 L
.30836 .36197 L
.30901 .36197 L
.31022 .36201 L
.31087 .36206 L
.31156 .36218 L
.31279 .36245 L
.31414 .36275 L
.31488 .36289 L
.31559 .36301 L
.31683 .36303 L
.31797 .36292 L
.31904 .36277 L
.32021 .36256 L
.3253 .36162 L
Mistroke
.32644 .36142 L
.32768 .36121 L
.32885 .36105 L
.32993 .36096 L
.33119 .36094 L
.33183 .36106 L
.33252 .36122 L
.33375 .36152 L
.33487 .36178 L
.33601 .362 L
.33709 .3619 L
.33823 .36169 L
.33947 .36143 L
.34055 .36122 L
.3417 .36114 L
.34268 .36125 L
.34376 .36141 L
.3449 .3616 L
.34611 .3618 L
.34681 .36182 L
.34744 .36181 L
.34868 .36177 L
.34996 .36173 L
.35068 .36172 L
.35134 .36173 L
.35256 .36197 L
.35386 .36224 L
.35495 .36244 L
.35613 .36258 L
.35725 .36242 L
.35826 .36217 L
.35947 .36182 L
.36061 .36149 L
.36192 .36127 L
.36311 .36127 L
.36439 .36131 L
.36511 .36135 L
.36577 .36138 L
.36697 .36137 L
.36823 .36126 L
.3689 .36121 L
.36961 .36116 L
.37089 .36112 L
.37168 .36116 L
.37242 .36131 L
.37381 .36163 L
.37504 .36192 L
.37634 .36218 L
.37746 .36213 L
.37868 .36199 L
Mistroke
.38 .3618 L
.38072 .36171 L
.38141 .36164 L
.38205 .36168 L
.38275 .36177 L
.38397 .36196 L
.38521 .36216 L
.38652 .36233 L
.3872 .3623 L
.38795 .36223 L
.38927 .36206 L
.39051 .36187 L
.39169 .36169 L
.39234 .36163 L
.39304 .36158 L
.39428 .36149 L
.39679 .36134 L
.39789 .36125 L
.39911 .36117 L
.40016 .36111 L
.4013 .36106 L
.4025 .36104 L
.40362 .36105 L
.40494 .3611 L
.40617 .36119 L
.40687 .36126 L
.40751 .36136 L
.40895 .36163 L
.41456 .36251 L
.41943 .36334 L
.42061 .36356 L
.42189 .36375 L
.42262 .36376 L
.42328 .36375 L
.42459 .36368 L
.42586 .36353 L
.42704 .36335 L
.42833 .36305 L
.4297 .36272 L
.43102 .36241 L
.43225 .3622 L
.43336 .36214 L
.43456 .36213 L
.43567 .36214 L
.43689 .36216 L
.43816 .36218 L
.43935 .36219 L
.44046 .36219 L
.44148 .36218 L
.44265 .36213 L
Mistroke
.44376 .36206 L
.44859 .36158 L
.44976 .36145 L
.45103 .36134 L
.45175 .36128 L
.45242 .36129 L
.45372 .3614 L
.45503 .36152 L
.45577 .36156 L
.45646 .36157 L
.45719 .36155 L
.45786 .36137 L
.45935 .36088 L
.46054 .36043 L
.46182 .35997 L
.46256 .35978 L
.46323 .35968 L
.46455 .35952 L
.4694 .35884 L
.4706 .35862 L
.47186 .35841 L
.47259 .35833 L
.47325 .35831 L
.47454 .3583 L
.47571 .35832 L
.47698 .35836 L
.47817 .35837 L
.47927 .35836 L
.48031 .35834 L
.48145 .3583 L
.48264 .35821 L
.48375 .35805 L
.48624 .35766 L
.4875 .35748 L
.48821 .35743 L
.48888 .3574 L
.49177 .35729 L
.49314 .35725 L
.49445 .35719 L
.49566 .35709 L
.49635 .35702 L
.49699 .35693 L
.49812 .35665 L
.49932 .35625 L
.50064 .35577 L
.50137 .35552 L
.50205 .3553 L
.50324 .35502 L
.50456 .35484 L
.50584 .35476 L
Mistroke
.50655 .35475 L
.50721 .35476 L
.50791 .35484 L
.50868 .35498 L
.51007 .35528 L
.51138 .35557 L
.51209 .35571 L
.51277 .3558 L
.51395 .3558 L
.51526 .35573 L
.51645 .3556 L
.5177 .35541 L
.51877 .35517 L
.51993 .3549 L
.5212 .35463 L
.52189 .3545 L
.52254 .35439 L
.52382 .35438 L
.52497 .35444 L
.52604 .35453 L
.52722 .35465 L
.52837 .35475 L
.52961 .35484 L
.53076 .35489 L
.53182 .3549 L
.53288 .35488 L
.53388 .35476 L
.5365 .35433 L
.53895 .3539 L
.54116 .35358 L
.5424 .35345 L
.54355 .35338 L
.5447 .35337 L
.54578 .35339 L
.54696 .35344 L
.54822 .35355 L
.55059 .35387 L
.55123 .35395 L
.55192 .35403 L
.55316 .35409 L
.55446 .35396 L
.55591 .35376 L
.55716 .35357 L
.55782 .35348 L
.55851 .3534 L
.55982 .35331 L
.56103 .35326 L
.56216 .35328 L
.56339 .35338 L
.56793 .35444 L
Mistroke
.57033 .35516 L
.57153 .35546 L
.57222 .35559 L
.57286 .35568 L
.57403 .35558 L
.5751 .35536 L
.57625 .35509 L
.57751 .3548 L
.57865 .35467 L
.5797 .35471 L
.58071 .35479 L
.58179 .35489 L
.583 .35502 L
.58431 .35509 L
.58554 .35512 L
.58668 .35511 L
.58794 .35504 L
.58865 .35495 L
.58931 .35483 L
.59209 .35416 L
.59439 .35342 L
.59689 .35257 L
.59804 .35222 L
.59925 .35194 L
.60029 .35176 L
.60143 .35162 L
.60275 .35153 L
.60349 .35152 L
.60417 .35156 L
.60549 .35169 L
.60674 .35187 L
.61156 .35266 L
.61407 .35303 L
.61547 .35319 L
.61674 .3533 L
.61747 .35335 L
.61825 .35339 L
.61899 .35339 L
.61967 .35337 L
.6203 .35335 L
.621 .35332 L
.62239 .35326 L
.6237 .35323 L
.62492 .35332 L
.62619 .35341 L
.62687 .35344 L
.6276 .35346 L
.62835 .35345 L
.62913 .35333 L
.62981 .35319 L
Mistroke
.63054 .35301 L
.63197 .35264 L
.63326 .35229 L
.6339 .35216 L
.63459 .35205 L
.63584 .35188 L
.63859 .35157 L
.64355 .35091 L
.64477 .35069 L
.64607 .35047 L
.6473 .3503 L
.64843 .35022 L
.64969 .35033 L
.65088 .35054 L
.65359 .35113 L
.6547 .35133 L
.65588 .3515 L
.657 .35162 L
.65801 .35169 L
.65921 .35168 L
.6605 .35153 L
.66283 .35117 L
.66401 .35099 L
.66527 .35086 L
.66646 .35078 L
.66755 .35075 L
.66882 .35079 L
.66954 .35095 L
.6702 .35112 L
.67149 .35148 L
.67271 .35181 L
.67387 .35207 L
.67511 .35207 L
.67582 .35203 L
.6765 .35197 L
.67776 .35183 L
.6791 .35166 L
.68036 .35155 L
.68105 .3515 L
.68181 .35145 L
.68312 .3514 L
.68429 .35142 L
.68553 .35158 L
.68667 .35175 L
.68774 .35191 L
.68873 .35204 L
.68979 .35208 L
.69096 .35205 L
.69203 .35201 L
.69319 .35195 L
Mistroke
.69442 .3519 L
.69506 .35189 L
.69577 .35189 L
.69702 .3519 L
.6982 .35194 L
.69947 .35206 L
.70066 .3523 L
.70176 .35251 L
.70303 .35271 L
.70424 .35282 L
.70532 .35266 L
.70649 .35242 L
.70895 .35182 L
.71019 .3516 L
.71155 .35141 L
.71273 .35127 L
.714 .35114 L
.7152 .35108 L
.71629 .35104 L
.71737 .35098 L
.71854 .35087 L
.71964 .35067 L
.72067 .35034 L
.72315 .34941 L
.72583 .34833 L
.72706 .34789 L
.72836 .34754 L
.72947 .34739 L
.73069 .34762 L
.73209 .348 L
.73286 .34824 L
.73359 .34846 L
.73427 .34865 L
.735 .3487 L
.73629 .34868 L
.73757 .34863 L
.73827 .3486 L
.73893 .34857 L
.74009 .34858 L
.74137 .34868 L
.74254 .34884 L
.7438 .3491 L
.74499 .34953 L
.74607 .3501 L
.74737 .35084 L
.74875 .35159 L
.74992 .35213 L
.75121 .35251 L
.75185 .35265 L
.75254 .35276 L
Mistroke
.75377 .35286 L
.75452 .35285 L
.75522 .35267 L
.75655 .35224 L
.75771 .35182 L
.75895 .3514 L
.7596 .35122 L
.76031 .35122 L
.76157 .35131 L
.78009 .3531 L
.78263 .35365 L
.78386 .3539 L
.78499 .35409 L
.78618 .35421 L
.78745 .35431 L
.78812 .35434 L
.78884 .35437 L
.79016 .35438 L
.79127 .35437 L
.79249 .35434 L
.79377 .35428 L
.79496 .35421 L
.79599 .35418 L
.79708 .35414 L
.79828 .35405 L
.7994 .35394 L
.80012 .35382 L
.80081 .35362 L
.80209 .35324 L
.80342 .35286 L
.80464 .35258 L
.80576 .35254 L
.80695 .35265 L
.80814 .35282 L
.80944 .35302 L
.81016 .35312 L
.81085 .35315 L
.81214 .3532 L
.81286 .35321 L
.81352 .35323 L
.81503 .35325 L
.81633 .35325 L
.81756 .35327 L
.81883 .35332 L
.81951 .35335 L
.82024 .35341 L
.8215 .35357 L
.82264 .35374 L
.8252 .35423 L
.8276 .35483 L
Mistroke
.82865 .35507 L
.82981 .35529 L
.83107 .35533 L
.83176 .35531 L
.8324 .35528 L
.83309 .35524 L
.83375 .35522 L
.83451 .35519 L
.8352 .3552 L
.83646 .35544 L
.83763 .35573 L
.83901 .35609 L
.84028 .35641 L
.84093 .3565 L
.84161 .3566 L
.84305 .35678 L
.84565 .35708 L
.8505 .35784 L
.85343 .35847 L
.8562 .35907 L
.85741 .35931 L
.85868 .35952 L
.85935 .3596 L
.86009 .35968 L
.86138 .35968 L
.86262 .3596 L
.86375 .35951 L
.86499 .35941 L
.86629 .3594 L
.86743 .35945 L
.86849 .35951 L
.86965 .35957 L
.87089 .35959 L
.87221 .35954 L
.87363 .35947 L
.87429 .35944 L
.87498 .35941 L
.87622 .3594 L
.87742 .35944 L
.87853 .35949 L
.88106 .35967 L
.88985 .36036 L
.89448 .36089 L
.89561 .36102 L
.89682 .36112 L
.89816 .3612 L
.89941 .36126 L
.90007 .36129 L
.90079 .3613 L
.90154 .36129 L
Mistroke
.90224 .36128 L
.90294 .36126 L
.9036 .36124 L
.90483 .36122 L
.90599 .36124 L
.90725 .36135 L
.90985 .36162 L
.91235 .36189 L
.91361 .362 L
.91432 .36205 L
.91499 .36209 L
.91619 .36211 L
.91728 .36205 L
.91854 .36196 L
.91974 .36184 L
.92197 .36158 L
.92319 .36144 L
.92434 .36132 L
.92542 .36122 L
.92658 .36118 L
.92764 .3612 L
.92861 .36123 L
.93328 .36138 L
.93393 .3614 L
.93463 .36141 L
.9359 .36145 L
.93714 .36155 L
.93829 .36165 L
.93933 .36173 L
.94045 .36179 L
.94167 .36178 L
.94283 .36168 L
.94517 .36143 L
.94645 .36128 L
.94764 .36115 L
.94869 .36106 L
.94981 .36101 L
.95106 .36102 L
.95219 .36125 L
.95422 .36176 L
.95533 .36201 L
.95636 .36214 L
.95758 .36203 L
.95822 .36194 L
.95891 .36182 L
.96126 .36133 L
.96268 .36108 L
.96403 .36087 L
.96524 .36072 L
.96657 .36063 L
Mistroke
.96784 .36063 L
.96899 .36069 L
.96962 .36075 L
.97031 .36082 L
.97156 .36104 L
.97274 .36142 L
.97397 .36179 L
.97503 .36204 L
.97619 .3622 L
Mfstroke
.85 0 0 r
.02381 .35932 m
.02846 .35906 L
.03068 .35893 L
.03178 .35888 L
.03279 .35885 L
.03398 .35883 L
.03527 .35888 L
.03637 .35893 L
.03754 .359 L
.04262 .35935 L
.04496 .3596 L
.0462 .35975 L
.04751 .35991 L
.04878 .36003 L
.04993 .36004 L
.05108 .36002 L
.05217 .35999 L
.05282 .35997 L
.05351 .35996 L
.05475 .35999 L
.05543 .36004 L
.05608 .36008 L
.05754 .36018 L
.05875 .36025 L
.0599 .36031 L
.06054 .36033 L
.06123 .36034 L
.06244 .36034 L
.06368 .36031 L
.06439 .36025 L
.06505 .36017 L
.06782 .35975 L
.07042 .35936 L
.0728 .35907 L
.07507 .35885 L
.07746 .35868 L
.0801 .35844 L
.0825 .35816 L
.08315 .3581 L
.08385 .35803 L
.08514 .35798 L
.08585 .35796 L
.08661 .35796 L
.08725 .35796 L
.08796 .35797 L
.08923 .358 L
.08992 .35801 L
.09059 .35802 L
.09187 .35805 L
.09304 .35808 L
Mistroke
.09443 .35813 L
.09519 .35815 L
.09591 .35817 L
.09658 .3582 L
.0973 .35823 L
.09856 .35832 L
.09929 .3584 L
.10009 .35855 L
.1017 .3589 L
.1032 .35922 L
.10385 .35935 L
.10458 .35946 L
.1058 .35953 L
.1071 .35958 L
.10778 .35959 L
.10851 .3596 L
.10915 .35961 L
.10984 .35962 L
.1111 .35965 L
.11179 .35968 L
.11243 .35971 L
.11358 .35977 L
.11481 .35991 L
.11602 .36012 L
.11733 .36036 L
.11856 .36055 L
.1197 .36065 L
.12072 .36058 L
.12185 .36046 L
.12294 .36035 L
.12413 .36024 L
.12486 .36024 L
.12553 .36031 L
.12686 .36048 L
.12814 .36066 L
.12935 .3608 L
.13064 .36075 L
.13132 .3607 L
.13206 .36065 L
.13279 .36059 L
.13357 .36054 L
.13423 .3605 L
.13495 .36053 L
.1373 .36087 L
.13859 .36106 L
.1398 .36119 L
.1411 .36117 L
.14179 .36114 L
.14253 .3611 L
.14506 .36091 L
Mistroke
.15033 .36057 L
.15531 .36017 L
.16464 .35939 L
.17551 .35866 L
.17823 .35837 L
.18079 .35807 L
.1831 .35783 L
.18439 .35774 L
.18558 .35771 L
.18672 .35773 L
.18797 .35776 L
.18928 .35781 L
.19048 .35783 L
.19178 .3578 L
.1925 .35778 L
.19318 .35776 L
.19439 .3577 L
.1957 .3576 L
.20673 .3569 L
.2118 .35629 L
.21303 .35613 L
.21367 .35605 L
.21435 .35599 L
.21511 .35595 L
.21581 .35601 L
.21646 .35609 L
.21717 .3562 L
.21842 .35642 L
.21959 .35663 L
.22024 .35675 L
.22095 .3568 L
.22218 .35686 L
.22683 .35712 L
.22795 .35723 L
.22917 .35735 L
.23025 .35744 L
.2314 .3575 L
.2321 .35752 L
.23273 .35754 L
.23396 .35756 L
.23517 .35756 L
.2363 .35755 L
.23696 .35753 L
.23765 .35751 L
.23889 .35746 L
.23954 .35743 L
.24023 .35739 L
.24098 .35732 L
.24169 .35724 L
.24304 .35709 L
Mistroke
.24432 .35696 L
.24547 .35688 L
.24672 .35691 L
.24802 .35697 L
.24925 .35704 L
.24993 .35708 L
.25059 .35712 L
.25134 .35714 L
.25203 .35715 L
.25271 .35715 L
.25343 .35715 L
.25472 .35714 L
.25552 .35713 L
.25626 .35711 L
.25766 .35707 L
.26252 .35689 L
.26385 .35683 L
.26457 .35679 L
.26525 .35675 L
.26645 .35663 L
.26777 .35646 L
.26903 .35632 L
.26972 .35625 L
.27037 .35619 L
.27151 .35621 L
.27277 .35629 L
.27405 .35638 L
.27474 .35642 L
.27539 .35645 L
.27609 .35642 L
.27686 .35632 L
.27821 .35612 L
.2795 .35593 L
.28072 .35576 L
.28181 .35569 L
.283 .35565 L
.28429 .35567 L
.28494 .3557 L
.28566 .35575 L
.28692 .35597 L
.28811 .35622 L
.28926 .35645 L
.29051 .35665 L
.29169 .35664 L
.29278 .35653 L
.29384 .35639 L
.29498 .35625 L
.29606 .35615 L
.29705 .35617 L
.29824 .35623 L
Mistroke
.2995 .35632 L
.30171 .35654 L
.30666 .35709 L
.30789 .35725 L
.30853 .35733 L
.30922 .3574 L
.31047 .3575 L
.31163 .35747 L
.31275 .35735 L
.31379 .35721 L
.31492 .35705 L
.31616 .35689 L
.31741 .35685 L
.31872 .35682 L
.31994 .35679 L
.32106 .35675 L
.32238 .35665 L
.32379 .3565 L
.3251 .35632 L
.32633 .35609 L
.32856 .35545 L
.32978 .35512 L
.33092 .35488 L
.33189 .3549 L
.33293 .35503 L
.33408 .35521 L
.33514 .35535 L
.33636 .35541 L
.33701 .35527 L
.3377 .35509 L
.33895 .35473 L
.34012 .35438 L
.34116 .3541 L
.34229 .35403 L
.34353 .35402 L
.34468 .35405 L
.34584 .35409 L
.34711 .35405 L
.3483 .35397 L
.3494 .35391 L
.35069 .35386 L
.35134 .35385 L
.35205 .35396 L
.35331 .35417 L
.35446 .35432 L
.35562 .35439 L
.35672 .35421 L
.35789 .35365 L
.35916 .35296 L
.36027 .35236 L
Mistroke
.36145 .35182 L
.36256 .35176 L
.36357 .35179 L
.36486 .35191 L
.36557 .35199 L
.36623 .35207 L
.3674 .35212 L
.36869 .35211 L
.3694 .35209 L
.37008 .35206 L
.37136 .35197 L
.37207 .35188 L
.37273 .35177 L
.37422 .35149 L
.37905 .35025 L
.38037 .34989 L
.38109 .34972 L
.38177 .34959 L
.38296 .34947 L
.38426 .34938 L
.38551 .3493 L
.3867 .34921 L
.38776 .34906 L
.38891 .34887 L
.39133 .34846 L
.39265 .34824 L
.39389 .34806 L
.39506 .34791 L
.39613 .34782 L
.39731 .34778 L
.39859 .34782 L
.39965 .3479 L
.40081 .34802 L
.40293 .34834 L
.4085 .34957 L
.41374 .35063 L
.41845 .3513 L
.41974 .35151 L
.42044 .35161 L
.4211 .35168 L
.42226 .35173 L
.42353 .35166 L
.42476 .35149 L
.42545 .35135 L
.42609 .35119 L
.42727 .35079 L
.42851 .35017 L
.4307 .34902 L
.43193 .34845 L
.43305 .34822 L
Mistroke
.43434 .34806 L
.43556 .34797 L
.4379 .34784 L
.43923 .34775 L
.44046 .34765 L
.44115 .34758 L
.44181 .34751 L
.44256 .3474 L
.44325 .34728 L
.45345 .34578 L
.46423 .34414 L
.46885 .34336 L
.47006 .34307 L
.4707 .34293 L
.47139 .34279 L
.47264 .34262 L
.47379 .34261 L
.47449 .34263 L
.47514 .34265 L
.47592 .34269 L
.47663 .34274 L
.47788 .34278 L
.47853 .34277 L
.47922 .34276 L
.48048 .34275 L
.48164 .34277 L
.48292 .34285 L
.48364 .34294 L
.48429 .34303 L
.48544 .34318 L
.48666 .34331 L
.4877 .34336 L
.48885 .34329 L
.49008 .34317 L
.4914 .34301 L
.49379 .34277 L
.49494 .34267 L
.49619 .34255 L
.49738 .34241 L
.49848 .34218 L
.50276 .3413 L
.50394 .34127 L
.50505 .34127 L
.50633 .34128 L
.5075 .34129 L
.5086 .34123 L
.50961 .34115 L
.51073 .34103 L
.51191 .34088 L
.51304 .3407 L
Mistroke
.51411 .34047 L
.51652 .33993 L
.52158 .33913 L
.52668 .33826 L
.53217 .33713 L
.53683 .33555 L
.5381 .33516 L
.53947 .33485 L
.54075 .33464 L
.54192 .3345 L
.54262 .33445 L
.54326 .33446 L
.54397 .33451 L
.54472 .33458 L
.546 .33473 L
.54737 .33489 L
.54811 .33495 L
.54878 .33497 L
.5501 .33497 L
.55084 .33495 L
.55164 .3349 L
.5524 .33484 L
.5531 .33475 L
.55375 .33461 L
.55445 .33445 L
.55571 .33415 L
.55684 .33389 L
.55807 .33367 L
.55876 .33362 L
.55941 .3336 L
.56009 .3336 L
.56082 .33363 L
.5615 .33368 L
.56215 .33374 L
.56335 .33396 L
.57314 .33508 L
.57573 .33549 L
.57715 .33576 L
.57785 .33589 L
.57851 .33599 L
.57976 .33613 L
.58113 .33627 L
.58353 .33651 L
.58467 .33668 L
.5859 .33684 L
.58706 .33694 L
.58813 .33698 L
.58938 .33683 L
.5907 .33658 L
.59303 .33604 L
Mistroke
.59844 .3351 L
.60109 .33449 L
.60224 .33424 L
.6035 .33401 L
.60463 .33392 L
.60568 .33386 L
.60674 .3338 L
.60774 .33375 L
.60879 .33366 L
.60994 .33351 L
.61229 .33318 L
.61455 .33288 L
.61693 .33262 L
.61818 .33252 L
.61888 .33249 L
.61954 .33248 L
.6207 .33248 L
.62194 .33249 L
.62258 .3325 L
.62327 .33251 L
.62452 .33251 L
.62583 .3325 L
.62658 .33249 L
.62726 .33248 L
.62847 .33245 L
.62978 .33237 L
.63102 .3323 L
.63218 .33224 L
.63288 .33221 L
.63364 .3322 L
.63433 .33225 L
.63497 .3323 L
.63638 .33242 L
.63713 .33248 L
.63794 .33254 L
.63864 .33258 L
.63928 .33259 L
.64054 .33256 L
.64121 .33252 L
.64195 .33246 L
.64264 .33239 L
.64328 .3323 L
.64571 .33163 L
.64698 .33124 L
.64768 .33104 L
.64832 .33087 L
.64951 .33071 L
.65079 .33066 L
.65189 .33069 L
.65306 .33078 L
Mistroke
.6537 .33085 L
.65439 .33097 L
.65564 .33122 L
.65676 .33144 L
.65799 .33165 L
.6587 .33174 L
.65937 .3317 L
.66007 .33161 L
.66082 .33151 L
.66206 .33131 L
.66272 .33122 L
.66343 .33112 L
.66475 .33111 L
.66599 .33122 L
.66668 .33129 L
.6674 .33139 L
.6687 .33158 L
.67106 .33197 L
.67236 .33216 L
.67358 .33228 L
.67427 .3323 L
.67502 .33226 L
.67632 .33215 L
.67764 .33199 L
.67886 .33182 L
.6803 .33163 L
.68185 .33144 L
.6826 .33136 L
.68331 .33129 L
.68394 .33124 L
.68464 .33125 L
.68581 .33129 L
.68705 .33136 L
.68813 .33142 L
.68929 .33146 L
.69001 .33142 L
.69067 .33139 L
.69197 .33133 L
.69316 .33131 L
.69441 .33137 L
.69564 .33157 L
.69696 .33185 L
.69934 .3325 L
.70197 .33346 L
.70329 .33386 L
.70405 .33404 L
.70475 .33404 L
.7054 .334 L
.70608 .33393 L
.7073 .33376 L
Mistroke
.70861 .33357 L
.70935 .3335 L
.71004 .33355 L
.71256 .33379 L
.7138 .33391 L
.71494 .33397 L
.71559 .33398 L
.71628 .33397 L
.71698 .33395 L
.71774 .33392 L
.71906 .33381 L
.72029 .33367 L
.72173 .33344 L
.72305 .33316 L
.72377 .33298 L
.72456 .33273 L
.72601 .33211 L
.72737 .33154 L
.72866 .3311 L
.72982 .33095 L
.73107 .33115 L
.73172 .33129 L
.73243 .33145 L
.73313 .33162 L
.73387 .33179 L
.73457 .33188 L
.73521 .33181 L
.73645 .33164 L
.73761 .33147 L
.73884 .33134 L
.73948 .33131 L
.74018 .33143 L
.74143 .33171 L
.74385 .33249 L
.74613 .33327 L
.75109 .33499 L
.75245 .33542 L
.75319 .33562 L
.75389 .33578 L
.75455 .3359 L
.75526 .33588 L
.7565 .33578 L
.75779 .33565 L
.759 .33555 L
.76026 .33568 L
.76092 .33586 L
.76164 .33606 L
.76291 .33644 L
.76411 .33677 L
.76519 .33688 L
Mistroke
.76636 .33682 L
.76752 .3367 L
.76877 .33655 L
.76995 .33643 L
.77103 .33644 L
.77217 .33645 L
.77338 .33647 L
.77462 .33648 L
.77533 .33639 L
.77598 .3363 L
.77714 .33615 L
.77824 .33605 L
.77922 .33604 L
.78029 .33624 L
.78145 .33672 L
.78268 .33729 L
.78382 .33783 L
.78489 .33827 L
.78609 .33845 L
.78741 .33857 L
.78857 .33863 L
.78981 .33867 L
.79103 .33883 L
.79217 .33897 L
.79431 .33921 L
.79496 .33927 L
.79564 .33925 L
.79688 .33922 L
.79818 .3392 L
.79892 .33921 L
.79959 .33924 L
.80079 .33946 L
.80209 .33982 L
.80445 .34056 L
.80872 .34154 L
.81105 .34209 L
.81325 .3427 L
.8156 .34358 L
.81819 .34493 L
.82276 .34762 L
.82394 .34827 L
.82519 .34889 L
.82638 .34929 L
.82746 .34957 L
.82873 .34982 L
.82945 .34993 L
.83011 .35002 L
.83132 .35008 L
.8326 .35012 L
.83384 .35014 L
Mistroke
.83516 .35019 L
.8364 .35046 L
.83754 .35071 L
.83887 .35097 L
.83963 .35108 L
.84032 .35114 L
.8416 .35095 L
.84225 .35082 L
.84297 .35065 L
.8452 .35003 L
.84755 .34941 L
.84879 .34916 L
.84949 .34906 L
.85014 .349 L
.85128 .34914 L
.85251 .34941 L
.86148 .35101 L
.8717 .35261 L
.87708 .35419 L
.87839 .35451 L
.87979 .35479 L
.8806 .3549 L
.88134 .35488 L
.88208 .35484 L
.88279 .3548 L
.88404 .35472 L
.88475 .35469 L
.88538 .35468 L
.88662 .35498 L
.88779 .35535 L
.88907 .35574 L
.88977 .35592 L
.89042 .35605 L
.89112 .35602 L
.8919 .35587 L
.89326 .35551 L
.89441 .35515 L
.89565 .35477 L
.89683 .35463 L
.89792 .35455 L
.89919 .3545 L
.89983 .35448 L
.90054 .35446 L
.90177 .35441 L
.90293 .35436 L
.9041 .35431 L
.90536 .35424 L
.90762 .35406 L
.90901 .35391 L
.91031 .35373 L
Mistroke
.91149 .35345 L
.91276 .35308 L
.91411 .35272 L
.91538 .35248 L
.91669 .35256 L
.91739 .35272 L
.91815 .35292 L
.91948 .35331 L
.92074 .35367 L
.92187 .35379 L
.92311 .35383 L
.92437 .35382 L
.92555 .35375 L
.92661 .35358 L
.92776 .35334 L
.92902 .35311 L
.92965 .35303 L
.93034 .35298 L
.93157 .35317 L
.93271 .35365 L
.93492 .35471 L
.93601 .35521 L
.93701 .35546 L
.93817 .35566 L
.93942 .35577 L
.94049 .3558 L
.94162 .3557 L
.97619 .35285 L
Mfstroke
.7 0 0 r
.02381 .36045 m
.03279 .35973 L
.04262 .35915 L
.04384 .35885 L
.04453 .35877 L
.04517 .35871 L
.04634 .35863 L
.04758 .35859 L
.0489 .35859 L
.04965 .35859 L
.05035 .35861 L
.05157 .35865 L
.05288 .35871 L
.05528 .3589 L
.0566 .35903 L
.05784 .35913 L
.059 .35921 L
.06026 .35918 L
.0614 .35914 L
.06244 .35909 L
.06369 .35904 L
.0644 .35905 L
.06507 .35908 L
.06649 .35916 L
.06719 .35919 L
.06784 .35922 L
.06855 .35924 L
.06932 .35924 L
.06998 .35919 L
.07068 .35914 L
.07373 .35887 L
.08445 .35777 L
.08561 .35773 L
.08669 .35773 L
.08782 .35773 L
.08905 .35772 L
.09031 .35754 L
.09164 .35732 L
.09278 .35715 L
.09402 .35701 L
.09478 .35704 L
.09549 .35711 L
.09687 .3573 L
.09811 .35746 L
.09881 .35753 L
.09947 .35756 L
.10066 .35744 L
.10195 .35726 L
.10458 .35679 L
.10713 .35642 L
Mistroke
.10852 .35623 L
.10984 .35609 L
.11107 .35599 L
.11239 .35591 L
.1136 .35586 L
.11471 .35583 L
.11605 .35585 L
.11681 .35585 L
.11749 .35586 L
.11813 .35585 L
.11882 .35584 L
.12008 .35571 L
.12077 .35559 L
.12149 .35546 L
.12279 .35523 L
.12347 .35512 L
.1242 .35501 L
.125 .35497 L
.12575 .35498 L
.12702 .35504 L
.1282 .35514 L
.12949 .35529 L
.13087 .35549 L
.1322 .3557 L
.13364 .35591 L
.1343 .356 L
.135 .35607 L
.13625 .35616 L
.13749 .35622 L
.13865 .35626 L
.14003 .35631 L
.14129 .35638 L
.14242 .35643 L
.14349 .35645 L
.14462 .35644 L
.14586 .3563 L
.14818 .35599 L
.14949 .35583 L
.15069 .35581 L
.15175 .35584 L
.15291 .35589 L
.15411 .35594 L
.15524 .35598 L
.15589 .35599 L
.1566 .356 L
.15783 .35598 L
.15854 .35596 L
.15928 .35592 L
.15991 .35587 L
.16061 .35577 L
Mistroke
.16319 .35532 L
.16561 .3548 L
.1669 .3545 L
.16759 .35435 L
.16832 .35422 L
.16902 .35411 L
.16965 .35403 L
.17089 .35412 L
.17209 .35429 L
.17338 .35449 L
.1746 .35466 L
.17573 .35462 L
.17703 .35446 L
.17825 .35427 L
.1797 .35401 L
.18102 .35384 L
.18372 .35357 L
.18661 .35329 L
.18773 .35319 L
.18891 .3531 L
.1902 .35305 L
.19139 .35308 L
.19242 .35311 L
.19353 .35313 L
.19474 .35312 L
.19587 .353 L
.19713 .35278 L
.19832 .35255 L
.1994 .35234 L
.20055 .35215 L
.20183 .35201 L
.20302 .3519 L
.20571 .35171 L
.20699 .35162 L
.2077 .35159 L
.20836 .35156 L
.20964 .35154 L
.21084 .35161 L
.21227 .35176 L
.21378 .35193 L
.21451 .35201 L
.2152 .35206 L
.21649 .35202 L
.21769 .35195 L
.21879 .35187 L
.22127 .3517 L
.22647 .35142 L
.22763 .35131 L
.2289 .3512 L
.23009 .35113 L
Mistroke
.23119 .3512 L
.23248 .35134 L
.23318 .3514 L
.23384 .35145 L
.23498 .35147 L
.23624 .35121 L
.24535 .34962 L
.2478 .34925 L
.24915 .34902 L
.25042 .34884 L
.25114 .34883 L
.25192 .34886 L
.25257 .34888 L
.25329 .3489 L
.25396 .34891 L
.25467 .3489 L
.25595 .34874 L
.25727 .34832 L
.25847 .34789 L
.25976 .34744 L
.26049 .34721 L
.26116 .34711 L
.26237 .347 L
.26366 .34696 L
.26479 .34695 L
.26603 .34694 L
.26731 .34689 L
.26795 .34688 L
.26865 .34687 L
.26989 .34687 L
.27105 .34693 L
.27251 .34711 L
.27389 .34727 L
.27513 .34738 L
.27582 .3474 L
.27647 .34733 L
.27756 .34718 L
.27877 .34697 L
.28121 .34651 L
.28247 .34632 L
.28382 .34613 L
.28627 .34587 L
.28742 .34583 L
.28867 .34579 L
.28984 .34574 L
.29092 .34565 L
.29219 .34539 L
.29352 .34509 L
.29466 .34483 L
.29588 .34457 L
Mistroke
.29703 .3444 L
.29808 .34428 L
.29913 .34419 L
.30013 .34413 L
.30129 .3441 L
.30236 .34414 L
.30362 .34419 L
.30479 .34423 L
.30592 .34425 L
.30713 .34417 L
.30778 .34411 L
.30847 .34404 L
.3097 .34388 L
.31219 .34345 L
.31492 .34291 L
.32596 .33981 L
.33637 .33772 L
.34605 .33607 L
.34722 .33593 L
.34833 .3359 L
.3496 .33592 L
.35077 .33597 L
.35306 .33615 L
.35406 .33621 L
.35517 .33626 L
.35624 .33626 L
.35737 .33613 L
.35861 .33591 L
.35977 .33565 L
.36482 .33419 L
.36991 .33291 L
.3754 .33103 L
.38514 .32673 L
.38795 .32553 L
.38932 .32499 L
.39057 .32459 L
.39189 .32431 L
.39261 .32427 L
.3933 .32427 L
.39404 .32431 L
.39473 .32438 L
.39549 .32448 L
.39629 .32461 L
.39883 .32517 L
.40023 .32551 L
.40093 .32568 L
.40157 .32584 L
.4028 .32598 L
.40415 .32612 L
.4053 .32626 L
Mistroke
.40652 .32648 L
.40776 .32692 L
.40911 .32753 L
.41155 .32881 L
.41611 .3313 L
.41879 .3325 L
.42025 .33303 L
.42096 .33324 L
.42162 .33341 L
.42278 .33364 L
.42403 .33378 L
.42468 .33382 L
.42539 .33384 L
.42668 .33381 L
.4279 .33369 L
.42901 .33353 L
.43153 .33305 L
.43389 .33263 L
.43608 .33213 L
.43725 .33178 L
.4385 .33131 L
.44114 .32999 L
.44257 .32898 L
.44392 .32778 L
.44646 .32545 L
.44901 .32357 L
.4517 .32204 L
.45401 .32109 L
.45654 .32015 L
.45922 .31878 L
.46064 .31801 L
.46142 .31761 L
.46215 .31726 L
.46284 .31703 L
.4636 .31681 L
.46491 .3165 L
.46747 .31601 L
.47005 .31544 L
.47145 .31517 L
.47277 .31499 L
.47389 .31491 L
.47509 .31484 L
.47577 .3148 L
.47642 .31475 L
.47763 .3146 L
.47876 .31438 L
.47995 .31408 L
.48209 .31342 L
.48327 .3129 L
.48439 .31237 L
Mistroke
.48692 .31118 L
.48821 .31076 L
.48894 .31058 L
.48961 .31044 L
.49085 .31023 L
.49217 .31008 L
.49347 .31005 L
.4947 .31006 L
.49579 .31006 L
.49698 .31001 L
.49829 .30973 L
.49903 .30947 L
.49972 .30922 L
.50124 .30868 L
.5019 .30846 L
.50262 .30826 L
.50391 .30814 L
.50513 .30813 L
.5058 .30815 L
.50652 .3082 L
.50781 .30838 L
.51019 .30898 L
.51139 .30922 L
.5127 .3093 L
.51382 .30891 L
.51501 .30839 L
.51614 .30784 L
.51717 .30734 L
.51848 .30693 L
.51916 .3068 L
.51989 .30669 L
.52111 .30654 L
.52246 .30641 L
.52727 .30584 L
.52944 .30574 L
.53063 .30569 L
.53175 .30561 L
.53239 .30554 L
.53308 .30539 L
.53429 .30497 L
.53541 .30455 L
.53664 .30413 L
.53781 .30379 L
.53889 .3038 L
.54004 .30389 L
.54128 .30403 L
.54242 .30416 L
.54351 .30414 L
.54448 .30404 L
.54554 .30391 L
Mistroke
.54686 .30375 L
.5481 .30363 L
.54939 .30365 L
.55008 .30367 L
.55081 .30369 L
.55205 .30372 L
.55336 .30366 L
.55447 .30348 L
.55569 .3033 L
.55691 .30315 L
.55802 .30308 L
.55929 .30327 L
.5605 .30353 L
.56263 .30408 L
.56497 .30458 L
.56619 .30479 L
.56751 .30499 L
.56823 .30506 L
.56889 .30509 L
.57019 .30512 L
.57137 .30511 L
.57266 .30509 L
.57387 .30509 L
.575 .3051 L
.57568 .3051 L
.57642 .30509 L
.57712 .30507 L
.57776 .30505 L
.57897 .30498 L
.58026 .30486 L
.58093 .30478 L
.58164 .30466 L
.58293 .30439 L
.58372 .30413 L
.58446 .30384 L
.58586 .30323 L
.59555 .29889 L
.60085 .29702 L
.60345 .29598 L
.60583 .2953 L
.61005 .29437 L
.6146 .29346 L
.61721 .29281 L
.61967 .29229 L
.62427 .29157 L
.62655 .29125 L
.62784 .29112 L
.62903 .29104 L
.63021 .29102 L
.6315 .29104 L
Mistroke
.63215 .29106 L
.63285 .2911 L
.63411 .2912 L
.63623 .29145 L
.63739 .29159 L
.63849 .29172 L
.63966 .29179 L
.64096 .29184 L
.64206 .29186 L
.64325 .29188 L
.64392 .29188 L
.64466 .29189 L
.64538 .29189 L
.64615 .29189 L
.64687 .2919 L
.64753 .2919 L
.64881 .29193 L
.65011 .29198 L
.65152 .29205 L
.65217 .2921 L
.65286 .29215 L
.65409 .29228 L
.65635 .29261 L
.6576 .29278 L
.65879 .2929 L
.65946 .29288 L
.66019 .29285 L
.66147 .29277 L
.66268 .29268 L
.66397 .2926 L
.66461 .29259 L
.6653 .29259 L
.66653 .29261 L
.66722 .29265 L
.66796 .2927 L
.66866 .29277 L
.6693 .29288 L
.67187 .29349 L
.67431 .29409 L
.67664 .2945 L
.6788 .29484 L
.68368 .29557 L
.68622 .29579 L
.6875 .29592 L
.68822 .29603 L
.68889 .29614 L
.68964 .29638 L
.69031 .29663 L
.69182 .29724 L
.69322 .29777 L
Mistroke
.69451 .29813 L
.69573 .29826 L
.69702 .29834 L
.69973 .29854 L
.70095 .29877 L
.70211 .29896 L
.70275 .29904 L
.70344 .29911 L
.70466 .29903 L
.70582 .29872 L
.70705 .29837 L
.70811 .29811 L
.70927 .29795 L
.71034 .29825 L
.71149 .29866 L
.71257 .29907 L
.71357 .29944 L
.71476 .29969 L
.71606 .29969 L
.71732 .29959 L
.71803 .2995 L
.71868 .2994 L
.72095 .29892 L
.72336 .29838 L
.72462 .29816 L
.72533 .29808 L
.726 .29803 L
.72718 .29798 L
.72844 .29801 L
.72915 .29807 L
.72992 .29826 L
.73133 .29871 L
.73271 .29914 L
.73396 .29941 L
.73526 .29922 L
.73648 .29875 L
.73787 .29818 L
.73915 .29772 L
.74028 .29765 L
.74147 .2978 L
.74267 .2981 L
.74398 .2986 L
.74528 .29932 L
.74649 .30013 L
.74922 .3021 L
.75419 .30465 L
.7635 .3105 L
.78442 .3274 L
.80309 .33852 L
.80821 .341 L
Mistroke
.81372 .34327 L
.81893 .34488 L
.8237 .34593 L
.82844 .34733 L
.83105 .3482 L
.83351 .34894 L
.83462 .34933 L
.8358 .3499 L
.8371 .3507 L
.83829 .35144 L
.83929 .35205 L
.84036 .35263 L
.84153 .35297 L
.84263 .35325 L
.84392 .35357 L
.84463 .35376 L
.84529 .35396 L
.84608 .35436 L
.84679 .35475 L
.84818 .35557 L
.85093 .35725 L
.85345 .35865 L
.85465 .35924 L
.85577 .35968 L
.85693 .36001 L
.8582 .36029 L
.8595 .3605 L
.86068 .36063 L
.86134 .36066 L
.86205 .3607 L
.86334 .36076 L
.86456 .36086 L
.86568 .36105 L
.86697 .3615 L
.86821 .36199 L
.87277 .36374 L
.87816 .36532 L
.88316 .36727 L
.88436 .36782 L
.88566 .36837 L
.88689 .36871 L
.88802 .36896 L
.88935 .36917 L
.89001 .36925 L
.89074 .3693 L
.89202 .36931 L
.89321 .36927 L
.89451 .36919 L
.8952 .36915 L
.89593 .36912 L
Mistroke
.89657 .36911 L
.89727 .36911 L
.89851 .36912 L
.89924 .36912 L
.90004 .36914 L
.90079 .36915 L
.90148 .36918 L
.90419 .36928 L
.90889 .36892 L
.91001 .36878 L
.9112 .36868 L
.91221 .36864 L
.91333 .36863 L
.9146 .36866 L
.91578 .36872 L
.91707 .36882 L
.91779 .36889 L
.91845 .36897 L
.92083 .36937 L
.9231 .36989 L
.92439 .37028 L
.92576 .37079 L
.92822 .37205 L
.93382 .37576 L
.94379 .38323 L
.95181 .38768 L
.96048 .39143 L
.97619 .40028 L
Mfstroke
.55 0 0 r
.02381 .35777 m
.02605 .35733 L
.02846 .35693 L
.03279 .3564 L
.03543 .3561 L
.03673 .35595 L
.03793 .35583 L
.03902 .35574 L
.04018 .35569 L
.04134 .35566 L
.04262 .35564 L
.04516 .35555 L
.0465 .35549 L
.04725 .35546 L
.04793 .35545 L
.04857 .35544 L
.04927 .35545 L
.05054 .35553 L
.0517 .35562 L
.05297 .35572 L
.05421 .35579 L
.05537 .35583 L
.05659 .35583 L
.05791 .3558 L
.05912 .35573 L
.06028 .35558 L
.06244 .35523 L
.07293 .35362 L
.07554 .35313 L
.07833 .35256 L
.07978 .35215 L
.08138 .35159 L
.08275 .35112 L
.0835 .35089 L
.0842 .35069 L
.08546 .35051 L
.08613 .35044 L
.08684 .35037 L
.08811 .35029 L
.08926 .35024 L
.09471 .34994 L
.09698 .35002 L
.09825 .35005 L
.09941 .35005 L
.10007 .34999 L
.10078 .34992 L
.10208 .34977 L
.10339 .34961 L
.10458 .34951 L
.1058 .34947 L
Mistroke
.1071 .34946 L
.1083 .34946 L
.10943 .34948 L
.11071 .34952 L
.1119 .34954 L
.11319 .34953 L
.11385 .34951 L
.11456 .34944 L
.11577 .34918 L
.11686 .34891 L
.11804 .34861 L
.11932 .34829 L
.12051 .34812 L
.12161 .34801 L
.12376 .34782 L
.12608 .34757 L
.12729 .34743 L
.12856 .34733 L
.12925 .3473 L
.12999 .34734 L
.1313 .3475 L
.13261 .34769 L
.13386 .34788 L
.13453 .34797 L
.13526 .348 L
.13654 .34801 L
.13727 .34801 L
.13803 .348 L
.13869 .34801 L
.13941 .34801 L
.14069 .34816 L
.14207 .34835 L
.14337 .3485 L
.14456 .34858 L
.14574 .34844 L
.14684 .34825 L
.14815 .348 L
.14936 .34778 L
.15055 .34775 L
.15181 .34781 L
.15308 .34785 L
.15379 .34785 L
.15446 .34781 L
.15565 .3475 L
.15678 .34707 L
.15889 .34611 L
.16362 .34404 L
.16614 .34309 L
.16751 .34265 L
.1688 .34231 L
Mistroke
.1699 .34208 L
.17107 .34205 L
.17238 .34207 L
.17358 .34208 L
.17424 .34207 L
.17495 .34203 L
.17622 .34168 L
.17771 .34121 L
.17911 .34077 L
.17976 .34058 L
.18044 .34045 L
.18119 .34035 L
.18187 .34028 L
.18307 .34019 L
.18437 .34016 L
.18568 .3402 L
.18689 .34029 L
.18819 .34038 L
.18893 .34042 L
.18962 .34045 L
.19078 .34041 L
.19203 .34027 L
.19268 .34017 L
.19337 .34005 L
.19459 .33976 L
.1957 .33939 L
.19689 .3389 L
.19904 .33797 L
.20035 .33746 L
.20159 .33712 L
.2039 .33665 L
.2052 .33645 L
.20643 .33634 L
.20785 .33624 L
.20915 .33615 L
.21037 .33603 L
.2115 .33584 L
.21406 .33532 L
.21919 .33422 L
.22482 .33297 L
.24485 .32761 L
.26331 .32243 L
.30251 .31018 L
.34416 .29828 L
.36508 .2901 L
.3843 .28224 L
.39403 .27741 L
.39878 .27541 L
.40085 .27467 L
.4031 .274 L
Mistroke
.40432 .27373 L
.40545 .27355 L
.40653 .27346 L
.40767 .2735 L
.40887 .27367 L
.41 .27391 L
.41123 .27427 L
.41256 .2748 L
.41516 .27607 L
.41793 .27739 L
.41928 .27791 L
.42055 .2783 L
.42169 .27855 L
.42292 .27857 L
.42414 .27845 L
.42483 .27834 L
.42548 .27821 L
.42818 .27757 L
.43052 .2769 L
.43302 .27591 L
.43598 .27432 L
.43879 .27224 L
.44405 .26731 L
.45379 .25968 L
.46413 .25358 L
.47359 .24958 L
.48404 .24586 L
.49301 .24159 L
.4979 .2399 L
.50028 .23887 L
.50132 .23845 L
.50245 .23803 L
.50365 .23774 L
.50478 .23751 L
.50727 .23712 L
.51254 .23624 L
.51694 .23518 L
.51928 .23461 L
.52057 .23432 L
.52179 .23407 L
.52247 .23395 L
.52321 .23386 L
.52451 .23376 L
.52585 .23367 L
.52706 .23359 L
.52778 .23352 L
.52846 .23342 L
.52995 .23316 L
.53264 .23263 L
.53498 .23203 L
Mistroke
.53626 .23175 L
.53745 .23157 L
.53874 .23163 L
.53942 .23173 L
.54015 .23186 L
.54144 .23212 L
.54264 .23236 L
.54387 .23243 L
.54451 .23243 L
.54521 .23243 L
.54591 .23243 L
.54664 .23242 L
.54794 .23242 L
.54915 .23256 L
.55028 .23269 L
.55151 .23282 L
.55215 .23287 L
.55284 .23292 L
.55359 .23289 L
.55428 .23285 L
.55565 .23272 L
.55688 .23258 L
.5582 .23243 L
.55893 .23238 L
.5596 .23233 L
.56092 .23225 L
.56166 .23221 L
.56246 .23218 L
.56321 .23216 L
.56391 .23217 L
.56506 .23218 L
.5663 .23221 L
.56747 .23223 L
.56855 .23222 L
.56974 .23219 L
.57104 .23215 L
.5724 .23209 L
.57367 .232 L
.5749 .23191 L
.57556 .23186 L
.57625 .23182 L
.57751 .23176 L
.57868 .23175 L
.57937 .23178 L
.58002 .23182 L
.58073 .23187 L
.58149 .23196 L
.58217 .23205 L
.58282 .23215 L
.58404 .23245 L
Mistroke
.58529 .23283 L
.58663 .23322 L
.58791 .23353 L
.58907 .23358 L
.59013 .23352 L
.59129 .2334 L
.59363 .23318 L
.59485 .23324 L
.59617 .2333 L
.59741 .23333 L
.59857 .2333 L
.59921 .23319 L
.59991 .23307 L
.60133 .2328 L
.60263 .23259 L
.60386 .2325 L
.60502 .23255 L
.60624 .23265 L
.60843 .2329 L
.61079 .23309 L
.61337 .23329 L
.61763 .23356 L
.61987 .23366 L
.6211 .23372 L
.62224 .23379 L
.62355 .23389 L
.62425 .234 L
.625 .23413 L
.62753 .23457 L
.62817 .23467 L
.62887 .23474 L
.63014 .2348 L
.63138 .23484 L
.63252 .23487 L
.63375 .23492 L
.6349 .23506 L
.63705 .23532 L
.63825 .23545 L
.63936 .23548 L
.64058 .23545 L
.64186 .23545 L
.64317 .23551 L
.64436 .23568 L
.64502 .23584 L
.64573 .23604 L
.64703 .23649 L
.64954 .23772 L
.65186 .23925 L
.66281 .24498 L
.70214 .26469 L
Mistroke
.72188 .27616 L
.73052 .27946 L
.73287 .28108 L
.73402 .28181 L
.73508 .28218 L
.73631 .2824 L
.73763 .28265 L
.73876 .28294 L
.73995 .28358 L
.74122 .28469 L
.7424 .28586 L
.7451 .2887 L
.74989 .2933 L
.75934 .30176 L
.76941 .3138 L
.78021 .3293 L
.80001 .35672 L
.81045 .37206 L
.82155 .38711 L
.83137 .39749 L
.84223 .40648 L
.86137 .41956 L
.87078 .42475 L
.8807 .43003 L
.88321 .43154 L
.88459 .43227 L
.88589 .43282 L
.88663 .43304 L
.88743 .43324 L
.8881 .43336 L
.88883 .43347 L
.88952 .43355 L
.89026 .4336 L
.89157 .43362 L
.89287 .43357 L
.89406 .43345 L
.89471 .43336 L
.89542 .43324 L
.89672 .43292 L
.89795 .43258 L
.89924 .43222 L
.90034 .43193 L
.90155 .43177 L
.90219 .43174 L
.90287 .43171 L
.90411 .43167 L
.90485 .43165 L
.90555 .43162 L
.90687 .43145 L
.90927 .43103 L
Mistroke
.91188 .43052 L
.9131 .43029 L
.91424 .43011 L
.91543 .42998 L
.91674 .42996 L
.91787 .43004 L
.91891 .43016 L
.92005 .43034 L
.92124 .43056 L
.92609 .43163 L
.92737 .43175 L
.92804 .43182 L
.92875 .43191 L
.93006 .43215 L
.93126 .43251 L
.932 .43286 L
.93268 .43323 L
.93424 .43419 L
.93694 .4362 L
.94222 .44044 L
.97619 .46477 L
Mfstroke
.4 0 0 r
.02381 .35586 m
.03279 .35352 L
.03793 .35214 L
.04262 .35114 L
.04758 .35036 L
.05288 .3497 L
.05752 .34922 L
.06006 .34902 L
.06131 .34894 L
.06244 .34885 L
.06368 .34872 L
.06437 .3486 L
.06501 .34844 L
.06785 .34769 L
.07026 .34714 L
.07283 .34667 L
.07359 .3465 L
.0743 .3463 L
.07563 .34579 L
.07822 .34465 L
.0841 .34198 L
.08889 .34015 L
.0915 .339 L
.09278 .33846 L
.09394 .33802 L
.09522 .33769 L
.09592 .33756 L
.09658 .33745 L
.09948 .3371 L
.10458 .33649 L
.10698 .33635 L
.10823 .33628 L
.10956 .33619 L
.11072 .33609 L
.112 .33595 L
.11317 .33579 L
.11423 .33561 L
.11545 .33533 L
.11676 .33499 L
.11911 .33426 L
.12449 .33223 L
.14291 .3269 L
.18289 .31069 L
.22136 .29294 L
.26228 .26946 L
.30168 .24552 L
.33957 .22337 L
.37991 .20064 L
.41873 .18408 L
.41995 .18424 L
Mistroke
.42126 .18427 L
.4225 .18401 L
.42364 .18351 L
.42638 .18197 L
.42886 .18069 L
.43165 .17932 L
.43459 .17794 L
.43582 .17724 L
.43713 .17632 L
.43788 .17558 L
.43856 .17486 L
.43991 .17335 L
.45035 .16235 L
.45495 .1585 L
.45738 .15672 L
.46001 .15458 L
.46123 .15367 L
.46251 .15288 L
.4636 .15243 L
.4648 .15203 L
.46929 .15055 L
.47913 .14812 L
.48434 .14649 L
.4899 .14411 L
.49111 .14334 L
.49241 .14254 L
.49364 .14201 L
.49476 .14158 L
.49721 .1408 L
.4999 .13998 L
.50122 .13968 L
.50196 .13956 L
.50265 .1395 L
.50391 .13958 L
.50455 .13966 L
.50525 .13976 L
.51017 .14051 L
.52129 .14248 L
.53169 .1449 L
.53413 .14545 L
.53548 .14566 L
.53674 .14589 L
.53793 .14616 L
.53921 .14667 L
.54145 .14771 L
.54614 .14985 L
.54881 .1514 L
.55127 .15323 L
.55619 .15588 L
.5588 .15713 L
Mistroke
.56161 .15895 L
.56404 .16106 L
.56625 .16342 L
.57059 .16749 L
.58011 .1757 L
.61984 .21129 L
.65805 .25931 L
.69872 .32408 L
.73787 .39264 L
.77947 .48712 L
.80035 .53489 L
.80951 .5531 L
.81955 .57057 L
.82861 .58427 L
.8336 .5904 L
.83832 .59508 L
.84088 .59708 L
.84234 .59788 L
.84368 .59853 L
.84856 .6011 L
.84971 .60168 L
.85096 .60223 L
.85205 .60263 L
.8532 .60296 L
.85442 .60321 L
.85554 .60332 L
.85678 .60324 L
.85748 .60315 L
.85813 .60303 L
.8594 .60271 L
.86076 .60228 L
.86318 .60132 L
.86866 .59929 L
.87339 .59706 L
.8786 .59375 L
.88323 .59077 L
.88578 .58891 L
.88821 .58655 L
.8929 .58072 L
.89719 .57476 L
.90681 .5629 L
.90935 .56 L
.91209 .55725 L
.91335 .55618 L
.91468 .55517 L
.91592 .55438 L
.91705 .55389 L
.9182 .55348 L
.91944 .55312 L
.92166 .55247 L
Mistroke
.92408 .55164 L
.92536 .55126 L
.92671 .55095 L
.92782 .55078 L
.92905 .55062 L
.93016 .55052 L
.93121 .55044 L
.93226 .55036 L
.93325 .55031 L
.9344 .55029 L
.93546 .55031 L
.9367 .55049 L
.9374 .55066 L
.93804 .55081 L
.9392 .55107 L
.94048 .55124 L
.94162 .55112 L
.94269 .55073 L
.94504 .54967 L
.94635 .54912 L
.94709 .54897 L
.94778 .54884 L
.94901 .54862 L
.94967 .54849 L
.95038 .54834 L
.9516 .54799 L
.95274 .54752 L
.95525 .5463 L
.96412 .54038 L
.96876 .5377 L
.96988 .53727 L
.97109 .53673 L
.97241 .53566 L
.97364 .53445 L
.97619 .53152 L
Mfstroke
.25 0 0 r
.02381 .34322 m
.06244 .32398 L
.10458 .29649 L
.12507 .28419 L
.14415 .27169 L
.18221 .23662 L
.2212 .1993 L
.26265 .14832 L
.28341 .12821 L
.30258 .1106 L
.31213 .10307 L
.32241 .09478 L
.32738 .09103 L
.32984 .0894 L
.33103 .08872 L
.33211 .08826 L
.33417 .08756 L
.33636 .0869 L
.34099 .08517 L
.35972 .0771 L
.38034 .06866 L
.3897 .06389 L
.39481 .0616 L
.39959 .05968 L
.40087 .05925 L
.40208 .05894 L
.40275 .0588 L
.40348 .05869 L
.40476 .0586 L
.40544 .05861 L
.40619 .05867 L
.40697 .05882 L
.4077 .0591 L
.41043 .06042 L
.4152 .06219 L
.42041 .06385 L
.42287 .06479 L
.42422 .06535 L
.4255 .0658 L
.42669 .06611 L
.42798 .06612 L
.42916 .06597 L
.43024 .06575 L
.44059 .06267 L
.44283 .06211 L
.44523 .06144 L
.4475 .06065 L
.44958 .05964 L
.45069 .05916 L
.4519 .05877 L
Mistroke
.45305 .05876 L
.45411 .05892 L
.45538 .05922 L
.45652 .05955 L
.45785 .05986 L
.4591 .06007 L
.46026 .0603 L
.46151 .06059 L
.46269 .06097 L
.46377 .06142 L
.46888 .06386 L
.47143 .06518 L
.47286 .06623 L
.47419 .06747 L
.47921 .0724 L
.4977 .09067 L
.50235 .09558 L
.50496 .09934 L
.50735 .10331 L
.5164 .12066 L
.53702 .1618 L
.57669 .26191 L
.61485 .35662 L
.65547 .44871 L
.69456 .52158 L
.71452 .55102 L
.72501 .56502 L
.73611 .57694 L
.74605 .58564 L
.74877 .58778 L
.75027 .58872 L
.75169 .58944 L
.75301 .58999 L
.7537 .59025 L
.75444 .59049 L
.75575 .59076 L
.75696 .59098 L
.76183 .593 L
.76311 .59385 L
.76382 .59429 L
.76449 .59467 L
.76579 .59507 L
.76696 .59527 L
.76806 .59538 L
.76907 .59542 L
.77018 .59543 L
.77135 .59542 L
.77253 .59537 L
.77363 .5953 L
.77492 .5952 L
Mistroke
.77615 .59514 L
.77727 .59505 L
.7785 .5949 L
.77962 .59471 L
.78066 .59446 L
.783 .59366 L
.78431 .59306 L
.7855 .59243 L
.788 .59076 L
.7907 .58826 L
.79559 .58187 L
.81387 .54873 L
.81885 .53904 L
.82419 .52708 L
.83382 .49773 L
.84387 .45901 L
.85489 .41365 L
.87472 .32557 L
.89627 .23083 L
.90632 .19233 L
.91182 .17482 L
.91451 .16793 L
.91698 .1628 L
.92137 .15606 L
.92609 .15051 L
.93098 .14638 L
.93614 .14284 L
.97426 .10979 L
.97619 .10799 L
Mfstroke
.1 0 0 r
.02381 .32643 m
.06244 .28125 L
.10458 .22259 L
.14415 .16683 L
.18221 .11141 L
.20342 .08052 L
.22272 .05687 L
.24299 .03463 L
.24728 .03051 L
.24965 .02808 L
.2519 .02624 L
.25454 .02454 L
.25696 .02298 L
.26171 .01996 L
.26615 .01767 L
.26737 .01717 L
.26867 .01671 L
.26989 .01637 L
.271 .01619 L
.27229 .01618 L
.2735 .01622 L
.27476 .01626 L
.27542 .01627 L
.27614 .01617 L
.2774 .01586 L
.2786 .01552 L
.2797 .01523 L
.28086 .01495 L
.28214 .01479 L
.28332 .01472 L
.28459 .01472 L
.28532 .01475 L
.286 .01482 L
.28668 .01495 L
.28739 .0151 L
.28867 .01541 L
.29156 .01603 L
.29276 .01614 L
.29389 .01626 L
.29519 .01647 L
.29637 .01681 L
.29768 .0174 L
.2991 .01815 L
.30164 .01967 L
.32152 .03602 L
.34256 .05831 L
.38045 .1031 L
.42079 .16261 L
.45961 .20482 L
.47936 .22975 L
Mistroke
.49053 .24025 L
.50089 .24849 L
.50566 .25145 L
.51081 .25596 L
.51318 .25788 L
.51437 .25858 L
.51567 .25919 L
.51679 .25958 L
.51799 .2598 L
.51912 .25976 L
.52014 .25966 L
.52143 .25951 L
.52208 .25945 L
.52279 .25943 L
.52357 .25962 L
.52429 .25983 L
.52567 .26023 L
.52699 .26055 L
.52819 .26067 L
.52951 .26053 L
.53018 .26039 L
.5309 .26019 L
.53218 .25971 L
.53335 .25907 L
.53595 .25713 L
.54065 .25389 L
.54184 .25323 L
.54298 .25267 L
.54428 .25224 L
.54548 .25184 L
.54652 .25143 L
.54764 .2509 L
.54886 .24993 L
.54999 .24883 L
.5547 .2437 L
.55987 .23856 L
.56502 .2335 L
.5707 .22621 L
.58068 .20987 L
.62085 .12937 L
.65951 .06784 L
.66987 .05323 L
.67952 .04019 L
.68959 .03053 L
.69233 .02849 L
.69492 .02687 L
.69635 .02614 L
.6979 .02549 L
.69859 .02526 L
.69931 .02508 L
Mistroke
.70061 .02494 L
.70182 .02488 L
.70314 .02484 L
.70438 .02472 L
.70554 .02439 L
.70665 .02405 L
.70785 .0237 L
.70899 .02341 L
.71004 .02332 L
.71129 .02331 L
.71261 .02338 L
.71372 .02349 L
.71494 .02368 L
.71634 .02393 L
.71767 .02417 L
.71887 .02434 L
.72016 .02434 L
.72132 .02424 L
.72254 .02412 L
.72358 .02403 L
.72474 .02398 L
.72595 .02401 L
.72726 .02416 L
.7285 .02446 L
.72963 .02494 L
.7307 .02572 L
.73169 .02652 L
.73394 .02848 L
.73613 .02989 L
.73847 .03126 L
.74106 .03322 L
.74381 .03602 L
.74615 .03939 L
.74872 .04365 L
.75408 .05122 L
.75983 .0592 L
.76528 .06988 L
.77025 .08011 L
.77999 .10172 L
.80063 .15414 L
.81977 .20329 L
.83831 .24329 L
.84866 .25925 L
.85313 .26483 L
.85803 .27015 L
.8604 .27234 L
.86172 .27324 L
.86293 .27396 L
.8656 .27534 L
.86809 .27661 L
Mistroke
.8729 .27857 L
.87733 .28009 L
.87862 .28052 L
.87983 .28084 L
.88108 .28107 L
.88175 .28112 L
.88247 .28114 L
.88318 .28111 L
.88396 .28103 L
.8847 .28089 L
.88538 .28072 L
.88667 .28018 L
.88804 .27942 L
.89078 .27742 L
.89335 .27512 L
.89817 .26991 L
.90282 .26337 L
.90793 .25464 L
.91824 .23843 L
.93671 .20498 L
.97619 .10395 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.846531 0.140037 0.97619 0.461099 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0297619 0.297619 [
[ 0 0 0 0 ]
[ 1 2.47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 2.47619 L
0 2.47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0535714 0.35119 0.35119 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.1 0 0 r
.007 w
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .20238 -61 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
73.750 16.625 moveto
(ns) show
87.375 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.39881 0.35119 0.696429 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.25 0 0 r
.007 w
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .54762 -61 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
73.750 16.625 moveto
(ns) show
87.375 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.744048 0.35119 1.04167 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.4 0 0 r
.007 w
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .89286 -61 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
73.750 16.625 moveto
(ns) show
87.375 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 1.08929 0.35119 1.3869 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.55 0 0 r
.007 w
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 1.2381 -61 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.188 16.625 moveto
(\\220) show
74.250 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
85.000 16.625 moveto
(ns) show
98.625 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 1.43452 0.35119 1.73214 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.7 0 0 r
.007 w
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 1.58333 -61 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.188 16.625 moveto
(\\220) show
74.250 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
85.000 16.625 moveto
(ns) show
98.625 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 1.77976 0.35119 2.07738 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.85 0 0 r
.007 w
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 1.92857 -61 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.188 16.625 moveto
(\\220) show
74.250 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
85.000 16.625 moveto
(ns) show
98.625 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 2.125 0.35119 2.42262 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.007 w
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 2.27381 -61 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.188 16.625 moveto
(\\220) show
74.250 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
92.188 16.625 moveto
(ns) show
105.813 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .52087 L
0 .52087 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{649.5, 338.25},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{57.1875, 575.75}, {532.25, 262.688}} -> {-1.33717, \
0.615831, 0.00385178, 0.00385178}, {{70, 485.438}, {525.813, 269.125}} -> \
{-75.0355, 0.408159, 0.46713, 0.00315802}, {{495.813, 562.938}, {459.75, \
293.625}} -> {-24.9328, 9.42517, 0.0400666, 0.0400666}, {{499.438, 519.375}, \
{456.125, 436.188}} -> {-26.3279, 30.0965, 0.0421321, 0.136342}, {{499.438, \
519.375}, {433, 413}} -> {-26.3279, 26.15, 0.0421321, 0.136342}, {{499.438, \
519.375}, {409.813, 389.875}} -> {-26.3279, 22.2035, 0.0421321, 0.136342}, \
{{499.438, 519.375}, {386.688, 366.688}} -> {-26.3279, 18.2571, 0.0421321, \
0.136342}, {{499.438, 519.375}, {363.5, 343.563}} -> {-26.3279, 14.3106, \
0.0421321, 0.136342}, {{499.438, 519.375}, {340.375, 320.375}} -> {-26.3279, \
10.3641, 0.0421321, 0.136342}, {{499.438, 519.375}, {317.188, 297.25}} -> \
{-26.3279, 6.41766, 0.0421321, 0.136342}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Projected Insertion Loss at 45\[Degree], 90\[Degree], 180\[Degree], 270\
\[Degree] and 360\[Degree]\
\>", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"seldel", "[", 
   RowBox[{"freq_", ",", 
    RowBox[{"phase_:", "180"}]}], "]"}], ":=", 
  RowBox[{"IntegerDigits", "[", 
   RowBox[{
    RowBox[{"Round", "[", 
     RowBox[{"16*^9", 
      FractionBox["phase", 
       RowBox[{"360", " ", "freq"}]]}], "]"}], ",", "2", ",", "9"}], 
   "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"del45", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"x", "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}], 
        "1.*^6"], ",", 
       RowBox[{
        RowBox[{"seldel", "[", 
         RowBox[{
          RowBox[{"x", "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}],
           ",", "45"}], "]"}], ".", 
        RowBox[{"Reverse", "[", 
         RowBox[{"Last", "/@", 
          RowBox[{
           RowBox[{"Transpose", "[", "dbmagall", "]"}], 
           "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}]}], 
         "]"}]}]}], "}"}], "&"}], "/@", 
    RowBox[{"Range", "[", 
     RowBox[{"16", ",", 
      RowBox[{
       RowBox[{"Length", "[", "x", "]"}], "-", "2"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"del90", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"x", "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}], 
        "1.*^6"], ",", 
       RowBox[{
        RowBox[{"seldel", "[", 
         RowBox[{
          RowBox[{"x", "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}],
           ",", "90"}], "]"}], ".", 
        RowBox[{"Reverse", "[", 
         RowBox[{"Last", "/@", 
          RowBox[{
           RowBox[{"Transpose", "[", "dbmagall", "]"}], 
           "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}]}], 
         "]"}]}]}], "}"}], "&"}], "/@", 
    RowBox[{"Range", "[", 
     RowBox[{"16", ",", 
      RowBox[{
       RowBox[{"Length", "[", "x", "]"}], "-", "2"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"del180", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"x", "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}], 
        "1.*^6"], ",", 
       RowBox[{
        RowBox[{"seldel", "[", 
         RowBox[{
          RowBox[{"x", "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}],
           ",", "180"}], "]"}], ".", 
        RowBox[{"Reverse", "[", 
         RowBox[{"Last", "/@", 
          RowBox[{
           RowBox[{"Transpose", "[", "dbmagall", "]"}], 
           "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}]}], 
         "]"}]}]}], "}"}], "&"}], "/@", 
    RowBox[{"Range", "[", 
     RowBox[{"16", ",", 
      RowBox[{
       RowBox[{"Length", "[", "x", "]"}], "-", "2"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"del270", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"x", "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}], 
        "1.*^6"], ",", 
       RowBox[{
        RowBox[{"seldel", "[", 
         RowBox[{
          RowBox[{"x", "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}],
           ",", "270"}], "]"}], ".", 
        RowBox[{"Reverse", "[", 
         RowBox[{"Last", "/@", 
          RowBox[{
           RowBox[{"Transpose", "[", "dbmagall", "]"}], 
           "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}]}], 
         "]"}]}]}], "}"}], "&"}], "/@", 
    RowBox[{"Range", "[", 
     RowBox[{"24", ",", 
      RowBox[{
       RowBox[{"Length", "[", "x", "]"}], "-", "2"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"del360", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"x", "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}], 
        "1.*^6"], ",", 
       RowBox[{
        RowBox[{"seldel", "[", 
         RowBox[{
          RowBox[{"x", "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}],
           ",", "360"}], "]"}], ".", 
        RowBox[{"Reverse", "[", 
         RowBox[{"Last", "/@", 
          RowBox[{
           RowBox[{"Transpose", "[", "dbmagall", "]"}], 
           "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}]}], 
         "]"}]}]}], "}"}], "&"}], "/@", 
    RowBox[{"Range", "[", 
     RowBox[{"32", ",", 
      RowBox[{
       RowBox[{"Length", "[", "x", "]"}], "-", "2"}]}], "]"}]}]}], 
  ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MultipleListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "del45", ",", "del90", ",", "del180", ",", "del270", ",", "del360"}], 
    "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
   "PlotLabel", "\[Rule]", 
    "\"\<Insertion Loss at multiple phase shifts\>\""}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Frequency (MHz)\>\"", ",", "\"\<Added Insertion Loss (dB)\>\""}], 
     "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"PlotLegend", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<45\[Degree]\>\"", ",", "\"\<90\[Degree]\>\"", ",", " ", 
      "\"\<180\[Degree]\>\"", ",", " ", "\"\<270\[Degree]\>\"", ",", " ", 
      "\"\<360\[Degree]\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"SymbolStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"RGBColor", " ", "[", 
        RowBox[{"1", ",", "0", ",", "0"}], "]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"RGBColor", " ", "[", 
        RowBox[{"0", ",", "0", ",", "1"}], "]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"RGBColor", " ", "[", 
        RowBox[{"0", ",", "0.6", ",", "0"}], "]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"RGBColor", " ", "[", 
        RowBox[{"0.5", ",", "0.3", ",", "0"}], "]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"RGBColor", " ", "[", 
        RowBox[{"0.2", ",", "0.3", ",", "0.4"}], "]"}], "}"}]}], "}"}]}], ",",
    "\[IndentingNewLine]", 
   RowBox[{"LegendPosition", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0.9", ",", 
      RowBox[{"-", "0.3"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"LegendShadow", "\[Rule]", "None"}]}], "]"}]], "Input",
 CellChangeTimes->{3.442868160474375*^9}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .52643 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.429423 0.405614 0.263217 0.405614 [
[ 0 0 0 0 ]
[ 1 .52643 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0125342 0.835037 0.5139 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0594849 0.00523042 0.46081 0.278964 [
[.07128 -0.0125 -9.1875 -16.375 ]
[.07128 -0.0125 9.1875 0 ]
[.20204 -0.0125 -9.1875 -16.375 ]
[.20204 -0.0125 9.1875 0 ]
[.3328 -0.0125 -9.1875 -16.375 ]
[.3328 -0.0125 9.1875 0 ]
[.46356 -0.0125 -12.7813 -16.375 ]
[.46356 -0.0125 12.7813 0 ]
[.59432 -0.0125 -12.7813 -16.375 ]
[.59432 -0.0125 12.7813 0 ]
[.72508 -0.0125 -12.7813 -16.375 ]
[.72508 -0.0125 12.7813 0 ]
[.85584 -0.0125 -12.7813 -16.375 ]
[.85584 -0.0125 12.7813 0 ]
[.9866 -0.0125 -12.7813 -16.375 ]
[.9866 -0.0125 12.7813 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -51.7188 -32.75 ]
[.5 -0.0125 51.7188 -16.375 ]
[-0.0125 .04236 -30.9375 -8.1875 ]
[-0.0125 .04236 0 8.1875 ]
[-0.0125 .18185 -20.1875 -8.1875 ]
[-0.0125 .18185 0 8.1875 ]
[-0.0125 .32133 -30.9375 -8.1875 ]
[-0.0125 .32133 0 8.1875 ]
[-0.0125 .46081 -11.1875 -8.1875 ]
[-0.0125 .46081 0 8.1875 ]
[-0.0125 .60029 -21.9375 -8.1875 ]
[-0.0125 .60029 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -47.3125 -76.5938 ]
[-0.01875 .30902 -30.9375 76.5938 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -109.563 0 ]
[.5 .63053 109.563 16.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.07128 0 m
.07128 .61803 L
s
.20204 0 m
.20204 .61803 L
s
.3328 0 m
.3328 .61803 L
s
.46356 0 m
.46356 .61803 L
s
.59432 0 m
.59432 .61803 L
s
.72508 0 m
.72508 .61803 L
s
.85584 0 m
.85584 .61803 L
s
0 .04236 m
1 .04236 L
s
0 .18185 m
1 .18185 L
s
0 .32133 m
1 .32133 L
s
0 .46081 m
1 .46081 L
s
0 g
.07128 0 m
.07128 .00625 L
s
gsave
.07128 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.20204 0 m
.20204 .00625 L
s
gsave
.20204 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.3328 0 m
.3328 .00625 L
s
gsave
.3328 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(75) show
1.000 setlinewidth
grestore
.46356 0 m
.46356 .00625 L
s
gsave
.46356 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.59432 0 m
.59432 .00625 L
s
gsave
.59432 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(125) show
1.000 setlinewidth
grestore
.72508 0 m
.72508 .00625 L
s
gsave
.72508 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.85584 0 m
.85584 .00625 L
s
gsave
.85584 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(175) show
1.000 setlinewidth
grestore
.9866 0 m
.9866 .00625 L
s
gsave
.9866 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.125 Mabswid
.09743 0 m
.09743 .00375 L
s
.12358 0 m
.12358 .00375 L
s
.14973 0 m
.14973 .00375 L
s
.17588 0 m
.17588 .00375 L
s
.22819 0 m
.22819 .00375 L
s
.25434 0 m
.25434 .00375 L
s
.28049 0 m
.28049 .00375 L
s
.30664 0 m
.30664 .00375 L
s
.35895 0 m
.35895 .00375 L
s
.3851 0 m
.3851 .00375 L
s
.41125 0 m
.41125 .00375 L
s
.4374 0 m
.4374 .00375 L
s
.48971 0 m
.48971 .00375 L
s
.51586 0 m
.51586 .00375 L
s
.54201 0 m
.54201 .00375 L
s
.56817 0 m
.56817 .00375 L
s
.62047 0 m
.62047 .00375 L
s
.64662 0 m
.64662 .00375 L
s
.67277 0 m
.67277 .00375 L
s
.69893 0 m
.69893 .00375 L
s
.75123 0 m
.75123 .00375 L
s
.77738 0 m
.77738 .00375 L
s
.80353 0 m
.80353 .00375 L
s
.82969 0 m
.82969 .00375 L
s
.88199 0 m
.88199 .00375 L
s
.90814 0 m
.90814 .00375 L
s
.93429 0 m
.93429 .00375 L
s
.96045 0 m
.96045 .00375 L
s
.04512 0 m
.04512 .00375 L
s
.01897 0 m
.01897 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -112.719 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Frequency) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
127.563 16.625 moveto
(H) show
131.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(MHz) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
158.250 16.625 moveto
(L) show
162.438 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .04236 m
.00625 .04236 L
s
gsave
-0.0125 .04236 -91.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .18185 m
.00625 .18185 L
s
gsave
-0.0125 .18185 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .32133 m
.00625 .32133 L
s
gsave
-0.0125 .32133 -91.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .46081 m
.00625 .46081 L
s
gsave
-0.0125 .46081 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .60029 m
.00625 .60029 L
s
gsave
-0.0125 .60029 -82.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07026 m
.00375 .07026 L
s
0 .09816 m
.00375 .09816 L
s
0 .12605 m
.00375 .12605 L
s
0 .15395 m
.00375 .15395 L
s
0 .20974 m
.00375 .20974 L
s
0 .23764 m
.00375 .23764 L
s
0 .26554 m
.00375 .26554 L
s
0 .29343 m
.00375 .29343 L
s
0 .34922 m
.00375 .34922 L
s
0 .37712 m
.00375 .37712 L
s
0 .40502 m
.00375 .40502 L
s
0 .43291 m
.00375 .43291 L
s
0 .48871 m
.00375 .48871 L
s
0 .5166 m
.00375 .5166 L
s
0 .5445 m
.00375 .5445 L
s
0 .5724 m
.00375 .5724 L
s
0 .01447 m
.00375 .01447 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -176.719 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
137.594 12.1875 translate
90 rotate
-137.594 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Added) show
104.125 16.625 moveto
(Insertion) show
157.188 16.625 moveto
(Loss) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
188.000 16.625 moveto
(H) show
192.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dB) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
208.000 16.625 moveto
(L) show
212.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.07128 .61178 m
.07128 .61803 L
s
.20204 .61178 m
.20204 .61803 L
s
.3328 .61178 m
.3328 .61803 L
s
.46356 .61178 m
.46356 .61803 L
s
.59432 .61178 m
.59432 .61803 L
s
.72508 .61178 m
.72508 .61803 L
s
.85584 .61178 m
.85584 .61803 L
s
.9866 .61178 m
.9866 .61803 L
s
.125 Mabswid
.09743 .61428 m
.09743 .61803 L
s
.12358 .61428 m
.12358 .61803 L
s
.14973 .61428 m
.14973 .61803 L
s
.17588 .61428 m
.17588 .61803 L
s
.22819 .61428 m
.22819 .61803 L
s
.25434 .61428 m
.25434 .61803 L
s
.28049 .61428 m
.28049 .61803 L
s
.30664 .61428 m
.30664 .61803 L
s
.35895 .61428 m
.35895 .61803 L
s
.3851 .61428 m
.3851 .61803 L
s
.41125 .61428 m
.41125 .61803 L
s
.4374 .61428 m
.4374 .61803 L
s
.48971 .61428 m
.48971 .61803 L
s
.51586 .61428 m
.51586 .61803 L
s
.54201 .61428 m
.54201 .61803 L
s
.56817 .61428 m
.56817 .61803 L
s
.62047 .61428 m
.62047 .61803 L
s
.64662 .61428 m
.64662 .61803 L
s
.67277 .61428 m
.67277 .61803 L
s
.69893 .61428 m
.69893 .61803 L
s
.75123 .61428 m
.75123 .61803 L
s
.77738 .61428 m
.77738 .61803 L
s
.80353 .61428 m
.80353 .61803 L
s
.82969 .61428 m
.82969 .61803 L
s
.88199 .61428 m
.88199 .61803 L
s
.90814 .61428 m
.90814 .61803 L
s
.93429 .61428 m
.93429 .61803 L
s
.96045 .61428 m
.96045 .61803 L
s
.04512 .61428 m
.04512 .61803 L
s
.01897 .61428 m
.01897 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04236 m
1 .04236 L
s
.99375 .18185 m
1 .18185 L
s
.99375 .32133 m
1 .32133 L
s
.99375 .46081 m
1 .46081 L
s
.99375 .60029 m
1 .60029 L
s
.125 Mabswid
.99625 .07026 m
1 .07026 L
s
.99625 .09816 m
1 .09816 L
s
.99625 .12605 m
1 .12605 L
s
.99625 .15395 m
1 .15395 L
s
.99625 .20974 m
1 .20974 L
s
.99625 .23764 m
1 .23764 L
s
.99625 .26554 m
1 .26554 L
s
.99625 .29343 m
1 .29343 L
s
.99625 .34922 m
1 .34922 L
s
.99625 .37712 m
1 .37712 L
s
.99625 .40502 m
1 .40502 L
s
.99625 .43291 m
1 .43291 L
s
.99625 .48871 m
1 .48871 L
s
.99625 .5166 m
1 .5166 L
s
.99625 .5445 m
1 .5445 L
s
.99625 .5724 m
1 .5724 L
s
.99625 .01447 m
1 .01447 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .46081 m
1 .46081 L
s
gsave
.5 .63053 -170.563 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Insertion) show
116.063 16.625 moveto
(Loss) show
146.875 16.625 moveto
(at) show
161.188 16.625 moveto
(multiple) show
209.313 16.625 moveto
(phase) show
248.063 16.625 moveto
(shifts) show
278.125 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 0 r
.0001 w
.02381 .39354 -1.875 0 Mabsadd m
.02381 .39354 0 2.5 Mabsadd L
.02381 .39354 1.875 0 Mabsadd L
.02381 .39354 0 -2.5 Mabsadd L
.02381 .39354 -1.875 0 Mabsadd L closepath F
.02901 .39369 -1.875 0 Mabsadd m
.02901 .39369 0 2.5 Mabsadd L
.02901 .39369 1.875 0 Mabsadd L
.02901 .39369 0 -2.5 Mabsadd L
.02901 .39369 -1.875 0 Mabsadd L closepath F
.03422 .39301 -1.875 0 Mabsadd m
.03422 .39301 0 2.5 Mabsadd L
.03422 .39301 1.875 0 Mabsadd L
.03422 .39301 0 -2.5 Mabsadd L
.03422 .39301 -1.875 0 Mabsadd L closepath F
.03942 .38915 -1.875 0 Mabsadd m
.03942 .38915 0 2.5 Mabsadd L
.03942 .38915 1.875 0 Mabsadd L
.03942 .38915 0 -2.5 Mabsadd L
.03942 .38915 -1.875 0 Mabsadd L closepath F
.04463 .38811 -1.875 0 Mabsadd m
.04463 .38811 0 2.5 Mabsadd L
.04463 .38811 1.875 0 Mabsadd L
.04463 .38811 0 -2.5 Mabsadd L
.04463 .38811 -1.875 0 Mabsadd L closepath F
.04983 .38745 -1.875 0 Mabsadd m
.04983 .38745 0 2.5 Mabsadd L
.04983 .38745 1.875 0 Mabsadd L
.04983 .38745 0 -2.5 Mabsadd L
.04983 .38745 -1.875 0 Mabsadd L closepath F
.05504 .39391 -1.875 0 Mabsadd m
.05504 .39391 0 2.5 Mabsadd L
.05504 .39391 1.875 0 Mabsadd L
.05504 .39391 0 -2.5 Mabsadd L
.05504 .39391 -1.875 0 Mabsadd L closepath F
.06024 .39666 -1.875 0 Mabsadd m
.06024 .39666 0 2.5 Mabsadd L
.06024 .39666 1.875 0 Mabsadd L
.06024 .39666 0 -2.5 Mabsadd L
.06024 .39666 -1.875 0 Mabsadd L closepath F
.06544 .39105 -1.875 0 Mabsadd m
.06544 .39105 0 2.5 Mabsadd L
.06544 .39105 1.875 0 Mabsadd L
.06544 .39105 0 -2.5 Mabsadd L
.06544 .39105 -1.875 0 Mabsadd L closepath F
.07065 .3907 -1.875 0 Mabsadd m
.07065 .3907 0 2.5 Mabsadd L
.07065 .3907 1.875 0 Mabsadd L
.07065 .3907 0 -2.5 Mabsadd L
.07065 .3907 -1.875 0 Mabsadd L closepath F
.07585 .39097 -1.875 0 Mabsadd m
.07585 .39097 0 2.5 Mabsadd L
.07585 .39097 1.875 0 Mabsadd L
.07585 .39097 0 -2.5 Mabsadd L
.07585 .39097 -1.875 0 Mabsadd L closepath F
.08106 .39014 -1.875 0 Mabsadd m
.08106 .39014 0 2.5 Mabsadd L
.08106 .39014 1.875 0 Mabsadd L
.08106 .39014 0 -2.5 Mabsadd L
.08106 .39014 -1.875 0 Mabsadd L closepath F
.08626 .389 -1.875 0 Mabsadd m
.08626 .389 0 2.5 Mabsadd L
.08626 .389 1.875 0 Mabsadd L
.08626 .389 0 -2.5 Mabsadd L
.08626 .389 -1.875 0 Mabsadd L closepath F
.09147 .38833 -1.875 0 Mabsadd m
.09147 .38833 0 2.5 Mabsadd L
.09147 .38833 1.875 0 Mabsadd L
.09147 .38833 0 -2.5 Mabsadd L
.09147 .38833 -1.875 0 Mabsadd L closepath F
.09667 .3864 -1.875 0 Mabsadd m
.09667 .3864 0 2.5 Mabsadd L
.09667 .3864 1.875 0 Mabsadd L
.09667 .3864 0 -2.5 Mabsadd L
.09667 .3864 -1.875 0 Mabsadd L closepath F
.10187 .38786 -1.875 0 Mabsadd m
.10187 .38786 0 2.5 Mabsadd L
.10187 .38786 1.875 0 Mabsadd L
.10187 .38786 0 -2.5 Mabsadd L
.10187 .38786 -1.875 0 Mabsadd L closepath F
.10708 .40238 -1.875 0 Mabsadd m
.10708 .40238 0 2.5 Mabsadd L
.10708 .40238 1.875 0 Mabsadd L
.10708 .40238 0 -2.5 Mabsadd L
.10708 .40238 -1.875 0 Mabsadd L closepath F
.11228 .39828 -1.875 0 Mabsadd m
.11228 .39828 0 2.5 Mabsadd L
.11228 .39828 1.875 0 Mabsadd L
.11228 .39828 0 -2.5 Mabsadd L
.11228 .39828 -1.875 0 Mabsadd L closepath F
.11749 .40162 -1.875 0 Mabsadd m
.11749 .40162 0 2.5 Mabsadd L
.11749 .40162 1.875 0 Mabsadd L
.11749 .40162 0 -2.5 Mabsadd L
.11749 .40162 -1.875 0 Mabsadd L closepath F
.12269 .3935 -1.875 0 Mabsadd m
.12269 .3935 0 2.5 Mabsadd L
.12269 .3935 1.875 0 Mabsadd L
.12269 .3935 0 -2.5 Mabsadd L
.12269 .3935 -1.875 0 Mabsadd L closepath F
.12789 .3903 -1.875 0 Mabsadd m
.12789 .3903 0 2.5 Mabsadd L
.12789 .3903 1.875 0 Mabsadd L
.12789 .3903 0 -2.5 Mabsadd L
.12789 .3903 -1.875 0 Mabsadd L closepath F
.1331 .38944 -1.875 0 Mabsadd m
.1331 .38944 0 2.5 Mabsadd L
.1331 .38944 1.875 0 Mabsadd L
.1331 .38944 0 -2.5 Mabsadd L
.1331 .38944 -1.875 0 Mabsadd L closepath F
.1383 .39217 -1.875 0 Mabsadd m
.1383 .39217 0 2.5 Mabsadd L
.1383 .39217 1.875 0 Mabsadd L
.1383 .39217 0 -2.5 Mabsadd L
.1383 .39217 -1.875 0 Mabsadd L closepath F
.14351 .38719 -1.875 0 Mabsadd m
.14351 .38719 0 2.5 Mabsadd L
.14351 .38719 1.875 0 Mabsadd L
.14351 .38719 0 -2.5 Mabsadd L
.14351 .38719 -1.875 0 Mabsadd L closepath F
.14871 .38883 -1.875 0 Mabsadd m
.14871 .38883 0 2.5 Mabsadd L
.14871 .38883 1.875 0 Mabsadd L
.14871 .38883 0 -2.5 Mabsadd L
.14871 .38883 -1.875 0 Mabsadd L closepath F
.15392 .38822 -1.875 0 Mabsadd m
.15392 .38822 0 2.5 Mabsadd L
.15392 .38822 1.875 0 Mabsadd L
.15392 .38822 0 -2.5 Mabsadd L
.15392 .38822 -1.875 0 Mabsadd L closepath F
.15912 .38277 -1.875 0 Mabsadd m
.15912 .38277 0 2.5 Mabsadd L
.15912 .38277 1.875 0 Mabsadd L
.15912 .38277 0 -2.5 Mabsadd L
.15912 .38277 -1.875 0 Mabsadd L closepath F
.16432 .38593 -1.875 0 Mabsadd m
.16432 .38593 0 2.5 Mabsadd L
.16432 .38593 1.875 0 Mabsadd L
.16432 .38593 0 -2.5 Mabsadd L
.16432 .38593 -1.875 0 Mabsadd L closepath F
.16953 .38568 -1.875 0 Mabsadd m
.16953 .38568 0 2.5 Mabsadd L
.16953 .38568 1.875 0 Mabsadd L
.16953 .38568 0 -2.5 Mabsadd L
.16953 .38568 -1.875 0 Mabsadd L closepath F
.17473 .3877 -1.875 0 Mabsadd m
.17473 .3877 0 2.5 Mabsadd L
.17473 .3877 1.875 0 Mabsadd L
.17473 .3877 0 -2.5 Mabsadd L
.17473 .3877 -1.875 0 Mabsadd L closepath F
.17994 .38625 -1.875 0 Mabsadd m
.17994 .38625 0 2.5 Mabsadd L
.17994 .38625 1.875 0 Mabsadd L
.17994 .38625 0 -2.5 Mabsadd L
.17994 .38625 -1.875 0 Mabsadd L closepath F
.18514 .38442 -1.875 0 Mabsadd m
.18514 .38442 0 2.5 Mabsadd L
.18514 .38442 1.875 0 Mabsadd L
.18514 .38442 0 -2.5 Mabsadd L
.18514 .38442 -1.875 0 Mabsadd L closepath F
.19035 .37874 -1.875 0 Mabsadd m
.19035 .37874 0 2.5 Mabsadd L
.19035 .37874 1.875 0 Mabsadd L
.19035 .37874 0 -2.5 Mabsadd L
.19035 .37874 -1.875 0 Mabsadd L closepath F
.19555 .3808 -1.875 0 Mabsadd m
.19555 .3808 0 2.5 Mabsadd L
.19555 .3808 1.875 0 Mabsadd L
.19555 .3808 0 -2.5 Mabsadd L
.19555 .3808 -1.875 0 Mabsadd L closepath F
.20075 .37725 -1.875 0 Mabsadd m
.20075 .37725 0 2.5 Mabsadd L
.20075 .37725 1.875 0 Mabsadd L
.20075 .37725 0 -2.5 Mabsadd L
.20075 .37725 -1.875 0 Mabsadd L closepath F
.20596 .37767 -1.875 0 Mabsadd m
.20596 .37767 0 2.5 Mabsadd L
.20596 .37767 1.875 0 Mabsadd L
.20596 .37767 0 -2.5 Mabsadd L
.20596 .37767 -1.875 0 Mabsadd L closepath F
.21116 .37863 -1.875 0 Mabsadd m
.21116 .37863 0 2.5 Mabsadd L
.21116 .37863 1.875 0 Mabsadd L
.21116 .37863 0 -2.5 Mabsadd L
.21116 .37863 -1.875 0 Mabsadd L closepath F
.21637 .3747 -1.875 0 Mabsadd m
.21637 .3747 0 2.5 Mabsadd L
.21637 .3747 1.875 0 Mabsadd L
.21637 .3747 0 -2.5 Mabsadd L
.21637 .3747 -1.875 0 Mabsadd L closepath F
.22157 .37689 -1.875 0 Mabsadd m
.22157 .37689 0 2.5 Mabsadd L
.22157 .37689 1.875 0 Mabsadd L
.22157 .37689 0 -2.5 Mabsadd L
.22157 .37689 -1.875 0 Mabsadd L closepath F
.22678 .37008 -1.875 0 Mabsadd m
.22678 .37008 0 2.5 Mabsadd L
.22678 .37008 1.875 0 Mabsadd L
.22678 .37008 0 -2.5 Mabsadd L
.22678 .37008 -1.875 0 Mabsadd L closepath F
.23198 .36903 -1.875 0 Mabsadd m
.23198 .36903 0 2.5 Mabsadd L
.23198 .36903 1.875 0 Mabsadd L
.23198 .36903 0 -2.5 Mabsadd L
.23198 .36903 -1.875 0 Mabsadd L closepath F
.23718 .37286 -1.875 0 Mabsadd m
.23718 .37286 0 2.5 Mabsadd L
.23718 .37286 1.875 0 Mabsadd L
.23718 .37286 0 -2.5 Mabsadd L
.23718 .37286 -1.875 0 Mabsadd L closepath F
.24239 .37404 -1.875 0 Mabsadd m
.24239 .37404 0 2.5 Mabsadd L
.24239 .37404 1.875 0 Mabsadd L
.24239 .37404 0 -2.5 Mabsadd L
.24239 .37404 -1.875 0 Mabsadd L closepath F
.24759 .36924 -1.875 0 Mabsadd m
.24759 .36924 0 2.5 Mabsadd L
.24759 .36924 1.875 0 Mabsadd L
.24759 .36924 0 -2.5 Mabsadd L
.24759 .36924 -1.875 0 Mabsadd L closepath F
.2528 .36639 -1.875 0 Mabsadd m
.2528 .36639 0 2.5 Mabsadd L
.2528 .36639 1.875 0 Mabsadd L
.2528 .36639 0 -2.5 Mabsadd L
.2528 .36639 -1.875 0 Mabsadd L closepath F
.258 .36707 -1.875 0 Mabsadd m
.258 .36707 0 2.5 Mabsadd L
.258 .36707 1.875 0 Mabsadd L
.258 .36707 0 -2.5 Mabsadd L
.258 .36707 -1.875 0 Mabsadd L closepath F
.26321 .36589 -1.875 0 Mabsadd m
.26321 .36589 0 2.5 Mabsadd L
.26321 .36589 1.875 0 Mabsadd L
.26321 .36589 0 -2.5 Mabsadd L
.26321 .36589 -1.875 0 Mabsadd L closepath F
.26841 .36587 -1.875 0 Mabsadd m
.26841 .36587 0 2.5 Mabsadd L
.26841 .36587 1.875 0 Mabsadd L
.26841 .36587 0 -2.5 Mabsadd L
.26841 .36587 -1.875 0 Mabsadd L closepath F
.27361 .3865 -1.875 0 Mabsadd m
.27361 .3865 0 2.5 Mabsadd L
.27361 .3865 1.875 0 Mabsadd L
.27361 .3865 0 -2.5 Mabsadd L
.27361 .3865 -1.875 0 Mabsadd L closepath F
.27882 .38003 -1.875 0 Mabsadd m
.27882 .38003 0 2.5 Mabsadd L
.27882 .38003 1.875 0 Mabsadd L
.27882 .38003 0 -2.5 Mabsadd L
.27882 .38003 -1.875 0 Mabsadd L closepath F
.28402 .38007 -1.875 0 Mabsadd m
.28402 .38007 0 2.5 Mabsadd L
.28402 .38007 1.875 0 Mabsadd L
.28402 .38007 0 -2.5 Mabsadd L
.28402 .38007 -1.875 0 Mabsadd L closepath F
.28923 .37659 -1.875 0 Mabsadd m
.28923 .37659 0 2.5 Mabsadd L
.28923 .37659 1.875 0 Mabsadd L
.28923 .37659 0 -2.5 Mabsadd L
.28923 .37659 -1.875 0 Mabsadd L closepath F
.29443 .37454 -1.875 0 Mabsadd m
.29443 .37454 0 2.5 Mabsadd L
.29443 .37454 1.875 0 Mabsadd L
.29443 .37454 0 -2.5 Mabsadd L
.29443 .37454 -1.875 0 Mabsadd L closepath F
.29964 .37498 -1.875 0 Mabsadd m
.29964 .37498 0 2.5 Mabsadd L
.29964 .37498 1.875 0 Mabsadd L
.29964 .37498 0 -2.5 Mabsadd L
.29964 .37498 -1.875 0 Mabsadd L closepath F
.30484 .37633 -1.875 0 Mabsadd m
.30484 .37633 0 2.5 Mabsadd L
.30484 .37633 1.875 0 Mabsadd L
.30484 .37633 0 -2.5 Mabsadd L
.30484 .37633 -1.875 0 Mabsadd L closepath F
.31004 .37296 -1.875 0 Mabsadd m
.31004 .37296 0 2.5 Mabsadd L
.31004 .37296 1.875 0 Mabsadd L
.31004 .37296 0 -2.5 Mabsadd L
.31004 .37296 -1.875 0 Mabsadd L closepath F
.31525 .36976 -1.875 0 Mabsadd m
.31525 .36976 0 2.5 Mabsadd L
.31525 .36976 1.875 0 Mabsadd L
.31525 .36976 0 -2.5 Mabsadd L
.31525 .36976 -1.875 0 Mabsadd L closepath F
.32045 .36669 -1.875 0 Mabsadd m
.32045 .36669 0 2.5 Mabsadd L
.32045 .36669 1.875 0 Mabsadd L
.32045 .36669 0 -2.5 Mabsadd L
.32045 .36669 -1.875 0 Mabsadd L closepath F
.32566 .37634 -1.875 0 Mabsadd m
.32566 .37634 0 2.5 Mabsadd L
.32566 .37634 1.875 0 Mabsadd L
.32566 .37634 0 -2.5 Mabsadd L
.32566 .37634 -1.875 0 Mabsadd L closepath F
.33086 .36683 -1.875 0 Mabsadd m
.33086 .36683 0 2.5 Mabsadd L
.33086 .36683 1.875 0 Mabsadd L
.33086 .36683 0 -2.5 Mabsadd L
.33086 .36683 -1.875 0 Mabsadd L closepath F
.33607 .36845 -1.875 0 Mabsadd m
.33607 .36845 0 2.5 Mabsadd L
.33607 .36845 1.875 0 Mabsadd L
.33607 .36845 0 -2.5 Mabsadd L
.33607 .36845 -1.875 0 Mabsadd L closepath F
.34127 .36828 -1.875 0 Mabsadd m
.34127 .36828 0 2.5 Mabsadd L
.34127 .36828 1.875 0 Mabsadd L
.34127 .36828 0 -2.5 Mabsadd L
.34127 .36828 -1.875 0 Mabsadd L closepath F
.34647 .36643 -1.875 0 Mabsadd m
.34647 .36643 0 2.5 Mabsadd L
.34647 .36643 1.875 0 Mabsadd L
.34647 .36643 0 -2.5 Mabsadd L
.34647 .36643 -1.875 0 Mabsadd L closepath F
.35168 .36424 -1.875 0 Mabsadd m
.35168 .36424 0 2.5 Mabsadd L
.35168 .36424 1.875 0 Mabsadd L
.35168 .36424 0 -2.5 Mabsadd L
.35168 .36424 -1.875 0 Mabsadd L closepath F
.35688 .36095 -1.875 0 Mabsadd m
.35688 .36095 0 2.5 Mabsadd L
.35688 .36095 1.875 0 Mabsadd L
.35688 .36095 0 -2.5 Mabsadd L
.35688 .36095 -1.875 0 Mabsadd L closepath F
.36209 .3588 -1.875 0 Mabsadd m
.36209 .3588 0 2.5 Mabsadd L
.36209 .3588 1.875 0 Mabsadd L
.36209 .3588 0 -2.5 Mabsadd L
.36209 .3588 -1.875 0 Mabsadd L closepath F
.36729 .35879 -1.875 0 Mabsadd m
.36729 .35879 0 2.5 Mabsadd L
.36729 .35879 1.875 0 Mabsadd L
.36729 .35879 0 -2.5 Mabsadd L
.36729 .35879 -1.875 0 Mabsadd L closepath F
.3725 .36385 -1.875 0 Mabsadd m
.3725 .36385 0 2.5 Mabsadd L
.3725 .36385 1.875 0 Mabsadd L
.3725 .36385 0 -2.5 Mabsadd L
.3725 .36385 -1.875 0 Mabsadd L closepath F
.3777 .35944 -1.875 0 Mabsadd m
.3777 .35944 0 2.5 Mabsadd L
.3777 .35944 1.875 0 Mabsadd L
.3777 .35944 0 -2.5 Mabsadd L
.3777 .35944 -1.875 0 Mabsadd L closepath F
.3829 .36299 -1.875 0 Mabsadd m
.3829 .36299 0 2.5 Mabsadd L
.3829 .36299 1.875 0 Mabsadd L
.3829 .36299 0 -2.5 Mabsadd L
.3829 .36299 -1.875 0 Mabsadd L closepath F
.38811 .38146 -1.875 0 Mabsadd m
.38811 .38146 0 2.5 Mabsadd L
.38811 .38146 1.875 0 Mabsadd L
.38811 .38146 0 -2.5 Mabsadd L
.38811 .38146 -1.875 0 Mabsadd L closepath F
.39331 .38181 -1.875 0 Mabsadd m
.39331 .38181 0 2.5 Mabsadd L
.39331 .38181 1.875 0 Mabsadd L
.39331 .38181 0 -2.5 Mabsadd L
.39331 .38181 -1.875 0 Mabsadd L closepath F
.39852 .37513 -1.875 0 Mabsadd m
.39852 .37513 0 2.5 Mabsadd L
.39852 .37513 1.875 0 Mabsadd L
.39852 .37513 0 -2.5 Mabsadd L
.39852 .37513 -1.875 0 Mabsadd L closepath F
.40372 .3642 -1.875 0 Mabsadd m
.40372 .3642 0 2.5 Mabsadd L
.40372 .3642 1.875 0 Mabsadd L
.40372 .3642 0 -2.5 Mabsadd L
.40372 .3642 -1.875 0 Mabsadd L closepath F
.40893 .37175 -1.875 0 Mabsadd m
.40893 .37175 0 2.5 Mabsadd L
.40893 .37175 1.875 0 Mabsadd L
.40893 .37175 0 -2.5 Mabsadd L
.40893 .37175 -1.875 0 Mabsadd L closepath F
.41413 .36589 -1.875 0 Mabsadd m
.41413 .36589 0 2.5 Mabsadd L
.41413 .36589 1.875 0 Mabsadd L
.41413 .36589 0 -2.5 Mabsadd L
.41413 .36589 -1.875 0 Mabsadd L closepath F
.41933 .36104 -1.875 0 Mabsadd m
.41933 .36104 0 2.5 Mabsadd L
.41933 .36104 1.875 0 Mabsadd L
.41933 .36104 0 -2.5 Mabsadd L
.41933 .36104 -1.875 0 Mabsadd L closepath F
.42454 .35834 -1.875 0 Mabsadd m
.42454 .35834 0 2.5 Mabsadd L
.42454 .35834 1.875 0 Mabsadd L
.42454 .35834 0 -2.5 Mabsadd L
.42454 .35834 -1.875 0 Mabsadd L closepath F
.42974 .36224 -1.875 0 Mabsadd m
.42974 .36224 0 2.5 Mabsadd L
.42974 .36224 1.875 0 Mabsadd L
.42974 .36224 0 -2.5 Mabsadd L
.42974 .36224 -1.875 0 Mabsadd L closepath F
.43495 .36253 -1.875 0 Mabsadd m
.43495 .36253 0 2.5 Mabsadd L
.43495 .36253 1.875 0 Mabsadd L
.43495 .36253 0 -2.5 Mabsadd L
.43495 .36253 -1.875 0 Mabsadd L closepath F
.44015 .36448 -1.875 0 Mabsadd m
.44015 .36448 0 2.5 Mabsadd L
.44015 .36448 1.875 0 Mabsadd L
.44015 .36448 0 -2.5 Mabsadd L
.44015 .36448 -1.875 0 Mabsadd L closepath F
.44536 .35981 -1.875 0 Mabsadd m
.44536 .35981 0 2.5 Mabsadd L
.44536 .35981 1.875 0 Mabsadd L
.44536 .35981 0 -2.5 Mabsadd L
.44536 .35981 -1.875 0 Mabsadd L closepath F
.45056 .36229 -1.875 0 Mabsadd m
.45056 .36229 0 2.5 Mabsadd L
.45056 .36229 1.875 0 Mabsadd L
.45056 .36229 0 -2.5 Mabsadd L
.45056 .36229 -1.875 0 Mabsadd L closepath F
.45576 .35806 -1.875 0 Mabsadd m
.45576 .35806 0 2.5 Mabsadd L
.45576 .35806 1.875 0 Mabsadd L
.45576 .35806 0 -2.5 Mabsadd L
.45576 .35806 -1.875 0 Mabsadd L closepath F
.46097 .35764 -1.875 0 Mabsadd m
.46097 .35764 0 2.5 Mabsadd L
.46097 .35764 1.875 0 Mabsadd L
.46097 .35764 0 -2.5 Mabsadd L
.46097 .35764 -1.875 0 Mabsadd L closepath F
.46617 .35831 -1.875 0 Mabsadd m
.46617 .35831 0 2.5 Mabsadd L
.46617 .35831 1.875 0 Mabsadd L
.46617 .35831 0 -2.5 Mabsadd L
.46617 .35831 -1.875 0 Mabsadd L closepath F
.47138 .35787 -1.875 0 Mabsadd m
.47138 .35787 0 2.5 Mabsadd L
.47138 .35787 1.875 0 Mabsadd L
.47138 .35787 0 -2.5 Mabsadd L
.47138 .35787 -1.875 0 Mabsadd L closepath F
.47658 .35745 -1.875 0 Mabsadd m
.47658 .35745 0 2.5 Mabsadd L
.47658 .35745 1.875 0 Mabsadd L
.47658 .35745 0 -2.5 Mabsadd L
.47658 .35745 -1.875 0 Mabsadd L closepath F
.48179 .36954 -1.875 0 Mabsadd m
.48179 .36954 0 2.5 Mabsadd L
.48179 .36954 1.875 0 Mabsadd L
.48179 .36954 0 -2.5 Mabsadd L
.48179 .36954 -1.875 0 Mabsadd L closepath F
.48699 .37082 -1.875 0 Mabsadd m
.48699 .37082 0 2.5 Mabsadd L
.48699 .37082 1.875 0 Mabsadd L
.48699 .37082 0 -2.5 Mabsadd L
.48699 .37082 -1.875 0 Mabsadd L closepath F
.49219 .36656 -1.875 0 Mabsadd m
.49219 .36656 0 2.5 Mabsadd L
.49219 .36656 1.875 0 Mabsadd L
.49219 .36656 0 -2.5 Mabsadd L
.49219 .36656 -1.875 0 Mabsadd L closepath F
.4974 .36548 -1.875 0 Mabsadd m
.4974 .36548 0 2.5 Mabsadd L
.4974 .36548 1.875 0 Mabsadd L
.4974 .36548 0 -2.5 Mabsadd L
.4974 .36548 -1.875 0 Mabsadd L closepath F
.5026 .36624 -1.875 0 Mabsadd m
.5026 .36624 0 2.5 Mabsadd L
.5026 .36624 1.875 0 Mabsadd L
.5026 .36624 0 -2.5 Mabsadd L
.5026 .36624 -1.875 0 Mabsadd L closepath F
.50781 .37299 -1.875 0 Mabsadd m
.50781 .37299 0 2.5 Mabsadd L
.50781 .37299 1.875 0 Mabsadd L
.50781 .37299 0 -2.5 Mabsadd L
.50781 .37299 -1.875 0 Mabsadd L closepath F
.51301 .37075 -1.875 0 Mabsadd m
.51301 .37075 0 2.5 Mabsadd L
.51301 .37075 1.875 0 Mabsadd L
.51301 .37075 0 -2.5 Mabsadd L
.51301 .37075 -1.875 0 Mabsadd L closepath F
.51821 .37175 -1.875 0 Mabsadd m
.51821 .37175 0 2.5 Mabsadd L
.51821 .37175 1.875 0 Mabsadd L
.51821 .37175 0 -2.5 Mabsadd L
.51821 .37175 -1.875 0 Mabsadd L closepath F
.52342 .37507 -1.875 0 Mabsadd m
.52342 .37507 0 2.5 Mabsadd L
.52342 .37507 1.875 0 Mabsadd L
.52342 .37507 0 -2.5 Mabsadd L
.52342 .37507 -1.875 0 Mabsadd L closepath F
.52862 .3759 -1.875 0 Mabsadd m
.52862 .3759 0 2.5 Mabsadd L
.52862 .3759 1.875 0 Mabsadd L
.52862 .3759 0 -2.5 Mabsadd L
.52862 .3759 -1.875 0 Mabsadd L closepath F
.53383 .37514 -1.875 0 Mabsadd m
.53383 .37514 0 2.5 Mabsadd L
.53383 .37514 1.875 0 Mabsadd L
.53383 .37514 0 -2.5 Mabsadd L
.53383 .37514 -1.875 0 Mabsadd L closepath F
.53903 .38484 -1.875 0 Mabsadd m
.53903 .38484 0 2.5 Mabsadd L
.53903 .38484 1.875 0 Mabsadd L
.53903 .38484 0 -2.5 Mabsadd L
.53903 .38484 -1.875 0 Mabsadd L closepath F
.54424 .39105 -1.875 0 Mabsadd m
.54424 .39105 0 2.5 Mabsadd L
.54424 .39105 1.875 0 Mabsadd L
.54424 .39105 0 -2.5 Mabsadd L
.54424 .39105 -1.875 0 Mabsadd L closepath F
.54944 .38994 -1.875 0 Mabsadd m
.54944 .38994 0 2.5 Mabsadd L
.54944 .38994 1.875 0 Mabsadd L
.54944 .38994 0 -2.5 Mabsadd L
.54944 .38994 -1.875 0 Mabsadd L closepath F
.55464 .39049 -1.875 0 Mabsadd m
.55464 .39049 0 2.5 Mabsadd L
.55464 .39049 1.875 0 Mabsadd L
.55464 .39049 0 -2.5 Mabsadd L
.55464 .39049 -1.875 0 Mabsadd L closepath F
.55985 .39305 -1.875 0 Mabsadd m
.55985 .39305 0 2.5 Mabsadd L
.55985 .39305 1.875 0 Mabsadd L
.55985 .39305 0 -2.5 Mabsadd L
.55985 .39305 -1.875 0 Mabsadd L closepath F
.56505 .39338 -1.875 0 Mabsadd m
.56505 .39338 0 2.5 Mabsadd L
.56505 .39338 1.875 0 Mabsadd L
.56505 .39338 0 -2.5 Mabsadd L
.56505 .39338 -1.875 0 Mabsadd L closepath F
.57026 .39567 -1.875 0 Mabsadd m
.57026 .39567 0 2.5 Mabsadd L
.57026 .39567 1.875 0 Mabsadd L
.57026 .39567 0 -2.5 Mabsadd L
.57026 .39567 -1.875 0 Mabsadd L closepath F
.57546 .40251 -1.875 0 Mabsadd m
.57546 .40251 0 2.5 Mabsadd L
.57546 .40251 1.875 0 Mabsadd L
.57546 .40251 0 -2.5 Mabsadd L
.57546 .40251 -1.875 0 Mabsadd L closepath F
.58067 .39978 -1.875 0 Mabsadd m
.58067 .39978 0 2.5 Mabsadd L
.58067 .39978 1.875 0 Mabsadd L
.58067 .39978 0 -2.5 Mabsadd L
.58067 .39978 -1.875 0 Mabsadd L closepath F
.58587 .4045 -1.875 0 Mabsadd m
.58587 .4045 0 2.5 Mabsadd L
.58587 .4045 1.875 0 Mabsadd L
.58587 .4045 0 -2.5 Mabsadd L
.58587 .4045 -1.875 0 Mabsadd L closepath F
.59107 .40593 -1.875 0 Mabsadd m
.59107 .40593 0 2.5 Mabsadd L
.59107 .40593 1.875 0 Mabsadd L
.59107 .40593 0 -2.5 Mabsadd L
.59107 .40593 -1.875 0 Mabsadd L closepath F
.59628 .40833 -1.875 0 Mabsadd m
.59628 .40833 0 2.5 Mabsadd L
.59628 .40833 1.875 0 Mabsadd L
.59628 .40833 0 -2.5 Mabsadd L
.59628 .40833 -1.875 0 Mabsadd L closepath F
.60148 .4111 -1.875 0 Mabsadd m
.60148 .4111 0 2.5 Mabsadd L
.60148 .4111 1.875 0 Mabsadd L
.60148 .4111 0 -2.5 Mabsadd L
.60148 .4111 -1.875 0 Mabsadd L closepath F
.60669 .4121 -1.875 0 Mabsadd m
.60669 .4121 0 2.5 Mabsadd L
.60669 .4121 1.875 0 Mabsadd L
.60669 .4121 0 -2.5 Mabsadd L
.60669 .4121 -1.875 0 Mabsadd L closepath F
.61189 .4151 -1.875 0 Mabsadd m
.61189 .4151 0 2.5 Mabsadd L
.61189 .4151 1.875 0 Mabsadd L
.61189 .4151 0 -2.5 Mabsadd L
.61189 .4151 -1.875 0 Mabsadd L closepath F
.6171 .3767 -1.875 0 Mabsadd m
.6171 .3767 0 2.5 Mabsadd L
.6171 .3767 1.875 0 Mabsadd L
.6171 .3767 0 -2.5 Mabsadd L
.6171 .3767 -1.875 0 Mabsadd L closepath F
.6223 .37063 -1.875 0 Mabsadd m
.6223 .37063 0 2.5 Mabsadd L
.6223 .37063 1.875 0 Mabsadd L
.6223 .37063 0 -2.5 Mabsadd L
.6223 .37063 -1.875 0 Mabsadd L closepath F
.6275 .36969 -1.875 0 Mabsadd m
.6275 .36969 0 2.5 Mabsadd L
.6275 .36969 1.875 0 Mabsadd L
.6275 .36969 0 -2.5 Mabsadd L
.6275 .36969 -1.875 0 Mabsadd L closepath F
.63271 .37979 -1.875 0 Mabsadd m
.63271 .37979 0 2.5 Mabsadd L
.63271 .37979 1.875 0 Mabsadd L
.63271 .37979 0 -2.5 Mabsadd L
.63271 .37979 -1.875 0 Mabsadd L closepath F
.63791 .38223 -1.875 0 Mabsadd m
.63791 .38223 0 2.5 Mabsadd L
.63791 .38223 1.875 0 Mabsadd L
.63791 .38223 0 -2.5 Mabsadd L
.63791 .38223 -1.875 0 Mabsadd L closepath F
.64312 .3762 -1.875 0 Mabsadd m
.64312 .3762 0 2.5 Mabsadd L
.64312 .3762 1.875 0 Mabsadd L
.64312 .3762 0 -2.5 Mabsadd L
.64312 .3762 -1.875 0 Mabsadd L closepath F
.64832 .37753 -1.875 0 Mabsadd m
.64832 .37753 0 2.5 Mabsadd L
.64832 .37753 1.875 0 Mabsadd L
.64832 .37753 0 -2.5 Mabsadd L
.64832 .37753 -1.875 0 Mabsadd L closepath F
.65353 .38004 -1.875 0 Mabsadd m
.65353 .38004 0 2.5 Mabsadd L
.65353 .38004 1.875 0 Mabsadd L
.65353 .38004 0 -2.5 Mabsadd L
.65353 .38004 -1.875 0 Mabsadd L closepath F
.65873 .38018 -1.875 0 Mabsadd m
.65873 .38018 0 2.5 Mabsadd L
.65873 .38018 1.875 0 Mabsadd L
.65873 .38018 0 -2.5 Mabsadd L
.65873 .38018 -1.875 0 Mabsadd L closepath F
.66393 .38948 -1.875 0 Mabsadd m
.66393 .38948 0 2.5 Mabsadd L
.66393 .38948 1.875 0 Mabsadd L
.66393 .38948 0 -2.5 Mabsadd L
.66393 .38948 -1.875 0 Mabsadd L closepath F
.66914 .38647 -1.875 0 Mabsadd m
.66914 .38647 0 2.5 Mabsadd L
.66914 .38647 1.875 0 Mabsadd L
.66914 .38647 0 -2.5 Mabsadd L
.66914 .38647 -1.875 0 Mabsadd L closepath F
.67434 .39036 -1.875 0 Mabsadd m
.67434 .39036 0 2.5 Mabsadd L
.67434 .39036 1.875 0 Mabsadd L
.67434 .39036 0 -2.5 Mabsadd L
.67434 .39036 -1.875 0 Mabsadd L closepath F
.67955 .39366 -1.875 0 Mabsadd m
.67955 .39366 0 2.5 Mabsadd L
.67955 .39366 1.875 0 Mabsadd L
.67955 .39366 0 -2.5 Mabsadd L
.67955 .39366 -1.875 0 Mabsadd L closepath F
.68475 .39603 -1.875 0 Mabsadd m
.68475 .39603 0 2.5 Mabsadd L
.68475 .39603 1.875 0 Mabsadd L
.68475 .39603 0 -2.5 Mabsadd L
.68475 .39603 -1.875 0 Mabsadd L closepath F
.68996 .38937 -1.875 0 Mabsadd m
.68996 .38937 0 2.5 Mabsadd L
.68996 .38937 1.875 0 Mabsadd L
.68996 .38937 0 -2.5 Mabsadd L
.68996 .38937 -1.875 0 Mabsadd L closepath F
.69516 .39905 -1.875 0 Mabsadd m
.69516 .39905 0 2.5 Mabsadd L
.69516 .39905 1.875 0 Mabsadd L
.69516 .39905 0 -2.5 Mabsadd L
.69516 .39905 -1.875 0 Mabsadd L closepath F
.70036 .3946 -1.875 0 Mabsadd m
.70036 .3946 0 2.5 Mabsadd L
.70036 .3946 1.875 0 Mabsadd L
.70036 .3946 0 -2.5 Mabsadd L
.70036 .3946 -1.875 0 Mabsadd L closepath F
.70557 .39258 -1.875 0 Mabsadd m
.70557 .39258 0 2.5 Mabsadd L
.70557 .39258 1.875 0 Mabsadd L
.70557 .39258 0 -2.5 Mabsadd L
.70557 .39258 -1.875 0 Mabsadd L closepath F
.71077 .39574 -1.875 0 Mabsadd m
.71077 .39574 0 2.5 Mabsadd L
.71077 .39574 1.875 0 Mabsadd L
.71077 .39574 0 -2.5 Mabsadd L
.71077 .39574 -1.875 0 Mabsadd L closepath F
.71598 .4073 -1.875 0 Mabsadd m
.71598 .4073 0 2.5 Mabsadd L
.71598 .4073 1.875 0 Mabsadd L
.71598 .4073 0 -2.5 Mabsadd L
.71598 .4073 -1.875 0 Mabsadd L closepath F
.72118 .40362 -1.875 0 Mabsadd m
.72118 .40362 0 2.5 Mabsadd L
.72118 .40362 1.875 0 Mabsadd L
.72118 .40362 0 -2.5 Mabsadd L
.72118 .40362 -1.875 0 Mabsadd L closepath F
.72639 .4131 -1.875 0 Mabsadd m
.72639 .4131 0 2.5 Mabsadd L
.72639 .4131 1.875 0 Mabsadd L
.72639 .4131 0 -2.5 Mabsadd L
.72639 .4131 -1.875 0 Mabsadd L closepath F
.73159 .41791 -1.875 0 Mabsadd m
.73159 .41791 0 2.5 Mabsadd L
.73159 .41791 1.875 0 Mabsadd L
.73159 .41791 0 -2.5 Mabsadd L
.73159 .41791 -1.875 0 Mabsadd L closepath F
.73679 .41763 -1.875 0 Mabsadd m
.73679 .41763 0 2.5 Mabsadd L
.73679 .41763 1.875 0 Mabsadd L
.73679 .41763 0 -2.5 Mabsadd L
.73679 .41763 -1.875 0 Mabsadd L closepath F
.742 .41515 -1.875 0 Mabsadd m
.742 .41515 0 2.5 Mabsadd L
.742 .41515 1.875 0 Mabsadd L
.742 .41515 0 -2.5 Mabsadd L
.742 .41515 -1.875 0 Mabsadd L closepath F
.7472 .42739 -1.875 0 Mabsadd m
.7472 .42739 0 2.5 Mabsadd L
.7472 .42739 1.875 0 Mabsadd L
.7472 .42739 0 -2.5 Mabsadd L
.7472 .42739 -1.875 0 Mabsadd L closepath F
.75241 .43225 -1.875 0 Mabsadd m
.75241 .43225 0 2.5 Mabsadd L
.75241 .43225 1.875 0 Mabsadd L
.75241 .43225 0 -2.5 Mabsadd L
.75241 .43225 -1.875 0 Mabsadd L closepath F
.75761 .4354 -1.875 0 Mabsadd m
.75761 .4354 0 2.5 Mabsadd L
.75761 .4354 1.875 0 Mabsadd L
.75761 .4354 0 -2.5 Mabsadd L
.75761 .4354 -1.875 0 Mabsadd L closepath F
.76282 .44184 -1.875 0 Mabsadd m
.76282 .44184 0 2.5 Mabsadd L
.76282 .44184 1.875 0 Mabsadd L
.76282 .44184 0 -2.5 Mabsadd L
.76282 .44184 -1.875 0 Mabsadd L closepath F
.76802 .43985 -1.875 0 Mabsadd m
.76802 .43985 0 2.5 Mabsadd L
.76802 .43985 1.875 0 Mabsadd L
.76802 .43985 0 -2.5 Mabsadd L
.76802 .43985 -1.875 0 Mabsadd L closepath F
.77322 .44752 -1.875 0 Mabsadd m
.77322 .44752 0 2.5 Mabsadd L
.77322 .44752 1.875 0 Mabsadd L
.77322 .44752 0 -2.5 Mabsadd L
.77322 .44752 -1.875 0 Mabsadd L closepath F
.77843 .45381 -1.875 0 Mabsadd m
.77843 .45381 0 2.5 Mabsadd L
.77843 .45381 1.875 0 Mabsadd L
.77843 .45381 0 -2.5 Mabsadd L
.77843 .45381 -1.875 0 Mabsadd L closepath F
.78363 .45651 -1.875 0 Mabsadd m
.78363 .45651 0 2.5 Mabsadd L
.78363 .45651 1.875 0 Mabsadd L
.78363 .45651 0 -2.5 Mabsadd L
.78363 .45651 -1.875 0 Mabsadd L closepath F
.78884 .45886 -1.875 0 Mabsadd m
.78884 .45886 0 2.5 Mabsadd L
.78884 .45886 1.875 0 Mabsadd L
.78884 .45886 0 -2.5 Mabsadd L
.78884 .45886 -1.875 0 Mabsadd L closepath F
.79404 .46456 -1.875 0 Mabsadd m
.79404 .46456 0 2.5 Mabsadd L
.79404 .46456 1.875 0 Mabsadd L
.79404 .46456 0 -2.5 Mabsadd L
.79404 .46456 -1.875 0 Mabsadd L closepath F
.79925 .46634 -1.875 0 Mabsadd m
.79925 .46634 0 2.5 Mabsadd L
.79925 .46634 1.875 0 Mabsadd L
.79925 .46634 0 -2.5 Mabsadd L
.79925 .46634 -1.875 0 Mabsadd L closepath F
.80445 .46956 -1.875 0 Mabsadd m
.80445 .46956 0 2.5 Mabsadd L
.80445 .46956 1.875 0 Mabsadd L
.80445 .46956 0 -2.5 Mabsadd L
.80445 .46956 -1.875 0 Mabsadd L closepath F
.80965 .46889 -1.875 0 Mabsadd m
.80965 .46889 0 2.5 Mabsadd L
.80965 .46889 1.875 0 Mabsadd L
.80965 .46889 0 -2.5 Mabsadd L
.80965 .46889 -1.875 0 Mabsadd L closepath F
.81486 .47206 -1.875 0 Mabsadd m
.81486 .47206 0 2.5 Mabsadd L
.81486 .47206 1.875 0 Mabsadd L
.81486 .47206 0 -2.5 Mabsadd L
.81486 .47206 -1.875 0 Mabsadd L closepath F
.82006 .47559 -1.875 0 Mabsadd m
.82006 .47559 0 2.5 Mabsadd L
.82006 .47559 1.875 0 Mabsadd L
.82006 .47559 0 -2.5 Mabsadd L
.82006 .47559 -1.875 0 Mabsadd L closepath F
.82527 .48006 -1.875 0 Mabsadd m
.82527 .48006 0 2.5 Mabsadd L
.82527 .48006 1.875 0 Mabsadd L
.82527 .48006 0 -2.5 Mabsadd L
.82527 .48006 -1.875 0 Mabsadd L closepath F
.83047 .479 -1.875 0 Mabsadd m
.83047 .479 0 2.5 Mabsadd L
.83047 .479 1.875 0 Mabsadd L
.83047 .479 0 -2.5 Mabsadd L
.83047 .479 -1.875 0 Mabsadd L closepath F
.83568 .48364 -1.875 0 Mabsadd m
.83568 .48364 0 2.5 Mabsadd L
.83568 .48364 1.875 0 Mabsadd L
.83568 .48364 0 -2.5 Mabsadd L
.83568 .48364 -1.875 0 Mabsadd L closepath F
.84088 .48241 -1.875 0 Mabsadd m
.84088 .48241 0 2.5 Mabsadd L
.84088 .48241 1.875 0 Mabsadd L
.84088 .48241 0 -2.5 Mabsadd L
.84088 .48241 -1.875 0 Mabsadd L closepath F
.84608 .48199 -1.875 0 Mabsadd m
.84608 .48199 0 2.5 Mabsadd L
.84608 .48199 1.875 0 Mabsadd L
.84608 .48199 0 -2.5 Mabsadd L
.84608 .48199 -1.875 0 Mabsadd L closepath F
.85129 .48135 -1.875 0 Mabsadd m
.85129 .48135 0 2.5 Mabsadd L
.85129 .48135 1.875 0 Mabsadd L
.85129 .48135 0 -2.5 Mabsadd L
.85129 .48135 -1.875 0 Mabsadd L closepath F
.85649 .48119 -1.875 0 Mabsadd m
.85649 .48119 0 2.5 Mabsadd L
.85649 .48119 1.875 0 Mabsadd L
.85649 .48119 0 -2.5 Mabsadd L
.85649 .48119 -1.875 0 Mabsadd L closepath F
.8617 .4845 -1.875 0 Mabsadd m
.8617 .4845 0 2.5 Mabsadd L
.8617 .4845 1.875 0 Mabsadd L
.8617 .4845 0 -2.5 Mabsadd L
.8617 .4845 -1.875 0 Mabsadd L closepath F
.8669 .48703 -1.875 0 Mabsadd m
.8669 .48703 0 2.5 Mabsadd L
.8669 .48703 1.875 0 Mabsadd L
.8669 .48703 0 -2.5 Mabsadd L
.8669 .48703 -1.875 0 Mabsadd L closepath F
.87211 .4836 -1.875 0 Mabsadd m
.87211 .4836 0 2.5 Mabsadd L
.87211 .4836 1.875 0 Mabsadd L
.87211 .4836 0 -2.5 Mabsadd L
.87211 .4836 -1.875 0 Mabsadd L closepath F
.87731 .48632 -1.875 0 Mabsadd m
.87731 .48632 0 2.5 Mabsadd L
.87731 .48632 1.875 0 Mabsadd L
.87731 .48632 0 -2.5 Mabsadd L
.87731 .48632 -1.875 0 Mabsadd L closepath F
.88251 .47903 -1.875 0 Mabsadd m
.88251 .47903 0 2.5 Mabsadd L
.88251 .47903 1.875 0 Mabsadd L
.88251 .47903 0 -2.5 Mabsadd L
.88251 .47903 -1.875 0 Mabsadd L closepath F
.88772 .48194 -1.875 0 Mabsadd m
.88772 .48194 0 2.5 Mabsadd L
.88772 .48194 1.875 0 Mabsadd L
.88772 .48194 0 -2.5 Mabsadd L
.88772 .48194 -1.875 0 Mabsadd L closepath F
.89292 .486 -1.875 0 Mabsadd m
.89292 .486 0 2.5 Mabsadd L
.89292 .486 1.875 0 Mabsadd L
.89292 .486 0 -2.5 Mabsadd L
.89292 .486 -1.875 0 Mabsadd L closepath F
.89813 .48189 -1.875 0 Mabsadd m
.89813 .48189 0 2.5 Mabsadd L
.89813 .48189 1.875 0 Mabsadd L
.89813 .48189 0 -2.5 Mabsadd L
.89813 .48189 -1.875 0 Mabsadd L closepath F
.90333 .48326 -1.875 0 Mabsadd m
.90333 .48326 0 2.5 Mabsadd L
.90333 .48326 1.875 0 Mabsadd L
.90333 .48326 0 -2.5 Mabsadd L
.90333 .48326 -1.875 0 Mabsadd L closepath F
.90853 .4817 -1.875 0 Mabsadd m
.90853 .4817 0 2.5 Mabsadd L
.90853 .4817 1.875 0 Mabsadd L
.90853 .4817 0 -2.5 Mabsadd L
.90853 .4817 -1.875 0 Mabsadd L closepath F
.91374 .48306 -1.875 0 Mabsadd m
.91374 .48306 0 2.5 Mabsadd L
.91374 .48306 1.875 0 Mabsadd L
.91374 .48306 0 -2.5 Mabsadd L
.91374 .48306 -1.875 0 Mabsadd L closepath F
.91894 .48635 -1.875 0 Mabsadd m
.91894 .48635 0 2.5 Mabsadd L
.91894 .48635 1.875 0 Mabsadd L
.91894 .48635 0 -2.5 Mabsadd L
.91894 .48635 -1.875 0 Mabsadd L closepath F
.92415 .492 -1.875 0 Mabsadd m
.92415 .492 0 2.5 Mabsadd L
.92415 .492 1.875 0 Mabsadd L
.92415 .492 0 -2.5 Mabsadd L
.92415 .492 -1.875 0 Mabsadd L closepath F
.92935 .49273 -1.875 0 Mabsadd m
.92935 .49273 0 2.5 Mabsadd L
.92935 .49273 1.875 0 Mabsadd L
.92935 .49273 0 -2.5 Mabsadd L
.92935 .49273 -1.875 0 Mabsadd L closepath F
.93456 .48554 -1.875 0 Mabsadd m
.93456 .48554 0 2.5 Mabsadd L
.93456 .48554 1.875 0 Mabsadd L
.93456 .48554 0 -2.5 Mabsadd L
.93456 .48554 -1.875 0 Mabsadd L closepath F
.93976 .49306 -1.875 0 Mabsadd m
.93976 .49306 0 2.5 Mabsadd L
.93976 .49306 1.875 0 Mabsadd L
.93976 .49306 0 -2.5 Mabsadd L
.93976 .49306 -1.875 0 Mabsadd L closepath F
.94496 .49613 -1.875 0 Mabsadd m
.94496 .49613 0 2.5 Mabsadd L
.94496 .49613 1.875 0 Mabsadd L
.94496 .49613 0 -2.5 Mabsadd L
.94496 .49613 -1.875 0 Mabsadd L closepath F
.95017 .49208 -1.875 0 Mabsadd m
.95017 .49208 0 2.5 Mabsadd L
.95017 .49208 1.875 0 Mabsadd L
.95017 .49208 0 -2.5 Mabsadd L
.95017 .49208 -1.875 0 Mabsadd L closepath F
.95537 .49712 -1.875 0 Mabsadd m
.95537 .49712 0 2.5 Mabsadd L
.95537 .49712 1.875 0 Mabsadd L
.95537 .49712 0 -2.5 Mabsadd L
.95537 .49712 -1.875 0 Mabsadd L closepath F
.96058 .49525 -1.875 0 Mabsadd m
.96058 .49525 0 2.5 Mabsadd L
.96058 .49525 1.875 0 Mabsadd L
.96058 .49525 0 -2.5 Mabsadd L
.96058 .49525 -1.875 0 Mabsadd L closepath F
.96578 .49724 -1.875 0 Mabsadd m
.96578 .49724 0 2.5 Mabsadd L
.96578 .49724 1.875 0 Mabsadd L
.96578 .49724 0 -2.5 Mabsadd L
.96578 .49724 -1.875 0 Mabsadd L closepath F
.97099 .49312 -1.875 0 Mabsadd m
.97099 .49312 0 2.5 Mabsadd L
.97099 .49312 1.875 0 Mabsadd L
.97099 .49312 0 -2.5 Mabsadd L
.97099 .49312 -1.875 0 Mabsadd L closepath F
.97619 .49861 -1.875 0 Mabsadd m
.97619 .49861 0 2.5 Mabsadd L
.97619 .49861 1.875 0 Mabsadd L
.97619 .49861 0 -2.5 Mabsadd L
.97619 .49861 -1.875 0 Mabsadd L closepath F
0 0 1 r
.02381 .31654 0 2.5 Mabsadd m
.02381 .31654 -0.56518 .7779 Mabsadd L
.02381 .31654 -2.37764 .77254 Mabsadd L
.02381 .31654 -0.91448 -0.29713 Mabsadd L
.02381 .31654 -1.46946 -2.02254 Mabsadd L
.02381 .31654 0 -0.96154 Mabsadd L
.02381 .31654 1.46946 -2.02254 Mabsadd L
.02381 .31654 .91448 -0.29713 Mabsadd L
.02381 .31654 2.37764 .77254 Mabsadd L
.02381 .31654 .56518 .7779 Mabsadd L
.02381 .31654 0 2.5 Mabsadd L closepath F
.02901 .31395 0 2.5 Mabsadd m
.02901 .31395 -0.56518 .7779 Mabsadd L
.02901 .31395 -2.37764 .77254 Mabsadd L
.02901 .31395 -0.91448 -0.29713 Mabsadd L
.02901 .31395 -1.46946 -2.02254 Mabsadd L
.02901 .31395 0 -0.96154 Mabsadd L
.02901 .31395 1.46946 -2.02254 Mabsadd L
.02901 .31395 .91448 -0.29713 Mabsadd L
.02901 .31395 2.37764 .77254 Mabsadd L
.02901 .31395 .56518 .7779 Mabsadd L
.02901 .31395 0 2.5 Mabsadd L closepath F
.03422 .31844 0 2.5 Mabsadd m
.03422 .31844 -0.56518 .7779 Mabsadd L
.03422 .31844 -2.37764 .77254 Mabsadd L
.03422 .31844 -0.91448 -0.29713 Mabsadd L
.03422 .31844 -1.46946 -2.02254 Mabsadd L
.03422 .31844 0 -0.96154 Mabsadd L
.03422 .31844 1.46946 -2.02254 Mabsadd L
.03422 .31844 .91448 -0.29713 Mabsadd L
.03422 .31844 2.37764 .77254 Mabsadd L
.03422 .31844 .56518 .7779 Mabsadd L
.03422 .31844 0 2.5 Mabsadd L closepath F
.03942 .31228 0 2.5 Mabsadd m
.03942 .31228 -0.56518 .7779 Mabsadd L
.03942 .31228 -2.37764 .77254 Mabsadd L
.03942 .31228 -0.91448 -0.29713 Mabsadd L
.03942 .31228 -1.46946 -2.02254 Mabsadd L
.03942 .31228 0 -0.96154 Mabsadd L
.03942 .31228 1.46946 -2.02254 Mabsadd L
.03942 .31228 .91448 -0.29713 Mabsadd L
.03942 .31228 2.37764 .77254 Mabsadd L
.03942 .31228 .56518 .7779 Mabsadd L
.03942 .31228 0 2.5 Mabsadd L closepath F
.04463 .30971 0 2.5 Mabsadd m
.04463 .30971 -0.56518 .7779 Mabsadd L
.04463 .30971 -2.37764 .77254 Mabsadd L
.04463 .30971 -0.91448 -0.29713 Mabsadd L
.04463 .30971 -1.46946 -2.02254 Mabsadd L
.04463 .30971 0 -0.96154 Mabsadd L
.04463 .30971 1.46946 -2.02254 Mabsadd L
.04463 .30971 .91448 -0.29713 Mabsadd L
.04463 .30971 2.37764 .77254 Mabsadd L
.04463 .30971 .56518 .7779 Mabsadd L
.04463 .30971 0 2.5 Mabsadd L closepath F
.04983 .32124 0 2.5 Mabsadd m
.04983 .32124 -0.56518 .7779 Mabsadd L
.04983 .32124 -2.37764 .77254 Mabsadd L
.04983 .32124 -0.91448 -0.29713 Mabsadd L
.04983 .32124 -1.46946 -2.02254 Mabsadd L
.04983 .32124 0 -0.96154 Mabsadd L
.04983 .32124 1.46946 -2.02254 Mabsadd L
.04983 .32124 .91448 -0.29713 Mabsadd L
.04983 .32124 2.37764 .77254 Mabsadd L
.04983 .32124 .56518 .7779 Mabsadd L
.04983 .32124 0 2.5 Mabsadd L closepath F
.05504 .31861 0 2.5 Mabsadd m
.05504 .31861 -0.56518 .7779 Mabsadd L
.05504 .31861 -2.37764 .77254 Mabsadd L
.05504 .31861 -0.91448 -0.29713 Mabsadd L
.05504 .31861 -1.46946 -2.02254 Mabsadd L
.05504 .31861 0 -0.96154 Mabsadd L
.05504 .31861 1.46946 -2.02254 Mabsadd L
.05504 .31861 .91448 -0.29713 Mabsadd L
.05504 .31861 2.37764 .77254 Mabsadd L
.05504 .31861 .56518 .7779 Mabsadd L
.05504 .31861 0 2.5 Mabsadd L closepath F
.06024 .32526 0 2.5 Mabsadd m
.06024 .32526 -0.56518 .7779 Mabsadd L
.06024 .32526 -2.37764 .77254 Mabsadd L
.06024 .32526 -0.91448 -0.29713 Mabsadd L
.06024 .32526 -1.46946 -2.02254 Mabsadd L
.06024 .32526 0 -0.96154 Mabsadd L
.06024 .32526 1.46946 -2.02254 Mabsadd L
.06024 .32526 .91448 -0.29713 Mabsadd L
.06024 .32526 2.37764 .77254 Mabsadd L
.06024 .32526 .56518 .7779 Mabsadd L
.06024 .32526 0 2.5 Mabsadd L closepath F
.06544 .32159 0 2.5 Mabsadd m
.06544 .32159 -0.56518 .7779 Mabsadd L
.06544 .32159 -2.37764 .77254 Mabsadd L
.06544 .32159 -0.91448 -0.29713 Mabsadd L
.06544 .32159 -1.46946 -2.02254 Mabsadd L
.06544 .32159 0 -0.96154 Mabsadd L
.06544 .32159 1.46946 -2.02254 Mabsadd L
.06544 .32159 .91448 -0.29713 Mabsadd L
.06544 .32159 2.37764 .77254 Mabsadd L
.06544 .32159 .56518 .7779 Mabsadd L
.06544 .32159 0 2.5 Mabsadd L closepath F
.07065 .31845 0 2.5 Mabsadd m
.07065 .31845 -0.56518 .7779 Mabsadd L
.07065 .31845 -2.37764 .77254 Mabsadd L
.07065 .31845 -0.91448 -0.29713 Mabsadd L
.07065 .31845 -1.46946 -2.02254 Mabsadd L
.07065 .31845 0 -0.96154 Mabsadd L
.07065 .31845 1.46946 -2.02254 Mabsadd L
.07065 .31845 .91448 -0.29713 Mabsadd L
.07065 .31845 2.37764 .77254 Mabsadd L
.07065 .31845 .56518 .7779 Mabsadd L
.07065 .31845 0 2.5 Mabsadd L closepath F
.07585 .32846 0 2.5 Mabsadd m
.07585 .32846 -0.56518 .7779 Mabsadd L
.07585 .32846 -2.37764 .77254 Mabsadd L
.07585 .32846 -0.91448 -0.29713 Mabsadd L
.07585 .32846 -1.46946 -2.02254 Mabsadd L
.07585 .32846 0 -0.96154 Mabsadd L
.07585 .32846 1.46946 -2.02254 Mabsadd L
.07585 .32846 .91448 -0.29713 Mabsadd L
.07585 .32846 2.37764 .77254 Mabsadd L
.07585 .32846 .56518 .7779 Mabsadd L
.07585 .32846 0 2.5 Mabsadd L closepath F
.08106 .32743 0 2.5 Mabsadd m
.08106 .32743 -0.56518 .7779 Mabsadd L
.08106 .32743 -2.37764 .77254 Mabsadd L
.08106 .32743 -0.91448 -0.29713 Mabsadd L
.08106 .32743 -1.46946 -2.02254 Mabsadd L
.08106 .32743 0 -0.96154 Mabsadd L
.08106 .32743 1.46946 -2.02254 Mabsadd L
.08106 .32743 .91448 -0.29713 Mabsadd L
.08106 .32743 2.37764 .77254 Mabsadd L
.08106 .32743 .56518 .7779 Mabsadd L
.08106 .32743 0 2.5 Mabsadd L closepath F
.08626 .32721 0 2.5 Mabsadd m
.08626 .32721 -0.56518 .7779 Mabsadd L
.08626 .32721 -2.37764 .77254 Mabsadd L
.08626 .32721 -0.91448 -0.29713 Mabsadd L
.08626 .32721 -1.46946 -2.02254 Mabsadd L
.08626 .32721 0 -0.96154 Mabsadd L
.08626 .32721 1.46946 -2.02254 Mabsadd L
.08626 .32721 .91448 -0.29713 Mabsadd L
.08626 .32721 2.37764 .77254 Mabsadd L
.08626 .32721 .56518 .7779 Mabsadd L
.08626 .32721 0 2.5 Mabsadd L closepath F
.09147 .33392 0 2.5 Mabsadd m
.09147 .33392 -0.56518 .7779 Mabsadd L
.09147 .33392 -2.37764 .77254 Mabsadd L
.09147 .33392 -0.91448 -0.29713 Mabsadd L
.09147 .33392 -1.46946 -2.02254 Mabsadd L
.09147 .33392 0 -0.96154 Mabsadd L
.09147 .33392 1.46946 -2.02254 Mabsadd L
.09147 .33392 .91448 -0.29713 Mabsadd L
.09147 .33392 2.37764 .77254 Mabsadd L
.09147 .33392 .56518 .7779 Mabsadd L
.09147 .33392 0 2.5 Mabsadd L closepath F
.09667 .33157 0 2.5 Mabsadd m
.09667 .33157 -0.56518 .7779 Mabsadd L
.09667 .33157 -2.37764 .77254 Mabsadd L
.09667 .33157 -0.91448 -0.29713 Mabsadd L
.09667 .33157 -1.46946 -2.02254 Mabsadd L
.09667 .33157 0 -0.96154 Mabsadd L
.09667 .33157 1.46946 -2.02254 Mabsadd L
.09667 .33157 .91448 -0.29713 Mabsadd L
.09667 .33157 2.37764 .77254 Mabsadd L
.09667 .33157 .56518 .7779 Mabsadd L
.09667 .33157 0 2.5 Mabsadd L closepath F
.10187 .33523 0 2.5 Mabsadd m
.10187 .33523 -0.56518 .7779 Mabsadd L
.10187 .33523 -2.37764 .77254 Mabsadd L
.10187 .33523 -0.91448 -0.29713 Mabsadd L
.10187 .33523 -1.46946 -2.02254 Mabsadd L
.10187 .33523 0 -0.96154 Mabsadd L
.10187 .33523 1.46946 -2.02254 Mabsadd L
.10187 .33523 .91448 -0.29713 Mabsadd L
.10187 .33523 2.37764 .77254 Mabsadd L
.10187 .33523 .56518 .7779 Mabsadd L
.10187 .33523 0 2.5 Mabsadd L closepath F
.10708 .32282 0 2.5 Mabsadd m
.10708 .32282 -0.56518 .7779 Mabsadd L
.10708 .32282 -2.37764 .77254 Mabsadd L
.10708 .32282 -0.91448 -0.29713 Mabsadd L
.10708 .32282 -1.46946 -2.02254 Mabsadd L
.10708 .32282 0 -0.96154 Mabsadd L
.10708 .32282 1.46946 -2.02254 Mabsadd L
.10708 .32282 .91448 -0.29713 Mabsadd L
.10708 .32282 2.37764 .77254 Mabsadd L
.10708 .32282 .56518 .7779 Mabsadd L
.10708 .32282 0 2.5 Mabsadd L closepath F
.11228 .3182 0 2.5 Mabsadd m
.11228 .3182 -0.56518 .7779 Mabsadd L
.11228 .3182 -2.37764 .77254 Mabsadd L
.11228 .3182 -0.91448 -0.29713 Mabsadd L
.11228 .3182 -1.46946 -2.02254 Mabsadd L
.11228 .3182 0 -0.96154 Mabsadd L
.11228 .3182 1.46946 -2.02254 Mabsadd L
.11228 .3182 .91448 -0.29713 Mabsadd L
.11228 .3182 2.37764 .77254 Mabsadd L
.11228 .3182 .56518 .7779 Mabsadd L
.11228 .3182 0 2.5 Mabsadd L closepath F
.11749 .3204 0 2.5 Mabsadd m
.11749 .3204 -0.56518 .7779 Mabsadd L
.11749 .3204 -2.37764 .77254 Mabsadd L
.11749 .3204 -0.91448 -0.29713 Mabsadd L
.11749 .3204 -1.46946 -2.02254 Mabsadd L
.11749 .3204 0 -0.96154 Mabsadd L
.11749 .3204 1.46946 -2.02254 Mabsadd L
.11749 .3204 .91448 -0.29713 Mabsadd L
.11749 .3204 2.37764 .77254 Mabsadd L
.11749 .3204 .56518 .7779 Mabsadd L
.11749 .3204 0 2.5 Mabsadd L closepath F
.12269 .31341 0 2.5 Mabsadd m
.12269 .31341 -0.56518 .7779 Mabsadd L
.12269 .31341 -2.37764 .77254 Mabsadd L
.12269 .31341 -0.91448 -0.29713 Mabsadd L
.12269 .31341 -1.46946 -2.02254 Mabsadd L
.12269 .31341 0 -0.96154 Mabsadd L
.12269 .31341 1.46946 -2.02254 Mabsadd L
.12269 .31341 .91448 -0.29713 Mabsadd L
.12269 .31341 2.37764 .77254 Mabsadd L
.12269 .31341 .56518 .7779 Mabsadd L
.12269 .31341 0 2.5 Mabsadd L closepath F
.12789 .30961 0 2.5 Mabsadd m
.12789 .30961 -0.56518 .7779 Mabsadd L
.12789 .30961 -2.37764 .77254 Mabsadd L
.12789 .30961 -0.91448 -0.29713 Mabsadd L
.12789 .30961 -1.46946 -2.02254 Mabsadd L
.12789 .30961 0 -0.96154 Mabsadd L
.12789 .30961 1.46946 -2.02254 Mabsadd L
.12789 .30961 .91448 -0.29713 Mabsadd L
.12789 .30961 2.37764 .77254 Mabsadd L
.12789 .30961 .56518 .7779 Mabsadd L
.12789 .30961 0 2.5 Mabsadd L closepath F
.1331 .30844 0 2.5 Mabsadd m
.1331 .30844 -0.56518 .7779 Mabsadd L
.1331 .30844 -2.37764 .77254 Mabsadd L
.1331 .30844 -0.91448 -0.29713 Mabsadd L
.1331 .30844 -1.46946 -2.02254 Mabsadd L
.1331 .30844 0 -0.96154 Mabsadd L
.1331 .30844 1.46946 -2.02254 Mabsadd L
.1331 .30844 .91448 -0.29713 Mabsadd L
.1331 .30844 2.37764 .77254 Mabsadd L
.1331 .30844 .56518 .7779 Mabsadd L
.1331 .30844 0 2.5 Mabsadd L closepath F
.1383 .31172 0 2.5 Mabsadd m
.1383 .31172 -0.56518 .7779 Mabsadd L
.1383 .31172 -2.37764 .77254 Mabsadd L
.1383 .31172 -0.91448 -0.29713 Mabsadd L
.1383 .31172 -1.46946 -2.02254 Mabsadd L
.1383 .31172 0 -0.96154 Mabsadd L
.1383 .31172 1.46946 -2.02254 Mabsadd L
.1383 .31172 .91448 -0.29713 Mabsadd L
.1383 .31172 2.37764 .77254 Mabsadd L
.1383 .31172 .56518 .7779 Mabsadd L
.1383 .31172 0 2.5 Mabsadd L closepath F
.14351 .30947 0 2.5 Mabsadd m
.14351 .30947 -0.56518 .7779 Mabsadd L
.14351 .30947 -2.37764 .77254 Mabsadd L
.14351 .30947 -0.91448 -0.29713 Mabsadd L
.14351 .30947 -1.46946 -2.02254 Mabsadd L
.14351 .30947 0 -0.96154 Mabsadd L
.14351 .30947 1.46946 -2.02254 Mabsadd L
.14351 .30947 .91448 -0.29713 Mabsadd L
.14351 .30947 2.37764 .77254 Mabsadd L
.14351 .30947 .56518 .7779 Mabsadd L
.14351 .30947 0 2.5 Mabsadd L closepath F
.14871 .30646 0 2.5 Mabsadd m
.14871 .30646 -0.56518 .7779 Mabsadd L
.14871 .30646 -2.37764 .77254 Mabsadd L
.14871 .30646 -0.91448 -0.29713 Mabsadd L
.14871 .30646 -1.46946 -2.02254 Mabsadd L
.14871 .30646 0 -0.96154 Mabsadd L
.14871 .30646 1.46946 -2.02254 Mabsadd L
.14871 .30646 .91448 -0.29713 Mabsadd L
.14871 .30646 2.37764 .77254 Mabsadd L
.14871 .30646 .56518 .7779 Mabsadd L
.14871 .30646 0 2.5 Mabsadd L closepath F
.15392 .30557 0 2.5 Mabsadd m
.15392 .30557 -0.56518 .7779 Mabsadd L
.15392 .30557 -2.37764 .77254 Mabsadd L
.15392 .30557 -0.91448 -0.29713 Mabsadd L
.15392 .30557 -1.46946 -2.02254 Mabsadd L
.15392 .30557 0 -0.96154 Mabsadd L
.15392 .30557 1.46946 -2.02254 Mabsadd L
.15392 .30557 .91448 -0.29713 Mabsadd L
.15392 .30557 2.37764 .77254 Mabsadd L
.15392 .30557 .56518 .7779 Mabsadd L
.15392 .30557 0 2.5 Mabsadd L closepath F
.15912 .29882 0 2.5 Mabsadd m
.15912 .29882 -0.56518 .7779 Mabsadd L
.15912 .29882 -2.37764 .77254 Mabsadd L
.15912 .29882 -0.91448 -0.29713 Mabsadd L
.15912 .29882 -1.46946 -2.02254 Mabsadd L
.15912 .29882 0 -0.96154 Mabsadd L
.15912 .29882 1.46946 -2.02254 Mabsadd L
.15912 .29882 .91448 -0.29713 Mabsadd L
.15912 .29882 2.37764 .77254 Mabsadd L
.15912 .29882 .56518 .7779 Mabsadd L
.15912 .29882 0 2.5 Mabsadd L closepath F
.16432 .31529 0 2.5 Mabsadd m
.16432 .31529 -0.56518 .7779 Mabsadd L
.16432 .31529 -2.37764 .77254 Mabsadd L
.16432 .31529 -0.91448 -0.29713 Mabsadd L
.16432 .31529 -1.46946 -2.02254 Mabsadd L
.16432 .31529 0 -0.96154 Mabsadd L
.16432 .31529 1.46946 -2.02254 Mabsadd L
.16432 .31529 .91448 -0.29713 Mabsadd L
.16432 .31529 2.37764 .77254 Mabsadd L
.16432 .31529 .56518 .7779 Mabsadd L
.16432 .31529 0 2.5 Mabsadd L closepath F
.16953 .31046 0 2.5 Mabsadd m
.16953 .31046 -0.56518 .7779 Mabsadd L
.16953 .31046 -2.37764 .77254 Mabsadd L
.16953 .31046 -0.91448 -0.29713 Mabsadd L
.16953 .31046 -1.46946 -2.02254 Mabsadd L
.16953 .31046 0 -0.96154 Mabsadd L
.16953 .31046 1.46946 -2.02254 Mabsadd L
.16953 .31046 .91448 -0.29713 Mabsadd L
.16953 .31046 2.37764 .77254 Mabsadd L
.16953 .31046 .56518 .7779 Mabsadd L
.16953 .31046 0 2.5 Mabsadd L closepath F
.17473 .3133 0 2.5 Mabsadd m
.17473 .3133 -0.56518 .7779 Mabsadd L
.17473 .3133 -2.37764 .77254 Mabsadd L
.17473 .3133 -0.91448 -0.29713 Mabsadd L
.17473 .3133 -1.46946 -2.02254 Mabsadd L
.17473 .3133 0 -0.96154 Mabsadd L
.17473 .3133 1.46946 -2.02254 Mabsadd L
.17473 .3133 .91448 -0.29713 Mabsadd L
.17473 .3133 2.37764 .77254 Mabsadd L
.17473 .3133 .56518 .7779 Mabsadd L
.17473 .3133 0 2.5 Mabsadd L closepath F
.17994 .31605 0 2.5 Mabsadd m
.17994 .31605 -0.56518 .7779 Mabsadd L
.17994 .31605 -2.37764 .77254 Mabsadd L
.17994 .31605 -0.91448 -0.29713 Mabsadd L
.17994 .31605 -1.46946 -2.02254 Mabsadd L
.17994 .31605 0 -0.96154 Mabsadd L
.17994 .31605 1.46946 -2.02254 Mabsadd L
.17994 .31605 .91448 -0.29713 Mabsadd L
.17994 .31605 2.37764 .77254 Mabsadd L
.17994 .31605 .56518 .7779 Mabsadd L
.17994 .31605 0 2.5 Mabsadd L closepath F
.18514 .31081 0 2.5 Mabsadd m
.18514 .31081 -0.56518 .7779 Mabsadd L
.18514 .31081 -2.37764 .77254 Mabsadd L
.18514 .31081 -0.91448 -0.29713 Mabsadd L
.18514 .31081 -1.46946 -2.02254 Mabsadd L
.18514 .31081 0 -0.96154 Mabsadd L
.18514 .31081 1.46946 -2.02254 Mabsadd L
.18514 .31081 .91448 -0.29713 Mabsadd L
.18514 .31081 2.37764 .77254 Mabsadd L
.18514 .31081 .56518 .7779 Mabsadd L
.18514 .31081 0 2.5 Mabsadd L closepath F
.19035 .30991 0 2.5 Mabsadd m
.19035 .30991 -0.56518 .7779 Mabsadd L
.19035 .30991 -2.37764 .77254 Mabsadd L
.19035 .30991 -0.91448 -0.29713 Mabsadd L
.19035 .30991 -1.46946 -2.02254 Mabsadd L
.19035 .30991 0 -0.96154 Mabsadd L
.19035 .30991 1.46946 -2.02254 Mabsadd L
.19035 .30991 .91448 -0.29713 Mabsadd L
.19035 .30991 2.37764 .77254 Mabsadd L
.19035 .30991 .56518 .7779 Mabsadd L
.19035 .30991 0 2.5 Mabsadd L closepath F
.19555 .30983 0 2.5 Mabsadd m
.19555 .30983 -0.56518 .7779 Mabsadd L
.19555 .30983 -2.37764 .77254 Mabsadd L
.19555 .30983 -0.91448 -0.29713 Mabsadd L
.19555 .30983 -1.46946 -2.02254 Mabsadd L
.19555 .30983 0 -0.96154 Mabsadd L
.19555 .30983 1.46946 -2.02254 Mabsadd L
.19555 .30983 .91448 -0.29713 Mabsadd L
.19555 .30983 2.37764 .77254 Mabsadd L
.19555 .30983 .56518 .7779 Mabsadd L
.19555 .30983 0 2.5 Mabsadd L closepath F
.20075 .30611 0 2.5 Mabsadd m
.20075 .30611 -0.56518 .7779 Mabsadd L
.20075 .30611 -2.37764 .77254 Mabsadd L
.20075 .30611 -0.91448 -0.29713 Mabsadd L
.20075 .30611 -1.46946 -2.02254 Mabsadd L
.20075 .30611 0 -0.96154 Mabsadd L
.20075 .30611 1.46946 -2.02254 Mabsadd L
.20075 .30611 .91448 -0.29713 Mabsadd L
.20075 .30611 2.37764 .77254 Mabsadd L
.20075 .30611 .56518 .7779 Mabsadd L
.20075 .30611 0 2.5 Mabsadd L closepath F
.20596 .31384 0 2.5 Mabsadd m
.20596 .31384 -0.56518 .7779 Mabsadd L
.20596 .31384 -2.37764 .77254 Mabsadd L
.20596 .31384 -0.91448 -0.29713 Mabsadd L
.20596 .31384 -1.46946 -2.02254 Mabsadd L
.20596 .31384 0 -0.96154 Mabsadd L
.20596 .31384 1.46946 -2.02254 Mabsadd L
.20596 .31384 .91448 -0.29713 Mabsadd L
.20596 .31384 2.37764 .77254 Mabsadd L
.20596 .31384 .56518 .7779 Mabsadd L
.20596 .31384 0 2.5 Mabsadd L closepath F
.21116 .3168 0 2.5 Mabsadd m
.21116 .3168 -0.56518 .7779 Mabsadd L
.21116 .3168 -2.37764 .77254 Mabsadd L
.21116 .3168 -0.91448 -0.29713 Mabsadd L
.21116 .3168 -1.46946 -2.02254 Mabsadd L
.21116 .3168 0 -0.96154 Mabsadd L
.21116 .3168 1.46946 -2.02254 Mabsadd L
.21116 .3168 .91448 -0.29713 Mabsadd L
.21116 .3168 2.37764 .77254 Mabsadd L
.21116 .3168 .56518 .7779 Mabsadd L
.21116 .3168 0 2.5 Mabsadd L closepath F
.21637 .31011 0 2.5 Mabsadd m
.21637 .31011 -0.56518 .7779 Mabsadd L
.21637 .31011 -2.37764 .77254 Mabsadd L
.21637 .31011 -0.91448 -0.29713 Mabsadd L
.21637 .31011 -1.46946 -2.02254 Mabsadd L
.21637 .31011 0 -0.96154 Mabsadd L
.21637 .31011 1.46946 -2.02254 Mabsadd L
.21637 .31011 .91448 -0.29713 Mabsadd L
.21637 .31011 2.37764 .77254 Mabsadd L
.21637 .31011 .56518 .7779 Mabsadd L
.21637 .31011 0 2.5 Mabsadd L closepath F
.22157 .32049 0 2.5 Mabsadd m
.22157 .32049 -0.56518 .7779 Mabsadd L
.22157 .32049 -2.37764 .77254 Mabsadd L
.22157 .32049 -0.91448 -0.29713 Mabsadd L
.22157 .32049 -1.46946 -2.02254 Mabsadd L
.22157 .32049 0 -0.96154 Mabsadd L
.22157 .32049 1.46946 -2.02254 Mabsadd L
.22157 .32049 .91448 -0.29713 Mabsadd L
.22157 .32049 2.37764 .77254 Mabsadd L
.22157 .32049 .56518 .7779 Mabsadd L
.22157 .32049 0 2.5 Mabsadd L closepath F
.22678 .31388 0 2.5 Mabsadd m
.22678 .31388 -0.56518 .7779 Mabsadd L
.22678 .31388 -2.37764 .77254 Mabsadd L
.22678 .31388 -0.91448 -0.29713 Mabsadd L
.22678 .31388 -1.46946 -2.02254 Mabsadd L
.22678 .31388 0 -0.96154 Mabsadd L
.22678 .31388 1.46946 -2.02254 Mabsadd L
.22678 .31388 .91448 -0.29713 Mabsadd L
.22678 .31388 2.37764 .77254 Mabsadd L
.22678 .31388 .56518 .7779 Mabsadd L
.22678 .31388 0 2.5 Mabsadd L closepath F
.23198 .31463 0 2.5 Mabsadd m
.23198 .31463 -0.56518 .7779 Mabsadd L
.23198 .31463 -2.37764 .77254 Mabsadd L
.23198 .31463 -0.91448 -0.29713 Mabsadd L
.23198 .31463 -1.46946 -2.02254 Mabsadd L
.23198 .31463 0 -0.96154 Mabsadd L
.23198 .31463 1.46946 -2.02254 Mabsadd L
.23198 .31463 .91448 -0.29713 Mabsadd L
.23198 .31463 2.37764 .77254 Mabsadd L
.23198 .31463 .56518 .7779 Mabsadd L
.23198 .31463 0 2.5 Mabsadd L closepath F
.23718 .32458 0 2.5 Mabsadd m
.23718 .32458 -0.56518 .7779 Mabsadd L
.23718 .32458 -2.37764 .77254 Mabsadd L
.23718 .32458 -0.91448 -0.29713 Mabsadd L
.23718 .32458 -1.46946 -2.02254 Mabsadd L
.23718 .32458 0 -0.96154 Mabsadd L
.23718 .32458 1.46946 -2.02254 Mabsadd L
.23718 .32458 .91448 -0.29713 Mabsadd L
.23718 .32458 2.37764 .77254 Mabsadd L
.23718 .32458 .56518 .7779 Mabsadd L
.23718 .32458 0 2.5 Mabsadd L closepath F
.24239 .32951 0 2.5 Mabsadd m
.24239 .32951 -0.56518 .7779 Mabsadd L
.24239 .32951 -2.37764 .77254 Mabsadd L
.24239 .32951 -0.91448 -0.29713 Mabsadd L
.24239 .32951 -1.46946 -2.02254 Mabsadd L
.24239 .32951 0 -0.96154 Mabsadd L
.24239 .32951 1.46946 -2.02254 Mabsadd L
.24239 .32951 .91448 -0.29713 Mabsadd L
.24239 .32951 2.37764 .77254 Mabsadd L
.24239 .32951 .56518 .7779 Mabsadd L
.24239 .32951 0 2.5 Mabsadd L closepath F
.24759 .32509 0 2.5 Mabsadd m
.24759 .32509 -0.56518 .7779 Mabsadd L
.24759 .32509 -2.37764 .77254 Mabsadd L
.24759 .32509 -0.91448 -0.29713 Mabsadd L
.24759 .32509 -1.46946 -2.02254 Mabsadd L
.24759 .32509 0 -0.96154 Mabsadd L
.24759 .32509 1.46946 -2.02254 Mabsadd L
.24759 .32509 .91448 -0.29713 Mabsadd L
.24759 .32509 2.37764 .77254 Mabsadd L
.24759 .32509 .56518 .7779 Mabsadd L
.24759 .32509 0 2.5 Mabsadd L closepath F
.2528 .32592 0 2.5 Mabsadd m
.2528 .32592 -0.56518 .7779 Mabsadd L
.2528 .32592 -2.37764 .77254 Mabsadd L
.2528 .32592 -0.91448 -0.29713 Mabsadd L
.2528 .32592 -1.46946 -2.02254 Mabsadd L
.2528 .32592 0 -0.96154 Mabsadd L
.2528 .32592 1.46946 -2.02254 Mabsadd L
.2528 .32592 .91448 -0.29713 Mabsadd L
.2528 .32592 2.37764 .77254 Mabsadd L
.2528 .32592 .56518 .7779 Mabsadd L
.2528 .32592 0 2.5 Mabsadd L closepath F
.258 .33225 0 2.5 Mabsadd m
.258 .33225 -0.56518 .7779 Mabsadd L
.258 .33225 -2.37764 .77254 Mabsadd L
.258 .33225 -0.91448 -0.29713 Mabsadd L
.258 .33225 -1.46946 -2.02254 Mabsadd L
.258 .33225 0 -0.96154 Mabsadd L
.258 .33225 1.46946 -2.02254 Mabsadd L
.258 .33225 .91448 -0.29713 Mabsadd L
.258 .33225 2.37764 .77254 Mabsadd L
.258 .33225 .56518 .7779 Mabsadd L
.258 .33225 0 2.5 Mabsadd L closepath F
.26321 .3332 0 2.5 Mabsadd m
.26321 .3332 -0.56518 .7779 Mabsadd L
.26321 .3332 -2.37764 .77254 Mabsadd L
.26321 .3332 -0.91448 -0.29713 Mabsadd L
.26321 .3332 -1.46946 -2.02254 Mabsadd L
.26321 .3332 0 -0.96154 Mabsadd L
.26321 .3332 1.46946 -2.02254 Mabsadd L
.26321 .3332 .91448 -0.29713 Mabsadd L
.26321 .3332 2.37764 .77254 Mabsadd L
.26321 .3332 .56518 .7779 Mabsadd L
.26321 .3332 0 2.5 Mabsadd L closepath F
.26841 .33778 0 2.5 Mabsadd m
.26841 .33778 -0.56518 .7779 Mabsadd L
.26841 .33778 -2.37764 .77254 Mabsadd L
.26841 .33778 -0.91448 -0.29713 Mabsadd L
.26841 .33778 -1.46946 -2.02254 Mabsadd L
.26841 .33778 0 -0.96154 Mabsadd L
.26841 .33778 1.46946 -2.02254 Mabsadd L
.26841 .33778 .91448 -0.29713 Mabsadd L
.26841 .33778 2.37764 .77254 Mabsadd L
.26841 .33778 .56518 .7779 Mabsadd L
.26841 .33778 0 2.5 Mabsadd L closepath F
.27361 .28868 0 2.5 Mabsadd m
.27361 .28868 -0.56518 .7779 Mabsadd L
.27361 .28868 -2.37764 .77254 Mabsadd L
.27361 .28868 -0.91448 -0.29713 Mabsadd L
.27361 .28868 -1.46946 -2.02254 Mabsadd L
.27361 .28868 0 -0.96154 Mabsadd L
.27361 .28868 1.46946 -2.02254 Mabsadd L
.27361 .28868 .91448 -0.29713 Mabsadd L
.27361 .28868 2.37764 .77254 Mabsadd L
.27361 .28868 .56518 .7779 Mabsadd L
.27361 .28868 0 2.5 Mabsadd L closepath F
.27882 .2817 0 2.5 Mabsadd m
.27882 .2817 -0.56518 .7779 Mabsadd L
.27882 .2817 -2.37764 .77254 Mabsadd L
.27882 .2817 -0.91448 -0.29713 Mabsadd L
.27882 .2817 -1.46946 -2.02254 Mabsadd L
.27882 .2817 0 -0.96154 Mabsadd L
.27882 .2817 1.46946 -2.02254 Mabsadd L
.27882 .2817 .91448 -0.29713 Mabsadd L
.27882 .2817 2.37764 .77254 Mabsadd L
.27882 .2817 .56518 .7779 Mabsadd L
.27882 .2817 0 2.5 Mabsadd L closepath F
.28402 .28275 0 2.5 Mabsadd m
.28402 .28275 -0.56518 .7779 Mabsadd L
.28402 .28275 -2.37764 .77254 Mabsadd L
.28402 .28275 -0.91448 -0.29713 Mabsadd L
.28402 .28275 -1.46946 -2.02254 Mabsadd L
.28402 .28275 0 -0.96154 Mabsadd L
.28402 .28275 1.46946 -2.02254 Mabsadd L
.28402 .28275 .91448 -0.29713 Mabsadd L
.28402 .28275 2.37764 .77254 Mabsadd L
.28402 .28275 .56518 .7779 Mabsadd L
.28402 .28275 0 2.5 Mabsadd L closepath F
.28923 .27791 0 2.5 Mabsadd m
.28923 .27791 -0.56518 .7779 Mabsadd L
.28923 .27791 -2.37764 .77254 Mabsadd L
.28923 .27791 -0.91448 -0.29713 Mabsadd L
.28923 .27791 -1.46946 -2.02254 Mabsadd L
.28923 .27791 0 -0.96154 Mabsadd L
.28923 .27791 1.46946 -2.02254 Mabsadd L
.28923 .27791 .91448 -0.29713 Mabsadd L
.28923 .27791 2.37764 .77254 Mabsadd L
.28923 .27791 .56518 .7779 Mabsadd L
.28923 .27791 0 2.5 Mabsadd L closepath F
.29443 .28228 0 2.5 Mabsadd m
.29443 .28228 -0.56518 .7779 Mabsadd L
.29443 .28228 -2.37764 .77254 Mabsadd L
.29443 .28228 -0.91448 -0.29713 Mabsadd L
.29443 .28228 -1.46946 -2.02254 Mabsadd L
.29443 .28228 0 -0.96154 Mabsadd L
.29443 .28228 1.46946 -2.02254 Mabsadd L
.29443 .28228 .91448 -0.29713 Mabsadd L
.29443 .28228 2.37764 .77254 Mabsadd L
.29443 .28228 .56518 .7779 Mabsadd L
.29443 .28228 0 2.5 Mabsadd L closepath F
.29964 .27823 0 2.5 Mabsadd m
.29964 .27823 -0.56518 .7779 Mabsadd L
.29964 .27823 -2.37764 .77254 Mabsadd L
.29964 .27823 -0.91448 -0.29713 Mabsadd L
.29964 .27823 -1.46946 -2.02254 Mabsadd L
.29964 .27823 0 -0.96154 Mabsadd L
.29964 .27823 1.46946 -2.02254 Mabsadd L
.29964 .27823 .91448 -0.29713 Mabsadd L
.29964 .27823 2.37764 .77254 Mabsadd L
.29964 .27823 .56518 .7779 Mabsadd L
.29964 .27823 0 2.5 Mabsadd L closepath F
.30484 .28198 0 2.5 Mabsadd m
.30484 .28198 -0.56518 .7779 Mabsadd L
.30484 .28198 -2.37764 .77254 Mabsadd L
.30484 .28198 -0.91448 -0.29713 Mabsadd L
.30484 .28198 -1.46946 -2.02254 Mabsadd L
.30484 .28198 0 -0.96154 Mabsadd L
.30484 .28198 1.46946 -2.02254 Mabsadd L
.30484 .28198 .91448 -0.29713 Mabsadd L
.30484 .28198 2.37764 .77254 Mabsadd L
.30484 .28198 .56518 .7779 Mabsadd L
.30484 .28198 0 2.5 Mabsadd L closepath F
.31004 .27743 0 2.5 Mabsadd m
.31004 .27743 -0.56518 .7779 Mabsadd L
.31004 .27743 -2.37764 .77254 Mabsadd L
.31004 .27743 -0.91448 -0.29713 Mabsadd L
.31004 .27743 -1.46946 -2.02254 Mabsadd L
.31004 .27743 0 -0.96154 Mabsadd L
.31004 .27743 1.46946 -2.02254 Mabsadd L
.31004 .27743 .91448 -0.29713 Mabsadd L
.31004 .27743 2.37764 .77254 Mabsadd L
.31004 .27743 .56518 .7779 Mabsadd L
.31004 .27743 0 2.5 Mabsadd L closepath F
.31525 .27536 0 2.5 Mabsadd m
.31525 .27536 -0.56518 .7779 Mabsadd L
.31525 .27536 -2.37764 .77254 Mabsadd L
.31525 .27536 -0.91448 -0.29713 Mabsadd L
.31525 .27536 -1.46946 -2.02254 Mabsadd L
.31525 .27536 0 -0.96154 Mabsadd L
.31525 .27536 1.46946 -2.02254 Mabsadd L
.31525 .27536 .91448 -0.29713 Mabsadd L
.31525 .27536 2.37764 .77254 Mabsadd L
.31525 .27536 .56518 .7779 Mabsadd L
.31525 .27536 0 2.5 Mabsadd L closepath F
.32045 .2825 0 2.5 Mabsadd m
.32045 .2825 -0.56518 .7779 Mabsadd L
.32045 .2825 -2.37764 .77254 Mabsadd L
.32045 .2825 -0.91448 -0.29713 Mabsadd L
.32045 .2825 -1.46946 -2.02254 Mabsadd L
.32045 .2825 0 -0.96154 Mabsadd L
.32045 .2825 1.46946 -2.02254 Mabsadd L
.32045 .2825 .91448 -0.29713 Mabsadd L
.32045 .2825 2.37764 .77254 Mabsadd L
.32045 .2825 .56518 .7779 Mabsadd L
.32045 .2825 0 2.5 Mabsadd L closepath F
.32566 .28582 0 2.5 Mabsadd m
.32566 .28582 -0.56518 .7779 Mabsadd L
.32566 .28582 -2.37764 .77254 Mabsadd L
.32566 .28582 -0.91448 -0.29713 Mabsadd L
.32566 .28582 -1.46946 -2.02254 Mabsadd L
.32566 .28582 0 -0.96154 Mabsadd L
.32566 .28582 1.46946 -2.02254 Mabsadd L
.32566 .28582 .91448 -0.29713 Mabsadd L
.32566 .28582 2.37764 .77254 Mabsadd L
.32566 .28582 .56518 .7779 Mabsadd L
.32566 .28582 0 2.5 Mabsadd L closepath F
.33086 .27736 0 2.5 Mabsadd m
.33086 .27736 -0.56518 .7779 Mabsadd L
.33086 .27736 -2.37764 .77254 Mabsadd L
.33086 .27736 -0.91448 -0.29713 Mabsadd L
.33086 .27736 -1.46946 -2.02254 Mabsadd L
.33086 .27736 0 -0.96154 Mabsadd L
.33086 .27736 1.46946 -2.02254 Mabsadd L
.33086 .27736 .91448 -0.29713 Mabsadd L
.33086 .27736 2.37764 .77254 Mabsadd L
.33086 .27736 .56518 .7779 Mabsadd L
.33086 .27736 0 2.5 Mabsadd L closepath F
.33607 .28073 0 2.5 Mabsadd m
.33607 .28073 -0.56518 .7779 Mabsadd L
.33607 .28073 -2.37764 .77254 Mabsadd L
.33607 .28073 -0.91448 -0.29713 Mabsadd L
.33607 .28073 -1.46946 -2.02254 Mabsadd L
.33607 .28073 0 -0.96154 Mabsadd L
.33607 .28073 1.46946 -2.02254 Mabsadd L
.33607 .28073 .91448 -0.29713 Mabsadd L
.33607 .28073 2.37764 .77254 Mabsadd L
.33607 .28073 .56518 .7779 Mabsadd L
.33607 .28073 0 2.5 Mabsadd L closepath F
.34127 .27924 0 2.5 Mabsadd m
.34127 .27924 -0.56518 .7779 Mabsadd L
.34127 .27924 -2.37764 .77254 Mabsadd L
.34127 .27924 -0.91448 -0.29713 Mabsadd L
.34127 .27924 -1.46946 -2.02254 Mabsadd L
.34127 .27924 0 -0.96154 Mabsadd L
.34127 .27924 1.46946 -2.02254 Mabsadd L
.34127 .27924 .91448 -0.29713 Mabsadd L
.34127 .27924 2.37764 .77254 Mabsadd L
.34127 .27924 .56518 .7779 Mabsadd L
.34127 .27924 0 2.5 Mabsadd L closepath F
.34647 .27591 0 2.5 Mabsadd m
.34647 .27591 -0.56518 .7779 Mabsadd L
.34647 .27591 -2.37764 .77254 Mabsadd L
.34647 .27591 -0.91448 -0.29713 Mabsadd L
.34647 .27591 -1.46946 -2.02254 Mabsadd L
.34647 .27591 0 -0.96154 Mabsadd L
.34647 .27591 1.46946 -2.02254 Mabsadd L
.34647 .27591 .91448 -0.29713 Mabsadd L
.34647 .27591 2.37764 .77254 Mabsadd L
.34647 .27591 .56518 .7779 Mabsadd L
.34647 .27591 0 2.5 Mabsadd L closepath F
.35168 .27905 0 2.5 Mabsadd m
.35168 .27905 -0.56518 .7779 Mabsadd L
.35168 .27905 -2.37764 .77254 Mabsadd L
.35168 .27905 -0.91448 -0.29713 Mabsadd L
.35168 .27905 -1.46946 -2.02254 Mabsadd L
.35168 .27905 0 -0.96154 Mabsadd L
.35168 .27905 1.46946 -2.02254 Mabsadd L
.35168 .27905 .91448 -0.29713 Mabsadd L
.35168 .27905 2.37764 .77254 Mabsadd L
.35168 .27905 .56518 .7779 Mabsadd L
.35168 .27905 0 2.5 Mabsadd L closepath F
.35688 .27447 0 2.5 Mabsadd m
.35688 .27447 -0.56518 .7779 Mabsadd L
.35688 .27447 -2.37764 .77254 Mabsadd L
.35688 .27447 -0.91448 -0.29713 Mabsadd L
.35688 .27447 -1.46946 -2.02254 Mabsadd L
.35688 .27447 0 -0.96154 Mabsadd L
.35688 .27447 1.46946 -2.02254 Mabsadd L
.35688 .27447 .91448 -0.29713 Mabsadd L
.35688 .27447 2.37764 .77254 Mabsadd L
.35688 .27447 .56518 .7779 Mabsadd L
.35688 .27447 0 2.5 Mabsadd L closepath F
.36209 .27493 0 2.5 Mabsadd m
.36209 .27493 -0.56518 .7779 Mabsadd L
.36209 .27493 -2.37764 .77254 Mabsadd L
.36209 .27493 -0.91448 -0.29713 Mabsadd L
.36209 .27493 -1.46946 -2.02254 Mabsadd L
.36209 .27493 0 -0.96154 Mabsadd L
.36209 .27493 1.46946 -2.02254 Mabsadd L
.36209 .27493 .91448 -0.29713 Mabsadd L
.36209 .27493 2.37764 .77254 Mabsadd L
.36209 .27493 .56518 .7779 Mabsadd L
.36209 .27493 0 2.5 Mabsadd L closepath F
.36729 .279 0 2.5 Mabsadd m
.36729 .279 -0.56518 .7779 Mabsadd L
.36729 .279 -2.37764 .77254 Mabsadd L
.36729 .279 -0.91448 -0.29713 Mabsadd L
.36729 .279 -1.46946 -2.02254 Mabsadd L
.36729 .279 0 -0.96154 Mabsadd L
.36729 .279 1.46946 -2.02254 Mabsadd L
.36729 .279 .91448 -0.29713 Mabsadd L
.36729 .279 2.37764 .77254 Mabsadd L
.36729 .279 .56518 .7779 Mabsadd L
.36729 .279 0 2.5 Mabsadd L closepath F
.3725 .28289 0 2.5 Mabsadd m
.3725 .28289 -0.56518 .7779 Mabsadd L
.3725 .28289 -2.37764 .77254 Mabsadd L
.3725 .28289 -0.91448 -0.29713 Mabsadd L
.3725 .28289 -1.46946 -2.02254 Mabsadd L
.3725 .28289 0 -0.96154 Mabsadd L
.3725 .28289 1.46946 -2.02254 Mabsadd L
.3725 .28289 .91448 -0.29713 Mabsadd L
.3725 .28289 2.37764 .77254 Mabsadd L
.3725 .28289 .56518 .7779 Mabsadd L
.3725 .28289 0 2.5 Mabsadd L closepath F
.3777 .28081 0 2.5 Mabsadd m
.3777 .28081 -0.56518 .7779 Mabsadd L
.3777 .28081 -2.37764 .77254 Mabsadd L
.3777 .28081 -0.91448 -0.29713 Mabsadd L
.3777 .28081 -1.46946 -2.02254 Mabsadd L
.3777 .28081 0 -0.96154 Mabsadd L
.3777 .28081 1.46946 -2.02254 Mabsadd L
.3777 .28081 .91448 -0.29713 Mabsadd L
.3777 .28081 2.37764 .77254 Mabsadd L
.3777 .28081 .56518 .7779 Mabsadd L
.3777 .28081 0 2.5 Mabsadd L closepath F
.3829 .30842 0 2.5 Mabsadd m
.3829 .30842 -0.56518 .7779 Mabsadd L
.3829 .30842 -2.37764 .77254 Mabsadd L
.3829 .30842 -0.91448 -0.29713 Mabsadd L
.3829 .30842 -1.46946 -2.02254 Mabsadd L
.3829 .30842 0 -0.96154 Mabsadd L
.3829 .30842 1.46946 -2.02254 Mabsadd L
.3829 .30842 .91448 -0.29713 Mabsadd L
.3829 .30842 2.37764 .77254 Mabsadd L
.3829 .30842 .56518 .7779 Mabsadd L
.3829 .30842 0 2.5 Mabsadd L closepath F
.38811 .30652 0 2.5 Mabsadd m
.38811 .30652 -0.56518 .7779 Mabsadd L
.38811 .30652 -2.37764 .77254 Mabsadd L
.38811 .30652 -0.91448 -0.29713 Mabsadd L
.38811 .30652 -1.46946 -2.02254 Mabsadd L
.38811 .30652 0 -0.96154 Mabsadd L
.38811 .30652 1.46946 -2.02254 Mabsadd L
.38811 .30652 .91448 -0.29713 Mabsadd L
.38811 .30652 2.37764 .77254 Mabsadd L
.38811 .30652 .56518 .7779 Mabsadd L
.38811 .30652 0 2.5 Mabsadd L closepath F
.39331 .30821 0 2.5 Mabsadd m
.39331 .30821 -0.56518 .7779 Mabsadd L
.39331 .30821 -2.37764 .77254 Mabsadd L
.39331 .30821 -0.91448 -0.29713 Mabsadd L
.39331 .30821 -1.46946 -2.02254 Mabsadd L
.39331 .30821 0 -0.96154 Mabsadd L
.39331 .30821 1.46946 -2.02254 Mabsadd L
.39331 .30821 .91448 -0.29713 Mabsadd L
.39331 .30821 2.37764 .77254 Mabsadd L
.39331 .30821 .56518 .7779 Mabsadd L
.39331 .30821 0 2.5 Mabsadd L closepath F
.39852 .30161 0 2.5 Mabsadd m
.39852 .30161 -0.56518 .7779 Mabsadd L
.39852 .30161 -2.37764 .77254 Mabsadd L
.39852 .30161 -0.91448 -0.29713 Mabsadd L
.39852 .30161 -1.46946 -2.02254 Mabsadd L
.39852 .30161 0 -0.96154 Mabsadd L
.39852 .30161 1.46946 -2.02254 Mabsadd L
.39852 .30161 .91448 -0.29713 Mabsadd L
.39852 .30161 2.37764 .77254 Mabsadd L
.39852 .30161 .56518 .7779 Mabsadd L
.39852 .30161 0 2.5 Mabsadd L closepath F
.40372 .29424 0 2.5 Mabsadd m
.40372 .29424 -0.56518 .7779 Mabsadd L
.40372 .29424 -2.37764 .77254 Mabsadd L
.40372 .29424 -0.91448 -0.29713 Mabsadd L
.40372 .29424 -1.46946 -2.02254 Mabsadd L
.40372 .29424 0 -0.96154 Mabsadd L
.40372 .29424 1.46946 -2.02254 Mabsadd L
.40372 .29424 .91448 -0.29713 Mabsadd L
.40372 .29424 2.37764 .77254 Mabsadd L
.40372 .29424 .56518 .7779 Mabsadd L
.40372 .29424 0 2.5 Mabsadd L closepath F
.40893 .30211 0 2.5 Mabsadd m
.40893 .30211 -0.56518 .7779 Mabsadd L
.40893 .30211 -2.37764 .77254 Mabsadd L
.40893 .30211 -0.91448 -0.29713 Mabsadd L
.40893 .30211 -1.46946 -2.02254 Mabsadd L
.40893 .30211 0 -0.96154 Mabsadd L
.40893 .30211 1.46946 -2.02254 Mabsadd L
.40893 .30211 .91448 -0.29713 Mabsadd L
.40893 .30211 2.37764 .77254 Mabsadd L
.40893 .30211 .56518 .7779 Mabsadd L
.40893 .30211 0 2.5 Mabsadd L closepath F
.41413 .29611 0 2.5 Mabsadd m
.41413 .29611 -0.56518 .7779 Mabsadd L
.41413 .29611 -2.37764 .77254 Mabsadd L
.41413 .29611 -0.91448 -0.29713 Mabsadd L
.41413 .29611 -1.46946 -2.02254 Mabsadd L
.41413 .29611 0 -0.96154 Mabsadd L
.41413 .29611 1.46946 -2.02254 Mabsadd L
.41413 .29611 .91448 -0.29713 Mabsadd L
.41413 .29611 2.37764 .77254 Mabsadd L
.41413 .29611 .56518 .7779 Mabsadd L
.41413 .29611 0 2.5 Mabsadd L closepath F
.41933 .29176 0 2.5 Mabsadd m
.41933 .29176 -0.56518 .7779 Mabsadd L
.41933 .29176 -2.37764 .77254 Mabsadd L
.41933 .29176 -0.91448 -0.29713 Mabsadd L
.41933 .29176 -1.46946 -2.02254 Mabsadd L
.41933 .29176 0 -0.96154 Mabsadd L
.41933 .29176 1.46946 -2.02254 Mabsadd L
.41933 .29176 .91448 -0.29713 Mabsadd L
.41933 .29176 2.37764 .77254 Mabsadd L
.41933 .29176 .56518 .7779 Mabsadd L
.41933 .29176 0 2.5 Mabsadd L closepath F
.42454 .29955 0 2.5 Mabsadd m
.42454 .29955 -0.56518 .7779 Mabsadd L
.42454 .29955 -2.37764 .77254 Mabsadd L
.42454 .29955 -0.91448 -0.29713 Mabsadd L
.42454 .29955 -1.46946 -2.02254 Mabsadd L
.42454 .29955 0 -0.96154 Mabsadd L
.42454 .29955 1.46946 -2.02254 Mabsadd L
.42454 .29955 .91448 -0.29713 Mabsadd L
.42454 .29955 2.37764 .77254 Mabsadd L
.42454 .29955 .56518 .7779 Mabsadd L
.42454 .29955 0 2.5 Mabsadd L closepath F
.42974 .29797 0 2.5 Mabsadd m
.42974 .29797 -0.56518 .7779 Mabsadd L
.42974 .29797 -2.37764 .77254 Mabsadd L
.42974 .29797 -0.91448 -0.29713 Mabsadd L
.42974 .29797 -1.46946 -2.02254 Mabsadd L
.42974 .29797 0 -0.96154 Mabsadd L
.42974 .29797 1.46946 -2.02254 Mabsadd L
.42974 .29797 .91448 -0.29713 Mabsadd L
.42974 .29797 2.37764 .77254 Mabsadd L
.42974 .29797 .56518 .7779 Mabsadd L
.42974 .29797 0 2.5 Mabsadd L closepath F
.43495 .30094 0 2.5 Mabsadd m
.43495 .30094 -0.56518 .7779 Mabsadd L
.43495 .30094 -2.37764 .77254 Mabsadd L
.43495 .30094 -0.91448 -0.29713 Mabsadd L
.43495 .30094 -1.46946 -2.02254 Mabsadd L
.43495 .30094 0 -0.96154 Mabsadd L
.43495 .30094 1.46946 -2.02254 Mabsadd L
.43495 .30094 .91448 -0.29713 Mabsadd L
.43495 .30094 2.37764 .77254 Mabsadd L
.43495 .30094 .56518 .7779 Mabsadd L
.43495 .30094 0 2.5 Mabsadd L closepath F
.44015 .30416 0 2.5 Mabsadd m
.44015 .30416 -0.56518 .7779 Mabsadd L
.44015 .30416 -2.37764 .77254 Mabsadd L
.44015 .30416 -0.91448 -0.29713 Mabsadd L
.44015 .30416 -1.46946 -2.02254 Mabsadd L
.44015 .30416 0 -0.96154 Mabsadd L
.44015 .30416 1.46946 -2.02254 Mabsadd L
.44015 .30416 .91448 -0.29713 Mabsadd L
.44015 .30416 2.37764 .77254 Mabsadd L
.44015 .30416 .56518 .7779 Mabsadd L
.44015 .30416 0 2.5 Mabsadd L closepath F
.44536 .30858 0 2.5 Mabsadd m
.44536 .30858 -0.56518 .7779 Mabsadd L
.44536 .30858 -2.37764 .77254 Mabsadd L
.44536 .30858 -0.91448 -0.29713 Mabsadd L
.44536 .30858 -1.46946 -2.02254 Mabsadd L
.44536 .30858 0 -0.96154 Mabsadd L
.44536 .30858 1.46946 -2.02254 Mabsadd L
.44536 .30858 .91448 -0.29713 Mabsadd L
.44536 .30858 2.37764 .77254 Mabsadd L
.44536 .30858 .56518 .7779 Mabsadd L
.44536 .30858 0 2.5 Mabsadd L closepath F
.45056 .31259 0 2.5 Mabsadd m
.45056 .31259 -0.56518 .7779 Mabsadd L
.45056 .31259 -2.37764 .77254 Mabsadd L
.45056 .31259 -0.91448 -0.29713 Mabsadd L
.45056 .31259 -1.46946 -2.02254 Mabsadd L
.45056 .31259 0 -0.96154 Mabsadd L
.45056 .31259 1.46946 -2.02254 Mabsadd L
.45056 .31259 .91448 -0.29713 Mabsadd L
.45056 .31259 2.37764 .77254 Mabsadd L
.45056 .31259 .56518 .7779 Mabsadd L
.45056 .31259 0 2.5 Mabsadd L closepath F
.45576 .31003 0 2.5 Mabsadd m
.45576 .31003 -0.56518 .7779 Mabsadd L
.45576 .31003 -2.37764 .77254 Mabsadd L
.45576 .31003 -0.91448 -0.29713 Mabsadd L
.45576 .31003 -1.46946 -2.02254 Mabsadd L
.45576 .31003 0 -0.96154 Mabsadd L
.45576 .31003 1.46946 -2.02254 Mabsadd L
.45576 .31003 .91448 -0.29713 Mabsadd L
.45576 .31003 2.37764 .77254 Mabsadd L
.45576 .31003 .56518 .7779 Mabsadd L
.45576 .31003 0 2.5 Mabsadd L closepath F
.46097 .31347 0 2.5 Mabsadd m
.46097 .31347 -0.56518 .7779 Mabsadd L
.46097 .31347 -2.37764 .77254 Mabsadd L
.46097 .31347 -0.91448 -0.29713 Mabsadd L
.46097 .31347 -1.46946 -2.02254 Mabsadd L
.46097 .31347 0 -0.96154 Mabsadd L
.46097 .31347 1.46946 -2.02254 Mabsadd L
.46097 .31347 .91448 -0.29713 Mabsadd L
.46097 .31347 2.37764 .77254 Mabsadd L
.46097 .31347 .56518 .7779 Mabsadd L
.46097 .31347 0 2.5 Mabsadd L closepath F
.46617 .31455 0 2.5 Mabsadd m
.46617 .31455 -0.56518 .7779 Mabsadd L
.46617 .31455 -2.37764 .77254 Mabsadd L
.46617 .31455 -0.91448 -0.29713 Mabsadd L
.46617 .31455 -1.46946 -2.02254 Mabsadd L
.46617 .31455 0 -0.96154 Mabsadd L
.46617 .31455 1.46946 -2.02254 Mabsadd L
.46617 .31455 .91448 -0.29713 Mabsadd L
.46617 .31455 2.37764 .77254 Mabsadd L
.46617 .31455 .56518 .7779 Mabsadd L
.46617 .31455 0 2.5 Mabsadd L closepath F
.47138 .33381 0 2.5 Mabsadd m
.47138 .33381 -0.56518 .7779 Mabsadd L
.47138 .33381 -2.37764 .77254 Mabsadd L
.47138 .33381 -0.91448 -0.29713 Mabsadd L
.47138 .33381 -1.46946 -2.02254 Mabsadd L
.47138 .33381 0 -0.96154 Mabsadd L
.47138 .33381 1.46946 -2.02254 Mabsadd L
.47138 .33381 .91448 -0.29713 Mabsadd L
.47138 .33381 2.37764 .77254 Mabsadd L
.47138 .33381 .56518 .7779 Mabsadd L
.47138 .33381 0 2.5 Mabsadd L closepath F
.47658 .33349 0 2.5 Mabsadd m
.47658 .33349 -0.56518 .7779 Mabsadd L
.47658 .33349 -2.37764 .77254 Mabsadd L
.47658 .33349 -0.91448 -0.29713 Mabsadd L
.47658 .33349 -1.46946 -2.02254 Mabsadd L
.47658 .33349 0 -0.96154 Mabsadd L
.47658 .33349 1.46946 -2.02254 Mabsadd L
.47658 .33349 .91448 -0.29713 Mabsadd L
.47658 .33349 2.37764 .77254 Mabsadd L
.47658 .33349 .56518 .7779 Mabsadd L
.47658 .33349 0 2.5 Mabsadd L closepath F
.48179 .34199 0 2.5 Mabsadd m
.48179 .34199 -0.56518 .7779 Mabsadd L
.48179 .34199 -2.37764 .77254 Mabsadd L
.48179 .34199 -0.91448 -0.29713 Mabsadd L
.48179 .34199 -1.46946 -2.02254 Mabsadd L
.48179 .34199 0 -0.96154 Mabsadd L
.48179 .34199 1.46946 -2.02254 Mabsadd L
.48179 .34199 .91448 -0.29713 Mabsadd L
.48179 .34199 2.37764 .77254 Mabsadd L
.48179 .34199 .56518 .7779 Mabsadd L
.48179 .34199 0 2.5 Mabsadd L closepath F
.48699 .34979 0 2.5 Mabsadd m
.48699 .34979 -0.56518 .7779 Mabsadd L
.48699 .34979 -2.37764 .77254 Mabsadd L
.48699 .34979 -0.91448 -0.29713 Mabsadd L
.48699 .34979 -1.46946 -2.02254 Mabsadd L
.48699 .34979 0 -0.96154 Mabsadd L
.48699 .34979 1.46946 -2.02254 Mabsadd L
.48699 .34979 .91448 -0.29713 Mabsadd L
.48699 .34979 2.37764 .77254 Mabsadd L
.48699 .34979 .56518 .7779 Mabsadd L
.48699 .34979 0 2.5 Mabsadd L closepath F
.49219 .34714 0 2.5 Mabsadd m
.49219 .34714 -0.56518 .7779 Mabsadd L
.49219 .34714 -2.37764 .77254 Mabsadd L
.49219 .34714 -0.91448 -0.29713 Mabsadd L
.49219 .34714 -1.46946 -2.02254 Mabsadd L
.49219 .34714 0 -0.96154 Mabsadd L
.49219 .34714 1.46946 -2.02254 Mabsadd L
.49219 .34714 .91448 -0.29713 Mabsadd L
.49219 .34714 2.37764 .77254 Mabsadd L
.49219 .34714 .56518 .7779 Mabsadd L
.49219 .34714 0 2.5 Mabsadd L closepath F
.4974 .35188 0 2.5 Mabsadd m
.4974 .35188 -0.56518 .7779 Mabsadd L
.4974 .35188 -2.37764 .77254 Mabsadd L
.4974 .35188 -0.91448 -0.29713 Mabsadd L
.4974 .35188 -1.46946 -2.02254 Mabsadd L
.4974 .35188 0 -0.96154 Mabsadd L
.4974 .35188 1.46946 -2.02254 Mabsadd L
.4974 .35188 .91448 -0.29713 Mabsadd L
.4974 .35188 2.37764 .77254 Mabsadd L
.4974 .35188 .56518 .7779 Mabsadd L
.4974 .35188 0 2.5 Mabsadd L closepath F
.5026 .36083 0 2.5 Mabsadd m
.5026 .36083 -0.56518 .7779 Mabsadd L
.5026 .36083 -2.37764 .77254 Mabsadd L
.5026 .36083 -0.91448 -0.29713 Mabsadd L
.5026 .36083 -1.46946 -2.02254 Mabsadd L
.5026 .36083 0 -0.96154 Mabsadd L
.5026 .36083 1.46946 -2.02254 Mabsadd L
.5026 .36083 .91448 -0.29713 Mabsadd L
.5026 .36083 2.37764 .77254 Mabsadd L
.5026 .36083 .56518 .7779 Mabsadd L
.5026 .36083 0 2.5 Mabsadd L closepath F
.50781 .36945 0 2.5 Mabsadd m
.50781 .36945 -0.56518 .7779 Mabsadd L
.50781 .36945 -2.37764 .77254 Mabsadd L
.50781 .36945 -0.91448 -0.29713 Mabsadd L
.50781 .36945 -1.46946 -2.02254 Mabsadd L
.50781 .36945 0 -0.96154 Mabsadd L
.50781 .36945 1.46946 -2.02254 Mabsadd L
.50781 .36945 .91448 -0.29713 Mabsadd L
.50781 .36945 2.37764 .77254 Mabsadd L
.50781 .36945 .56518 .7779 Mabsadd L
.50781 .36945 0 2.5 Mabsadd L closepath F
.51301 .36827 0 2.5 Mabsadd m
.51301 .36827 -0.56518 .7779 Mabsadd L
.51301 .36827 -2.37764 .77254 Mabsadd L
.51301 .36827 -0.91448 -0.29713 Mabsadd L
.51301 .36827 -1.46946 -2.02254 Mabsadd L
.51301 .36827 0 -0.96154 Mabsadd L
.51301 .36827 1.46946 -2.02254 Mabsadd L
.51301 .36827 .91448 -0.29713 Mabsadd L
.51301 .36827 2.37764 .77254 Mabsadd L
.51301 .36827 .56518 .7779 Mabsadd L
.51301 .36827 0 2.5 Mabsadd L closepath F
.51821 .37856 0 2.5 Mabsadd m
.51821 .37856 -0.56518 .7779 Mabsadd L
.51821 .37856 -2.37764 .77254 Mabsadd L
.51821 .37856 -0.91448 -0.29713 Mabsadd L
.51821 .37856 -1.46946 -2.02254 Mabsadd L
.51821 .37856 0 -0.96154 Mabsadd L
.51821 .37856 1.46946 -2.02254 Mabsadd L
.51821 .37856 .91448 -0.29713 Mabsadd L
.51821 .37856 2.37764 .77254 Mabsadd L
.51821 .37856 .56518 .7779 Mabsadd L
.51821 .37856 0 2.5 Mabsadd L closepath F
.52342 .38431 0 2.5 Mabsadd m
.52342 .38431 -0.56518 .7779 Mabsadd L
.52342 .38431 -2.37764 .77254 Mabsadd L
.52342 .38431 -0.91448 -0.29713 Mabsadd L
.52342 .38431 -1.46946 -2.02254 Mabsadd L
.52342 .38431 0 -0.96154 Mabsadd L
.52342 .38431 1.46946 -2.02254 Mabsadd L
.52342 .38431 .91448 -0.29713 Mabsadd L
.52342 .38431 2.37764 .77254 Mabsadd L
.52342 .38431 .56518 .7779 Mabsadd L
.52342 .38431 0 2.5 Mabsadd L closepath F
.52862 .38833 0 2.5 Mabsadd m
.52862 .38833 -0.56518 .7779 Mabsadd L
.52862 .38833 -2.37764 .77254 Mabsadd L
.52862 .38833 -0.91448 -0.29713 Mabsadd L
.52862 .38833 -1.46946 -2.02254 Mabsadd L
.52862 .38833 0 -0.96154 Mabsadd L
.52862 .38833 1.46946 -2.02254 Mabsadd L
.52862 .38833 .91448 -0.29713 Mabsadd L
.52862 .38833 2.37764 .77254 Mabsadd L
.52862 .38833 .56518 .7779 Mabsadd L
.52862 .38833 0 2.5 Mabsadd L closepath F
.53383 .39812 0 2.5 Mabsadd m
.53383 .39812 -0.56518 .7779 Mabsadd L
.53383 .39812 -2.37764 .77254 Mabsadd L
.53383 .39812 -0.91448 -0.29713 Mabsadd L
.53383 .39812 -1.46946 -2.02254 Mabsadd L
.53383 .39812 0 -0.96154 Mabsadd L
.53383 .39812 1.46946 -2.02254 Mabsadd L
.53383 .39812 .91448 -0.29713 Mabsadd L
.53383 .39812 2.37764 .77254 Mabsadd L
.53383 .39812 .56518 .7779 Mabsadd L
.53383 .39812 0 2.5 Mabsadd L closepath F
.53903 .40575 0 2.5 Mabsadd m
.53903 .40575 -0.56518 .7779 Mabsadd L
.53903 .40575 -2.37764 .77254 Mabsadd L
.53903 .40575 -0.91448 -0.29713 Mabsadd L
.53903 .40575 -1.46946 -2.02254 Mabsadd L
.53903 .40575 0 -0.96154 Mabsadd L
.53903 .40575 1.46946 -2.02254 Mabsadd L
.53903 .40575 .91448 -0.29713 Mabsadd L
.53903 .40575 2.37764 .77254 Mabsadd L
.53903 .40575 .56518 .7779 Mabsadd L
.53903 .40575 0 2.5 Mabsadd L closepath F
.54424 .41751 0 2.5 Mabsadd m
.54424 .41751 -0.56518 .7779 Mabsadd L
.54424 .41751 -2.37764 .77254 Mabsadd L
.54424 .41751 -0.91448 -0.29713 Mabsadd L
.54424 .41751 -1.46946 -2.02254 Mabsadd L
.54424 .41751 0 -0.96154 Mabsadd L
.54424 .41751 1.46946 -2.02254 Mabsadd L
.54424 .41751 .91448 -0.29713 Mabsadd L
.54424 .41751 2.37764 .77254 Mabsadd L
.54424 .41751 .56518 .7779 Mabsadd L
.54424 .41751 0 2.5 Mabsadd L closepath F
.54944 .42018 0 2.5 Mabsadd m
.54944 .42018 -0.56518 .7779 Mabsadd L
.54944 .42018 -2.37764 .77254 Mabsadd L
.54944 .42018 -0.91448 -0.29713 Mabsadd L
.54944 .42018 -1.46946 -2.02254 Mabsadd L
.54944 .42018 0 -0.96154 Mabsadd L
.54944 .42018 1.46946 -2.02254 Mabsadd L
.54944 .42018 .91448 -0.29713 Mabsadd L
.54944 .42018 2.37764 .77254 Mabsadd L
.54944 .42018 .56518 .7779 Mabsadd L
.54944 .42018 0 2.5 Mabsadd L closepath F
.55464 .42655 0 2.5 Mabsadd m
.55464 .42655 -0.56518 .7779 Mabsadd L
.55464 .42655 -2.37764 .77254 Mabsadd L
.55464 .42655 -0.91448 -0.29713 Mabsadd L
.55464 .42655 -1.46946 -2.02254 Mabsadd L
.55464 .42655 0 -0.96154 Mabsadd L
.55464 .42655 1.46946 -2.02254 Mabsadd L
.55464 .42655 .91448 -0.29713 Mabsadd L
.55464 .42655 2.37764 .77254 Mabsadd L
.55464 .42655 .56518 .7779 Mabsadd L
.55464 .42655 0 2.5 Mabsadd L closepath F
.55985 .42922 0 2.5 Mabsadd m
.55985 .42922 -0.56518 .7779 Mabsadd L
.55985 .42922 -2.37764 .77254 Mabsadd L
.55985 .42922 -0.91448 -0.29713 Mabsadd L
.55985 .42922 -1.46946 -2.02254 Mabsadd L
.55985 .42922 0 -0.96154 Mabsadd L
.55985 .42922 1.46946 -2.02254 Mabsadd L
.55985 .42922 .91448 -0.29713 Mabsadd L
.55985 .42922 2.37764 .77254 Mabsadd L
.55985 .42922 .56518 .7779 Mabsadd L
.55985 .42922 0 2.5 Mabsadd L closepath F
.56505 .44257 0 2.5 Mabsadd m
.56505 .44257 -0.56518 .7779 Mabsadd L
.56505 .44257 -2.37764 .77254 Mabsadd L
.56505 .44257 -0.91448 -0.29713 Mabsadd L
.56505 .44257 -1.46946 -2.02254 Mabsadd L
.56505 .44257 0 -0.96154 Mabsadd L
.56505 .44257 1.46946 -2.02254 Mabsadd L
.56505 .44257 .91448 -0.29713 Mabsadd L
.56505 .44257 2.37764 .77254 Mabsadd L
.56505 .44257 .56518 .7779 Mabsadd L
.56505 .44257 0 2.5 Mabsadd L closepath F
.57026 .44555 0 2.5 Mabsadd m
.57026 .44555 -0.56518 .7779 Mabsadd L
.57026 .44555 -2.37764 .77254 Mabsadd L
.57026 .44555 -0.91448 -0.29713 Mabsadd L
.57026 .44555 -1.46946 -2.02254 Mabsadd L
.57026 .44555 0 -0.96154 Mabsadd L
.57026 .44555 1.46946 -2.02254 Mabsadd L
.57026 .44555 .91448 -0.29713 Mabsadd L
.57026 .44555 2.37764 .77254 Mabsadd L
.57026 .44555 .56518 .7779 Mabsadd L
.57026 .44555 0 2.5 Mabsadd L closepath F
.57546 .44734 0 2.5 Mabsadd m
.57546 .44734 -0.56518 .7779 Mabsadd L
.57546 .44734 -2.37764 .77254 Mabsadd L
.57546 .44734 -0.91448 -0.29713 Mabsadd L
.57546 .44734 -1.46946 -2.02254 Mabsadd L
.57546 .44734 0 -0.96154 Mabsadd L
.57546 .44734 1.46946 -2.02254 Mabsadd L
.57546 .44734 .91448 -0.29713 Mabsadd L
.57546 .44734 2.37764 .77254 Mabsadd L
.57546 .44734 .56518 .7779 Mabsadd L
.57546 .44734 0 2.5 Mabsadd L closepath F
.58067 .45175 0 2.5 Mabsadd m
.58067 .45175 -0.56518 .7779 Mabsadd L
.58067 .45175 -2.37764 .77254 Mabsadd L
.58067 .45175 -0.91448 -0.29713 Mabsadd L
.58067 .45175 -1.46946 -2.02254 Mabsadd L
.58067 .45175 0 -0.96154 Mabsadd L
.58067 .45175 1.46946 -2.02254 Mabsadd L
.58067 .45175 .91448 -0.29713 Mabsadd L
.58067 .45175 2.37764 .77254 Mabsadd L
.58067 .45175 .56518 .7779 Mabsadd L
.58067 .45175 0 2.5 Mabsadd L closepath F
.58587 .46129 0 2.5 Mabsadd m
.58587 .46129 -0.56518 .7779 Mabsadd L
.58587 .46129 -2.37764 .77254 Mabsadd L
.58587 .46129 -0.91448 -0.29713 Mabsadd L
.58587 .46129 -1.46946 -2.02254 Mabsadd L
.58587 .46129 0 -0.96154 Mabsadd L
.58587 .46129 1.46946 -2.02254 Mabsadd L
.58587 .46129 .91448 -0.29713 Mabsadd L
.58587 .46129 2.37764 .77254 Mabsadd L
.58587 .46129 .56518 .7779 Mabsadd L
.58587 .46129 0 2.5 Mabsadd L closepath F
.59107 .46751 0 2.5 Mabsadd m
.59107 .46751 -0.56518 .7779 Mabsadd L
.59107 .46751 -2.37764 .77254 Mabsadd L
.59107 .46751 -0.91448 -0.29713 Mabsadd L
.59107 .46751 -1.46946 -2.02254 Mabsadd L
.59107 .46751 0 -0.96154 Mabsadd L
.59107 .46751 1.46946 -2.02254 Mabsadd L
.59107 .46751 .91448 -0.29713 Mabsadd L
.59107 .46751 2.37764 .77254 Mabsadd L
.59107 .46751 .56518 .7779 Mabsadd L
.59107 .46751 0 2.5 Mabsadd L closepath F
.59628 .47243 0 2.5 Mabsadd m
.59628 .47243 -0.56518 .7779 Mabsadd L
.59628 .47243 -2.37764 .77254 Mabsadd L
.59628 .47243 -0.91448 -0.29713 Mabsadd L
.59628 .47243 -1.46946 -2.02254 Mabsadd L
.59628 .47243 0 -0.96154 Mabsadd L
.59628 .47243 1.46946 -2.02254 Mabsadd L
.59628 .47243 .91448 -0.29713 Mabsadd L
.59628 .47243 2.37764 .77254 Mabsadd L
.59628 .47243 .56518 .7779 Mabsadd L
.59628 .47243 0 2.5 Mabsadd L closepath F
.60148 .47386 0 2.5 Mabsadd m
.60148 .47386 -0.56518 .7779 Mabsadd L
.60148 .47386 -2.37764 .77254 Mabsadd L
.60148 .47386 -0.91448 -0.29713 Mabsadd L
.60148 .47386 -1.46946 -2.02254 Mabsadd L
.60148 .47386 0 -0.96154 Mabsadd L
.60148 .47386 1.46946 -2.02254 Mabsadd L
.60148 .47386 .91448 -0.29713 Mabsadd L
.60148 .47386 2.37764 .77254 Mabsadd L
.60148 .47386 .56518 .7779 Mabsadd L
.60148 .47386 0 2.5 Mabsadd L closepath F
.60669 .32233 0 2.5 Mabsadd m
.60669 .32233 -0.56518 .7779 Mabsadd L
.60669 .32233 -2.37764 .77254 Mabsadd L
.60669 .32233 -0.91448 -0.29713 Mabsadd L
.60669 .32233 -1.46946 -2.02254 Mabsadd L
.60669 .32233 0 -0.96154 Mabsadd L
.60669 .32233 1.46946 -2.02254 Mabsadd L
.60669 .32233 .91448 -0.29713 Mabsadd L
.60669 .32233 2.37764 .77254 Mabsadd L
.60669 .32233 .56518 .7779 Mabsadd L
.60669 .32233 0 2.5 Mabsadd L closepath F
.61189 .32647 0 2.5 Mabsadd m
.61189 .32647 -0.56518 .7779 Mabsadd L
.61189 .32647 -2.37764 .77254 Mabsadd L
.61189 .32647 -0.91448 -0.29713 Mabsadd L
.61189 .32647 -1.46946 -2.02254 Mabsadd L
.61189 .32647 0 -0.96154 Mabsadd L
.61189 .32647 1.46946 -2.02254 Mabsadd L
.61189 .32647 .91448 -0.29713 Mabsadd L
.61189 .32647 2.37764 .77254 Mabsadd L
.61189 .32647 .56518 .7779 Mabsadd L
.61189 .32647 0 2.5 Mabsadd L closepath F
.6171 .33417 0 2.5 Mabsadd m
.6171 .33417 -0.56518 .7779 Mabsadd L
.6171 .33417 -2.37764 .77254 Mabsadd L
.6171 .33417 -0.91448 -0.29713 Mabsadd L
.6171 .33417 -1.46946 -2.02254 Mabsadd L
.6171 .33417 0 -0.96154 Mabsadd L
.6171 .33417 1.46946 -2.02254 Mabsadd L
.6171 .33417 .91448 -0.29713 Mabsadd L
.6171 .33417 2.37764 .77254 Mabsadd L
.6171 .33417 .56518 .7779 Mabsadd L
.6171 .33417 0 2.5 Mabsadd L closepath F
.6223 .32935 0 2.5 Mabsadd m
.6223 .32935 -0.56518 .7779 Mabsadd L
.6223 .32935 -2.37764 .77254 Mabsadd L
.6223 .32935 -0.91448 -0.29713 Mabsadd L
.6223 .32935 -1.46946 -2.02254 Mabsadd L
.6223 .32935 0 -0.96154 Mabsadd L
.6223 .32935 1.46946 -2.02254 Mabsadd L
.6223 .32935 .91448 -0.29713 Mabsadd L
.6223 .32935 2.37764 .77254 Mabsadd L
.6223 .32935 .56518 .7779 Mabsadd L
.6223 .32935 0 2.5 Mabsadd L closepath F
.6275 .33638 0 2.5 Mabsadd m
.6275 .33638 -0.56518 .7779 Mabsadd L
.6275 .33638 -2.37764 .77254 Mabsadd L
.6275 .33638 -0.91448 -0.29713 Mabsadd L
.6275 .33638 -1.46946 -2.02254 Mabsadd L
.6275 .33638 0 -0.96154 Mabsadd L
.6275 .33638 1.46946 -2.02254 Mabsadd L
.6275 .33638 .91448 -0.29713 Mabsadd L
.6275 .33638 2.37764 .77254 Mabsadd L
.6275 .33638 .56518 .7779 Mabsadd L
.6275 .33638 0 2.5 Mabsadd L closepath F
.63271 .34826 0 2.5 Mabsadd m
.63271 .34826 -0.56518 .7779 Mabsadd L
.63271 .34826 -2.37764 .77254 Mabsadd L
.63271 .34826 -0.91448 -0.29713 Mabsadd L
.63271 .34826 -1.46946 -2.02254 Mabsadd L
.63271 .34826 0 -0.96154 Mabsadd L
.63271 .34826 1.46946 -2.02254 Mabsadd L
.63271 .34826 .91448 -0.29713 Mabsadd L
.63271 .34826 2.37764 .77254 Mabsadd L
.63271 .34826 .56518 .7779 Mabsadd L
.63271 .34826 0 2.5 Mabsadd L closepath F
.63791 .35374 0 2.5 Mabsadd m
.63791 .35374 -0.56518 .7779 Mabsadd L
.63791 .35374 -2.37764 .77254 Mabsadd L
.63791 .35374 -0.91448 -0.29713 Mabsadd L
.63791 .35374 -1.46946 -2.02254 Mabsadd L
.63791 .35374 0 -0.96154 Mabsadd L
.63791 .35374 1.46946 -2.02254 Mabsadd L
.63791 .35374 .91448 -0.29713 Mabsadd L
.63791 .35374 2.37764 .77254 Mabsadd L
.63791 .35374 .56518 .7779 Mabsadd L
.63791 .35374 0 2.5 Mabsadd L closepath F
.64312 .34969 0 2.5 Mabsadd m
.64312 .34969 -0.56518 .7779 Mabsadd L
.64312 .34969 -2.37764 .77254 Mabsadd L
.64312 .34969 -0.91448 -0.29713 Mabsadd L
.64312 .34969 -1.46946 -2.02254 Mabsadd L
.64312 .34969 0 -0.96154 Mabsadd L
.64312 .34969 1.46946 -2.02254 Mabsadd L
.64312 .34969 .91448 -0.29713 Mabsadd L
.64312 .34969 2.37764 .77254 Mabsadd L
.64312 .34969 .56518 .7779 Mabsadd L
.64312 .34969 0 2.5 Mabsadd L closepath F
.64832 .35576 0 2.5 Mabsadd m
.64832 .35576 -0.56518 .7779 Mabsadd L
.64832 .35576 -2.37764 .77254 Mabsadd L
.64832 .35576 -0.91448 -0.29713 Mabsadd L
.64832 .35576 -1.46946 -2.02254 Mabsadd L
.64832 .35576 0 -0.96154 Mabsadd L
.64832 .35576 1.46946 -2.02254 Mabsadd L
.64832 .35576 .91448 -0.29713 Mabsadd L
.64832 .35576 2.37764 .77254 Mabsadd L
.64832 .35576 .56518 .7779 Mabsadd L
.64832 .35576 0 2.5 Mabsadd L closepath F
.65353 .36791 0 2.5 Mabsadd m
.65353 .36791 -0.56518 .7779 Mabsadd L
.65353 .36791 -2.37764 .77254 Mabsadd L
.65353 .36791 -0.91448 -0.29713 Mabsadd L
.65353 .36791 -1.46946 -2.02254 Mabsadd L
.65353 .36791 0 -0.96154 Mabsadd L
.65353 .36791 1.46946 -2.02254 Mabsadd L
.65353 .36791 .91448 -0.29713 Mabsadd L
.65353 .36791 2.37764 .77254 Mabsadd L
.65353 .36791 .56518 .7779 Mabsadd L
.65353 .36791 0 2.5 Mabsadd L closepath F
.65873 .37145 0 2.5 Mabsadd m
.65873 .37145 -0.56518 .7779 Mabsadd L
.65873 .37145 -2.37764 .77254 Mabsadd L
.65873 .37145 -0.91448 -0.29713 Mabsadd L
.65873 .37145 -1.46946 -2.02254 Mabsadd L
.65873 .37145 0 -0.96154 Mabsadd L
.65873 .37145 1.46946 -2.02254 Mabsadd L
.65873 .37145 .91448 -0.29713 Mabsadd L
.65873 .37145 2.37764 .77254 Mabsadd L
.65873 .37145 .56518 .7779 Mabsadd L
.65873 .37145 0 2.5 Mabsadd L closepath F
.66393 .3803 0 2.5 Mabsadd m
.66393 .3803 -0.56518 .7779 Mabsadd L
.66393 .3803 -2.37764 .77254 Mabsadd L
.66393 .3803 -0.91448 -0.29713 Mabsadd L
.66393 .3803 -1.46946 -2.02254 Mabsadd L
.66393 .3803 0 -0.96154 Mabsadd L
.66393 .3803 1.46946 -2.02254 Mabsadd L
.66393 .3803 .91448 -0.29713 Mabsadd L
.66393 .3803 2.37764 .77254 Mabsadd L
.66393 .3803 .56518 .7779 Mabsadd L
.66393 .3803 0 2.5 Mabsadd L closepath F
.66914 .37989 0 2.5 Mabsadd m
.66914 .37989 -0.56518 .7779 Mabsadd L
.66914 .37989 -2.37764 .77254 Mabsadd L
.66914 .37989 -0.91448 -0.29713 Mabsadd L
.66914 .37989 -1.46946 -2.02254 Mabsadd L
.66914 .37989 0 -0.96154 Mabsadd L
.66914 .37989 1.46946 -2.02254 Mabsadd L
.66914 .37989 .91448 -0.29713 Mabsadd L
.66914 .37989 2.37764 .77254 Mabsadd L
.66914 .37989 .56518 .7779 Mabsadd L
.66914 .37989 0 2.5 Mabsadd L closepath F
.67434 .3866 0 2.5 Mabsadd m
.67434 .3866 -0.56518 .7779 Mabsadd L
.67434 .3866 -2.37764 .77254 Mabsadd L
.67434 .3866 -0.91448 -0.29713 Mabsadd L
.67434 .3866 -1.46946 -2.02254 Mabsadd L
.67434 .3866 0 -0.96154 Mabsadd L
.67434 .3866 1.46946 -2.02254 Mabsadd L
.67434 .3866 .91448 -0.29713 Mabsadd L
.67434 .3866 2.37764 .77254 Mabsadd L
.67434 .3866 .56518 .7779 Mabsadd L
.67434 .3866 0 2.5 Mabsadd L closepath F
.67955 .39645 0 2.5 Mabsadd m
.67955 .39645 -0.56518 .7779 Mabsadd L
.67955 .39645 -2.37764 .77254 Mabsadd L
.67955 .39645 -0.91448 -0.29713 Mabsadd L
.67955 .39645 -1.46946 -2.02254 Mabsadd L
.67955 .39645 0 -0.96154 Mabsadd L
.67955 .39645 1.46946 -2.02254 Mabsadd L
.67955 .39645 .91448 -0.29713 Mabsadd L
.67955 .39645 2.37764 .77254 Mabsadd L
.67955 .39645 .56518 .7779 Mabsadd L
.67955 .39645 0 2.5 Mabsadd L closepath F
.68475 .40045 0 2.5 Mabsadd m
.68475 .40045 -0.56518 .7779 Mabsadd L
.68475 .40045 -2.37764 .77254 Mabsadd L
.68475 .40045 -0.91448 -0.29713 Mabsadd L
.68475 .40045 -1.46946 -2.02254 Mabsadd L
.68475 .40045 0 -0.96154 Mabsadd L
.68475 .40045 1.46946 -2.02254 Mabsadd L
.68475 .40045 .91448 -0.29713 Mabsadd L
.68475 .40045 2.37764 .77254 Mabsadd L
.68475 .40045 .56518 .7779 Mabsadd L
.68475 .40045 0 2.5 Mabsadd L closepath F
.68996 .40035 0 2.5 Mabsadd m
.68996 .40035 -0.56518 .7779 Mabsadd L
.68996 .40035 -2.37764 .77254 Mabsadd L
.68996 .40035 -0.91448 -0.29713 Mabsadd L
.68996 .40035 -1.46946 -2.02254 Mabsadd L
.68996 .40035 0 -0.96154 Mabsadd L
.68996 .40035 1.46946 -2.02254 Mabsadd L
.68996 .40035 .91448 -0.29713 Mabsadd L
.68996 .40035 2.37764 .77254 Mabsadd L
.68996 .40035 .56518 .7779 Mabsadd L
.68996 .40035 0 2.5 Mabsadd L closepath F
.69516 .41141 0 2.5 Mabsadd m
.69516 .41141 -0.56518 .7779 Mabsadd L
.69516 .41141 -2.37764 .77254 Mabsadd L
.69516 .41141 -0.91448 -0.29713 Mabsadd L
.69516 .41141 -1.46946 -2.02254 Mabsadd L
.69516 .41141 0 -0.96154 Mabsadd L
.69516 .41141 1.46946 -2.02254 Mabsadd L
.69516 .41141 .91448 -0.29713 Mabsadd L
.69516 .41141 2.37764 .77254 Mabsadd L
.69516 .41141 .56518 .7779 Mabsadd L
.69516 .41141 0 2.5 Mabsadd L closepath F
.70036 .41057 0 2.5 Mabsadd m
.70036 .41057 -0.56518 .7779 Mabsadd L
.70036 .41057 -2.37764 .77254 Mabsadd L
.70036 .41057 -0.91448 -0.29713 Mabsadd L
.70036 .41057 -1.46946 -2.02254 Mabsadd L
.70036 .41057 0 -0.96154 Mabsadd L
.70036 .41057 1.46946 -2.02254 Mabsadd L
.70036 .41057 .91448 -0.29713 Mabsadd L
.70036 .41057 2.37764 .77254 Mabsadd L
.70036 .41057 .56518 .7779 Mabsadd L
.70036 .41057 0 2.5 Mabsadd L closepath F
.70557 .41869 0 2.5 Mabsadd m
.70557 .41869 -0.56518 .7779 Mabsadd L
.70557 .41869 -2.37764 .77254 Mabsadd L
.70557 .41869 -0.91448 -0.29713 Mabsadd L
.70557 .41869 -1.46946 -2.02254 Mabsadd L
.70557 .41869 0 -0.96154 Mabsadd L
.70557 .41869 1.46946 -2.02254 Mabsadd L
.70557 .41869 .91448 -0.29713 Mabsadd L
.70557 .41869 2.37764 .77254 Mabsadd L
.70557 .41869 .56518 .7779 Mabsadd L
.70557 .41869 0 2.5 Mabsadd L closepath F
.71077 .42686 0 2.5 Mabsadd m
.71077 .42686 -0.56518 .7779 Mabsadd L
.71077 .42686 -2.37764 .77254 Mabsadd L
.71077 .42686 -0.91448 -0.29713 Mabsadd L
.71077 .42686 -1.46946 -2.02254 Mabsadd L
.71077 .42686 0 -0.96154 Mabsadd L
.71077 .42686 1.46946 -2.02254 Mabsadd L
.71077 .42686 .91448 -0.29713 Mabsadd L
.71077 .42686 2.37764 .77254 Mabsadd L
.71077 .42686 .56518 .7779 Mabsadd L
.71077 .42686 0 2.5 Mabsadd L closepath F
.71598 .4374 0 2.5 Mabsadd m
.71598 .4374 -0.56518 .7779 Mabsadd L
.71598 .4374 -2.37764 .77254 Mabsadd L
.71598 .4374 -0.91448 -0.29713 Mabsadd L
.71598 .4374 -1.46946 -2.02254 Mabsadd L
.71598 .4374 0 -0.96154 Mabsadd L
.71598 .4374 1.46946 -2.02254 Mabsadd L
.71598 .4374 .91448 -0.29713 Mabsadd L
.71598 .4374 2.37764 .77254 Mabsadd L
.71598 .4374 .56518 .7779 Mabsadd L
.71598 .4374 0 2.5 Mabsadd L closepath F
.72118 .43592 0 2.5 Mabsadd m
.72118 .43592 -0.56518 .7779 Mabsadd L
.72118 .43592 -2.37764 .77254 Mabsadd L
.72118 .43592 -0.91448 -0.29713 Mabsadd L
.72118 .43592 -1.46946 -2.02254 Mabsadd L
.72118 .43592 0 -0.96154 Mabsadd L
.72118 .43592 1.46946 -2.02254 Mabsadd L
.72118 .43592 .91448 -0.29713 Mabsadd L
.72118 .43592 2.37764 .77254 Mabsadd L
.72118 .43592 .56518 .7779 Mabsadd L
.72118 .43592 0 2.5 Mabsadd L closepath F
.72639 .44937 0 2.5 Mabsadd m
.72639 .44937 -0.56518 .7779 Mabsadd L
.72639 .44937 -2.37764 .77254 Mabsadd L
.72639 .44937 -0.91448 -0.29713 Mabsadd L
.72639 .44937 -1.46946 -2.02254 Mabsadd L
.72639 .44937 0 -0.96154 Mabsadd L
.72639 .44937 1.46946 -2.02254 Mabsadd L
.72639 .44937 .91448 -0.29713 Mabsadd L
.72639 .44937 2.37764 .77254 Mabsadd L
.72639 .44937 .56518 .7779 Mabsadd L
.72639 .44937 0 2.5 Mabsadd L closepath F
.73159 .4591 0 2.5 Mabsadd m
.73159 .4591 -0.56518 .7779 Mabsadd L
.73159 .4591 -2.37764 .77254 Mabsadd L
.73159 .4591 -0.91448 -0.29713 Mabsadd L
.73159 .4591 -1.46946 -2.02254 Mabsadd L
.73159 .4591 0 -0.96154 Mabsadd L
.73159 .4591 1.46946 -2.02254 Mabsadd L
.73159 .4591 .91448 -0.29713 Mabsadd L
.73159 .4591 2.37764 .77254 Mabsadd L
.73159 .4591 .56518 .7779 Mabsadd L
.73159 .4591 0 2.5 Mabsadd L closepath F
.73679 .46504 0 2.5 Mabsadd m
.73679 .46504 -0.56518 .7779 Mabsadd L
.73679 .46504 -2.37764 .77254 Mabsadd L
.73679 .46504 -0.91448 -0.29713 Mabsadd L
.73679 .46504 -1.46946 -2.02254 Mabsadd L
.73679 .46504 0 -0.96154 Mabsadd L
.73679 .46504 1.46946 -2.02254 Mabsadd L
.73679 .46504 .91448 -0.29713 Mabsadd L
.73679 .46504 2.37764 .77254 Mabsadd L
.73679 .46504 .56518 .7779 Mabsadd L
.73679 .46504 0 2.5 Mabsadd L closepath F
.742 .46686 0 2.5 Mabsadd m
.742 .46686 -0.56518 .7779 Mabsadd L
.742 .46686 -2.37764 .77254 Mabsadd L
.742 .46686 -0.91448 -0.29713 Mabsadd L
.742 .46686 -1.46946 -2.02254 Mabsadd L
.742 .46686 0 -0.96154 Mabsadd L
.742 .46686 1.46946 -2.02254 Mabsadd L
.742 .46686 .91448 -0.29713 Mabsadd L
.742 .46686 2.37764 .77254 Mabsadd L
.742 .46686 .56518 .7779 Mabsadd L
.742 .46686 0 2.5 Mabsadd L closepath F
.7472 .4795 0 2.5 Mabsadd m
.7472 .4795 -0.56518 .7779 Mabsadd L
.7472 .4795 -2.37764 .77254 Mabsadd L
.7472 .4795 -0.91448 -0.29713 Mabsadd L
.7472 .4795 -1.46946 -2.02254 Mabsadd L
.7472 .4795 0 -0.96154 Mabsadd L
.7472 .4795 1.46946 -2.02254 Mabsadd L
.7472 .4795 .91448 -0.29713 Mabsadd L
.7472 .4795 2.37764 .77254 Mabsadd L
.7472 .4795 .56518 .7779 Mabsadd L
.7472 .4795 0 2.5 Mabsadd L closepath F
.75241 .48756 0 2.5 Mabsadd m
.75241 .48756 -0.56518 .7779 Mabsadd L
.75241 .48756 -2.37764 .77254 Mabsadd L
.75241 .48756 -0.91448 -0.29713 Mabsadd L
.75241 .48756 -1.46946 -2.02254 Mabsadd L
.75241 .48756 0 -0.96154 Mabsadd L
.75241 .48756 1.46946 -2.02254 Mabsadd L
.75241 .48756 .91448 -0.29713 Mabsadd L
.75241 .48756 2.37764 .77254 Mabsadd L
.75241 .48756 .56518 .7779 Mabsadd L
.75241 .48756 0 2.5 Mabsadd L closepath F
.75761 .49394 0 2.5 Mabsadd m
.75761 .49394 -0.56518 .7779 Mabsadd L
.75761 .49394 -2.37764 .77254 Mabsadd L
.75761 .49394 -0.91448 -0.29713 Mabsadd L
.75761 .49394 -1.46946 -2.02254 Mabsadd L
.75761 .49394 0 -0.96154 Mabsadd L
.75761 .49394 1.46946 -2.02254 Mabsadd L
.75761 .49394 .91448 -0.29713 Mabsadd L
.75761 .49394 2.37764 .77254 Mabsadd L
.75761 .49394 .56518 .7779 Mabsadd L
.75761 .49394 0 2.5 Mabsadd L closepath F
.76282 .50745 0 2.5 Mabsadd m
.76282 .50745 -0.56518 .7779 Mabsadd L
.76282 .50745 -2.37764 .77254 Mabsadd L
.76282 .50745 -0.91448 -0.29713 Mabsadd L
.76282 .50745 -1.46946 -2.02254 Mabsadd L
.76282 .50745 0 -0.96154 Mabsadd L
.76282 .50745 1.46946 -2.02254 Mabsadd L
.76282 .50745 .91448 -0.29713 Mabsadd L
.76282 .50745 2.37764 .77254 Mabsadd L
.76282 .50745 .56518 .7779 Mabsadd L
.76282 .50745 0 2.5 Mabsadd L closepath F
.76802 .51116 0 2.5 Mabsadd m
.76802 .51116 -0.56518 .7779 Mabsadd L
.76802 .51116 -2.37764 .77254 Mabsadd L
.76802 .51116 -0.91448 -0.29713 Mabsadd L
.76802 .51116 -1.46946 -2.02254 Mabsadd L
.76802 .51116 0 -0.96154 Mabsadd L
.76802 .51116 1.46946 -2.02254 Mabsadd L
.76802 .51116 .91448 -0.29713 Mabsadd L
.76802 .51116 2.37764 .77254 Mabsadd L
.76802 .51116 .56518 .7779 Mabsadd L
.76802 .51116 0 2.5 Mabsadd L closepath F
.77322 .52111 0 2.5 Mabsadd m
.77322 .52111 -0.56518 .7779 Mabsadd L
.77322 .52111 -2.37764 .77254 Mabsadd L
.77322 .52111 -0.91448 -0.29713 Mabsadd L
.77322 .52111 -1.46946 -2.02254 Mabsadd L
.77322 .52111 0 -0.96154 Mabsadd L
.77322 .52111 1.46946 -2.02254 Mabsadd L
.77322 .52111 .91448 -0.29713 Mabsadd L
.77322 .52111 2.37764 .77254 Mabsadd L
.77322 .52111 .56518 .7779 Mabsadd L
.77322 .52111 0 2.5 Mabsadd L closepath F
.77843 .52639 0 2.5 Mabsadd m
.77843 .52639 -0.56518 .7779 Mabsadd L
.77843 .52639 -2.37764 .77254 Mabsadd L
.77843 .52639 -0.91448 -0.29713 Mabsadd L
.77843 .52639 -1.46946 -2.02254 Mabsadd L
.77843 .52639 0 -0.96154 Mabsadd L
.77843 .52639 1.46946 -2.02254 Mabsadd L
.77843 .52639 .91448 -0.29713 Mabsadd L
.77843 .52639 2.37764 .77254 Mabsadd L
.77843 .52639 .56518 .7779 Mabsadd L
.77843 .52639 0 2.5 Mabsadd L closepath F
.78363 .53224 0 2.5 Mabsadd m
.78363 .53224 -0.56518 .7779 Mabsadd L
.78363 .53224 -2.37764 .77254 Mabsadd L
.78363 .53224 -0.91448 -0.29713 Mabsadd L
.78363 .53224 -1.46946 -2.02254 Mabsadd L
.78363 .53224 0 -0.96154 Mabsadd L
.78363 .53224 1.46946 -2.02254 Mabsadd L
.78363 .53224 .91448 -0.29713 Mabsadd L
.78363 .53224 2.37764 .77254 Mabsadd L
.78363 .53224 .56518 .7779 Mabsadd L
.78363 .53224 0 2.5 Mabsadd L closepath F
.78884 .5356 0 2.5 Mabsadd m
.78884 .5356 -0.56518 .7779 Mabsadd L
.78884 .5356 -2.37764 .77254 Mabsadd L
.78884 .5356 -0.91448 -0.29713 Mabsadd L
.78884 .5356 -1.46946 -2.02254 Mabsadd L
.78884 .5356 0 -0.96154 Mabsadd L
.78884 .5356 1.46946 -2.02254 Mabsadd L
.78884 .5356 .91448 -0.29713 Mabsadd L
.78884 .5356 2.37764 .77254 Mabsadd L
.78884 .5356 .56518 .7779 Mabsadd L
.78884 .5356 0 2.5 Mabsadd L closepath F
.79404 .54644 0 2.5 Mabsadd m
.79404 .54644 -0.56518 .7779 Mabsadd L
.79404 .54644 -2.37764 .77254 Mabsadd L
.79404 .54644 -0.91448 -0.29713 Mabsadd L
.79404 .54644 -1.46946 -2.02254 Mabsadd L
.79404 .54644 0 -0.96154 Mabsadd L
.79404 .54644 1.46946 -2.02254 Mabsadd L
.79404 .54644 .91448 -0.29713 Mabsadd L
.79404 .54644 2.37764 .77254 Mabsadd L
.79404 .54644 .56518 .7779 Mabsadd L
.79404 .54644 0 2.5 Mabsadd L closepath F
.79925 .55346 0 2.5 Mabsadd m
.79925 .55346 -0.56518 .7779 Mabsadd L
.79925 .55346 -2.37764 .77254 Mabsadd L
.79925 .55346 -0.91448 -0.29713 Mabsadd L
.79925 .55346 -1.46946 -2.02254 Mabsadd L
.79925 .55346 0 -0.96154 Mabsadd L
.79925 .55346 1.46946 -2.02254 Mabsadd L
.79925 .55346 .91448 -0.29713 Mabsadd L
.79925 .55346 2.37764 .77254 Mabsadd L
.79925 .55346 .56518 .7779 Mabsadd L
.79925 .55346 0 2.5 Mabsadd L closepath F
.80445 .55841 0 2.5 Mabsadd m
.80445 .55841 -0.56518 .7779 Mabsadd L
.80445 .55841 -2.37764 .77254 Mabsadd L
.80445 .55841 -0.91448 -0.29713 Mabsadd L
.80445 .55841 -1.46946 -2.02254 Mabsadd L
.80445 .55841 0 -0.96154 Mabsadd L
.80445 .55841 1.46946 -2.02254 Mabsadd L
.80445 .55841 .91448 -0.29713 Mabsadd L
.80445 .55841 2.37764 .77254 Mabsadd L
.80445 .55841 .56518 .7779 Mabsadd L
.80445 .55841 0 2.5 Mabsadd L closepath F
.80965 .56002 0 2.5 Mabsadd m
.80965 .56002 -0.56518 .7779 Mabsadd L
.80965 .56002 -2.37764 .77254 Mabsadd L
.80965 .56002 -0.91448 -0.29713 Mabsadd L
.80965 .56002 -1.46946 -2.02254 Mabsadd L
.80965 .56002 0 -0.96154 Mabsadd L
.80965 .56002 1.46946 -2.02254 Mabsadd L
.80965 .56002 .91448 -0.29713 Mabsadd L
.80965 .56002 2.37764 .77254 Mabsadd L
.80965 .56002 .56518 .7779 Mabsadd L
.80965 .56002 0 2.5 Mabsadd L closepath F
.81486 .56413 0 2.5 Mabsadd m
.81486 .56413 -0.56518 .7779 Mabsadd L
.81486 .56413 -2.37764 .77254 Mabsadd L
.81486 .56413 -0.91448 -0.29713 Mabsadd L
.81486 .56413 -1.46946 -2.02254 Mabsadd L
.81486 .56413 0 -0.96154 Mabsadd L
.81486 .56413 1.46946 -2.02254 Mabsadd L
.81486 .56413 .91448 -0.29713 Mabsadd L
.81486 .56413 2.37764 .77254 Mabsadd L
.81486 .56413 .56518 .7779 Mabsadd L
.81486 .56413 0 2.5 Mabsadd L closepath F
.82006 .56774 0 2.5 Mabsadd m
.82006 .56774 -0.56518 .7779 Mabsadd L
.82006 .56774 -2.37764 .77254 Mabsadd L
.82006 .56774 -0.91448 -0.29713 Mabsadd L
.82006 .56774 -1.46946 -2.02254 Mabsadd L
.82006 .56774 0 -0.96154 Mabsadd L
.82006 .56774 1.46946 -2.02254 Mabsadd L
.82006 .56774 .91448 -0.29713 Mabsadd L
.82006 .56774 2.37764 .77254 Mabsadd L
.82006 .56774 .56518 .7779 Mabsadd L
.82006 .56774 0 2.5 Mabsadd L closepath F
.82527 .57022 0 2.5 Mabsadd m
.82527 .57022 -0.56518 .7779 Mabsadd L
.82527 .57022 -2.37764 .77254 Mabsadd L
.82527 .57022 -0.91448 -0.29713 Mabsadd L
.82527 .57022 -1.46946 -2.02254 Mabsadd L
.82527 .57022 0 -0.96154 Mabsadd L
.82527 .57022 1.46946 -2.02254 Mabsadd L
.82527 .57022 .91448 -0.29713 Mabsadd L
.82527 .57022 2.37764 .77254 Mabsadd L
.82527 .57022 .56518 .7779 Mabsadd L
.82527 .57022 0 2.5 Mabsadd L closepath F
.83047 .57009 0 2.5 Mabsadd m
.83047 .57009 -0.56518 .7779 Mabsadd L
.83047 .57009 -2.37764 .77254 Mabsadd L
.83047 .57009 -0.91448 -0.29713 Mabsadd L
.83047 .57009 -1.46946 -2.02254 Mabsadd L
.83047 .57009 0 -0.96154 Mabsadd L
.83047 .57009 1.46946 -2.02254 Mabsadd L
.83047 .57009 .91448 -0.29713 Mabsadd L
.83047 .57009 2.37764 .77254 Mabsadd L
.83047 .57009 .56518 .7779 Mabsadd L
.83047 .57009 0 2.5 Mabsadd L closepath F
.83568 .54556 0 2.5 Mabsadd m
.83568 .54556 -0.56518 .7779 Mabsadd L
.83568 .54556 -2.37764 .77254 Mabsadd L
.83568 .54556 -0.91448 -0.29713 Mabsadd L
.83568 .54556 -1.46946 -2.02254 Mabsadd L
.83568 .54556 0 -0.96154 Mabsadd L
.83568 .54556 1.46946 -2.02254 Mabsadd L
.83568 .54556 .91448 -0.29713 Mabsadd L
.83568 .54556 2.37764 .77254 Mabsadd L
.83568 .54556 .56518 .7779 Mabsadd L
.83568 .54556 0 2.5 Mabsadd L closepath F
.84088 .54713 0 2.5 Mabsadd m
.84088 .54713 -0.56518 .7779 Mabsadd L
.84088 .54713 -2.37764 .77254 Mabsadd L
.84088 .54713 -0.91448 -0.29713 Mabsadd L
.84088 .54713 -1.46946 -2.02254 Mabsadd L
.84088 .54713 0 -0.96154 Mabsadd L
.84088 .54713 1.46946 -2.02254 Mabsadd L
.84088 .54713 .91448 -0.29713 Mabsadd L
.84088 .54713 2.37764 .77254 Mabsadd L
.84088 .54713 .56518 .7779 Mabsadd L
.84088 .54713 0 2.5 Mabsadd L closepath F
.84608 .54279 0 2.5 Mabsadd m
.84608 .54279 -0.56518 .7779 Mabsadd L
.84608 .54279 -2.37764 .77254 Mabsadd L
.84608 .54279 -0.91448 -0.29713 Mabsadd L
.84608 .54279 -1.46946 -2.02254 Mabsadd L
.84608 .54279 0 -0.96154 Mabsadd L
.84608 .54279 1.46946 -2.02254 Mabsadd L
.84608 .54279 .91448 -0.29713 Mabsadd L
.84608 .54279 2.37764 .77254 Mabsadd L
.84608 .54279 .56518 .7779 Mabsadd L
.84608 .54279 0 2.5 Mabsadd L closepath F
.85129 .54364 0 2.5 Mabsadd m
.85129 .54364 -0.56518 .7779 Mabsadd L
.85129 .54364 -2.37764 .77254 Mabsadd L
.85129 .54364 -0.91448 -0.29713 Mabsadd L
.85129 .54364 -1.46946 -2.02254 Mabsadd L
.85129 .54364 0 -0.96154 Mabsadd L
.85129 .54364 1.46946 -2.02254 Mabsadd L
.85129 .54364 .91448 -0.29713 Mabsadd L
.85129 .54364 2.37764 .77254 Mabsadd L
.85129 .54364 .56518 .7779 Mabsadd L
.85129 .54364 0 2.5 Mabsadd L closepath F
.85649 .54348 0 2.5 Mabsadd m
.85649 .54348 -0.56518 .7779 Mabsadd L
.85649 .54348 -2.37764 .77254 Mabsadd L
.85649 .54348 -0.91448 -0.29713 Mabsadd L
.85649 .54348 -1.46946 -2.02254 Mabsadd L
.85649 .54348 0 -0.96154 Mabsadd L
.85649 .54348 1.46946 -2.02254 Mabsadd L
.85649 .54348 .91448 -0.29713 Mabsadd L
.85649 .54348 2.37764 .77254 Mabsadd L
.85649 .54348 .56518 .7779 Mabsadd L
.85649 .54348 0 2.5 Mabsadd L closepath F
.8617 .54569 0 2.5 Mabsadd m
.8617 .54569 -0.56518 .7779 Mabsadd L
.8617 .54569 -2.37764 .77254 Mabsadd L
.8617 .54569 -0.91448 -0.29713 Mabsadd L
.8617 .54569 -1.46946 -2.02254 Mabsadd L
.8617 .54569 0 -0.96154 Mabsadd L
.8617 .54569 1.46946 -2.02254 Mabsadd L
.8617 .54569 .91448 -0.29713 Mabsadd L
.8617 .54569 2.37764 .77254 Mabsadd L
.8617 .54569 .56518 .7779 Mabsadd L
.8617 .54569 0 2.5 Mabsadd L closepath F
.8669 .5462 0 2.5 Mabsadd m
.8669 .5462 -0.56518 .7779 Mabsadd L
.8669 .5462 -2.37764 .77254 Mabsadd L
.8669 .5462 -0.91448 -0.29713 Mabsadd L
.8669 .5462 -1.46946 -2.02254 Mabsadd L
.8669 .5462 0 -0.96154 Mabsadd L
.8669 .5462 1.46946 -2.02254 Mabsadd L
.8669 .5462 .91448 -0.29713 Mabsadd L
.8669 .5462 2.37764 .77254 Mabsadd L
.8669 .5462 .56518 .7779 Mabsadd L
.8669 .5462 0 2.5 Mabsadd L closepath F
.87211 .54211 0 2.5 Mabsadd m
.87211 .54211 -0.56518 .7779 Mabsadd L
.87211 .54211 -2.37764 .77254 Mabsadd L
.87211 .54211 -0.91448 -0.29713 Mabsadd L
.87211 .54211 -1.46946 -2.02254 Mabsadd L
.87211 .54211 0 -0.96154 Mabsadd L
.87211 .54211 1.46946 -2.02254 Mabsadd L
.87211 .54211 .91448 -0.29713 Mabsadd L
.87211 .54211 2.37764 .77254 Mabsadd L
.87211 .54211 .56518 .7779 Mabsadd L
.87211 .54211 0 2.5 Mabsadd L closepath F
.87731 .53892 0 2.5 Mabsadd m
.87731 .53892 -0.56518 .7779 Mabsadd L
.87731 .53892 -2.37764 .77254 Mabsadd L
.87731 .53892 -0.91448 -0.29713 Mabsadd L
.87731 .53892 -1.46946 -2.02254 Mabsadd L
.87731 .53892 0 -0.96154 Mabsadd L
.87731 .53892 1.46946 -2.02254 Mabsadd L
.87731 .53892 .91448 -0.29713 Mabsadd L
.87731 .53892 2.37764 .77254 Mabsadd L
.87731 .53892 .56518 .7779 Mabsadd L
.87731 .53892 0 2.5 Mabsadd L closepath F
.88251 .5292 0 2.5 Mabsadd m
.88251 .5292 -0.56518 .7779 Mabsadd L
.88251 .5292 -2.37764 .77254 Mabsadd L
.88251 .5292 -0.91448 -0.29713 Mabsadd L
.88251 .5292 -1.46946 -2.02254 Mabsadd L
.88251 .5292 0 -0.96154 Mabsadd L
.88251 .5292 1.46946 -2.02254 Mabsadd L
.88251 .5292 .91448 -0.29713 Mabsadd L
.88251 .5292 2.37764 .77254 Mabsadd L
.88251 .5292 .56518 .7779 Mabsadd L
.88251 .5292 0 2.5 Mabsadd L closepath F
.88772 .53355 0 2.5 Mabsadd m
.88772 .53355 -0.56518 .7779 Mabsadd L
.88772 .53355 -2.37764 .77254 Mabsadd L
.88772 .53355 -0.91448 -0.29713 Mabsadd L
.88772 .53355 -1.46946 -2.02254 Mabsadd L
.88772 .53355 0 -0.96154 Mabsadd L
.88772 .53355 1.46946 -2.02254 Mabsadd L
.88772 .53355 .91448 -0.29713 Mabsadd L
.88772 .53355 2.37764 .77254 Mabsadd L
.88772 .53355 .56518 .7779 Mabsadd L
.88772 .53355 0 2.5 Mabsadd L closepath F
.89292 .5348 0 2.5 Mabsadd m
.89292 .5348 -0.56518 .7779 Mabsadd L
.89292 .5348 -2.37764 .77254 Mabsadd L
.89292 .5348 -0.91448 -0.29713 Mabsadd L
.89292 .5348 -1.46946 -2.02254 Mabsadd L
.89292 .5348 0 -0.96154 Mabsadd L
.89292 .5348 1.46946 -2.02254 Mabsadd L
.89292 .5348 .91448 -0.29713 Mabsadd L
.89292 .5348 2.37764 .77254 Mabsadd L
.89292 .5348 .56518 .7779 Mabsadd L
.89292 .5348 0 2.5 Mabsadd L closepath F
.89813 .5294 0 2.5 Mabsadd m
.89813 .5294 -0.56518 .7779 Mabsadd L
.89813 .5294 -2.37764 .77254 Mabsadd L
.89813 .5294 -0.91448 -0.29713 Mabsadd L
.89813 .5294 -1.46946 -2.02254 Mabsadd L
.89813 .5294 0 -0.96154 Mabsadd L
.89813 .5294 1.46946 -2.02254 Mabsadd L
.89813 .5294 .91448 -0.29713 Mabsadd L
.89813 .5294 2.37764 .77254 Mabsadd L
.89813 .5294 .56518 .7779 Mabsadd L
.89813 .5294 0 2.5 Mabsadd L closepath F
.90333 .52915 0 2.5 Mabsadd m
.90333 .52915 -0.56518 .7779 Mabsadd L
.90333 .52915 -2.37764 .77254 Mabsadd L
.90333 .52915 -0.91448 -0.29713 Mabsadd L
.90333 .52915 -1.46946 -2.02254 Mabsadd L
.90333 .52915 0 -0.96154 Mabsadd L
.90333 .52915 1.46946 -2.02254 Mabsadd L
.90333 .52915 .91448 -0.29713 Mabsadd L
.90333 .52915 2.37764 .77254 Mabsadd L
.90333 .52915 .56518 .7779 Mabsadd L
.90333 .52915 0 2.5 Mabsadd L closepath F
.90853 .52972 0 2.5 Mabsadd m
.90853 .52972 -0.56518 .7779 Mabsadd L
.90853 .52972 -2.37764 .77254 Mabsadd L
.90853 .52972 -0.91448 -0.29713 Mabsadd L
.90853 .52972 -1.46946 -2.02254 Mabsadd L
.90853 .52972 0 -0.96154 Mabsadd L
.90853 .52972 1.46946 -2.02254 Mabsadd L
.90853 .52972 .91448 -0.29713 Mabsadd L
.90853 .52972 2.37764 .77254 Mabsadd L
.90853 .52972 .56518 .7779 Mabsadd L
.90853 .52972 0 2.5 Mabsadd L closepath F
.91374 .53526 0 2.5 Mabsadd m
.91374 .53526 -0.56518 .7779 Mabsadd L
.91374 .53526 -2.37764 .77254 Mabsadd L
.91374 .53526 -0.91448 -0.29713 Mabsadd L
.91374 .53526 -1.46946 -2.02254 Mabsadd L
.91374 .53526 0 -0.96154 Mabsadd L
.91374 .53526 1.46946 -2.02254 Mabsadd L
.91374 .53526 .91448 -0.29713 Mabsadd L
.91374 .53526 2.37764 .77254 Mabsadd L
.91374 .53526 .56518 .7779 Mabsadd L
.91374 .53526 0 2.5 Mabsadd L closepath F
.91894 .54077 0 2.5 Mabsadd m
.91894 .54077 -0.56518 .7779 Mabsadd L
.91894 .54077 -2.37764 .77254 Mabsadd L
.91894 .54077 -0.91448 -0.29713 Mabsadd L
.91894 .54077 -1.46946 -2.02254 Mabsadd L
.91894 .54077 0 -0.96154 Mabsadd L
.91894 .54077 1.46946 -2.02254 Mabsadd L
.91894 .54077 .91448 -0.29713 Mabsadd L
.91894 .54077 2.37764 .77254 Mabsadd L
.91894 .54077 .56518 .7779 Mabsadd L
.91894 .54077 0 2.5 Mabsadd L closepath F
.92415 .54077 0 2.5 Mabsadd m
.92415 .54077 -0.56518 .7779 Mabsadd L
.92415 .54077 -2.37764 .77254 Mabsadd L
.92415 .54077 -0.91448 -0.29713 Mabsadd L
.92415 .54077 -1.46946 -2.02254 Mabsadd L
.92415 .54077 0 -0.96154 Mabsadd L
.92415 .54077 1.46946 -2.02254 Mabsadd L
.92415 .54077 .91448 -0.29713 Mabsadd L
.92415 .54077 2.37764 .77254 Mabsadd L
.92415 .54077 .56518 .7779 Mabsadd L
.92415 .54077 0 2.5 Mabsadd L closepath F
.92935 .54308 0 2.5 Mabsadd m
.92935 .54308 -0.56518 .7779 Mabsadd L
.92935 .54308 -2.37764 .77254 Mabsadd L
.92935 .54308 -0.91448 -0.29713 Mabsadd L
.92935 .54308 -1.46946 -2.02254 Mabsadd L
.92935 .54308 0 -0.96154 Mabsadd L
.92935 .54308 1.46946 -2.02254 Mabsadd L
.92935 .54308 .91448 -0.29713 Mabsadd L
.92935 .54308 2.37764 .77254 Mabsadd L
.92935 .54308 .56518 .7779 Mabsadd L
.92935 .54308 0 2.5 Mabsadd L closepath F
.93456 .53208 0 2.5 Mabsadd m
.93456 .53208 -0.56518 .7779 Mabsadd L
.93456 .53208 -2.37764 .77254 Mabsadd L
.93456 .53208 -0.91448 -0.29713 Mabsadd L
.93456 .53208 -1.46946 -2.02254 Mabsadd L
.93456 .53208 0 -0.96154 Mabsadd L
.93456 .53208 1.46946 -2.02254 Mabsadd L
.93456 .53208 .91448 -0.29713 Mabsadd L
.93456 .53208 2.37764 .77254 Mabsadd L
.93456 .53208 .56518 .7779 Mabsadd L
.93456 .53208 0 2.5 Mabsadd L closepath F
.93976 .53832 0 2.5 Mabsadd m
.93976 .53832 -0.56518 .7779 Mabsadd L
.93976 .53832 -2.37764 .77254 Mabsadd L
.93976 .53832 -0.91448 -0.29713 Mabsadd L
.93976 .53832 -1.46946 -2.02254 Mabsadd L
.93976 .53832 0 -0.96154 Mabsadd L
.93976 .53832 1.46946 -2.02254 Mabsadd L
.93976 .53832 .91448 -0.29713 Mabsadd L
.93976 .53832 2.37764 .77254 Mabsadd L
.93976 .53832 .56518 .7779 Mabsadd L
.93976 .53832 0 2.5 Mabsadd L closepath F
.94496 .54347 0 2.5 Mabsadd m
.94496 .54347 -0.56518 .7779 Mabsadd L
.94496 .54347 -2.37764 .77254 Mabsadd L
.94496 .54347 -0.91448 -0.29713 Mabsadd L
.94496 .54347 -1.46946 -2.02254 Mabsadd L
.94496 .54347 0 -0.96154 Mabsadd L
.94496 .54347 1.46946 -2.02254 Mabsadd L
.94496 .54347 .91448 -0.29713 Mabsadd L
.94496 .54347 2.37764 .77254 Mabsadd L
.94496 .54347 .56518 .7779 Mabsadd L
.94496 .54347 0 2.5 Mabsadd L closepath F
.95017 .53704 0 2.5 Mabsadd m
.95017 .53704 -0.56518 .7779 Mabsadd L
.95017 .53704 -2.37764 .77254 Mabsadd L
.95017 .53704 -0.91448 -0.29713 Mabsadd L
.95017 .53704 -1.46946 -2.02254 Mabsadd L
.95017 .53704 0 -0.96154 Mabsadd L
.95017 .53704 1.46946 -2.02254 Mabsadd L
.95017 .53704 .91448 -0.29713 Mabsadd L
.95017 .53704 2.37764 .77254 Mabsadd L
.95017 .53704 .56518 .7779 Mabsadd L
.95017 .53704 0 2.5 Mabsadd L closepath F
.95537 .53869 0 2.5 Mabsadd m
.95537 .53869 -0.56518 .7779 Mabsadd L
.95537 .53869 -2.37764 .77254 Mabsadd L
.95537 .53869 -0.91448 -0.29713 Mabsadd L
.95537 .53869 -1.46946 -2.02254 Mabsadd L
.95537 .53869 0 -0.96154 Mabsadd L
.95537 .53869 1.46946 -2.02254 Mabsadd L
.95537 .53869 .91448 -0.29713 Mabsadd L
.95537 .53869 2.37764 .77254 Mabsadd L
.95537 .53869 .56518 .7779 Mabsadd L
.95537 .53869 0 2.5 Mabsadd L closepath F
.96058 .53513 0 2.5 Mabsadd m
.96058 .53513 -0.56518 .7779 Mabsadd L
.96058 .53513 -2.37764 .77254 Mabsadd L
.96058 .53513 -0.91448 -0.29713 Mabsadd L
.96058 .53513 -1.46946 -2.02254 Mabsadd L
.96058 .53513 0 -0.96154 Mabsadd L
.96058 .53513 1.46946 -2.02254 Mabsadd L
.96058 .53513 .91448 -0.29713 Mabsadd L
.96058 .53513 2.37764 .77254 Mabsadd L
.96058 .53513 .56518 .7779 Mabsadd L
.96058 .53513 0 2.5 Mabsadd L closepath F
.96578 .5353 0 2.5 Mabsadd m
.96578 .5353 -0.56518 .7779 Mabsadd L
.96578 .5353 -2.37764 .77254 Mabsadd L
.96578 .5353 -0.91448 -0.29713 Mabsadd L
.96578 .5353 -1.46946 -2.02254 Mabsadd L
.96578 .5353 0 -0.96154 Mabsadd L
.96578 .5353 1.46946 -2.02254 Mabsadd L
.96578 .5353 .91448 -0.29713 Mabsadd L
.96578 .5353 2.37764 .77254 Mabsadd L
.96578 .5353 .56518 .7779 Mabsadd L
.96578 .5353 0 2.5 Mabsadd L closepath F
.97099 .52982 0 2.5 Mabsadd m
.97099 .52982 -0.56518 .7779 Mabsadd L
.97099 .52982 -2.37764 .77254 Mabsadd L
.97099 .52982 -0.91448 -0.29713 Mabsadd L
.97099 .52982 -1.46946 -2.02254 Mabsadd L
.97099 .52982 0 -0.96154 Mabsadd L
.97099 .52982 1.46946 -2.02254 Mabsadd L
.97099 .52982 .91448 -0.29713 Mabsadd L
.97099 .52982 2.37764 .77254 Mabsadd L
.97099 .52982 .56518 .7779 Mabsadd L
.97099 .52982 0 2.5 Mabsadd L closepath F
.97619 .52804 0 2.5 Mabsadd m
.97619 .52804 -0.56518 .7779 Mabsadd L
.97619 .52804 -2.37764 .77254 Mabsadd L
.97619 .52804 -0.91448 -0.29713 Mabsadd L
.97619 .52804 -1.46946 -2.02254 Mabsadd L
.97619 .52804 0 -0.96154 Mabsadd L
.97619 .52804 1.46946 -2.02254 Mabsadd L
.97619 .52804 .91448 -0.29713 Mabsadd L
.97619 .52804 2.37764 .77254 Mabsadd L
.97619 .52804 .56518 .7779 Mabsadd L
.97619 .52804 0 2.5 Mabsadd L closepath F
0 .6 0 r
.02381 .18938 -2.5 2.5 Mabsadd m
.02381 .18938 2.5 2.5 Mabsadd L
.02381 .18938 2.5 -2.5 Mabsadd L
.02381 .18938 -2.5 -2.5 Mabsadd L
.02381 .18938 -2.5 2.5 Mabsadd L closepath F
.02901 .19503 -2.5 2.5 Mabsadd m
.02901 .19503 2.5 2.5 Mabsadd L
.02901 .19503 2.5 -2.5 Mabsadd L
.02901 .19503 -2.5 -2.5 Mabsadd L
.02901 .19503 -2.5 2.5 Mabsadd L closepath F
.03422 .20353 -2.5 2.5 Mabsadd m
.03422 .20353 2.5 2.5 Mabsadd L
.03422 .20353 2.5 -2.5 Mabsadd L
.03422 .20353 -2.5 -2.5 Mabsadd L
.03422 .20353 -2.5 2.5 Mabsadd L closepath F
.03942 .20319 -2.5 2.5 Mabsadd m
.03942 .20319 2.5 2.5 Mabsadd L
.03942 .20319 2.5 -2.5 Mabsadd L
.03942 .20319 -2.5 -2.5 Mabsadd L
.03942 .20319 -2.5 2.5 Mabsadd L closepath F
.04463 .21353 -2.5 2.5 Mabsadd m
.04463 .21353 2.5 2.5 Mabsadd L
.04463 .21353 2.5 -2.5 Mabsadd L
.04463 .21353 -2.5 -2.5 Mabsadd L
.04463 .21353 -2.5 2.5 Mabsadd L closepath F
.04983 .22972 -2.5 2.5 Mabsadd m
.04983 .22972 2.5 2.5 Mabsadd L
.04983 .22972 2.5 -2.5 Mabsadd L
.04983 .22972 -2.5 -2.5 Mabsadd L
.04983 .22972 -2.5 2.5 Mabsadd L closepath F
.05504 .23657 -2.5 2.5 Mabsadd m
.05504 .23657 2.5 2.5 Mabsadd L
.05504 .23657 2.5 -2.5 Mabsadd L
.05504 .23657 -2.5 -2.5 Mabsadd L
.05504 .23657 -2.5 2.5 Mabsadd L closepath F
.06024 .25123 -2.5 2.5 Mabsadd m
.06024 .25123 2.5 2.5 Mabsadd L
.06024 .25123 2.5 -2.5 Mabsadd L
.06024 .25123 -2.5 -2.5 Mabsadd L
.06024 .25123 -2.5 2.5 Mabsadd L closepath F
.06544 .25217 -2.5 2.5 Mabsadd m
.06544 .25217 2.5 2.5 Mabsadd L
.06544 .25217 2.5 -2.5 Mabsadd L
.06544 .25217 -2.5 -2.5 Mabsadd L
.06544 .25217 -2.5 2.5 Mabsadd L closepath F
.07065 .255 -2.5 2.5 Mabsadd m
.07065 .255 2.5 2.5 Mabsadd L
.07065 .255 2.5 -2.5 Mabsadd L
.07065 .255 -2.5 -2.5 Mabsadd L
.07065 .255 -2.5 2.5 Mabsadd L closepath F
.07585 .27353 -2.5 2.5 Mabsadd m
.07585 .27353 2.5 2.5 Mabsadd L
.07585 .27353 2.5 -2.5 Mabsadd L
.07585 .27353 -2.5 -2.5 Mabsadd L
.07585 .27353 -2.5 2.5 Mabsadd L closepath F
.08106 .27658 -2.5 2.5 Mabsadd m
.08106 .27658 2.5 2.5 Mabsadd L
.08106 .27658 2.5 -2.5 Mabsadd L
.08106 .27658 -2.5 -2.5 Mabsadd L
.08106 .27658 -2.5 2.5 Mabsadd L closepath F
.08626 .29142 -2.5 2.5 Mabsadd m
.08626 .29142 2.5 2.5 Mabsadd L
.08626 .29142 2.5 -2.5 Mabsadd L
.08626 .29142 -2.5 -2.5 Mabsadd L
.08626 .29142 -2.5 2.5 Mabsadd L closepath F
.09147 .29576 -2.5 2.5 Mabsadd m
.09147 .29576 2.5 2.5 Mabsadd L
.09147 .29576 2.5 -2.5 Mabsadd L
.09147 .29576 -2.5 -2.5 Mabsadd L
.09147 .29576 -2.5 2.5 Mabsadd L closepath F
.09667 .302 -2.5 2.5 Mabsadd m
.09667 .302 2.5 2.5 Mabsadd L
.09667 .302 2.5 -2.5 Mabsadd L
.09667 .302 -2.5 -2.5 Mabsadd L
.09667 .302 -2.5 2.5 Mabsadd L closepath F
.10187 .30934 -2.5 2.5 Mabsadd m
.10187 .30934 2.5 2.5 Mabsadd L
.10187 .30934 2.5 -2.5 Mabsadd L
.10187 .30934 -2.5 -2.5 Mabsadd L
.10187 .30934 -2.5 2.5 Mabsadd L closepath F
.10708 .19814 -2.5 2.5 Mabsadd m
.10708 .19814 2.5 2.5 Mabsadd L
.10708 .19814 2.5 -2.5 Mabsadd L
.10708 .19814 -2.5 -2.5 Mabsadd L
.10708 .19814 -2.5 2.5 Mabsadd L closepath F
.11228 .19416 -2.5 2.5 Mabsadd m
.11228 .19416 2.5 2.5 Mabsadd L
.11228 .19416 2.5 -2.5 Mabsadd L
.11228 .19416 -2.5 -2.5 Mabsadd L
.11228 .19416 -2.5 2.5 Mabsadd L closepath F
.11749 .1984 -2.5 2.5 Mabsadd m
.11749 .1984 2.5 2.5 Mabsadd L
.11749 .1984 2.5 -2.5 Mabsadd L
.11749 .1984 -2.5 -2.5 Mabsadd L
.11749 .1984 -2.5 2.5 Mabsadd L closepath F
.12269 .19464 -2.5 2.5 Mabsadd m
.12269 .19464 2.5 2.5 Mabsadd L
.12269 .19464 2.5 -2.5 Mabsadd L
.12269 .19464 -2.5 -2.5 Mabsadd L
.12269 .19464 -2.5 2.5 Mabsadd L closepath F
.12789 .20723 -2.5 2.5 Mabsadd m
.12789 .20723 2.5 2.5 Mabsadd L
.12789 .20723 2.5 -2.5 Mabsadd L
.12789 .20723 -2.5 -2.5 Mabsadd L
.12789 .20723 -2.5 2.5 Mabsadd L closepath F
.1331 .2046 -2.5 2.5 Mabsadd m
.1331 .2046 2.5 2.5 Mabsadd L
.1331 .2046 2.5 -2.5 Mabsadd L
.1331 .2046 -2.5 -2.5 Mabsadd L
.1331 .2046 -2.5 2.5 Mabsadd L closepath F
.1383 .21346 -2.5 2.5 Mabsadd m
.1383 .21346 2.5 2.5 Mabsadd L
.1383 .21346 2.5 -2.5 Mabsadd L
.1383 .21346 -2.5 -2.5 Mabsadd L
.1383 .21346 -2.5 2.5 Mabsadd L closepath F
.14351 .21488 -2.5 2.5 Mabsadd m
.14351 .21488 2.5 2.5 Mabsadd L
.14351 .21488 2.5 -2.5 Mabsadd L
.14351 .21488 -2.5 -2.5 Mabsadd L
.14351 .21488 -2.5 2.5 Mabsadd L closepath F
.14871 .21795 -2.5 2.5 Mabsadd m
.14871 .21795 2.5 2.5 Mabsadd L
.14871 .21795 2.5 -2.5 Mabsadd L
.14871 .21795 -2.5 -2.5 Mabsadd L
.14871 .21795 -2.5 2.5 Mabsadd L closepath F
.15392 .22142 -2.5 2.5 Mabsadd m
.15392 .22142 2.5 2.5 Mabsadd L
.15392 .22142 2.5 -2.5 Mabsadd L
.15392 .22142 -2.5 -2.5 Mabsadd L
.15392 .22142 -2.5 2.5 Mabsadd L closepath F
.15912 .23479 -2.5 2.5 Mabsadd m
.15912 .23479 2.5 2.5 Mabsadd L
.15912 .23479 2.5 -2.5 Mabsadd L
.15912 .23479 -2.5 -2.5 Mabsadd L
.15912 .23479 -2.5 2.5 Mabsadd L closepath F
.16432 .23433 -2.5 2.5 Mabsadd m
.16432 .23433 2.5 2.5 Mabsadd L
.16432 .23433 2.5 -2.5 Mabsadd L
.16432 .23433 -2.5 -2.5 Mabsadd L
.16432 .23433 -2.5 2.5 Mabsadd L closepath F
.16953 .23821 -2.5 2.5 Mabsadd m
.16953 .23821 2.5 2.5 Mabsadd L
.16953 .23821 2.5 -2.5 Mabsadd L
.16953 .23821 -2.5 -2.5 Mabsadd L
.16953 .23821 -2.5 2.5 Mabsadd L closepath F
.17473 .24437 -2.5 2.5 Mabsadd m
.17473 .24437 2.5 2.5 Mabsadd L
.17473 .24437 2.5 -2.5 Mabsadd L
.17473 .24437 -2.5 -2.5 Mabsadd L
.17473 .24437 -2.5 2.5 Mabsadd L closepath F
.17994 .25687 -2.5 2.5 Mabsadd m
.17994 .25687 2.5 2.5 Mabsadd L
.17994 .25687 2.5 -2.5 Mabsadd L
.17994 .25687 -2.5 -2.5 Mabsadd L
.17994 .25687 -2.5 2.5 Mabsadd L closepath F
.18514 .25673 -2.5 2.5 Mabsadd m
.18514 .25673 2.5 2.5 Mabsadd L
.18514 .25673 2.5 -2.5 Mabsadd L
.18514 .25673 -2.5 -2.5 Mabsadd L
.18514 .25673 -2.5 2.5 Mabsadd L closepath F
.19035 .26213 -2.5 2.5 Mabsadd m
.19035 .26213 2.5 2.5 Mabsadd L
.19035 .26213 2.5 -2.5 Mabsadd L
.19035 .26213 -2.5 -2.5 Mabsadd L
.19035 .26213 -2.5 2.5 Mabsadd L closepath F
.19555 .26439 -2.5 2.5 Mabsadd m
.19555 .26439 2.5 2.5 Mabsadd L
.19555 .26439 2.5 -2.5 Mabsadd L
.19555 .26439 -2.5 -2.5 Mabsadd L
.19555 .26439 -2.5 2.5 Mabsadd L closepath F
.20075 .26883 -2.5 2.5 Mabsadd m
.20075 .26883 2.5 2.5 Mabsadd L
.20075 .26883 2.5 -2.5 Mabsadd L
.20075 .26883 -2.5 -2.5 Mabsadd L
.20075 .26883 -2.5 2.5 Mabsadd L closepath F
.20596 .28501 -2.5 2.5 Mabsadd m
.20596 .28501 2.5 2.5 Mabsadd L
.20596 .28501 2.5 -2.5 Mabsadd L
.20596 .28501 -2.5 -2.5 Mabsadd L
.20596 .28501 -2.5 2.5 Mabsadd L closepath F
.21116 .29456 -2.5 2.5 Mabsadd m
.21116 .29456 2.5 2.5 Mabsadd L
.21116 .29456 2.5 -2.5 Mabsadd L
.21116 .29456 -2.5 -2.5 Mabsadd L
.21116 .29456 -2.5 2.5 Mabsadd L closepath F
.21637 .29202 -2.5 2.5 Mabsadd m
.21637 .29202 2.5 2.5 Mabsadd L
.21637 .29202 2.5 -2.5 Mabsadd L
.21637 .29202 -2.5 -2.5 Mabsadd L
.21637 .29202 -2.5 2.5 Mabsadd L closepath F
.22157 .30536 -2.5 2.5 Mabsadd m
.22157 .30536 2.5 2.5 Mabsadd L
.22157 .30536 2.5 -2.5 Mabsadd L
.22157 .30536 -2.5 -2.5 Mabsadd L
.22157 .30536 -2.5 2.5 Mabsadd L closepath F
.22678 .30221 -2.5 2.5 Mabsadd m
.22678 .30221 2.5 2.5 Mabsadd L
.22678 .30221 2.5 -2.5 Mabsadd L
.22678 .30221 -2.5 -2.5 Mabsadd L
.22678 .30221 -2.5 2.5 Mabsadd L closepath F
.23198 .30737 -2.5 2.5 Mabsadd m
.23198 .30737 2.5 2.5 Mabsadd L
.23198 .30737 2.5 -2.5 Mabsadd L
.23198 .30737 -2.5 -2.5 Mabsadd L
.23198 .30737 -2.5 2.5 Mabsadd L closepath F
.23718 .32473 -2.5 2.5 Mabsadd m
.23718 .32473 2.5 2.5 Mabsadd L
.23718 .32473 2.5 -2.5 Mabsadd L
.23718 .32473 -2.5 -2.5 Mabsadd L
.23718 .32473 -2.5 2.5 Mabsadd L closepath F
.24239 .33045 -2.5 2.5 Mabsadd m
.24239 .33045 2.5 2.5 Mabsadd L
.24239 .33045 2.5 -2.5 Mabsadd L
.24239 .33045 -2.5 -2.5 Mabsadd L
.24239 .33045 -2.5 2.5 Mabsadd L closepath F
.24759 .32397 -2.5 2.5 Mabsadd m
.24759 .32397 2.5 2.5 Mabsadd L
.24759 .32397 2.5 -2.5 Mabsadd L
.24759 .32397 -2.5 -2.5 Mabsadd L
.24759 .32397 -2.5 2.5 Mabsadd L closepath F
.2528 .32905 -2.5 2.5 Mabsadd m
.2528 .32905 2.5 2.5 Mabsadd L
.2528 .32905 2.5 -2.5 Mabsadd L
.2528 .32905 -2.5 -2.5 Mabsadd L
.2528 .32905 -2.5 2.5 Mabsadd L closepath F
.258 .332 -2.5 2.5 Mabsadd m
.258 .332 2.5 2.5 Mabsadd L
.258 .332 2.5 -2.5 Mabsadd L
.258 .332 -2.5 -2.5 Mabsadd L
.258 .332 -2.5 2.5 Mabsadd L closepath F
.26321 .33312 -2.5 2.5 Mabsadd m
.26321 .33312 2.5 2.5 Mabsadd L
.26321 .33312 2.5 -2.5 Mabsadd L
.26321 .33312 -2.5 -2.5 Mabsadd L
.26321 .33312 -2.5 2.5 Mabsadd L closepath F
.26841 .33582 -2.5 2.5 Mabsadd m
.26841 .33582 2.5 2.5 Mabsadd L
.26841 .33582 2.5 -2.5 Mabsadd L
.26841 .33582 -2.5 -2.5 Mabsadd L
.26841 .33582 -2.5 2.5 Mabsadd L closepath F
.27361 .16553 -2.5 2.5 Mabsadd m
.27361 .16553 2.5 2.5 Mabsadd L
.27361 .16553 2.5 -2.5 Mabsadd L
.27361 .16553 -2.5 -2.5 Mabsadd L
.27361 .16553 -2.5 2.5 Mabsadd L closepath F
.27882 .16089 -2.5 2.5 Mabsadd m
.27882 .16089 2.5 2.5 Mabsadd L
.27882 .16089 2.5 -2.5 Mabsadd L
.27882 .16089 -2.5 -2.5 Mabsadd L
.27882 .16089 -2.5 2.5 Mabsadd L closepath F
.28402 .16806 -2.5 2.5 Mabsadd m
.28402 .16806 2.5 2.5 Mabsadd L
.28402 .16806 2.5 -2.5 Mabsadd L
.28402 .16806 -2.5 -2.5 Mabsadd L
.28402 .16806 -2.5 2.5 Mabsadd L closepath F
.28923 .16706 -2.5 2.5 Mabsadd m
.28923 .16706 2.5 2.5 Mabsadd L
.28923 .16706 2.5 -2.5 Mabsadd L
.28923 .16706 -2.5 -2.5 Mabsadd L
.28923 .16706 -2.5 2.5 Mabsadd L closepath F
.29443 .17973 -2.5 2.5 Mabsadd m
.29443 .17973 2.5 2.5 Mabsadd L
.29443 .17973 2.5 -2.5 Mabsadd L
.29443 .17973 -2.5 -2.5 Mabsadd L
.29443 .17973 -2.5 2.5 Mabsadd L closepath F
.29964 .18105 -2.5 2.5 Mabsadd m
.29964 .18105 2.5 2.5 Mabsadd L
.29964 .18105 2.5 -2.5 Mabsadd L
.29964 .18105 -2.5 -2.5 Mabsadd L
.29964 .18105 -2.5 2.5 Mabsadd L closepath F
.30484 .19406 -2.5 2.5 Mabsadd m
.30484 .19406 2.5 2.5 Mabsadd L
.30484 .19406 2.5 -2.5 Mabsadd L
.30484 .19406 -2.5 -2.5 Mabsadd L
.30484 .19406 -2.5 2.5 Mabsadd L closepath F
.31004 .19244 -2.5 2.5 Mabsadd m
.31004 .19244 2.5 2.5 Mabsadd L
.31004 .19244 2.5 -2.5 Mabsadd L
.31004 .19244 -2.5 -2.5 Mabsadd L
.31004 .19244 -2.5 2.5 Mabsadd L closepath F
.31525 .19447 -2.5 2.5 Mabsadd m
.31525 .19447 2.5 2.5 Mabsadd L
.31525 .19447 2.5 -2.5 Mabsadd L
.31525 .19447 -2.5 -2.5 Mabsadd L
.31525 .19447 -2.5 2.5 Mabsadd L closepath F
.32045 .21017 -2.5 2.5 Mabsadd m
.32045 .21017 2.5 2.5 Mabsadd L
.32045 .21017 2.5 -2.5 Mabsadd L
.32045 .21017 -2.5 -2.5 Mabsadd L
.32045 .21017 -2.5 2.5 Mabsadd L closepath F
.32566 .21576 -2.5 2.5 Mabsadd m
.32566 .21576 2.5 2.5 Mabsadd L
.32566 .21576 2.5 -2.5 Mabsadd L
.32566 .21576 -2.5 -2.5 Mabsadd L
.32566 .21576 -2.5 2.5 Mabsadd L closepath F
.33086 .216 -2.5 2.5 Mabsadd m
.33086 .216 2.5 2.5 Mabsadd L
.33086 .216 2.5 -2.5 Mabsadd L
.33086 .216 -2.5 -2.5 Mabsadd L
.33086 .216 -2.5 2.5 Mabsadd L closepath F
.33607 .22107 -2.5 2.5 Mabsadd m
.33607 .22107 2.5 2.5 Mabsadd L
.33607 .22107 2.5 -2.5 Mabsadd L
.33607 .22107 -2.5 -2.5 Mabsadd L
.33607 .22107 -2.5 2.5 Mabsadd L closepath F
.34127 .22714 -2.5 2.5 Mabsadd m
.34127 .22714 2.5 2.5 Mabsadd L
.34127 .22714 2.5 -2.5 Mabsadd L
.34127 .22714 -2.5 -2.5 Mabsadd L
.34127 .22714 -2.5 2.5 Mabsadd L closepath F
.34647 .2416 -2.5 2.5 Mabsadd m
.34647 .2416 2.5 2.5 Mabsadd L
.34647 .2416 2.5 -2.5 Mabsadd L
.34647 .2416 -2.5 -2.5 Mabsadd L
.34647 .2416 -2.5 2.5 Mabsadd L closepath F
.35168 .23829 -2.5 2.5 Mabsadd m
.35168 .23829 2.5 2.5 Mabsadd L
.35168 .23829 2.5 -2.5 Mabsadd L
.35168 .23829 -2.5 -2.5 Mabsadd L
.35168 .23829 -2.5 2.5 Mabsadd L closepath F
.35688 .24348 -2.5 2.5 Mabsadd m
.35688 .24348 2.5 2.5 Mabsadd L
.35688 .24348 2.5 -2.5 Mabsadd L
.35688 .24348 -2.5 -2.5 Mabsadd L
.35688 .24348 -2.5 2.5 Mabsadd L closepath F
.36209 .25487 -2.5 2.5 Mabsadd m
.36209 .25487 2.5 2.5 Mabsadd L
.36209 .25487 2.5 -2.5 Mabsadd L
.36209 .25487 -2.5 -2.5 Mabsadd L
.36209 .25487 -2.5 2.5 Mabsadd L closepath F
.36729 .25847 -2.5 2.5 Mabsadd m
.36729 .25847 2.5 2.5 Mabsadd L
.36729 .25847 2.5 -2.5 Mabsadd L
.36729 .25847 -2.5 -2.5 Mabsadd L
.36729 .25847 -2.5 2.5 Mabsadd L closepath F
.3725 .26893 -2.5 2.5 Mabsadd m
.3725 .26893 2.5 2.5 Mabsadd L
.3725 .26893 2.5 -2.5 Mabsadd L
.3725 .26893 -2.5 -2.5 Mabsadd L
.3725 .26893 -2.5 2.5 Mabsadd L closepath F
.3777 .27069 -2.5 2.5 Mabsadd m
.3777 .27069 2.5 2.5 Mabsadd L
.3777 .27069 2.5 -2.5 Mabsadd L
.3777 .27069 -2.5 -2.5 Mabsadd L
.3777 .27069 -2.5 2.5 Mabsadd L closepath F
.3829 .27721 -2.5 2.5 Mabsadd m
.3829 .27721 2.5 2.5 Mabsadd L
.3829 .27721 2.5 -2.5 Mabsadd L
.3829 .27721 -2.5 -2.5 Mabsadd L
.3829 .27721 -2.5 2.5 Mabsadd L closepath F
.38811 .28652 -2.5 2.5 Mabsadd m
.38811 .28652 2.5 2.5 Mabsadd L
.38811 .28652 2.5 -2.5 Mabsadd L
.38811 .28652 -2.5 -2.5 Mabsadd L
.38811 .28652 -2.5 2.5 Mabsadd L closepath F
.39331 .28822 -2.5 2.5 Mabsadd m
.39331 .28822 2.5 2.5 Mabsadd L
.39331 .28822 2.5 -2.5 Mabsadd L
.39331 .28822 -2.5 -2.5 Mabsadd L
.39331 .28822 -2.5 2.5 Mabsadd L closepath F
.39852 .28733 -2.5 2.5 Mabsadd m
.39852 .28733 2.5 2.5 Mabsadd L
.39852 .28733 2.5 -2.5 Mabsadd L
.39852 .28733 -2.5 -2.5 Mabsadd L
.39852 .28733 -2.5 2.5 Mabsadd L closepath F
.40372 .27732 -2.5 2.5 Mabsadd m
.40372 .27732 2.5 2.5 Mabsadd L
.40372 .27732 2.5 -2.5 Mabsadd L
.40372 .27732 -2.5 -2.5 Mabsadd L
.40372 .27732 -2.5 2.5 Mabsadd L closepath F
.40893 .29215 -2.5 2.5 Mabsadd m
.40893 .29215 2.5 2.5 Mabsadd L
.40893 .29215 2.5 -2.5 Mabsadd L
.40893 .29215 -2.5 -2.5 Mabsadd L
.40893 .29215 -2.5 2.5 Mabsadd L closepath F
.41413 .28567 -2.5 2.5 Mabsadd m
.41413 .28567 2.5 2.5 Mabsadd L
.41413 .28567 2.5 -2.5 Mabsadd L
.41413 .28567 -2.5 -2.5 Mabsadd L
.41413 .28567 -2.5 2.5 Mabsadd L closepath F
.41933 .30305 -2.5 2.5 Mabsadd m
.41933 .30305 2.5 2.5 Mabsadd L
.41933 .30305 2.5 -2.5 Mabsadd L
.41933 .30305 -2.5 -2.5 Mabsadd L
.41933 .30305 -2.5 2.5 Mabsadd L closepath F
.42454 .29965 -2.5 2.5 Mabsadd m
.42454 .29965 2.5 2.5 Mabsadd L
.42454 .29965 2.5 -2.5 Mabsadd L
.42454 .29965 -2.5 -2.5 Mabsadd L
.42454 .29965 -2.5 2.5 Mabsadd L closepath F
.42974 .30082 -2.5 2.5 Mabsadd m
.42974 .30082 2.5 2.5 Mabsadd L
.42974 .30082 2.5 -2.5 Mabsadd L
.42974 .30082 -2.5 -2.5 Mabsadd L
.42974 .30082 -2.5 2.5 Mabsadd L closepath F
.43495 .31017 -2.5 2.5 Mabsadd m
.43495 .31017 2.5 2.5 Mabsadd L
.43495 .31017 2.5 -2.5 Mabsadd L
.43495 .31017 -2.5 -2.5 Mabsadd L
.43495 .31017 -2.5 2.5 Mabsadd L closepath F
.44015 .31558 -2.5 2.5 Mabsadd m
.44015 .31558 2.5 2.5 Mabsadd L
.44015 .31558 2.5 -2.5 Mabsadd L
.44015 .31558 -2.5 -2.5 Mabsadd L
.44015 .31558 -2.5 2.5 Mabsadd L closepath F
.44536 .32296 -2.5 2.5 Mabsadd m
.44536 .32296 2.5 2.5 Mabsadd L
.44536 .32296 2.5 -2.5 Mabsadd L
.44536 .32296 -2.5 -2.5 Mabsadd L
.44536 .32296 -2.5 2.5 Mabsadd L closepath F
.45056 .32931 -2.5 2.5 Mabsadd m
.45056 .32931 2.5 2.5 Mabsadd L
.45056 .32931 2.5 -2.5 Mabsadd L
.45056 .32931 -2.5 -2.5 Mabsadd L
.45056 .32931 -2.5 2.5 Mabsadd L closepath F
.45576 .33179 -2.5 2.5 Mabsadd m
.45576 .33179 2.5 2.5 Mabsadd L
.45576 .33179 2.5 -2.5 Mabsadd L
.45576 .33179 -2.5 -2.5 Mabsadd L
.45576 .33179 -2.5 2.5 Mabsadd L closepath F
.46097 .33442 -2.5 2.5 Mabsadd m
.46097 .33442 2.5 2.5 Mabsadd L
.46097 .33442 2.5 -2.5 Mabsadd L
.46097 .33442 -2.5 -2.5 Mabsadd L
.46097 .33442 -2.5 2.5 Mabsadd L closepath F
.46617 .33576 -2.5 2.5 Mabsadd m
.46617 .33576 2.5 2.5 Mabsadd L
.46617 .33576 2.5 -2.5 Mabsadd L
.46617 .33576 -2.5 -2.5 Mabsadd L
.46617 .33576 -2.5 2.5 Mabsadd L closepath F
.47138 .34391 -2.5 2.5 Mabsadd m
.47138 .34391 2.5 2.5 Mabsadd L
.47138 .34391 2.5 -2.5 Mabsadd L
.47138 .34391 -2.5 -2.5 Mabsadd L
.47138 .34391 -2.5 2.5 Mabsadd L closepath F
.47658 .34517 -2.5 2.5 Mabsadd m
.47658 .34517 2.5 2.5 Mabsadd L
.47658 .34517 2.5 -2.5 Mabsadd L
.47658 .34517 -2.5 -2.5 Mabsadd L
.47658 .34517 -2.5 2.5 Mabsadd L closepath F
.48179 .35326 -2.5 2.5 Mabsadd m
.48179 .35326 2.5 2.5 Mabsadd L
.48179 .35326 2.5 -2.5 Mabsadd L
.48179 .35326 -2.5 -2.5 Mabsadd L
.48179 .35326 -2.5 2.5 Mabsadd L closepath F
.48699 .35654 -2.5 2.5 Mabsadd m
.48699 .35654 2.5 2.5 Mabsadd L
.48699 .35654 2.5 -2.5 Mabsadd L
.48699 .35654 -2.5 -2.5 Mabsadd L
.48699 .35654 -2.5 2.5 Mabsadd L closepath F
.49219 .35214 -2.5 2.5 Mabsadd m
.49219 .35214 2.5 2.5 Mabsadd L
.49219 .35214 2.5 -2.5 Mabsadd L
.49219 .35214 -2.5 -2.5 Mabsadd L
.49219 .35214 -2.5 2.5 Mabsadd L closepath F
.4974 .35747 -2.5 2.5 Mabsadd m
.4974 .35747 2.5 2.5 Mabsadd L
.4974 .35747 2.5 -2.5 Mabsadd L
.4974 .35747 -2.5 -2.5 Mabsadd L
.4974 .35747 -2.5 2.5 Mabsadd L closepath F
.5026 .36569 -2.5 2.5 Mabsadd m
.5026 .36569 2.5 2.5 Mabsadd L
.5026 .36569 2.5 -2.5 Mabsadd L
.5026 .36569 -2.5 -2.5 Mabsadd L
.5026 .36569 -2.5 2.5 Mabsadd L closepath F
.50781 .3623 -2.5 2.5 Mabsadd m
.50781 .3623 2.5 2.5 Mabsadd L
.50781 .3623 2.5 -2.5 Mabsadd L
.50781 .3623 -2.5 -2.5 Mabsadd L
.50781 .3623 -2.5 2.5 Mabsadd L closepath F
.51301 .36552 -2.5 2.5 Mabsadd m
.51301 .36552 2.5 2.5 Mabsadd L
.51301 .36552 2.5 -2.5 Mabsadd L
.51301 .36552 -2.5 -2.5 Mabsadd L
.51301 .36552 -2.5 2.5 Mabsadd L closepath F
.51821 .37102 -2.5 2.5 Mabsadd m
.51821 .37102 2.5 2.5 Mabsadd L
.51821 .37102 2.5 -2.5 Mabsadd L
.51821 .37102 -2.5 -2.5 Mabsadd L
.51821 .37102 -2.5 2.5 Mabsadd L closepath F
.52342 .36809 -2.5 2.5 Mabsadd m
.52342 .36809 2.5 2.5 Mabsadd L
.52342 .36809 2.5 -2.5 Mabsadd L
.52342 .36809 -2.5 -2.5 Mabsadd L
.52342 .36809 -2.5 2.5 Mabsadd L closepath F
.52862 .37993 -2.5 2.5 Mabsadd m
.52862 .37993 2.5 2.5 Mabsadd L
.52862 .37993 2.5 -2.5 Mabsadd L
.52862 .37993 -2.5 -2.5 Mabsadd L
.52862 .37993 -2.5 2.5 Mabsadd L closepath F
.53383 .37405 -2.5 2.5 Mabsadd m
.53383 .37405 2.5 2.5 Mabsadd L
.53383 .37405 2.5 -2.5 Mabsadd L
.53383 .37405 -2.5 -2.5 Mabsadd L
.53383 .37405 -2.5 2.5 Mabsadd L closepath F
.53903 .37784 -2.5 2.5 Mabsadd m
.53903 .37784 2.5 2.5 Mabsadd L
.53903 .37784 2.5 -2.5 Mabsadd L
.53903 .37784 -2.5 -2.5 Mabsadd L
.53903 .37784 -2.5 2.5 Mabsadd L closepath F
.54424 .38572 -2.5 2.5 Mabsadd m
.54424 .38572 2.5 2.5 Mabsadd L
.54424 .38572 2.5 -2.5 Mabsadd L
.54424 .38572 -2.5 -2.5 Mabsadd L
.54424 .38572 -2.5 2.5 Mabsadd L closepath F
.54944 .37913 -2.5 2.5 Mabsadd m
.54944 .37913 2.5 2.5 Mabsadd L
.54944 .37913 2.5 -2.5 Mabsadd L
.54944 .37913 -2.5 -2.5 Mabsadd L
.54944 .37913 -2.5 2.5 Mabsadd L closepath F
.55464 .37657 -2.5 2.5 Mabsadd m
.55464 .37657 2.5 2.5 Mabsadd L
.55464 .37657 2.5 -2.5 Mabsadd L
.55464 .37657 -2.5 -2.5 Mabsadd L
.55464 .37657 -2.5 2.5 Mabsadd L closepath F
.55985 .37176 -2.5 2.5 Mabsadd m
.55985 .37176 2.5 2.5 Mabsadd L
.55985 .37176 2.5 -2.5 Mabsadd L
.55985 .37176 -2.5 -2.5 Mabsadd L
.55985 .37176 -2.5 2.5 Mabsadd L closepath F
.56505 .37901 -2.5 2.5 Mabsadd m
.56505 .37901 2.5 2.5 Mabsadd L
.56505 .37901 2.5 -2.5 Mabsadd L
.56505 .37901 -2.5 -2.5 Mabsadd L
.56505 .37901 -2.5 2.5 Mabsadd L closepath F
.57026 .37674 -2.5 2.5 Mabsadd m
.57026 .37674 2.5 2.5 Mabsadd L
.57026 .37674 2.5 -2.5 Mabsadd L
.57026 .37674 -2.5 -2.5 Mabsadd L
.57026 .37674 -2.5 2.5 Mabsadd L closepath F
.57546 .37291 -2.5 2.5 Mabsadd m
.57546 .37291 2.5 2.5 Mabsadd L
.57546 .37291 2.5 -2.5 Mabsadd L
.57546 .37291 -2.5 -2.5 Mabsadd L
.57546 .37291 -2.5 2.5 Mabsadd L closepath F
.58067 .37341 -2.5 2.5 Mabsadd m
.58067 .37341 2.5 2.5 Mabsadd L
.58067 .37341 2.5 -2.5 Mabsadd L
.58067 .37341 -2.5 -2.5 Mabsadd L
.58067 .37341 -2.5 2.5 Mabsadd L closepath F
.58587 .37446 -2.5 2.5 Mabsadd m
.58587 .37446 2.5 2.5 Mabsadd L
.58587 .37446 2.5 -2.5 Mabsadd L
.58587 .37446 -2.5 -2.5 Mabsadd L
.58587 .37446 -2.5 2.5 Mabsadd L closepath F
.59107 .37221 -2.5 2.5 Mabsadd m
.59107 .37221 2.5 2.5 Mabsadd L
.59107 .37221 2.5 -2.5 Mabsadd L
.59107 .37221 -2.5 -2.5 Mabsadd L
.59107 .37221 -2.5 2.5 Mabsadd L closepath F
.59628 .36871 -2.5 2.5 Mabsadd m
.59628 .36871 2.5 2.5 Mabsadd L
.59628 .36871 2.5 -2.5 Mabsadd L
.59628 .36871 -2.5 -2.5 Mabsadd L
.59628 .36871 -2.5 2.5 Mabsadd L closepath F
.60148 .33382 -2.5 2.5 Mabsadd m
.60148 .33382 2.5 2.5 Mabsadd L
.60148 .33382 2.5 -2.5 Mabsadd L
.60148 .33382 -2.5 -2.5 Mabsadd L
.60148 .33382 -2.5 2.5 Mabsadd L closepath F
.60669 .3408 -2.5 2.5 Mabsadd m
.60669 .3408 2.5 2.5 Mabsadd L
.60669 .3408 2.5 -2.5 Mabsadd L
.60669 .3408 -2.5 -2.5 Mabsadd L
.60669 .3408 -2.5 2.5 Mabsadd L closepath F
.61189 .35207 -2.5 2.5 Mabsadd m
.61189 .35207 2.5 2.5 Mabsadd L
.61189 .35207 2.5 -2.5 Mabsadd L
.61189 .35207 -2.5 -2.5 Mabsadd L
.61189 .35207 -2.5 2.5 Mabsadd L closepath F
.6171 .36527 -2.5 2.5 Mabsadd m
.6171 .36527 2.5 2.5 Mabsadd L
.6171 .36527 2.5 -2.5 Mabsadd L
.6171 .36527 -2.5 -2.5 Mabsadd L
.6171 .36527 -2.5 2.5 Mabsadd L closepath F
.6223 .37155 -2.5 2.5 Mabsadd m
.6223 .37155 2.5 2.5 Mabsadd L
.6223 .37155 2.5 -2.5 Mabsadd L
.6223 .37155 -2.5 -2.5 Mabsadd L
.6223 .37155 -2.5 2.5 Mabsadd L closepath F
.6275 .3773 -2.5 2.5 Mabsadd m
.6275 .3773 2.5 2.5 Mabsadd L
.6275 .3773 2.5 -2.5 Mabsadd L
.6275 .3773 -2.5 -2.5 Mabsadd L
.6275 .3773 -2.5 2.5 Mabsadd L closepath F
.63271 .39858 -2.5 2.5 Mabsadd m
.63271 .39858 2.5 2.5 Mabsadd L
.63271 .39858 2.5 -2.5 Mabsadd L
.63271 .39858 -2.5 -2.5 Mabsadd L
.63271 .39858 -2.5 2.5 Mabsadd L closepath F
.63791 .40727 -2.5 2.5 Mabsadd m
.63791 .40727 2.5 2.5 Mabsadd L
.63791 .40727 2.5 -2.5 Mabsadd L
.63791 .40727 -2.5 -2.5 Mabsadd L
.63791 .40727 -2.5 2.5 Mabsadd L closepath F
.64312 .40577 -2.5 2.5 Mabsadd m
.64312 .40577 2.5 2.5 Mabsadd L
.64312 .40577 2.5 -2.5 Mabsadd L
.64312 .40577 -2.5 -2.5 Mabsadd L
.64312 .40577 -2.5 2.5 Mabsadd L closepath F
.64832 .42647 -2.5 2.5 Mabsadd m
.64832 .42647 2.5 2.5 Mabsadd L
.64832 .42647 2.5 -2.5 Mabsadd L
.64832 .42647 -2.5 -2.5 Mabsadd L
.64832 .42647 -2.5 2.5 Mabsadd L closepath F
.65353 .43196 -2.5 2.5 Mabsadd m
.65353 .43196 2.5 2.5 Mabsadd L
.65353 .43196 2.5 -2.5 Mabsadd L
.65353 .43196 -2.5 -2.5 Mabsadd L
.65353 .43196 -2.5 2.5 Mabsadd L closepath F
.65873 .44294 -2.5 2.5 Mabsadd m
.65873 .44294 2.5 2.5 Mabsadd L
.65873 .44294 2.5 -2.5 Mabsadd L
.65873 .44294 -2.5 -2.5 Mabsadd L
.65873 .44294 -2.5 2.5 Mabsadd L closepath F
.66393 .45633 -2.5 2.5 Mabsadd m
.66393 .45633 2.5 2.5 Mabsadd L
.66393 .45633 2.5 -2.5 Mabsadd L
.66393 .45633 -2.5 -2.5 Mabsadd L
.66393 .45633 -2.5 2.5 Mabsadd L closepath F
.66914 .46772 -2.5 2.5 Mabsadd m
.66914 .46772 2.5 2.5 Mabsadd L
.66914 .46772 2.5 -2.5 Mabsadd L
.66914 .46772 -2.5 -2.5 Mabsadd L
.66914 .46772 -2.5 2.5 Mabsadd L closepath F
.67434 .47374 -2.5 2.5 Mabsadd m
.67434 .47374 2.5 2.5 Mabsadd L
.67434 .47374 2.5 -2.5 Mabsadd L
.67434 .47374 -2.5 -2.5 Mabsadd L
.67434 .47374 -2.5 2.5 Mabsadd L closepath F
.67955 .48164 -2.5 2.5 Mabsadd m
.67955 .48164 2.5 2.5 Mabsadd L
.67955 .48164 2.5 -2.5 Mabsadd L
.67955 .48164 -2.5 -2.5 Mabsadd L
.67955 .48164 -2.5 2.5 Mabsadd L closepath F
.68475 .49528 -2.5 2.5 Mabsadd m
.68475 .49528 2.5 2.5 Mabsadd L
.68475 .49528 2.5 -2.5 Mabsadd L
.68475 .49528 -2.5 -2.5 Mabsadd L
.68475 .49528 -2.5 2.5 Mabsadd L closepath F
.68996 .49773 -2.5 2.5 Mabsadd m
.68996 .49773 2.5 2.5 Mabsadd L
.68996 .49773 2.5 -2.5 Mabsadd L
.68996 .49773 -2.5 -2.5 Mabsadd L
.68996 .49773 -2.5 2.5 Mabsadd L closepath F
.69516 .50357 -2.5 2.5 Mabsadd m
.69516 .50357 2.5 2.5 Mabsadd L
.69516 .50357 2.5 -2.5 Mabsadd L
.69516 .50357 -2.5 -2.5 Mabsadd L
.69516 .50357 -2.5 2.5 Mabsadd L closepath F
.70036 .50122 -2.5 2.5 Mabsadd m
.70036 .50122 2.5 2.5 Mabsadd L
.70036 .50122 2.5 -2.5 Mabsadd L
.70036 .50122 -2.5 -2.5 Mabsadd L
.70036 .50122 -2.5 2.5 Mabsadd L closepath F
.70557 .50291 -2.5 2.5 Mabsadd m
.70557 .50291 2.5 2.5 Mabsadd L
.70557 .50291 2.5 -2.5 Mabsadd L
.70557 .50291 -2.5 -2.5 Mabsadd L
.70557 .50291 -2.5 2.5 Mabsadd L closepath F
.71077 .52004 -2.5 2.5 Mabsadd m
.71077 .52004 2.5 2.5 Mabsadd L
.71077 .52004 2.5 -2.5 Mabsadd L
.71077 .52004 -2.5 -2.5 Mabsadd L
.71077 .52004 -2.5 2.5 Mabsadd L closepath F
.71598 .52966 -2.5 2.5 Mabsadd m
.71598 .52966 2.5 2.5 Mabsadd L
.71598 .52966 2.5 -2.5 Mabsadd L
.71598 .52966 -2.5 -2.5 Mabsadd L
.71598 .52966 -2.5 2.5 Mabsadd L closepath F
.72118 .52502 -2.5 2.5 Mabsadd m
.72118 .52502 2.5 2.5 Mabsadd L
.72118 .52502 2.5 -2.5 Mabsadd L
.72118 .52502 -2.5 -2.5 Mabsadd L
.72118 .52502 -2.5 2.5 Mabsadd L closepath F
.72639 .54505 -2.5 2.5 Mabsadd m
.72639 .54505 2.5 2.5 Mabsadd L
.72639 .54505 2.5 -2.5 Mabsadd L
.72639 .54505 -2.5 -2.5 Mabsadd L
.72639 .54505 -2.5 2.5 Mabsadd L closepath F
.73159 .55488 -2.5 2.5 Mabsadd m
.73159 .55488 2.5 2.5 Mabsadd L
.73159 .55488 2.5 -2.5 Mabsadd L
.73159 .55488 -2.5 -2.5 Mabsadd L
.73159 .55488 -2.5 2.5 Mabsadd L closepath F
.73679 .55984 -2.5 2.5 Mabsadd m
.73679 .55984 2.5 2.5 Mabsadd L
.73679 .55984 2.5 -2.5 Mabsadd L
.73679 .55984 -2.5 -2.5 Mabsadd L
.73679 .55984 -2.5 2.5 Mabsadd L closepath F
.742 .56295 -2.5 2.5 Mabsadd m
.742 .56295 2.5 2.5 Mabsadd L
.742 .56295 2.5 -2.5 Mabsadd L
.742 .56295 -2.5 -2.5 Mabsadd L
.742 .56295 -2.5 2.5 Mabsadd L closepath F
.7472 .57795 -2.5 2.5 Mabsadd m
.7472 .57795 2.5 2.5 Mabsadd L
.7472 .57795 2.5 -2.5 Mabsadd L
.7472 .57795 -2.5 -2.5 Mabsadd L
.7472 .57795 -2.5 2.5 Mabsadd L closepath F
.75241 .58188 -2.5 2.5 Mabsadd m
.75241 .58188 2.5 2.5 Mabsadd L
.75241 .58188 2.5 -2.5 Mabsadd L
.75241 .58188 -2.5 -2.5 Mabsadd L
.75241 .58188 -2.5 2.5 Mabsadd L closepath F
.75761 .58653 -2.5 2.5 Mabsadd m
.75761 .58653 2.5 2.5 Mabsadd L
.75761 .58653 2.5 -2.5 Mabsadd L
.75761 .58653 -2.5 -2.5 Mabsadd L
.75761 .58653 -2.5 2.5 Mabsadd L closepath F
.76282 .58884 -2.5 2.5 Mabsadd m
.76282 .58884 2.5 2.5 Mabsadd L
.76282 .58884 2.5 -2.5 Mabsadd L
.76282 .58884 -2.5 -2.5 Mabsadd L
.76282 .58884 -2.5 2.5 Mabsadd L closepath F
.76802 .59185 -2.5 2.5 Mabsadd m
.76802 .59185 2.5 2.5 Mabsadd L
.76802 .59185 2.5 -2.5 Mabsadd L
.76802 .59185 -2.5 -2.5 Mabsadd L
.76802 .59185 -2.5 2.5 Mabsadd L closepath F
.77322 .59923 -2.5 2.5 Mabsadd m
.77322 .59923 2.5 2.5 Mabsadd L
.77322 .59923 2.5 -2.5 Mabsadd L
.77322 .59923 -2.5 -2.5 Mabsadd L
.77322 .59923 -2.5 2.5 Mabsadd L closepath F
.77843 .59675 -2.5 2.5 Mabsadd m
.77843 .59675 2.5 2.5 Mabsadd L
.77843 .59675 2.5 -2.5 Mabsadd L
.77843 .59675 -2.5 -2.5 Mabsadd L
.77843 .59675 -2.5 2.5 Mabsadd L closepath F
.78363 .59491 -2.5 2.5 Mabsadd m
.78363 .59491 2.5 2.5 Mabsadd L
.78363 .59491 2.5 -2.5 Mabsadd L
.78363 .59491 -2.5 -2.5 Mabsadd L
.78363 .59491 -2.5 2.5 Mabsadd L closepath F
.78884 .59642 -2.5 2.5 Mabsadd m
.78884 .59642 2.5 2.5 Mabsadd L
.78884 .59642 2.5 -2.5 Mabsadd L
.78884 .59642 -2.5 -2.5 Mabsadd L
.78884 .59642 -2.5 2.5 Mabsadd L closepath F
.79404 .60332 -2.5 2.5 Mabsadd m
.79404 .60332 2.5 2.5 Mabsadd L
.79404 .60332 2.5 -2.5 Mabsadd L
.79404 .60332 -2.5 -2.5 Mabsadd L
.79404 .60332 -2.5 2.5 Mabsadd L closepath F
.79925 .60186 -2.5 2.5 Mabsadd m
.79925 .60186 2.5 2.5 Mabsadd L
.79925 .60186 2.5 -2.5 Mabsadd L
.79925 .60186 -2.5 -2.5 Mabsadd L
.79925 .60186 -2.5 2.5 Mabsadd L closepath F
.80445 .60306 -2.5 2.5 Mabsadd m
.80445 .60306 2.5 2.5 Mabsadd L
.80445 .60306 2.5 -2.5 Mabsadd L
.80445 .60306 -2.5 -2.5 Mabsadd L
.80445 .60306 -2.5 2.5 Mabsadd L closepath F
.80965 .5956 -2.5 2.5 Mabsadd m
.80965 .5956 2.5 2.5 Mabsadd L
.80965 .5956 2.5 -2.5 Mabsadd L
.80965 .5956 -2.5 -2.5 Mabsadd L
.80965 .5956 -2.5 2.5 Mabsadd L closepath F
.81486 .58786 -2.5 2.5 Mabsadd m
.81486 .58786 2.5 2.5 Mabsadd L
.81486 .58786 2.5 -2.5 Mabsadd L
.81486 .58786 -2.5 -2.5 Mabsadd L
.81486 .58786 -2.5 2.5 Mabsadd L closepath F
.82006 .58424 -2.5 2.5 Mabsadd m
.82006 .58424 2.5 2.5 Mabsadd L
.82006 .58424 2.5 -2.5 Mabsadd L
.82006 .58424 -2.5 -2.5 Mabsadd L
.82006 .58424 -2.5 2.5 Mabsadd L closepath F
.82527 .50348 -2.5 2.5 Mabsadd m
.82527 .50348 2.5 2.5 Mabsadd L
.82527 .50348 2.5 -2.5 Mabsadd L
.82527 .50348 -2.5 -2.5 Mabsadd L
.82527 .50348 -2.5 2.5 Mabsadd L closepath F
.83047 .49046 -2.5 2.5 Mabsadd m
.83047 .49046 2.5 2.5 Mabsadd L
.83047 .49046 2.5 -2.5 Mabsadd L
.83047 .49046 -2.5 -2.5 Mabsadd L
.83047 .49046 -2.5 2.5 Mabsadd L closepath F
.83568 .4876 -2.5 2.5 Mabsadd m
.83568 .4876 2.5 2.5 Mabsadd L
.83568 .4876 2.5 -2.5 Mabsadd L
.83568 .4876 -2.5 -2.5 Mabsadd L
.83568 .4876 -2.5 2.5 Mabsadd L closepath F
.84088 .4816 -2.5 2.5 Mabsadd m
.84088 .4816 2.5 2.5 Mabsadd L
.84088 .4816 2.5 -2.5 Mabsadd L
.84088 .4816 -2.5 -2.5 Mabsadd L
.84088 .4816 -2.5 2.5 Mabsadd L closepath F
.84608 .47263 -2.5 2.5 Mabsadd m
.84608 .47263 2.5 2.5 Mabsadd L
.84608 .47263 2.5 -2.5 Mabsadd L
.84608 .47263 -2.5 -2.5 Mabsadd L
.84608 .47263 -2.5 2.5 Mabsadd L closepath F
.85129 .46822 -2.5 2.5 Mabsadd m
.85129 .46822 2.5 2.5 Mabsadd L
.85129 .46822 2.5 -2.5 Mabsadd L
.85129 .46822 -2.5 -2.5 Mabsadd L
.85129 .46822 -2.5 2.5 Mabsadd L closepath F
.85649 .45968 -2.5 2.5 Mabsadd m
.85649 .45968 2.5 2.5 Mabsadd L
.85649 .45968 2.5 -2.5 Mabsadd L
.85649 .45968 -2.5 -2.5 Mabsadd L
.85649 .45968 -2.5 2.5 Mabsadd L closepath F
.8617 .45851 -2.5 2.5 Mabsadd m
.8617 .45851 2.5 2.5 Mabsadd L
.8617 .45851 2.5 -2.5 Mabsadd L
.8617 .45851 -2.5 -2.5 Mabsadd L
.8617 .45851 -2.5 2.5 Mabsadd L closepath F
.8669 .45178 -2.5 2.5 Mabsadd m
.8669 .45178 2.5 2.5 Mabsadd L
.8669 .45178 2.5 -2.5 Mabsadd L
.8669 .45178 -2.5 -2.5 Mabsadd L
.8669 .45178 -2.5 2.5 Mabsadd L closepath F
.87211 .44279 -2.5 2.5 Mabsadd m
.87211 .44279 2.5 2.5 Mabsadd L
.87211 .44279 2.5 -2.5 Mabsadd L
.87211 .44279 -2.5 -2.5 Mabsadd L
.87211 .44279 -2.5 2.5 Mabsadd L closepath F
.87731 .43325 -2.5 2.5 Mabsadd m
.87731 .43325 2.5 2.5 Mabsadd L
.87731 .43325 2.5 -2.5 Mabsadd L
.87731 .43325 -2.5 -2.5 Mabsadd L
.87731 .43325 -2.5 2.5 Mabsadd L closepath F
.88251 .42134 -2.5 2.5 Mabsadd m
.88251 .42134 2.5 2.5 Mabsadd L
.88251 .42134 2.5 -2.5 Mabsadd L
.88251 .42134 -2.5 -2.5 Mabsadd L
.88251 .42134 -2.5 2.5 Mabsadd L closepath F
.88772 .41857 -2.5 2.5 Mabsadd m
.88772 .41857 2.5 2.5 Mabsadd L
.88772 .41857 2.5 -2.5 Mabsadd L
.88772 .41857 -2.5 -2.5 Mabsadd L
.88772 .41857 -2.5 2.5 Mabsadd L closepath F
.89292 .41714 -2.5 2.5 Mabsadd m
.89292 .41714 2.5 2.5 Mabsadd L
.89292 .41714 2.5 -2.5 Mabsadd L
.89292 .41714 -2.5 -2.5 Mabsadd L
.89292 .41714 -2.5 2.5 Mabsadd L closepath F
.89813 .41016 -2.5 2.5 Mabsadd m
.89813 .41016 2.5 2.5 Mabsadd L
.89813 .41016 2.5 -2.5 Mabsadd L
.89813 .41016 -2.5 -2.5 Mabsadd L
.89813 .41016 -2.5 2.5 Mabsadd L closepath F
.90333 .40349 -2.5 2.5 Mabsadd m
.90333 .40349 2.5 2.5 Mabsadd L
.90333 .40349 2.5 -2.5 Mabsadd L
.90333 .40349 -2.5 -2.5 Mabsadd L
.90333 .40349 -2.5 2.5 Mabsadd L closepath F
.90853 .40099 -2.5 2.5 Mabsadd m
.90853 .40099 2.5 2.5 Mabsadd L
.90853 .40099 2.5 -2.5 Mabsadd L
.90853 .40099 -2.5 -2.5 Mabsadd L
.90853 .40099 -2.5 2.5 Mabsadd L closepath F
.91374 .40201 -2.5 2.5 Mabsadd m
.91374 .40201 2.5 2.5 Mabsadd L
.91374 .40201 2.5 -2.5 Mabsadd L
.91374 .40201 -2.5 -2.5 Mabsadd L
.91374 .40201 -2.5 2.5 Mabsadd L closepath F
.91894 .40477 -2.5 2.5 Mabsadd m
.91894 .40477 2.5 2.5 Mabsadd L
.91894 .40477 2.5 -2.5 Mabsadd L
.91894 .40477 -2.5 -2.5 Mabsadd L
.91894 .40477 -2.5 2.5 Mabsadd L closepath F
.92415 .40704 -2.5 2.5 Mabsadd m
.92415 .40704 2.5 2.5 Mabsadd L
.92415 .40704 2.5 -2.5 Mabsadd L
.92415 .40704 -2.5 -2.5 Mabsadd L
.92415 .40704 -2.5 2.5 Mabsadd L closepath F
.92935 .40472 -2.5 2.5 Mabsadd m
.92935 .40472 2.5 2.5 Mabsadd L
.92935 .40472 2.5 -2.5 Mabsadd L
.92935 .40472 -2.5 -2.5 Mabsadd L
.92935 .40472 -2.5 2.5 Mabsadd L closepath F
.93456 .40105 -2.5 2.5 Mabsadd m
.93456 .40105 2.5 2.5 Mabsadd L
.93456 .40105 2.5 -2.5 Mabsadd L
.93456 .40105 -2.5 -2.5 Mabsadd L
.93456 .40105 -2.5 2.5 Mabsadd L closepath F
.93976 .40418 -2.5 2.5 Mabsadd m
.93976 .40418 2.5 2.5 Mabsadd L
.93976 .40418 2.5 -2.5 Mabsadd L
.93976 .40418 -2.5 -2.5 Mabsadd L
.93976 .40418 -2.5 2.5 Mabsadd L closepath F
.94496 .40583 -2.5 2.5 Mabsadd m
.94496 .40583 2.5 2.5 Mabsadd L
.94496 .40583 2.5 -2.5 Mabsadd L
.94496 .40583 -2.5 -2.5 Mabsadd L
.94496 .40583 -2.5 2.5 Mabsadd L closepath F
.95017 .40153 -2.5 2.5 Mabsadd m
.95017 .40153 2.5 2.5 Mabsadd L
.95017 .40153 2.5 -2.5 Mabsadd L
.95017 .40153 -2.5 -2.5 Mabsadd L
.95017 .40153 -2.5 2.5 Mabsadd L closepath F
.95537 .40503 -2.5 2.5 Mabsadd m
.95537 .40503 2.5 2.5 Mabsadd L
.95537 .40503 2.5 -2.5 Mabsadd L
.95537 .40503 -2.5 -2.5 Mabsadd L
.95537 .40503 -2.5 2.5 Mabsadd L closepath F
.96058 .40173 -2.5 2.5 Mabsadd m
.96058 .40173 2.5 2.5 Mabsadd L
.96058 .40173 2.5 -2.5 Mabsadd L
.96058 .40173 -2.5 -2.5 Mabsadd L
.96058 .40173 -2.5 2.5 Mabsadd L closepath F
.96578 .40404 -2.5 2.5 Mabsadd m
.96578 .40404 2.5 2.5 Mabsadd L
.96578 .40404 2.5 -2.5 Mabsadd L
.96578 .40404 -2.5 -2.5 Mabsadd L
.96578 .40404 -2.5 2.5 Mabsadd L closepath F
.97099 .3933 -2.5 2.5 Mabsadd m
.97099 .3933 2.5 2.5 Mabsadd L
.97099 .3933 2.5 -2.5 Mabsadd L
.97099 .3933 -2.5 -2.5 Mabsadd L
.97099 .3933 -2.5 2.5 Mabsadd L closepath F
.97619 .3966 -2.5 2.5 Mabsadd m
.97619 .3966 2.5 2.5 Mabsadd L
.97619 .3966 2.5 -2.5 Mabsadd L
.97619 .3966 -2.5 -2.5 Mabsadd L
.97619 .3966 -2.5 2.5 Mabsadd L closepath F
.5 .3 0 r
.06544 .10931 0 2.5 Mabsadd m
.06544 .10931 -2.165 -1.25 Mabsadd L
.06544 .10931 2.165 -1.25 Mabsadd L
.06544 .10931 0 2.5 Mabsadd L closepath F
.07065 .1127 0 2.5 Mabsadd m
.07065 .1127 -2.165 -1.25 Mabsadd L
.07065 .1127 2.165 -1.25 Mabsadd L
.07065 .1127 0 2.5 Mabsadd L closepath F
.07585 .12556 0 2.5 Mabsadd m
.07585 .12556 -2.165 -1.25 Mabsadd L
.07585 .12556 2.165 -1.25 Mabsadd L
.07585 .12556 0 2.5 Mabsadd L closepath F
.08106 .14321 0 2.5 Mabsadd m
.08106 .14321 -2.165 -1.25 Mabsadd L
.08106 .14321 2.165 -1.25 Mabsadd L
.08106 .14321 0 2.5 Mabsadd L closepath F
.08626 .15163 0 2.5 Mabsadd m
.08626 .15163 -2.165 -1.25 Mabsadd L
.08626 .15163 2.165 -1.25 Mabsadd L
.08626 .15163 0 2.5 Mabsadd L closepath F
.09147 .15597 0 2.5 Mabsadd m
.09147 .15597 -2.165 -1.25 Mabsadd L
.09147 .15597 2.165 -1.25 Mabsadd L
.09147 .15597 0 2.5 Mabsadd L closepath F
.09667 .16806 0 2.5 Mabsadd m
.09667 .16806 -2.165 -1.25 Mabsadd L
.09667 .16806 2.165 -1.25 Mabsadd L
.09667 .16806 0 2.5 Mabsadd L closepath F
.10187 .181 0 2.5 Mabsadd m
.10187 .181 -2.165 -1.25 Mabsadd L
.10187 .181 2.165 -1.25 Mabsadd L
.10187 .181 0 2.5 Mabsadd L closepath F
.10708 .16959 0 2.5 Mabsadd m
.10708 .16959 -2.165 -1.25 Mabsadd L
.10708 .16959 2.165 -1.25 Mabsadd L
.10708 .16959 0 2.5 Mabsadd L closepath F
.11228 .17337 0 2.5 Mabsadd m
.11228 .17337 -2.165 -1.25 Mabsadd L
.11228 .17337 2.165 -1.25 Mabsadd L
.11228 .17337 0 2.5 Mabsadd L closepath F
.11749 .1763 0 2.5 Mabsadd m
.11749 .1763 -2.165 -1.25 Mabsadd L
.11749 .1763 2.165 -1.25 Mabsadd L
.11749 .1763 0 2.5 Mabsadd L closepath F
.12269 .18142 0 2.5 Mabsadd m
.12269 .18142 -2.165 -1.25 Mabsadd L
.12269 .18142 2.165 -1.25 Mabsadd L
.12269 .18142 0 2.5 Mabsadd L closepath F
.12789 .18583 0 2.5 Mabsadd m
.12789 .18583 -2.165 -1.25 Mabsadd L
.12789 .18583 2.165 -1.25 Mabsadd L
.12789 .18583 0 2.5 Mabsadd L closepath F
.1331 .18516 0 2.5 Mabsadd m
.1331 .18516 -2.165 -1.25 Mabsadd L
.1331 .18516 2.165 -1.25 Mabsadd L
.1331 .18516 0 2.5 Mabsadd L closepath F
.1383 .20431 0 2.5 Mabsadd m
.1383 .20431 -2.165 -1.25 Mabsadd L
.1383 .20431 2.165 -1.25 Mabsadd L
.1383 .20431 0 2.5 Mabsadd L closepath F
.14351 .19989 0 2.5 Mabsadd m
.14351 .19989 -2.165 -1.25 Mabsadd L
.14351 .19989 2.165 -1.25 Mabsadd L
.14351 .19989 0 2.5 Mabsadd L closepath F
.14871 .20325 0 2.5 Mabsadd m
.14871 .20325 -2.165 -1.25 Mabsadd L
.14871 .20325 2.165 -1.25 Mabsadd L
.14871 .20325 0 2.5 Mabsadd L closepath F
.15392 .20284 0 2.5 Mabsadd m
.15392 .20284 -2.165 -1.25 Mabsadd L
.15392 .20284 2.165 -1.25 Mabsadd L
.15392 .20284 0 2.5 Mabsadd L closepath F
.15912 .21327 0 2.5 Mabsadd m
.15912 .21327 -2.165 -1.25 Mabsadd L
.15912 .21327 2.165 -1.25 Mabsadd L
.15912 .21327 0 2.5 Mabsadd L closepath F
.16432 .21231 0 2.5 Mabsadd m
.16432 .21231 -2.165 -1.25 Mabsadd L
.16432 .21231 2.165 -1.25 Mabsadd L
.16432 .21231 0 2.5 Mabsadd L closepath F
.16953 .21114 0 2.5 Mabsadd m
.16953 .21114 -2.165 -1.25 Mabsadd L
.16953 .21114 2.165 -1.25 Mabsadd L
.16953 .21114 0 2.5 Mabsadd L closepath F
.17473 .22043 0 2.5 Mabsadd m
.17473 .22043 -2.165 -1.25 Mabsadd L
.17473 .22043 2.165 -1.25 Mabsadd L
.17473 .22043 0 2.5 Mabsadd L closepath F
.17994 .22371 0 2.5 Mabsadd m
.17994 .22371 -2.165 -1.25 Mabsadd L
.17994 .22371 2.165 -1.25 Mabsadd L
.17994 .22371 0 2.5 Mabsadd L closepath F
.18514 .2236 0 2.5 Mabsadd m
.18514 .2236 -2.165 -1.25 Mabsadd L
.18514 .2236 2.165 -1.25 Mabsadd L
.18514 .2236 0 2.5 Mabsadd L closepath F
.19035 .10761 0 2.5 Mabsadd m
.19035 .10761 -2.165 -1.25 Mabsadd L
.19035 .10761 2.165 -1.25 Mabsadd L
.19035 .10761 0 2.5 Mabsadd L closepath F
.19555 .11341 0 2.5 Mabsadd m
.19555 .11341 -2.165 -1.25 Mabsadd L
.19555 .11341 2.165 -1.25 Mabsadd L
.19555 .11341 0 2.5 Mabsadd L closepath F
.20075 .11413 0 2.5 Mabsadd m
.20075 .11413 -2.165 -1.25 Mabsadd L
.20075 .11413 2.165 -1.25 Mabsadd L
.20075 .11413 0 2.5 Mabsadd L closepath F
.20596 .12032 0 2.5 Mabsadd m
.20596 .12032 -2.165 -1.25 Mabsadd L
.20596 .12032 2.165 -1.25 Mabsadd L
.20596 .12032 0 2.5 Mabsadd L closepath F
.21116 .12548 0 2.5 Mabsadd m
.21116 .12548 -2.165 -1.25 Mabsadd L
.21116 .12548 2.165 -1.25 Mabsadd L
.21116 .12548 0 2.5 Mabsadd L closepath F
.21637 .1312 0 2.5 Mabsadd m
.21637 .1312 -2.165 -1.25 Mabsadd L
.21637 .1312 2.165 -1.25 Mabsadd L
.21637 .1312 0 2.5 Mabsadd L closepath F
.22157 .16504 0 2.5 Mabsadd m
.22157 .16504 -2.165 -1.25 Mabsadd L
.22157 .16504 2.165 -1.25 Mabsadd L
.22157 .16504 0 2.5 Mabsadd L closepath F
.22678 .15528 0 2.5 Mabsadd m
.22678 .15528 -2.165 -1.25 Mabsadd L
.22678 .15528 2.165 -1.25 Mabsadd L
.22678 .15528 0 2.5 Mabsadd L closepath F
.23198 .16894 0 2.5 Mabsadd m
.23198 .16894 -2.165 -1.25 Mabsadd L
.23198 .16894 2.165 -1.25 Mabsadd L
.23198 .16894 0 2.5 Mabsadd L closepath F
.23718 .17265 0 2.5 Mabsadd m
.23718 .17265 -2.165 -1.25 Mabsadd L
.23718 .17265 2.165 -1.25 Mabsadd L
.23718 .17265 0 2.5 Mabsadd L closepath F
.24239 .1783 0 2.5 Mabsadd m
.24239 .1783 -2.165 -1.25 Mabsadd L
.24239 .1783 2.165 -1.25 Mabsadd L
.24239 .1783 0 2.5 Mabsadd L closepath F
.24759 .18825 0 2.5 Mabsadd m
.24759 .18825 -2.165 -1.25 Mabsadd L
.24759 .18825 2.165 -1.25 Mabsadd L
.24759 .18825 0 2.5 Mabsadd L closepath F
.2528 .18803 0 2.5 Mabsadd m
.2528 .18803 -2.165 -1.25 Mabsadd L
.2528 .18803 2.165 -1.25 Mabsadd L
.2528 .18803 0 2.5 Mabsadd L closepath F
.258 .20344 0 2.5 Mabsadd m
.258 .20344 -2.165 -1.25 Mabsadd L
.258 .20344 2.165 -1.25 Mabsadd L
.258 .20344 0 2.5 Mabsadd L closepath F
.26321 .20551 0 2.5 Mabsadd m
.26321 .20551 -2.165 -1.25 Mabsadd L
.26321 .20551 2.165 -1.25 Mabsadd L
.26321 .20551 0 2.5 Mabsadd L closepath F
.26841 .17122 0 2.5 Mabsadd m
.26841 .17122 -2.165 -1.25 Mabsadd L
.26841 .17122 2.165 -1.25 Mabsadd L
.26841 .17122 0 2.5 Mabsadd L closepath F
.27361 .16122 0 2.5 Mabsadd m
.27361 .16122 -2.165 -1.25 Mabsadd L
.27361 .16122 2.165 -1.25 Mabsadd L
.27361 .16122 0 2.5 Mabsadd L closepath F
.27882 .15753 0 2.5 Mabsadd m
.27882 .15753 -2.165 -1.25 Mabsadd L
.27882 .15753 2.165 -1.25 Mabsadd L
.27882 .15753 0 2.5 Mabsadd L closepath F
.28402 .16737 0 2.5 Mabsadd m
.28402 .16737 -2.165 -1.25 Mabsadd L
.28402 .16737 2.165 -1.25 Mabsadd L
.28402 .16737 0 2.5 Mabsadd L closepath F
.28923 .15885 0 2.5 Mabsadd m
.28923 .15885 -2.165 -1.25 Mabsadd L
.28923 .15885 2.165 -1.25 Mabsadd L
.28923 .15885 0 2.5 Mabsadd L closepath F
.29443 .16392 0 2.5 Mabsadd m
.29443 .16392 -2.165 -1.25 Mabsadd L
.29443 .16392 2.165 -1.25 Mabsadd L
.29443 .16392 0 2.5 Mabsadd L closepath F
.29964 .17102 0 2.5 Mabsadd m
.29964 .17102 -2.165 -1.25 Mabsadd L
.29964 .17102 2.165 -1.25 Mabsadd L
.29964 .17102 0 2.5 Mabsadd L closepath F
.30484 .17432 0 2.5 Mabsadd m
.30484 .17432 -2.165 -1.25 Mabsadd L
.30484 .17432 2.165 -1.25 Mabsadd L
.30484 .17432 0 2.5 Mabsadd L closepath F
.31004 .1696 0 2.5 Mabsadd m
.31004 .1696 -2.165 -1.25 Mabsadd L
.31004 .1696 2.165 -1.25 Mabsadd L
.31004 .1696 0 2.5 Mabsadd L closepath F
.31525 .18129 0 2.5 Mabsadd m
.31525 .18129 -2.165 -1.25 Mabsadd L
.31525 .18129 2.165 -1.25 Mabsadd L
.31525 .18129 0 2.5 Mabsadd L closepath F
.32045 .17776 0 2.5 Mabsadd m
.32045 .17776 -2.165 -1.25 Mabsadd L
.32045 .17776 2.165 -1.25 Mabsadd L
.32045 .17776 0 2.5 Mabsadd L closepath F
.32566 .18139 0 2.5 Mabsadd m
.32566 .18139 -2.165 -1.25 Mabsadd L
.32566 .18139 2.165 -1.25 Mabsadd L
.32566 .18139 0 2.5 Mabsadd L closepath F
.33086 .17328 0 2.5 Mabsadd m
.33086 .17328 -2.165 -1.25 Mabsadd L
.33086 .17328 2.165 -1.25 Mabsadd L
.33086 .17328 0 2.5 Mabsadd L closepath F
.33607 .17698 0 2.5 Mabsadd m
.33607 .17698 -2.165 -1.25 Mabsadd L
.33607 .17698 2.165 -1.25 Mabsadd L
.33607 .17698 0 2.5 Mabsadd L closepath F
.34127 .17192 0 2.5 Mabsadd m
.34127 .17192 -2.165 -1.25 Mabsadd L
.34127 .17192 2.165 -1.25 Mabsadd L
.34127 .17192 0 2.5 Mabsadd L closepath F
.34647 .17695 0 2.5 Mabsadd m
.34647 .17695 -2.165 -1.25 Mabsadd L
.34647 .17695 2.165 -1.25 Mabsadd L
.34647 .17695 0 2.5 Mabsadd L closepath F
.35168 .16773 0 2.5 Mabsadd m
.35168 .16773 -2.165 -1.25 Mabsadd L
.35168 .16773 2.165 -1.25 Mabsadd L
.35168 .16773 0 2.5 Mabsadd L closepath F
.35688 .1713 0 2.5 Mabsadd m
.35688 .1713 -2.165 -1.25 Mabsadd L
.35688 .1713 2.165 -1.25 Mabsadd L
.35688 .1713 0 2.5 Mabsadd L closepath F
.36209 .16982 0 2.5 Mabsadd m
.36209 .16982 -2.165 -1.25 Mabsadd L
.36209 .16982 2.165 -1.25 Mabsadd L
.36209 .16982 0 2.5 Mabsadd L closepath F
.36729 .17404 0 2.5 Mabsadd m
.36729 .17404 -2.165 -1.25 Mabsadd L
.36729 .17404 2.165 -1.25 Mabsadd L
.36729 .17404 0 2.5 Mabsadd L closepath F
.3725 .18377 0 2.5 Mabsadd m
.3725 .18377 -2.165 -1.25 Mabsadd L
.3725 .18377 2.165 -1.25 Mabsadd L
.3725 .18377 0 2.5 Mabsadd L closepath F
.3777 .1766 0 2.5 Mabsadd m
.3777 .1766 -2.165 -1.25 Mabsadd L
.3777 .1766 2.165 -1.25 Mabsadd L
.3777 .1766 0 2.5 Mabsadd L closepath F
.3829 .20133 0 2.5 Mabsadd m
.3829 .20133 -2.165 -1.25 Mabsadd L
.3829 .20133 2.165 -1.25 Mabsadd L
.3829 .20133 0 2.5 Mabsadd L closepath F
.38811 .2071 0 2.5 Mabsadd m
.38811 .2071 -2.165 -1.25 Mabsadd L
.38811 .2071 2.165 -1.25 Mabsadd L
.38811 .2071 0 2.5 Mabsadd L closepath F
.39331 .21473 0 2.5 Mabsadd m
.39331 .21473 -2.165 -1.25 Mabsadd L
.39331 .21473 2.165 -1.25 Mabsadd L
.39331 .21473 0 2.5 Mabsadd L closepath F
.39852 .21306 0 2.5 Mabsadd m
.39852 .21306 -2.165 -1.25 Mabsadd L
.39852 .21306 2.165 -1.25 Mabsadd L
.39852 .21306 0 2.5 Mabsadd L closepath F
.40372 .20553 0 2.5 Mabsadd m
.40372 .20553 -2.165 -1.25 Mabsadd L
.40372 .20553 2.165 -1.25 Mabsadd L
.40372 .20553 0 2.5 Mabsadd L closepath F
.40893 .22582 0 2.5 Mabsadd m
.40893 .22582 -2.165 -1.25 Mabsadd L
.40893 .22582 2.165 -1.25 Mabsadd L
.40893 .22582 0 2.5 Mabsadd L closepath F
.41413 .22533 0 2.5 Mabsadd m
.41413 .22533 -2.165 -1.25 Mabsadd L
.41413 .22533 2.165 -1.25 Mabsadd L
.41413 .22533 0 2.5 Mabsadd L closepath F
.41933 .23525 0 2.5 Mabsadd m
.41933 .23525 -2.165 -1.25 Mabsadd L
.41933 .23525 2.165 -1.25 Mabsadd L
.41933 .23525 0 2.5 Mabsadd L closepath F
.42454 .23528 0 2.5 Mabsadd m
.42454 .23528 -2.165 -1.25 Mabsadd L
.42454 .23528 2.165 -1.25 Mabsadd L
.42454 .23528 0 2.5 Mabsadd L closepath F
.42974 .24431 0 2.5 Mabsadd m
.42974 .24431 -2.165 -1.25 Mabsadd L
.42974 .24431 2.165 -1.25 Mabsadd L
.42974 .24431 0 2.5 Mabsadd L closepath F
.43495 .1503 0 2.5 Mabsadd m
.43495 .1503 -2.165 -1.25 Mabsadd L
.43495 .1503 2.165 -1.25 Mabsadd L
.43495 .1503 0 2.5 Mabsadd L closepath F
.44015 .15893 0 2.5 Mabsadd m
.44015 .15893 -2.165 -1.25 Mabsadd L
.44015 .15893 2.165 -1.25 Mabsadd L
.44015 .15893 0 2.5 Mabsadd L closepath F
.44536 .16214 0 2.5 Mabsadd m
.44536 .16214 -2.165 -1.25 Mabsadd L
.44536 .16214 2.165 -1.25 Mabsadd L
.44536 .16214 0 2.5 Mabsadd L closepath F
.45056 .18109 0 2.5 Mabsadd m
.45056 .18109 -2.165 -1.25 Mabsadd L
.45056 .18109 2.165 -1.25 Mabsadd L
.45056 .18109 0 2.5 Mabsadd L closepath F
.45576 .17725 0 2.5 Mabsadd m
.45576 .17725 -2.165 -1.25 Mabsadd L
.45576 .17725 2.165 -1.25 Mabsadd L
.45576 .17725 0 2.5 Mabsadd L closepath F
.46097 .18368 0 2.5 Mabsadd m
.46097 .18368 -2.165 -1.25 Mabsadd L
.46097 .18368 2.165 -1.25 Mabsadd L
.46097 .18368 0 2.5 Mabsadd L closepath F
.46617 .20845 0 2.5 Mabsadd m
.46617 .20845 -2.165 -1.25 Mabsadd L
.46617 .20845 2.165 -1.25 Mabsadd L
.46617 .20845 0 2.5 Mabsadd L closepath F
.47138 .21271 0 2.5 Mabsadd m
.47138 .21271 -2.165 -1.25 Mabsadd L
.47138 .21271 2.165 -1.25 Mabsadd L
.47138 .21271 0 2.5 Mabsadd L closepath F
.47658 .21966 0 2.5 Mabsadd m
.47658 .21966 -2.165 -1.25 Mabsadd L
.47658 .21966 2.165 -1.25 Mabsadd L
.47658 .21966 0 2.5 Mabsadd L closepath F
.48179 .23272 0 2.5 Mabsadd m
.48179 .23272 -2.165 -1.25 Mabsadd L
.48179 .23272 2.165 -1.25 Mabsadd L
.48179 .23272 0 2.5 Mabsadd L closepath F
.48699 .25104 0 2.5 Mabsadd m
.48699 .25104 -2.165 -1.25 Mabsadd L
.48699 .25104 2.165 -1.25 Mabsadd L
.48699 .25104 0 2.5 Mabsadd L closepath F
.49219 .25059 0 2.5 Mabsadd m
.49219 .25059 -2.165 -1.25 Mabsadd L
.49219 .25059 2.165 -1.25 Mabsadd L
.49219 .25059 0 2.5 Mabsadd L closepath F
.4974 .25649 0 2.5 Mabsadd m
.4974 .25649 -2.165 -1.25 Mabsadd L
.4974 .25649 2.165 -1.25 Mabsadd L
.4974 .25649 0 2.5 Mabsadd L closepath F
.5026 .26728 0 2.5 Mabsadd m
.5026 .26728 -2.165 -1.25 Mabsadd L
.5026 .26728 2.165 -1.25 Mabsadd L
.5026 .26728 0 2.5 Mabsadd L closepath F
.50781 .27094 0 2.5 Mabsadd m
.50781 .27094 -2.165 -1.25 Mabsadd L
.50781 .27094 2.165 -1.25 Mabsadd L
.50781 .27094 0 2.5 Mabsadd L closepath F
.51301 .26793 0 2.5 Mabsadd m
.51301 .26793 -2.165 -1.25 Mabsadd L
.51301 .26793 2.165 -1.25 Mabsadd L
.51301 .26793 0 2.5 Mabsadd L closepath F
.51821 .28512 0 2.5 Mabsadd m
.51821 .28512 -2.165 -1.25 Mabsadd L
.51821 .28512 2.165 -1.25 Mabsadd L
.51821 .28512 0 2.5 Mabsadd L closepath F
.52342 .29159 0 2.5 Mabsadd m
.52342 .29159 -2.165 -1.25 Mabsadd L
.52342 .29159 2.165 -1.25 Mabsadd L
.52342 .29159 0 2.5 Mabsadd L closepath F
.52862 .30373 0 2.5 Mabsadd m
.52862 .30373 -2.165 -1.25 Mabsadd L
.52862 .30373 2.165 -1.25 Mabsadd L
.52862 .30373 0 2.5 Mabsadd L closepath F
.53383 .30164 0 2.5 Mabsadd m
.53383 .30164 -2.165 -1.25 Mabsadd L
.53383 .30164 2.165 -1.25 Mabsadd L
.53383 .30164 0 2.5 Mabsadd L closepath F
.53903 .31501 0 2.5 Mabsadd m
.53903 .31501 -2.165 -1.25 Mabsadd L
.53903 .31501 2.165 -1.25 Mabsadd L
.53903 .31501 0 2.5 Mabsadd L closepath F
.54424 .32686 0 2.5 Mabsadd m
.54424 .32686 -2.165 -1.25 Mabsadd L
.54424 .32686 2.165 -1.25 Mabsadd L
.54424 .32686 0 2.5 Mabsadd L closepath F
.54944 .33849 0 2.5 Mabsadd m
.54944 .33849 -2.165 -1.25 Mabsadd L
.54944 .33849 2.165 -1.25 Mabsadd L
.54944 .33849 0 2.5 Mabsadd L closepath F
.55464 .34231 0 2.5 Mabsadd m
.55464 .34231 -2.165 -1.25 Mabsadd L
.55464 .34231 2.165 -1.25 Mabsadd L
.55464 .34231 0 2.5 Mabsadd L closepath F
.55985 .34801 0 2.5 Mabsadd m
.55985 .34801 -2.165 -1.25 Mabsadd L
.55985 .34801 2.165 -1.25 Mabsadd L
.55985 .34801 0 2.5 Mabsadd L closepath F
.56505 .35222 0 2.5 Mabsadd m
.56505 .35222 -2.165 -1.25 Mabsadd L
.56505 .35222 2.165 -1.25 Mabsadd L
.56505 .35222 0 2.5 Mabsadd L closepath F
.57026 .35051 0 2.5 Mabsadd m
.57026 .35051 -2.165 -1.25 Mabsadd L
.57026 .35051 2.165 -1.25 Mabsadd L
.57026 .35051 0 2.5 Mabsadd L closepath F
.57546 .35943 0 2.5 Mabsadd m
.57546 .35943 -2.165 -1.25 Mabsadd L
.57546 .35943 2.165 -1.25 Mabsadd L
.57546 .35943 0 2.5 Mabsadd L closepath F
.58067 .36363 0 2.5 Mabsadd m
.58067 .36363 -2.165 -1.25 Mabsadd L
.58067 .36363 2.165 -1.25 Mabsadd L
.58067 .36363 0 2.5 Mabsadd L closepath F
.58587 .37494 0 2.5 Mabsadd m
.58587 .37494 -2.165 -1.25 Mabsadd L
.58587 .37494 2.165 -1.25 Mabsadd L
.58587 .37494 0 2.5 Mabsadd L closepath F
.59107 .3789 0 2.5 Mabsadd m
.59107 .3789 -2.165 -1.25 Mabsadd L
.59107 .3789 2.165 -1.25 Mabsadd L
.59107 .3789 0 2.5 Mabsadd L closepath F
.59628 .38033 0 2.5 Mabsadd m
.59628 .38033 -2.165 -1.25 Mabsadd L
.59628 .38033 2.165 -1.25 Mabsadd L
.59628 .38033 0 2.5 Mabsadd L closepath F
.60148 .22612 0 2.5 Mabsadd m
.60148 .22612 -2.165 -1.25 Mabsadd L
.60148 .22612 2.165 -1.25 Mabsadd L
.60148 .22612 0 2.5 Mabsadd L closepath F
.60669 .22908 0 2.5 Mabsadd m
.60669 .22908 -2.165 -1.25 Mabsadd L
.60669 .22908 2.165 -1.25 Mabsadd L
.60669 .22908 0 2.5 Mabsadd L closepath F
.61189 .23694 0 2.5 Mabsadd m
.61189 .23694 -2.165 -1.25 Mabsadd L
.61189 .23694 2.165 -1.25 Mabsadd L
.61189 .23694 0 2.5 Mabsadd L closepath F
.6171 .24174 0 2.5 Mabsadd m
.6171 .24174 -2.165 -1.25 Mabsadd L
.6171 .24174 2.165 -1.25 Mabsadd L
.6171 .24174 0 2.5 Mabsadd L closepath F
.6223 .23713 0 2.5 Mabsadd m
.6223 .23713 -2.165 -1.25 Mabsadd L
.6223 .23713 2.165 -1.25 Mabsadd L
.6223 .23713 0 2.5 Mabsadd L closepath F
.6275 .24607 0 2.5 Mabsadd m
.6275 .24607 -2.165 -1.25 Mabsadd L
.6275 .24607 2.165 -1.25 Mabsadd L
.6275 .24607 0 2.5 Mabsadd L closepath F
.63271 .26076 0 2.5 Mabsadd m
.63271 .26076 -2.165 -1.25 Mabsadd L
.63271 .26076 2.165 -1.25 Mabsadd L
.63271 .26076 0 2.5 Mabsadd L closepath F
.63791 .26382 0 2.5 Mabsadd m
.63791 .26382 -2.165 -1.25 Mabsadd L
.63791 .26382 2.165 -1.25 Mabsadd L
.63791 .26382 0 2.5 Mabsadd L closepath F
.64312 .26493 0 2.5 Mabsadd m
.64312 .26493 -2.165 -1.25 Mabsadd L
.64312 .26493 2.165 -1.25 Mabsadd L
.64312 .26493 0 2.5 Mabsadd L closepath F
.64832 .26858 0 2.5 Mabsadd m
.64832 .26858 -2.165 -1.25 Mabsadd L
.64832 .26858 2.165 -1.25 Mabsadd L
.64832 .26858 0 2.5 Mabsadd L closepath F
.65353 .27426 0 2.5 Mabsadd m
.65353 .27426 -2.165 -1.25 Mabsadd L
.65353 .27426 2.165 -1.25 Mabsadd L
.65353 .27426 0 2.5 Mabsadd L closepath F
.65873 .27611 0 2.5 Mabsadd m
.65873 .27611 -2.165 -1.25 Mabsadd L
.65873 .27611 2.165 -1.25 Mabsadd L
.65873 .27611 0 2.5 Mabsadd L closepath F
.66393 .28256 0 2.5 Mabsadd m
.66393 .28256 -2.165 -1.25 Mabsadd L
.66393 .28256 2.165 -1.25 Mabsadd L
.66393 .28256 0 2.5 Mabsadd L closepath F
.66914 .28378 0 2.5 Mabsadd m
.66914 .28378 -2.165 -1.25 Mabsadd L
.66914 .28378 2.165 -1.25 Mabsadd L
.66914 .28378 0 2.5 Mabsadd L closepath F
.67434 .29019 0 2.5 Mabsadd m
.67434 .29019 -2.165 -1.25 Mabsadd L
.67434 .29019 2.165 -1.25 Mabsadd L
.67434 .29019 0 2.5 Mabsadd L closepath F
.67955 .29996 0 2.5 Mabsadd m
.67955 .29996 -2.165 -1.25 Mabsadd L
.67955 .29996 2.165 -1.25 Mabsadd L
.67955 .29996 0 2.5 Mabsadd L closepath F
.68475 .30856 0 2.5 Mabsadd m
.68475 .30856 -2.165 -1.25 Mabsadd L
.68475 .30856 2.165 -1.25 Mabsadd L
.68475 .30856 0 2.5 Mabsadd L closepath F
.68996 .30779 0 2.5 Mabsadd m
.68996 .30779 -2.165 -1.25 Mabsadd L
.68996 .30779 2.165 -1.25 Mabsadd L
.68996 .30779 0 2.5 Mabsadd L closepath F
.69516 .32255 0 2.5 Mabsadd m
.69516 .32255 -2.165 -1.25 Mabsadd L
.69516 .32255 2.165 -1.25 Mabsadd L
.69516 .32255 0 2.5 Mabsadd L closepath F
.70036 .32346 0 2.5 Mabsadd m
.70036 .32346 -2.165 -1.25 Mabsadd L
.70036 .32346 2.165 -1.25 Mabsadd L
.70036 .32346 0 2.5 Mabsadd L closepath F
.70557 .33005 0 2.5 Mabsadd m
.70557 .33005 -2.165 -1.25 Mabsadd L
.70557 .33005 2.165 -1.25 Mabsadd L
.70557 .33005 0 2.5 Mabsadd L closepath F
.71077 .34529 0 2.5 Mabsadd m
.71077 .34529 -2.165 -1.25 Mabsadd L
.71077 .34529 2.165 -1.25 Mabsadd L
.71077 .34529 0 2.5 Mabsadd L closepath F
.71598 .3565 0 2.5 Mabsadd m
.71598 .3565 -2.165 -1.25 Mabsadd L
.71598 .3565 2.165 -1.25 Mabsadd L
.71598 .3565 0 2.5 Mabsadd L closepath F
.72118 .35896 0 2.5 Mabsadd m
.72118 .35896 -2.165 -1.25 Mabsadd L
.72118 .35896 2.165 -1.25 Mabsadd L
.72118 .35896 0 2.5 Mabsadd L closepath F
.72639 .36837 0 2.5 Mabsadd m
.72639 .36837 -2.165 -1.25 Mabsadd L
.72639 .36837 2.165 -1.25 Mabsadd L
.72639 .36837 0 2.5 Mabsadd L closepath F
.73159 .29739 0 2.5 Mabsadd m
.73159 .29739 -2.165 -1.25 Mabsadd L
.73159 .29739 2.165 -1.25 Mabsadd L
.73159 .29739 0 2.5 Mabsadd L closepath F
.73679 .2975 0 2.5 Mabsadd m
.73679 .2975 -2.165 -1.25 Mabsadd L
.73679 .2975 2.165 -1.25 Mabsadd L
.73679 .2975 0 2.5 Mabsadd L closepath F
.742 .30384 0 2.5 Mabsadd m
.742 .30384 -2.165 -1.25 Mabsadd L
.742 .30384 2.165 -1.25 Mabsadd L
.742 .30384 0 2.5 Mabsadd L closepath F
.7472 .31979 0 2.5 Mabsadd m
.7472 .31979 -2.165 -1.25 Mabsadd L
.7472 .31979 2.165 -1.25 Mabsadd L
.7472 .31979 0 2.5 Mabsadd L closepath F
.75241 .33567 0 2.5 Mabsadd m
.75241 .33567 -2.165 -1.25 Mabsadd L
.75241 .33567 2.165 -1.25 Mabsadd L
.75241 .33567 0 2.5 Mabsadd L closepath F
.75761 .34283 0 2.5 Mabsadd m
.75761 .34283 -2.165 -1.25 Mabsadd L
.75761 .34283 2.165 -1.25 Mabsadd L
.75761 .34283 0 2.5 Mabsadd L closepath F
.76282 .35566 0 2.5 Mabsadd m
.76282 .35566 -2.165 -1.25 Mabsadd L
.76282 .35566 2.165 -1.25 Mabsadd L
.76282 .35566 0 2.5 Mabsadd L closepath F
.76802 .36017 0 2.5 Mabsadd m
.76802 .36017 -2.165 -1.25 Mabsadd L
.76802 .36017 2.165 -1.25 Mabsadd L
.76802 .36017 0 2.5 Mabsadd L closepath F
.77322 .37066 0 2.5 Mabsadd m
.77322 .37066 -2.165 -1.25 Mabsadd L
.77322 .37066 2.165 -1.25 Mabsadd L
.77322 .37066 0 2.5 Mabsadd L closepath F
.77843 .37705 0 2.5 Mabsadd m
.77843 .37705 -2.165 -1.25 Mabsadd L
.77843 .37705 2.165 -1.25 Mabsadd L
.77843 .37705 0 2.5 Mabsadd L closepath F
.78363 .38638 0 2.5 Mabsadd m
.78363 .38638 -2.165 -1.25 Mabsadd L
.78363 .38638 2.165 -1.25 Mabsadd L
.78363 .38638 0 2.5 Mabsadd L closepath F
.78884 .39504 0 2.5 Mabsadd m
.78884 .39504 -2.165 -1.25 Mabsadd L
.78884 .39504 2.165 -1.25 Mabsadd L
.78884 .39504 0 2.5 Mabsadd L closepath F
.79404 .40781 0 2.5 Mabsadd m
.79404 .40781 -2.165 -1.25 Mabsadd L
.79404 .40781 2.165 -1.25 Mabsadd L
.79404 .40781 0 2.5 Mabsadd L closepath F
.79925 .41535 0 2.5 Mabsadd m
.79925 .41535 -2.165 -1.25 Mabsadd L
.79925 .41535 2.165 -1.25 Mabsadd L
.79925 .41535 0 2.5 Mabsadd L closepath F
.80445 .42165 0 2.5 Mabsadd m
.80445 .42165 -2.165 -1.25 Mabsadd L
.80445 .42165 2.165 -1.25 Mabsadd L
.80445 .42165 0 2.5 Mabsadd L closepath F
.80965 .4288 0 2.5 Mabsadd m
.80965 .4288 -2.165 -1.25 Mabsadd L
.80965 .4288 2.165 -1.25 Mabsadd L
.80965 .4288 0 2.5 Mabsadd L closepath F
.81486 .43443 0 2.5 Mabsadd m
.81486 .43443 -2.165 -1.25 Mabsadd L
.81486 .43443 2.165 -1.25 Mabsadd L
.81486 .43443 0 2.5 Mabsadd L closepath F
.82006 .40917 0 2.5 Mabsadd m
.82006 .40917 -2.165 -1.25 Mabsadd L
.82006 .40917 2.165 -1.25 Mabsadd L
.82006 .40917 0 2.5 Mabsadd L closepath F
.82527 .42134 0 2.5 Mabsadd m
.82527 .42134 -2.165 -1.25 Mabsadd L
.82527 .42134 2.165 -1.25 Mabsadd L
.82527 .42134 0 2.5 Mabsadd L closepath F
.83047 .41592 0 2.5 Mabsadd m
.83047 .41592 -2.165 -1.25 Mabsadd L
.83047 .41592 2.165 -1.25 Mabsadd L
.83047 .41592 0 2.5 Mabsadd L closepath F
.83568 .42261 0 2.5 Mabsadd m
.83568 .42261 -2.165 -1.25 Mabsadd L
.83568 .42261 2.165 -1.25 Mabsadd L
.83568 .42261 0 2.5 Mabsadd L closepath F
.84088 .42616 0 2.5 Mabsadd m
.84088 .42616 -2.165 -1.25 Mabsadd L
.84088 .42616 2.165 -1.25 Mabsadd L
.84088 .42616 0 2.5 Mabsadd L closepath F
.84608 .42654 0 2.5 Mabsadd m
.84608 .42654 -2.165 -1.25 Mabsadd L
.84608 .42654 2.165 -1.25 Mabsadd L
.84608 .42654 0 2.5 Mabsadd L closepath F
.85129 .43028 0 2.5 Mabsadd m
.85129 .43028 -2.165 -1.25 Mabsadd L
.85129 .43028 2.165 -1.25 Mabsadd L
.85129 .43028 0 2.5 Mabsadd L closepath F
.85649 .43017 0 2.5 Mabsadd m
.85649 .43017 -2.165 -1.25 Mabsadd L
.85649 .43017 2.165 -1.25 Mabsadd L
.85649 .43017 0 2.5 Mabsadd L closepath F
.8617 .43428 0 2.5 Mabsadd m
.8617 .43428 -2.165 -1.25 Mabsadd L
.8617 .43428 2.165 -1.25 Mabsadd L
.8617 .43428 0 2.5 Mabsadd L closepath F
.8669 .43507 0 2.5 Mabsadd m
.8669 .43507 -2.165 -1.25 Mabsadd L
.8669 .43507 2.165 -1.25 Mabsadd L
.8669 .43507 0 2.5 Mabsadd L closepath F
.87211 .42401 0 2.5 Mabsadd m
.87211 .42401 -2.165 -1.25 Mabsadd L
.87211 .42401 2.165 -1.25 Mabsadd L
.87211 .42401 0 2.5 Mabsadd L closepath F
.87731 .42395 0 2.5 Mabsadd m
.87731 .42395 -2.165 -1.25 Mabsadd L
.87731 .42395 2.165 -1.25 Mabsadd L
.87731 .42395 0 2.5 Mabsadd L closepath F
.88251 .41465 0 2.5 Mabsadd m
.88251 .41465 -2.165 -1.25 Mabsadd L
.88251 .41465 2.165 -1.25 Mabsadd L
.88251 .41465 0 2.5 Mabsadd L closepath F
.88772 .41678 0 2.5 Mabsadd m
.88772 .41678 -2.165 -1.25 Mabsadd L
.88772 .41678 2.165 -1.25 Mabsadd L
.88772 .41678 0 2.5 Mabsadd L closepath F
.89292 .4154 0 2.5 Mabsadd m
.89292 .4154 -2.165 -1.25 Mabsadd L
.89292 .4154 2.165 -1.25 Mabsadd L
.89292 .4154 0 2.5 Mabsadd L closepath F
.89813 .40763 0 2.5 Mabsadd m
.89813 .40763 -2.165 -1.25 Mabsadd L
.89813 .40763 2.165 -1.25 Mabsadd L
.89813 .40763 0 2.5 Mabsadd L closepath F
.90333 .41116 0 2.5 Mabsadd m
.90333 .41116 -2.165 -1.25 Mabsadd L
.90333 .41116 2.165 -1.25 Mabsadd L
.90333 .41116 0 2.5 Mabsadd L closepath F
.90853 .40474 0 2.5 Mabsadd m
.90853 .40474 -2.165 -1.25 Mabsadd L
.90853 .40474 2.165 -1.25 Mabsadd L
.90853 .40474 0 2.5 Mabsadd L closepath F
.91374 .40099 0 2.5 Mabsadd m
.91374 .40099 -2.165 -1.25 Mabsadd L
.91374 .40099 2.165 -1.25 Mabsadd L
.91374 .40099 0 2.5 Mabsadd L closepath F
.91894 .4005 0 2.5 Mabsadd m
.91894 .4005 -2.165 -1.25 Mabsadd L
.91894 .4005 2.165 -1.25 Mabsadd L
.91894 .4005 0 2.5 Mabsadd L closepath F
.92415 .39593 0 2.5 Mabsadd m
.92415 .39593 -2.165 -1.25 Mabsadd L
.92415 .39593 2.165 -1.25 Mabsadd L
.92415 .39593 0 2.5 Mabsadd L closepath F
.92935 .48699 0 2.5 Mabsadd m
.92935 .48699 -2.165 -1.25 Mabsadd L
.92935 .48699 2.165 -1.25 Mabsadd L
.92935 .48699 0 2.5 Mabsadd L closepath F
.93456 .47232 0 2.5 Mabsadd m
.93456 .47232 -2.165 -1.25 Mabsadd L
.93456 .47232 2.165 -1.25 Mabsadd L
.93456 .47232 0 2.5 Mabsadd L closepath F
.93976 .48169 0 2.5 Mabsadd m
.93976 .48169 -2.165 -1.25 Mabsadd L
.93976 .48169 2.165 -1.25 Mabsadd L
.93976 .48169 0 2.5 Mabsadd L closepath F
.94496 .48618 0 2.5 Mabsadd m
.94496 .48618 -2.165 -1.25 Mabsadd L
.94496 .48618 2.165 -1.25 Mabsadd L
.94496 .48618 0 2.5 Mabsadd L closepath F
.95017 .4756 0 2.5 Mabsadd m
.95017 .4756 -2.165 -1.25 Mabsadd L
.95017 .4756 2.165 -1.25 Mabsadd L
.95017 .4756 0 2.5 Mabsadd L closepath F
.95537 .47938 0 2.5 Mabsadd m
.95537 .47938 -2.165 -1.25 Mabsadd L
.95537 .47938 2.165 -1.25 Mabsadd L
.95537 .47938 0 2.5 Mabsadd L closepath F
.96058 .4748 0 2.5 Mabsadd m
.96058 .4748 -2.165 -1.25 Mabsadd L
.96058 .4748 2.165 -1.25 Mabsadd L
.96058 .4748 0 2.5 Mabsadd L closepath F
.96578 .47853 0 2.5 Mabsadd m
.96578 .47853 -2.165 -1.25 Mabsadd L
.96578 .47853 2.165 -1.25 Mabsadd L
.96578 .47853 0 2.5 Mabsadd L closepath F
.97099 .46231 0 2.5 Mabsadd m
.97099 .46231 -2.165 -1.25 Mabsadd L
.97099 .46231 2.165 -1.25 Mabsadd L
.97099 .46231 0 2.5 Mabsadd L closepath F
.97619 .46364 0 2.5 Mabsadd m
.97619 .46364 -2.165 -1.25 Mabsadd L
.97619 .46364 2.165 -1.25 Mabsadd L
.97619 .46364 0 2.5 Mabsadd L closepath F
.2 .3 .4 r
.01 w
.10708 .0434 Mdot
.11228 .04881 Mdot
.11749 .06474 Mdot
.12269 .06513 Mdot
.12789 .08086 Mdot
.1331 .08182 Mdot
.1383 .0953 Mdot
.14351 .10529 Mdot
.14871 .11196 Mdot
.15392 .11815 Mdot
.15912 .05128 Mdot
.16432 .05026 Mdot
.16953 .05314 Mdot
.17473 .05814 Mdot
.17994 .07321 Mdot
.18514 .07352 Mdot
.19035 .08184 Mdot
.19555 .08343 Mdot
.20075 .08707 Mdot
.20596 .08814 Mdot
.21116 .09933 Mdot
.21637 .10697 Mdot
.22157 .11895 Mdot
.22678 .12189 Mdot
.23198 .15318 Mdot
.23718 .16033 Mdot
.24239 .17677 Mdot
.24759 .17727 Mdot
.2528 .18918 Mdot
.258 .19619 Mdot
.26321 .20909 Mdot
.26841 .04819 Mdot
.27361 .04316 Mdot
.27882 .04578 Mdot
.28402 .04799 Mdot
.28923 .048 Mdot
.29443 .06666 Mdot
.29964 .07131 Mdot
.30484 .0864 Mdot
.31004 .08461 Mdot
.31525 .10013 Mdot
.32045 .09748 Mdot
.32566 .10645 Mdot
.33086 .10747 Mdot
.33607 .11214 Mdot
.34127 .11804 Mdot
.34647 .13007 Mdot
.35168 .12697 Mdot
.35688 .13658 Mdot
.36209 .14549 Mdot
.36729 .15154 Mdot
.3725 .16417 Mdot
.3777 .01472 Mdot
.3829 .03068 Mdot
.38811 .03777 Mdot
.39331 .04188 Mdot
.39852 .05083 Mdot
.40372 .03951 Mdot
.40893 .05492 Mdot
.41413 .05237 Mdot
.41933 .0662 Mdot
.42454 .07076 Mdot
.42974 .08147 Mdot
.43495 .09165 Mdot
.44015 .1163 Mdot
.44536 .11668 Mdot
.45056 .13448 Mdot
.45576 .1474 Mdot
.46097 .15636 Mdot
.46617 .1086 Mdot
.47138 .1133 Mdot
.47658 .12652 Mdot
.48179 .14527 Mdot
.48699 .16036 Mdot
.49219 .16178 Mdot
.4974 .18582 Mdot
.5026 .19474 Mdot
.50781 .20672 Mdot
.51301 .2184 Mdot
.51821 .23172 Mdot
.52342 .24016 Mdot
.52862 .24002 Mdot
.53383 .2424 Mdot
.53903 .24728 Mdot
.54424 .26177 Mdot
.54944 .26638 Mdot
.55464 .26714 Mdot
.55985 .27539 Mdot
.56505 .27181 Mdot
.57026 .2744 Mdot
.57546 .2736 Mdot
.58067 .27793 Mdot
.58587 .27882 Mdot
.59107 .28164 Mdot
.59628 .27989 Mdot
.60148 .23917 Mdot
.60669 .24755 Mdot
.61189 .25872 Mdot
.6171 .27284 Mdot
.6223 .27857 Mdot
.6275 .28635 Mdot
.63271 .31108 Mdot
.63791 .31734 Mdot
.64312 .31468 Mdot
.64832 .32595 Mdot
.65353 .33878 Mdot
.65873 .34316 Mdot
.66393 .3578 Mdot
.66914 .3686 Mdot
.67434 .37734 Mdot
.67955 .38911 Mdot
.68475 .40339 Mdot
.68996 .40517 Mdot
.69516 .34584 Mdot
.70036 .34583 Mdot
.70557 .34944 Mdot
.71077 .36186 Mdot
.71598 .37463 Mdot
.72118 .37951 Mdot
.72639 .40056 Mdot
.73159 .40503 Mdot
.73679 .41214 Mdot
.742 .42051 Mdot
.7472 .43118 Mdot
.75241 .42511 Mdot
.75761 .43191 Mdot
.76282 .43705 Mdot
.76802 .44368 Mdot
.77322 .45627 Mdot
.77843 .4568 Mdot
.78363 .45128 Mdot
.78884 .45133 Mdot
.79404 .46469 Mdot
.79925 .4662 Mdot
.80445 .4663 Mdot
.80965 .46437 Mdot
.81486 .45816 Mdot
.82006 .5161 Mdot
.82527 .53075 Mdot
.83047 .52712 Mdot
.83568 .54123 Mdot
.84088 .54024 Mdot
.84608 .53786 Mdot
.85129 .54197 Mdot
.85649 .53615 Mdot
.8617 .54035 Mdot
.8669 .5419 Mdot
.87211 .5335 Mdot
.87731 .52715 Mdot
.88251 .51797 Mdot
.88772 .51751 Mdot
.89292 .51613 Mdot
.89813 .4808 Mdot
.90333 .47951 Mdot
.90853 .47477 Mdot
.91374 .47345 Mdot
.91894 .47735 Mdot
.92415 .47589 Mdot
.92935 .4745 Mdot
.93456 .45615 Mdot
.93976 .4604 Mdot
.94496 .44309 Mdot
.95017 .43034 Mdot
.95537 .42305 Mdot
.96058 .41735 Mdot
.96578 .4073 Mdot
.97099 .397 Mdot
.97619 .3913 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.794476 0.141533 0.97619 0.466024 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0297619 0.297619 [
[ 0 0 0 0 ]
[ 1 1.78571 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.78571 L
0 1.78571 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0535714 0.35119 0.35119 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.2 .3 .4 r
.11688 w
.5 .5 Mdot
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .20238 -61 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(360) show
84.563 16.625 moveto
(\\260) show
93.250 16.625 moveto
(phase) show
128.438 16.625 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.39881 0.35119 0.696429 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 .3 0 r
.00117 w
[ ] 0 setdash
.5 .5 0 2.5 Mabsadd m
.5 .5 -2.165 -1.25 Mabsadd L
.5 .5 2.165 -1.25 Mabsadd L
.5 .5 0 2.5 Mabsadd L closepath F
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .54762 -61 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(270) show
84.563 16.625 moveto
(\\260) show
93.250 16.625 moveto
(phase) show
128.438 16.625 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.744048 0.35119 1.04167 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 .6 0 r
.00117 w
[ ] 0 setdash
.5 .5 -2.5 2.5 Mabsadd m
.5 .5 2.5 2.5 Mabsadd L
.5 .5 2.5 -2.5 Mabsadd L
.5 .5 -2.5 -2.5 Mabsadd L
.5 .5 -2.5 2.5 Mabsadd L closepath F
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .89286 -61 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(180) show
84.563 16.625 moveto
(\\260) show
93.250 16.625 moveto
(phase) show
128.438 16.625 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 1.08929 0.35119 1.3869 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.00117 w
[ ] 0 setdash
.5 .5 0 2.5 Mabsadd m
.5 .5 -0.56518 .7779 Mabsadd L
.5 .5 -2.37764 .77254 Mabsadd L
.5 .5 -0.91448 -0.29713 Mabsadd L
.5 .5 -1.46946 -2.02254 Mabsadd L
.5 .5 0 -0.96154 Mabsadd L
.5 .5 1.46946 -2.02254 Mabsadd L
.5 .5 .91448 -0.29713 Mabsadd L
.5 .5 2.37764 .77254 Mabsadd L
.5 .5 .56518 .7779 Mabsadd L
.5 .5 0 2.5 Mabsadd L closepath F
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 1.2381 -61 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(90) show
77.375 16.625 moveto
(\\260) show
86.063 16.625 moveto
(phase) show
121.250 16.625 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 1.43452 0.35119 1.73214 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.00117 w
[ ] 0 setdash
.5 .5 -1.875 0 Mabsadd m
.5 .5 0 2.5 Mabsadd L
.5 .5 1.875 0 Mabsadd L
.5 .5 0 -2.5 Mabsadd L
.5 .5 -1.875 0 Mabsadd L closepath F
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 1.58333 -61 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45) show
77.375 16.625 moveto
(\\260) show
86.063 16.625 moveto
(phase) show
121.250 16.625 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .52643 L
0 .52643 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{627.75, 330.4375},
 ImageMargins->0,
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{57.1875, 558.375}, {652.563, 389.25}} -> {-1.34306, \
1.26968, 0.00394322, 0.00394322}, {{69.625, 475.375}, {646.313, 395.5}} -> \
{-62.525, 2.19177, 0.465, 0.00871849}, {{455.063, 545.938}, {581.75, \
419.438}} -> {-16.9256, 11.6733, 0.0295794, 0.0295794}, {{459.938, 487}, \
{576.875, 549.813}} -> {-34.9911, 22.1734, 0.059123, 0.059123}, {{459.938, \
487}, {545.5, 518.438}} -> {-34.9911, 19.8547, 0.059123, 0.059123}, \
{{459.938, 487}, {514.125, 487.063}} -> {-34.9911, 17.536, 0.059123, \
0.059123}, {{459.938, 487}, {482.75, 455.688}} -> {-34.9911, 15.2172, \
0.059123, 0.059123}, {{459.938, 487}, {451.375, 424.313}} -> {-34.9911, \
12.8985, 0.059123, 0.059123}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot of Delay Data", "Subtitle"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"delays", "=", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "16"], ",", 
     FractionBox["1", "8"], ",", 
     FractionBox["1", "4"], ",", 
     FractionBox["1", "2"], ",", "1", ",", "2", ",", "4", ",", "8", ",", 
     "16"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "delay", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"delay", "[", "n_", "]"}], ":=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "/", "1*^6"}], ",", 
      RowBox[{"1*^9", 
       FractionBox[
        RowBox[{"unwrap", "[", 
         RowBox[{"-", 
          RowBox[{"Phase", "[", 
           RowBox[{
            RowBox[{"y", "[", "n", "]"}], "/", 
            RowBox[{"y", "[", "0", "]"}]}], "]"}]}], "]"}], 
        RowBox[{"360", " ", "x", " "}]]}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"delayall", "=", 
   RowBox[{"delay", "/@", "delays"}]}], ";"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "delaysmooth", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"delaysmooth", "[", "n_", "]"}], ":=", 
  RowBox[{"Interpolation", "[", 
   RowBox[{"smooth", "[", 
    RowBox[{
     RowBox[{"delay", "[", "n", "]"}], ",", "5"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"delaysmoothall", "=", 
   RowBox[{"delaysmooth", "/@", "delays"}]}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"1*^9", 
     FractionBox[
      RowBox[{"unwrap", "[", 
       RowBox[{"-", 
        RowBox[{"Phase", "[", 
         RowBox[{
          RowBox[{"y", "[", "#", "]"}], "/", 
          RowBox[{"y", "[", "0", "]"}]}], "]"}]}], "]"}], 
      RowBox[{"360", " ", "x", " "}]]}], "&"}], "/@", "delays"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"d50", "=", 
  RowBox[{"Reverse", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", "%", "]"}], "\[LeftDoubleBracket]", "100", 
    "\[RightDoubleBracket]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dseries50", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"d50", ".", "#"}], "&"}], "/@", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"IntegerDigits", "[", 
        RowBox[{"#", ",", "2", ",", "9"}], "]"}], "&"}], "/@", 
      RowBox[{"Range", "[", 
       RowBox[{"0", ",", "511"}], "]"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ddiff50", "=", 
   RowBox[{
    RowBox[{"Drop", "[", 
     RowBox[{"dseries50", ",", "1"}], "]"}], "-", 
    RowBox[{"Drop", "[", 
     RowBox[{"dseries50", ",", 
      RowBox[{"-", "1"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"ddiff50", ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "15.299316616737528`", ",", "7.603335399210439`", ",", 
   "3.8020590812493165`", ",", "1.8605011470840613`", ",", 
   "0.9424707871679641`", ",", "0.4816982961015104`", ",", 
   "0.24255062588831158`", ",", "0.1273302863942033`", ",", 
   "0.0643351250464208`"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["16ns Delay as Function of Frequency", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"f", "=", 
   RowBox[{"delaysmooth", "[", "16", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "10", ",", "194"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
       RowBox[{"RGBColor", " ", "[", 
        RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "}"}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Delay\>\""}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Frequency (MHz)\>\"", ",", "\"\<Delay (ns)\>\""}], "}"}]}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}]}], "]"}]}], "Input",
 CellChangeTimes->{3.442868165286875*^9}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0279504 0.00517598 -14.6257 0.961857 [
[.10145 -0.0125 -9.1875 -16.375 ]
[.10145 -0.0125 9.1875 0 ]
[.23085 -0.0125 -9.1875 -16.375 ]
[.23085 -0.0125 9.1875 0 ]
[.36025 -0.0125 -9.1875 -16.375 ]
[.36025 -0.0125 9.1875 0 ]
[.48965 -0.0125 -12.7813 -16.375 ]
[.48965 -0.0125 12.7813 0 ]
[.61905 -0.0125 -12.7813 -16.375 ]
[.61905 -0.0125 12.7813 0 ]
[.74845 -0.0125 -12.7813 -16.375 ]
[.74845 -0.0125 12.7813 0 ]
[.87785 -0.0125 -12.7813 -16.375 ]
[.87785 -0.0125 12.7813 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -51.7188 -32.75 ]
[.5 -0.0125 51.7188 -16.375 ]
[-0.0125 .09068 -29.125 -8.1875 ]
[-0.0125 .09068 0 8.1875 ]
[-0.0125 .18687 -29.125 -8.1875 ]
[-0.0125 .18687 0 8.1875 ]
[-0.0125 .28305 -29.125 -8.1875 ]
[-0.0125 .28305 0 8.1875 ]
[-0.0125 .37924 -29.125 -8.1875 ]
[-0.0125 .37924 0 8.1875 ]
[-0.0125 .47543 -29.125 -8.1875 ]
[-0.0125 .47543 0 8.1875 ]
[-0.0125 .57161 -29.125 -8.1875 ]
[-0.0125 .57161 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -45.5 -31.2813 ]
[-0.01875 .30902 -29.125 31.2813 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -18.5 0 ]
[.5 .63053 18.5 16.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.10145 0 m
.10145 .61803 L
s
.23085 0 m
.23085 .61803 L
s
.36025 0 m
.36025 .61803 L
s
.48965 0 m
.48965 .61803 L
s
.61905 0 m
.61905 .61803 L
s
.74845 0 m
.74845 .61803 L
s
.87785 0 m
.87785 .61803 L
s
0 .09068 m
1 .09068 L
s
0 .18687 m
1 .18687 L
s
0 .28305 m
1 .28305 L
s
0 .37924 m
1 .37924 L
s
0 .47543 m
1 .47543 L
s
0 .57161 m
1 .57161 L
s
0 g
.10145 0 m
.10145 .00625 L
s
gsave
.10145 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.23085 0 m
.23085 .00625 L
s
gsave
.23085 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.36025 0 m
.36025 .00625 L
s
gsave
.36025 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(75) show
1.000 setlinewidth
grestore
.48965 0 m
.48965 .00625 L
s
gsave
.48965 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.61905 0 m
.61905 .00625 L
s
gsave
.61905 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(125) show
1.000 setlinewidth
grestore
.74845 0 m
.74845 .00625 L
s
gsave
.74845 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.87785 0 m
.87785 .00625 L
s
gsave
.87785 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(175) show
1.000 setlinewidth
grestore
.125 Mabswid
.12733 0 m
.12733 .00375 L
s
.15321 0 m
.15321 .00375 L
s
.17909 0 m
.17909 .00375 L
s
.20497 0 m
.20497 .00375 L
s
.25673 0 m
.25673 .00375 L
s
.28261 0 m
.28261 .00375 L
s
.30849 0 m
.30849 .00375 L
s
.33437 0 m
.33437 .00375 L
s
.38613 0 m
.38613 .00375 L
s
.41201 0 m
.41201 .00375 L
s
.43789 0 m
.43789 .00375 L
s
.46377 0 m
.46377 .00375 L
s
.51553 0 m
.51553 .00375 L
s
.54141 0 m
.54141 .00375 L
s
.56729 0 m
.56729 .00375 L
s
.59317 0 m
.59317 .00375 L
s
.64493 0 m
.64493 .00375 L
s
.67081 0 m
.67081 .00375 L
s
.69669 0 m
.69669 .00375 L
s
.72257 0 m
.72257 .00375 L
s
.77433 0 m
.77433 .00375 L
s
.80021 0 m
.80021 .00375 L
s
.82609 0 m
.82609 .00375 L
s
.85197 0 m
.85197 .00375 L
s
.07557 0 m
.07557 .00375 L
s
.04969 0 m
.04969 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.90373 0 m
.90373 .00375 L
s
.92961 0 m
.92961 .00375 L
s
.95549 0 m
.95549 .00375 L
s
.98137 0 m
.98137 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -112.719 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Frequency) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
127.563 16.625 moveto
(H) show
131.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(MHz) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
158.250 16.625 moveto
(L) show
162.438 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .09068 m
.00625 .09068 L
s
gsave
-0.0125 .09068 -90.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15.3) show
1.000 setlinewidth
grestore
0 .18687 m
.00625 .18687 L
s
gsave
-0.0125 .18687 -90.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15.4) show
1.000 setlinewidth
grestore
0 .28305 m
.00625 .28305 L
s
gsave
-0.0125 .28305 -90.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15.5) show
1.000 setlinewidth
grestore
0 .37924 m
.00625 .37924 L
s
gsave
-0.0125 .37924 -90.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15.6) show
1.000 setlinewidth
grestore
0 .47543 m
.00625 .47543 L
s
gsave
-0.0125 .47543 -90.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15.7) show
1.000 setlinewidth
grestore
0 .57161 m
.00625 .57161 L
s
gsave
-0.0125 .57161 -90.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15.8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .10992 m
.00375 .10992 L
s
0 .12916 m
.00375 .12916 L
s
0 .14839 m
.00375 .14839 L
s
0 .16763 m
.00375 .16763 L
s
0 .20611 m
.00375 .20611 L
s
0 .22534 m
.00375 .22534 L
s
0 .24458 m
.00375 .24458 L
s
0 .26382 m
.00375 .26382 L
s
0 .30229 m
.00375 .30229 L
s
0 .32153 m
.00375 .32153 L
s
0 .34077 m
.00375 .34077 L
s
0 .36 m
.00375 .36 L
s
0 .39848 m
.00375 .39848 L
s
0 .41771 m
.00375 .41771 L
s
0 .43695 m
.00375 .43695 L
s
0 .45619 m
.00375 .45619 L
s
0 .49466 m
.00375 .49466 L
s
0 .5139 m
.00375 .5139 L
s
0 .53314 m
.00375 .53314 L
s
0 .55237 m
.00375 .55237 L
s
0 .07145 m
.00375 .07145 L
s
0 .05221 m
.00375 .05221 L
s
0 .03297 m
.00375 .03297 L
s
0 .01373 m
.00375 .01373 L
s
0 .59085 m
.00375 .59085 L
s
0 .61009 m
.00375 .61009 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -129.594 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
92.2813 12.1875 translate
90 rotate
-92.2813 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Delay) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.563 16.625 moveto
(H) show
103.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ns) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.375 16.625 moveto
(L) show
121.563 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.10145 .61178 m
.10145 .61803 L
s
.23085 .61178 m
.23085 .61803 L
s
.36025 .61178 m
.36025 .61803 L
s
.48965 .61178 m
.48965 .61803 L
s
.61905 .61178 m
.61905 .61803 L
s
.74845 .61178 m
.74845 .61803 L
s
.87785 .61178 m
.87785 .61803 L
s
.125 Mabswid
.12733 .61428 m
.12733 .61803 L
s
.15321 .61428 m
.15321 .61803 L
s
.17909 .61428 m
.17909 .61803 L
s
.20497 .61428 m
.20497 .61803 L
s
.25673 .61428 m
.25673 .61803 L
s
.28261 .61428 m
.28261 .61803 L
s
.30849 .61428 m
.30849 .61803 L
s
.33437 .61428 m
.33437 .61803 L
s
.38613 .61428 m
.38613 .61803 L
s
.41201 .61428 m
.41201 .61803 L
s
.43789 .61428 m
.43789 .61803 L
s
.46377 .61428 m
.46377 .61803 L
s
.51553 .61428 m
.51553 .61803 L
s
.54141 .61428 m
.54141 .61803 L
s
.56729 .61428 m
.56729 .61803 L
s
.59317 .61428 m
.59317 .61803 L
s
.64493 .61428 m
.64493 .61803 L
s
.67081 .61428 m
.67081 .61803 L
s
.69669 .61428 m
.69669 .61803 L
s
.72257 .61428 m
.72257 .61803 L
s
.77433 .61428 m
.77433 .61803 L
s
.80021 .61428 m
.80021 .61803 L
s
.82609 .61428 m
.82609 .61803 L
s
.85197 .61428 m
.85197 .61803 L
s
.07557 .61428 m
.07557 .61803 L
s
.04969 .61428 m
.04969 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.90373 .61428 m
.90373 .61803 L
s
.92961 .61428 m
.92961 .61803 L
s
.95549 .61428 m
.95549 .61803 L
s
.98137 .61428 m
.98137 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .09068 m
1 .09068 L
s
.99375 .18687 m
1 .18687 L
s
.99375 .28305 m
1 .28305 L
s
.99375 .37924 m
1 .37924 L
s
.99375 .47543 m
1 .47543 L
s
.99375 .57161 m
1 .57161 L
s
.125 Mabswid
.99625 .10992 m
1 .10992 L
s
.99625 .12916 m
1 .12916 L
s
.99625 .14839 m
1 .14839 L
s
.99625 .16763 m
1 .16763 L
s
.99625 .20611 m
1 .20611 L
s
.99625 .22534 m
1 .22534 L
s
.99625 .24458 m
1 .24458 L
s
.99625 .26382 m
1 .26382 L
s
.99625 .30229 m
1 .30229 L
s
.99625 .32153 m
1 .32153 L
s
.99625 .34077 m
1 .34077 L
s
.99625 .36 m
1 .36 L
s
.99625 .39848 m
1 .39848 L
s
.99625 .41771 m
1 .41771 L
s
.99625 .43695 m
1 .43695 L
s
.99625 .45619 m
1 .45619 L
s
.99625 .49466 m
1 .49466 L
s
.99625 .5139 m
1 .5139 L
s
.99625 .53314 m
1 .53314 L
s
.99625 .55237 m
1 .55237 L
s
.99625 .07145 m
1 .07145 L
s
.99625 .05221 m
1 .05221 L
s
.99625 .03297 m
1 .03297 L
s
.99625 .01373 m
1 .01373 L
s
.99625 .59085 m
1 .59085 L
s
.99625 .61009 m
1 .61009 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .09068 m
1 .09068 L
s
.10145 0 m
.10145 .61803 L
s
gsave
.5 .63053 -79.5 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Delay) show
96.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 0 r
.007 w
.02381 .60332 m
.03279 .52971 L
.04262 .45865 L
.053 .3999 L
.06244 .35581 L
.07298 .31774 L
.07839 .30403 L
.08124 .29606 L
.0828 .29091 L
.08426 .28638 L
.0855 .28308 L
.0862 .28198 L
.08684 .28112 L
.08969 .27842 L
.0947 .27337 L
.09948 .26852 L
.10216 .26477 L
.10458 .26088 L
.10585 .25921 L
.10701 .25875 L
.1083 .25868 L
.10894 .25872 L
.10965 .2588 L
.11084 .25891 L
.11212 .25843 L
.11333 .25772 L
.11442 .25702 L
.11667 .25561 L
.11794 .25504 L
.11912 .25456 L
.12357 .25303 L
.14429 .24706 L
.14675 .24628 L
.14904 .24546 L
.15019 .24513 L
.15142 .24491 L
.15213 .24485 L
.15279 .24502 L
.15403 .24556 L
.15531 .24622 L
.15666 .24689 L
.15737 .2472 L
.15815 .24726 L
.15885 .24724 L
.15952 .24718 L
.16075 .247 L
.1614 .24688 L
.16209 .24675 L
.16336 .24663 L
.16454 .24662 L
Mistroke
.16584 .24657 L
.16705 .24646 L
.16815 .24622 L
.16933 .24575 L
.17371 .24403 L
.175 .24385 L
.1762 .24365 L
.17746 .24332 L
.17813 .24306 L
.17884 .24259 L
.18131 .24046 L
.18355 .23789 L
.22131 .18412 L
.23137 .1688 L
.23688 .16141 L
.24204 .15551 L
.24643 .15184 L
.25116 .14896 L
.25348 .14649 L
.25475 .14521 L
.25596 .14434 L
.25664 .14402 L
.25738 .14373 L
.25868 .14332 L
.2612 .14258 L
.26367 .14169 L
.26492 .14132 L
.26563 .14114 L
.26629 .14109 L
.26747 .14105 L
.26855 .14104 L
.26979 .14102 L
.27097 .14094 L
.27221 .14058 L
.27352 .14019 L
.27466 .13989 L
.27589 .13965 L
.2772 .13979 L
.27843 .14005 L
.28124 .1408 L
.29958 .14532 L
.3042 .14689 L
.30674 .1476 L
.30799 .14791 L
.30914 .14814 L
.3098 .14823 L
.3105 .14831 L
.3112 .14834 L
.31198 .14834 L
.31262 .1482 L
Mistroke
.31331 .14801 L
.31456 .14762 L
.3196 .14635 L
.3249 .1455 L
.3278 .14489 L
.32923 .14468 L
.33054 .14443 L
.33179 .14411 L
.3331 .14353 L
.33442 .14266 L
.33587 .14165 L
.33707 .14084 L
.33836 .14027 L
.33958 .14002 L
.34069 .13981 L
.34199 .13952 L
.34318 .13906 L
.34449 .13814 L
.34589 .13701 L
.35081 .13304 L
.36184 .12299 L
.38194 .10159 L
.39132 .09237 L
.39659 .08821 L
.40142 .08547 L
.40597 .08251 L
.40821 .08095 L
.40919 .08033 L
.41027 .07976 L
.41142 .07932 L
.41264 .07894 L
.41397 .07861 L
.41521 .07838 L
.41635 .07824 L
.41738 .07812 L
.41851 .07799 L
.41971 .07783 L
.42096 .07747 L
.42212 .07703 L
.42347 .07653 L
.42474 .0761 L
.42595 .07587 L
.42725 .0758 L
.42843 .07582 L
.42952 .07589 L
.43062 .076 L
.43164 .07614 L
.43396 .0765 L
.43512 .07668 L
.43622 .07677 L
Mistroke
.43749 .07682 L
.43865 .07686 L
.43984 .07692 L
.44115 .07703 L
.44181 .07712 L
.44252 .07723 L
.44381 .07748 L
.44508 .07781 L
.4463 .07824 L
.44857 .07939 L
.45935 .08343 L
.46893 .08646 L
.47026 .08691 L
.47095 .08713 L
.47169 .08735 L
.47233 .08749 L
.47304 .08763 L
.47429 .08783 L
.4755 .08798 L
.4768 .08809 L
.47803 .08817 L
.47915 .08821 L
.48029 .08822 L
.4815 .08818 L
.48253 .08811 L
.48367 .08798 L
.4862 .08759 L
.48859 .08718 L
.49068 .08676 L
.49289 .08618 L
.49531 .08534 L
.49753 .08441 L
.50253 .08174 L
.50707 .07864 L
.51231 .07392 L
.51726 .06861 L
.52601 .05916 L
.53563 .05028 L
.54534 .04373 L
.55563 .03833 L
.55799 .03693 L
.55915 .03631 L
.56023 .03592 L
.56146 .03556 L
.56281 .03524 L
.56516 .03476 L
.56739 .03435 L
.56848 .03419 L
.56948 .03407 L
.57064 .03398 L
Mistroke
.5719 .03392 L
.57296 .0339 L
.57408 .03391 L
.57531 .03392 L
.576 .03393 L
.57664 .03395 L
.57781 .03403 L
.57905 .03417 L
.58016 .03437 L
.58121 .03466 L
.58358 .03548 L
.59375 .04005 L
.60252 .0437 L
.60715 .0455 L
.61209 .04779 L
.61477 .04869 L
.6172 .0493 L
.62195 .05027 L
.62692 .05161 L
.62954 .05236 L
.63086 .05264 L
.63161 .05273 L
.63231 .05275 L
.63356 .05272 L
.6347 .05263 L
.63602 .05246 L
.63727 .05225 L
.64183 .05144 L
.64292 .05138 L
.64406 .05132 L
.64532 .05122 L
.64647 .05109 L
.64754 .05079 L
.64855 .05044 L
.65082 .0495 L
.6554 .04769 L
.66045 .0458 L
.6707 .04155 L
.68911 .03289 L
.69414 .02981 L
.69961 .0272 L
.70211 .02599 L
.70348 .02541 L
.70477 .025 L
.70703 .02441 L
.70953 .02388 L
.71193 .02344 L
.7142 .02313 L
.71519 .02301 L
.71625 .02292 L
Mistroke
.71741 .02286 L
.71848 .02284 L
.71973 .02293 L
.72043 .02302 L
.72108 .02311 L
.72225 .02328 L
.72353 .02346 L
.72468 .0235 L
.72576 .02346 L
.72687 .02342 L
.72811 .02339 L
.72937 .02344 L
.73006 .02355 L
.73071 .02368 L
.73311 .02421 L
.73574 .02464 L
.73709 .0248 L
.7378 .02491 L
.73856 .02504 L
.73987 .0254 L
.74108 .02593 L
.74373 .02724 L
.74846 .02898 L
.75812 .03226 L
.76236 .03406 L
.76351 .03464 L
.76461 .03514 L
.76587 .03555 L
.76702 .03578 L
.76959 .03614 L
.772 .03656 L
.77727 .03785 L
.77984 .03853 L
.78058 .0387 L
.78128 .03881 L
.78258 .03898 L
.78334 .03905 L
.78403 .03911 L
.78479 .03915 L
.78559 .03917 L
.78628 .03918 L
.78692 .03917 L
.78762 .03915 L
.78837 .03911 L
.78903 .03907 L
.78973 .03902 L
.79097 .03891 L
.7938 .03856 L
.79644 .03816 L
.79892 .03778 L
Mistroke
.80112 .03736 L
.80236 .03703 L
.80349 .0367 L
.80853 .03563 L
.8291 .03061 L
.83426 .0291 L
.83549 .0287 L
.83679 .02833 L
.8379 .02814 L
.83912 .02805 L
.84123 .02796 L
.84241 .0279 L
.84349 .02771 L
.84593 .02723 L
.84821 .02681 L
.84935 .02667 L
.85057 .02654 L
.85161 .02647 L
.85275 .02642 L
.85398 .02647 L
.8553 .02655 L
.85655 .02667 L
.85769 .02679 L
.85996 .02706 L
.86106 .02719 L
.86207 .02729 L
.86313 .02736 L
.86427 .02734 L
.86551 .02729 L
.86668 .02725 L
.86782 .02723 L
.86907 .02727 L
.87037 .02738 L
.8716 .02753 L
.87274 .0277 L
.87378 .02792 L
.87613 .02856 L
.87735 .02889 L
.87864 .02919 L
.87939 .0293 L
.88007 .02938 L
.88139 .0295 L
.88262 .02959 L
.88396 .02967 L
.88523 .02973 L
.88638 .02979 L
.8876 .02988 L
.88876 .02998 L
.88998 .03017 L
.8913 .03042 L
Mistroke
.8959 .03144 L
.89726 .03173 L
.89853 .03195 L
.89917 .03203 L
.89986 .03205 L
.90062 .03205 L
.90132 .03203 L
.90249 .03196 L
.90377 .03188 L
.90441 .03184 L
.9051 .03182 L
.90634 .03179 L
.90766 .03176 L
.90839 .03174 L
.90907 .03173 L
.9098 .03172 L
.91061 .03172 L
.91129 .03172 L
.91202 .03171 L
.91271 .03169 L
.91346 .03167 L
.91417 .03164 L
.91482 .03159 L
.91606 .03144 L
.91738 .03125 L
.92741 .02956 L
.93774 .02745 L
.94057 .02669 L
.94211 .02636 L
.94355 .02602 L
.94423 .02584 L
.94488 .02566 L
.9461 .02519 L
.94744 .02453 L
.94888 .0238 L
.95938 .01983 L
.96409 .01803 L
.96907 .01624 L
.9707 .01568 L
.97162 .01543 L
.97246 .01528 L
.97439 .01498 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{575.813, 355.875},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{57.1875, 516.813}, {473.688, 190}} -> {-54.9346, \
15.6408, 0.406681, 0.00218845}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Delay Taps as Function of Frequency", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
      "delaysmoothall", "\[LeftDoubleBracket]", "1", 
       "\[RightDoubleBracket]"}], "[", "fr", "]"}], ",", 
     RowBox[{
      RowBox[{
      "delaysmoothall", "\[LeftDoubleBracket]", "2", 
       "\[RightDoubleBracket]"}], "[", "fr", "]"}], ",", 
     RowBox[{
      RowBox[{
      "delaysmoothall", "\[LeftDoubleBracket]", "3", 
       "\[RightDoubleBracket]"}], "[", "fr", "]"}], ",", 
     RowBox[{
      RowBox[{
      "delaysmoothall", "\[LeftDoubleBracket]", "4", 
       "\[RightDoubleBracket]"}], "[", "fr", "]"}], ",", 
     RowBox[{
      RowBox[{
      "delaysmoothall", "\[LeftDoubleBracket]", "5", 
       "\[RightDoubleBracket]"}], "[", "fr", "]"}], ",", 
     RowBox[{
      RowBox[{
      "delaysmoothall", "\[LeftDoubleBracket]", "6", 
       "\[RightDoubleBracket]"}], "[", "fr", "]"}], ",", 
     RowBox[{
      RowBox[{
      "delaysmoothall", "\[LeftDoubleBracket]", "7", 
       "\[RightDoubleBracket]"}], "[", "fr", "]"}], ",", 
     RowBox[{
      RowBox[{
      "delaysmoothall", "\[LeftDoubleBracket]", "8", 
       "\[RightDoubleBracket]"}], "[", "fr", "]"}], ",", 
     RowBox[{
      RowBox[{
      "delaysmoothall", "\[LeftDoubleBracket]", "9", 
       "\[RightDoubleBracket]"}], "[", "fr", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"fr", ",", "10", ",", "194"}], "}"}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.9", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.8", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.7", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", "\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.6", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", "\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.5", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", "\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.4", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", "\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.3", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", "\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.2", ",", "0", ",", "0"}], "]"}]}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Delay Taps\>\""}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Frequency (MHz)\>\"", ",", "\"\<Delay (ns)\>\""}], "}"}]}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"PlotLegend", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<1/16 ns\>\"", ",", "\"\<1/8 ns\>\"", ",", "\"\<1/4 ns\>\"", ",", 
      "\"\<1/2 ns\>\"", ",", "\"\<1 ns\>\"", ",", "\"\<2 ns\>\"", ",", 
      "\"\<4 ns\>\"", ",", "\"\<8 ns\>\"", ",", " ", "\"\<16 ns\>\""}], 
     "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"LegendPosition", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1.05", ",", 
      RowBox[{"-", "0.3"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"LegendShadow", "\[Rule]", "None"}]}], "]"}]], "Input",
 CellChangeTimes->{3.44286817152125*^9}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0279504 0.00517598 0.312126 0.242749 [
[.10145 -0.0125 -9.1875 -16.375 ]
[.10145 -0.0125 9.1875 0 ]
[.23085 -0.0125 -9.1875 -16.375 ]
[.23085 -0.0125 9.1875 0 ]
[.36025 -0.0125 -9.1875 -16.375 ]
[.36025 -0.0125 9.1875 0 ]
[.48965 -0.0125 -12.7813 -16.375 ]
[.48965 -0.0125 12.7813 0 ]
[.61905 -0.0125 -12.7813 -16.375 ]
[.61905 -0.0125 12.7813 0 ]
[.74845 -0.0125 -12.7813 -16.375 ]
[.74845 -0.0125 12.7813 0 ]
[.87785 -0.0125 -12.7813 -16.375 ]
[.87785 -0.0125 12.7813 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -51.7188 -32.75 ]
[.5 -0.0125 51.7188 -16.375 ]
[-0.0125 .06938 -21.9375 -8.1875 ]
[-0.0125 .06938 0 8.1875 ]
[-0.0125 .14245 -21.9375 -8.1875 ]
[-0.0125 .14245 0 8.1875 ]
[-0.0125 .23905 -21.9375 -8.1875 ]
[-0.0125 .23905 0 8.1875 ]
[-0.0125 .31213 -11.1875 -8.1875 ]
[-0.0125 .31213 0 8.1875 ]
[-0.0125 .3852 -11.1875 -8.1875 ]
[-0.0125 .3852 0 8.1875 ]
[-0.0125 .4818 -11.1875 -8.1875 ]
[-0.0125 .4818 0 8.1875 ]
[-0.0125 .55488 -18.375 -8.1875 ]
[-0.0125 .55488 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -38.3125 -31.2813 ]
[-0.01875 .30902 -21.9375 31.2813 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -34.6875 0 ]
[.5 .63053 34.6875 16.375 ]
[ -0.0005 0 0 0 ]
[ 1.0005 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.10145 0 m
.10145 .61803 L
s
.23085 0 m
.23085 .61803 L
s
.36025 0 m
.36025 .61803 L
s
.48965 0 m
.48965 .61803 L
s
.61905 0 m
.61905 .61803 L
s
.74845 0 m
.74845 .61803 L
s
.87785 0 m
.87785 .61803 L
s
0 .06938 m
1 .06938 L
s
0 .14245 m
1 .14245 L
s
0 .23905 m
1 .23905 L
s
0 .31213 m
1 .31213 L
s
0 .3852 m
1 .3852 L
s
0 .4818 m
1 .4818 L
s
0 .55488 m
1 .55488 L
s
0 .1852 m
1 .1852 L
s
0 .21553 m
1 .21553 L
s
0 .25827 m
1 .25827 L
s
0 .27452 m
1 .27452 L
s
0 .2886 m
1 .2886 L
s
0 .30102 m
1 .30102 L
s
0 .42795 m
1 .42795 L
s
0 .45828 m
1 .45828 L
s
0 .50102 m
1 .50102 L
s
0 .51727 m
1 .51727 L
s
0 .53135 m
1 .53135 L
s
0 .54377 m
1 .54377 L
s
0 g
.10145 0 m
.10145 .00625 L
s
gsave
.10145 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.23085 0 m
.23085 .00625 L
s
gsave
.23085 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.36025 0 m
.36025 .00625 L
s
gsave
.36025 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(75) show
1.000 setlinewidth
grestore
.48965 0 m
.48965 .00625 L
s
gsave
.48965 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.61905 0 m
.61905 .00625 L
s
gsave
.61905 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(125) show
1.000 setlinewidth
grestore
.74845 0 m
.74845 .00625 L
s
gsave
.74845 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.87785 0 m
.87785 .00625 L
s
gsave
.87785 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(175) show
1.000 setlinewidth
grestore
.125 Mabswid
.12733 0 m
.12733 .00375 L
s
.15321 0 m
.15321 .00375 L
s
.17909 0 m
.17909 .00375 L
s
.20497 0 m
.20497 .00375 L
s
.25673 0 m
.25673 .00375 L
s
.28261 0 m
.28261 .00375 L
s
.30849 0 m
.30849 .00375 L
s
.33437 0 m
.33437 .00375 L
s
.38613 0 m
.38613 .00375 L
s
.41201 0 m
.41201 .00375 L
s
.43789 0 m
.43789 .00375 L
s
.46377 0 m
.46377 .00375 L
s
.51553 0 m
.51553 .00375 L
s
.54141 0 m
.54141 .00375 L
s
.56729 0 m
.56729 .00375 L
s
.59317 0 m
.59317 .00375 L
s
.64493 0 m
.64493 .00375 L
s
.67081 0 m
.67081 .00375 L
s
.69669 0 m
.69669 .00375 L
s
.72257 0 m
.72257 .00375 L
s
.77433 0 m
.77433 .00375 L
s
.80021 0 m
.80021 .00375 L
s
.82609 0 m
.82609 .00375 L
s
.85197 0 m
.85197 .00375 L
s
.07557 0 m
.07557 .00375 L
s
.04969 0 m
.04969 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.90373 0 m
.90373 .00375 L
s
.92961 0 m
.92961 .00375 L
s
.95549 0 m
.95549 .00375 L
s
.98137 0 m
.98137 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -112.719 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Frequency) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
127.563 16.625 moveto
(H) show
131.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(MHz) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
158.250 16.625 moveto
(L) show
162.438 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .06938 m
.00625 .06938 L
s
gsave
-0.0125 .06938 -82.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
80.938 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .14245 m
.00625 .14245 L
s
gsave
-0.0125 .14245 -82.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
80.938 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .23905 m
.00625 .23905 L
s
gsave
-0.0125 .23905 -82.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
80.938 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .31213 m
.00625 .31213 L
s
gsave
-0.0125 .31213 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
70.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .3852 m
.00625 .3852 L
s
gsave
-0.0125 .3852 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
70.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .4818 m
.00625 .4818 L
s
gsave
-0.0125 .4818 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
70.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .55488 m
.00625 .55488 L
s
gsave
-0.0125 .55488 -79.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
77.375 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .1852 m
.00375 .1852 L
s
0 .21553 m
.00375 .21553 L
s
0 .25827 m
.00375 .25827 L
s
0 .27452 m
.00375 .27452 L
s
0 .2886 m
.00375 .2886 L
s
0 .30102 m
.00375 .30102 L
s
0 .42795 m
.00375 .42795 L
s
0 .45828 m
.00375 .45828 L
s
0 .50102 m
.00375 .50102 L
s
0 .51727 m
.00375 .51727 L
s
0 .53135 m
.00375 .53135 L
s
0 .54377 m
.00375 .54377 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -122.406 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
92.2813 12.1875 translate
90 rotate
-92.2813 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Delay) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.563 16.625 moveto
(H) show
103.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ns) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.375 16.625 moveto
(L) show
121.563 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.10145 .61178 m
.10145 .61803 L
s
.23085 .61178 m
.23085 .61803 L
s
.36025 .61178 m
.36025 .61803 L
s
.48965 .61178 m
.48965 .61803 L
s
.61905 .61178 m
.61905 .61803 L
s
.74845 .61178 m
.74845 .61803 L
s
.87785 .61178 m
.87785 .61803 L
s
.125 Mabswid
.12733 .61428 m
.12733 .61803 L
s
.15321 .61428 m
.15321 .61803 L
s
.17909 .61428 m
.17909 .61803 L
s
.20497 .61428 m
.20497 .61803 L
s
.25673 .61428 m
.25673 .61803 L
s
.28261 .61428 m
.28261 .61803 L
s
.30849 .61428 m
.30849 .61803 L
s
.33437 .61428 m
.33437 .61803 L
s
.38613 .61428 m
.38613 .61803 L
s
.41201 .61428 m
.41201 .61803 L
s
.43789 .61428 m
.43789 .61803 L
s
.46377 .61428 m
.46377 .61803 L
s
.51553 .61428 m
.51553 .61803 L
s
.54141 .61428 m
.54141 .61803 L
s
.56729 .61428 m
.56729 .61803 L
s
.59317 .61428 m
.59317 .61803 L
s
.64493 .61428 m
.64493 .61803 L
s
.67081 .61428 m
.67081 .61803 L
s
.69669 .61428 m
.69669 .61803 L
s
.72257 .61428 m
.72257 .61803 L
s
.77433 .61428 m
.77433 .61803 L
s
.80021 .61428 m
.80021 .61803 L
s
.82609 .61428 m
.82609 .61803 L
s
.85197 .61428 m
.85197 .61803 L
s
.07557 .61428 m
.07557 .61803 L
s
.04969 .61428 m
.04969 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.90373 .61428 m
.90373 .61803 L
s
.92961 .61428 m
.92961 .61803 L
s
.95549 .61428 m
.95549 .61803 L
s
.98137 .61428 m
.98137 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06938 m
1 .06938 L
s
.99375 .14245 m
1 .14245 L
s
.99375 .23905 m
1 .23905 L
s
.99375 .31213 m
1 .31213 L
s
.99375 .3852 m
1 .3852 L
s
.99375 .4818 m
1 .4818 L
s
.99375 .55488 m
1 .55488 L
s
.001 w
.99625 .1852 m
1 .1852 L
s
.99625 .21553 m
1 .21553 L
s
.99625 .25827 m
1 .25827 L
s
.99625 .27452 m
1 .27452 L
s
.99625 .2886 m
1 .2886 L
s
.99625 .30102 m
1 .30102 L
s
.99625 .42795 m
1 .42795 L
s
.99625 .45828 m
1 .45828 L
s
.99625 .50102 m
1 .50102 L
s
.99625 .51727 m
1 .51727 L
s
.99625 .53135 m
1 .53135 L
s
.99625 .54377 m
1 .54377 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -95.6875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Delay) show
99.563 16.625 moveto
(Taps) show
128.375 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.007 w
.02381 .01861 m
.02499 .01723 L
.02605 .0166 L
.02729 .01655 L
.02846 .01712 L
.02954 .01847 L
.03053 .02006 L
.03279 .02362 L
.03396 .02495 L
.03506 .02465 L
.03626 .0239 L
.03756 .02279 L
.03883 .02158 L
.04018 .02066 L
.04146 .02003 L
.04262 .01971 L
.04392 .0197 L
.04516 .02072 L
.04649 .02228 L
.04793 .024 L
.0492 .02533 L
.04985 .02543 L
.05055 .02532 L
.0518 .02499 L
.05297 .02463 L
.0542 .02436 L
.05536 .02511 L
.05641 .02613 L
.05754 .02724 L
.05878 .02827 L
.06009 .02861 L
.06121 .02796 L
.06244 .02696 L
.0651 .02444 L
.06644 .02349 L
.0672 .02305 L
.0679 .02272 L
.06915 .02236 L
.06984 .02231 L
.07049 .02264 L
.07165 .02351 L
.0729 .02464 L
.07438 .02602 L
.07575 .02708 L
.07644 .02747 L
.07719 .0278 L
.07801 .02807 L
.07877 .02821 L
.07946 .02823 L
.0801 .02816 L
Mistroke
.0808 .02763 L
.08154 .02689 L
.08282 .02549 L
.08418 .02404 L
.08484 .02343 L
.08556 .02299 L
.08683 .02322 L
.08755 .02353 L
.08831 .02399 L
.08969 .02507 L
.09236 .02818 L
.09367 .02966 L
.09488 .03068 L
.09606 .03083 L
.09732 .02963 L
.09857 .02802 L
.09996 .02603 L
.10111 .02455 L
.10234 .02363 L
.10351 .02297 L
.10458 .02256 L
.10586 .0223 L
.10707 .02261 L
.10816 .02304 L
.10934 .02352 L
.11062 .02395 L
.11127 .02403 L
.11198 .02384 L
.11323 .02331 L
.11441 .02261 L
.1155 .0218 L
.11665 .02066 L
.11792 .01901 L
.1191 .01755 L
.12011 .01649 L
.12121 .01568 L
.12241 .01647 L
.12354 .01782 L
.12487 .01954 L
.12559 .02042 L
.12627 .02114 L
.12746 .02115 L
.12877 .02035 L
.12994 .01941 L
.13122 .01831 L
.13242 .01772 L
.13353 .01754 L
.13485 .01748 L
.13552 .01749 L
.13625 .01752 L
Mistroke
.13872 .01765 L
.14158 .01783 L
.14426 .01804 L
.14888 .01704 L
.14999 .01645 L
.15115 .01595 L
.15215 .01567 L
.15324 .01614 L
.15449 .01702 L
.15565 .01793 L
.15635 .01847 L
.15701 .01896 L
.15826 .01938 L
.15931 .01943 L
.16045 .01937 L
.16168 .01924 L
.16281 .01913 L
.16406 .01923 L
.16523 .01933 L
.16651 .01941 L
.16724 .01943 L
.1679 .01941 L
.16916 .01916 L
.17053 .01885 L
.17123 .01871 L
.17197 .01857 L
.17267 .01848 L
.17331 .01848 L
.17456 .01867 L
.17571 .01892 L
.17832 .01971 L
.1806 .0206 L
.18188 .02099 L
.18305 .02123 L
.18435 .02099 L
.18558 .02058 L
.18672 .02015 L
.18794 .01971 L
.18864 .01954 L
.18928 .01948 L
.19052 .01947 L
.19121 .01951 L
.19196 .01962 L
.19267 .01976 L
.19332 .01993 L
.19583 .02128 L
.19721 .02212 L
.19851 .02285 L
.19925 .02312 L
.20005 .02333 L
Mistroke
.20072 .02346 L
.20146 .02359 L
.20215 .02367 L
.20288 .02374 L
.2042 .02379 L
.20547 .02375 L
.20663 .0237 L
.20727 .02368 L
.20797 .02366 L
.20925 .02373 L
.21043 .02408 L
.2117 .02442 L
.21289 .02467 L
.21398 .02477 L
.21462 .02462 L
.21531 .02435 L
.21653 .02374 L
.21929 .02192 L
.22186 .02005 L
.22312 .01921 L
.22429 .01853 L
.22544 .01824 L
.22666 .01809 L
.22789 .01803 L
.22859 .01801 L
.22925 .01799 L
.23038 .01781 L
.23142 .01757 L
.23255 .01732 L
.23376 .01709 L
.23499 .01696 L
.23613 .01701 L
.23682 .01708 L
.23748 .01716 L
.23871 .01736 L
.24392 .0183 L
.24813 .02049 L
.24934 .02117 L
.25049 .02163 L
.25152 .02174 L
.25265 .02177 L
.25389 .02172 L
.25459 .02167 L
.25522 .02162 L
.25645 .02162 L
.25761 .02163 L
.25877 .02166 L
.25984 .0217 L
.26101 .02179 L
.26225 .02193 L
Mistroke
.26341 .02206 L
.26465 .02217 L
.26582 .02222 L
.26689 .02217 L
.26814 .02206 L
.26884 .02196 L
.2695 .02184 L
.27069 .02157 L
.27197 .02106 L
.27432 .02001 L
.27497 .01974 L
.27565 .01948 L
.27686 .01923 L
.27755 .01916 L
.27819 .01912 L
.27889 .0191 L
.27964 .01909 L
.28035 .0191 L
.28101 .01912 L
.28226 .01918 L
.28341 .01924 L
.2845 .01927 L
.28563 .01926 L
.28687 .01902 L
.28794 .01866 L
.28892 .01832 L
.28998 .01801 L
.29111 .01777 L
.29234 .01795 L
.29347 .01834 L
.29604 .01956 L
.29827 .02068 L
.29953 .02127 L
.30071 .02175 L
.30185 .02213 L
.30308 .02229 L
.30439 .02237 L
.30558 .02238 L
.30668 .02235 L
.30788 .02232 L
.309 .0223 L
.31005 .02228 L
.31127 .02229 L
.31191 .02231 L
.3126 .02241 L
.31399 .02267 L
.3153 .02291 L
.31651 .0231 L
.31783 .02316 L
.31903 .02308 L
Mistroke
.32014 .02295 L
.32121 .0228 L
.32233 .0226 L
.32356 .02227 L
.3247 .02199 L
.32568 .02179 L
.32674 .02163 L
.3279 .02168 L
.32899 .02198 L
.33031 .02244 L
.33157 .02291 L
.3327 .02331 L
.33393 .0235 L
.33841 .02429 L
.34062 .02511 L
.34182 .02555 L
.34294 .0259 L
.34415 .02607 L
.3448 .02614 L
.34548 .0262 L
.3466 .02627 L
.34781 .02635 L
.34857 .02646 L
.34926 .02659 L
.35062 .02683 L
.35186 .02698 L
.35317 .02704 L
.3544 .02676 L
.35556 .02642 L
.35819 .0255 L
.36068 .02501 L
.36199 .02476 L
.36271 .02462 L
.36339 .02447 L
.36403 .02426 L
.36473 .024 L
.36595 .02355 L
.36708 .02314 L
.36832 .02275 L
.36907 .02262 L
.36976 .02257 L
.3705 .02254 L
.37128 .02253 L
.37202 .02253 L
.37271 .02253 L
.37401 .0225 L
.3753 .02234 L
.3765 .02216 L
.3792 .02165 L
.38158 .02108 L
Mistroke
.38276 .02085 L
.38385 .02069 L
.3851 .02078 L
.38576 .02089 L
.38647 .02101 L
.38771 .02123 L
.38886 .0214 L
.39003 .02135 L
.3913 .02115 L
.3924 .02095 L
.3936 .02074 L
.39469 .02062 L
.3957 .02066 L
.39676 .02073 L
.39791 .02082 L
.39919 .02093 L
.39984 .02096 L
.40056 .02099 L
.40133 .021 L
.40206 .02099 L
.40272 .02096 L
.40344 .0209 L
.40408 .02082 L
.40478 .02069 L
.4055 .0204 L
.40618 .0201 L
.40747 .01951 L
.40869 .01898 L
.40989 .01856 L
.41118 .01859 L
.41236 .01869 L
.41345 .0188 L
.41462 .01888 L
.41591 .01871 L
.41656 .01854 L
.41726 .01834 L
.41853 .01791 L
.42343 .01571 L
.4241 .01543 L
.42484 .01515 L
.42553 .01495 L
.42617 .01483 L
.42737 .01472 L
.42865 .01472 L
.42933 .01477 L
.43006 .01487 L
.43138 .01525 L
.43291 .01584 L
.43437 .01643 L
.43502 .01667 L
Mistroke
.4357 .01689 L
.43646 .01698 L
.43715 .01705 L
.43835 .01712 L
.43904 .01714 L
.43968 .01716 L
.44096 .0172 L
.44214 .01724 L
.44338 .01735 L
.44403 .01744 L
.44473 .01757 L
.44598 .01793 L
.44716 .01865 L
.44936 .02017 L
.45062 .02102 L
.45126 .02137 L
.45196 .02163 L
.45436 .02233 L
.45695 .02294 L
.45832 .0233 L
.45978 .02361 L
.46051 .02374 L
.4612 .02383 L
.46249 .02375 L
.4637 .02361 L
.465 .02349 L
.46626 .02345 L
.46689 .02361 L
.46758 .02391 L
.46883 .02449 L
.46996 .025 L
.47115 .02545 L
.47228 .0255 L
.47347 .02523 L
.47477 .02481 L
.4759 .02441 L
.4771 .02409 L
.47812 .02404 L
.47925 .02401 L
.47991 .024 L
.48064 .02397 L
.48132 .02393 L
.48196 .02387 L
.48316 .02348 L
.48445 .02301 L
.48596 .02245 L
.4867 .0222 L
.48738 .02204 L
.48866 .02195 L
.48933 .02191 L
Mistroke
.49004 .02188 L
.49124 .0218 L
.49253 .02159 L
.49375 .02109 L
.49486 .02061 L
.49616 .02008 L
.49689 .01983 L
.49757 .01969 L
.49882 .01982 L
.49945 .01992 L
.50015 .02005 L
.50128 .02025 L
.50249 .02041 L
.50319 .02026 L
.50382 .02008 L
.50506 .0197 L
.50634 .01931 L
.50701 .01914 L
.50772 .01899 L
.50903 .01918 L
.51024 .01944 L
.51133 .01969 L
.51251 .01994 L
.51363 .01993 L
.51464 .01981 L
.51583 .01966 L
.51713 .01951 L
.51835 .01954 L
.51949 .01986 L
.5208 .02024 L
.52149 .02042 L
.52222 .02058 L
.52286 .02068 L
.52356 .02059 L
.52479 .02016 L
.52608 .01962 L
.5273 .01912 L
.5284 .01878 L
.52959 .01886 L
.53027 .01895 L
.53099 .01907 L
.53228 .01933 L
.53294 .01946 L
.53365 .01956 L
.53443 .01956 L
.53516 .01956 L
.53648 .01953 L
.53714 .01953 L
.53786 .01952 L
.53915 .01962 L
Mistroke
.54035 .01981 L
.54281 .02024 L
.54405 .02042 L
.54475 .02049 L
.54541 .02053 L
.54613 .02057 L
.54679 .0206 L
.54755 .02061 L
.54826 .02062 L
.54952 .02058 L
.55023 .02054 L
.55089 .0205 L
.55209 .02041 L
.55338 .02031 L
.5546 .02025 L
.55571 .02022 L
.5569 .02021 L
.55815 .02023 L
.55943 .02027 L
.56016 .02033 L
.56084 .02038 L
.562 .02048 L
.56326 .02058 L
.56445 .02064 L
.56555 .02063 L
.56654 .0206 L
.56762 .02055 L
.56983 .02041 L
.57222 .02023 L
.57291 .02018 L
.57356 .02014 L
.57479 .0201 L
.57594 .02018 L
.57701 .02025 L
.57819 .02032 L
.57944 .02035 L
.58203 .01986 L
.58329 .01959 L
.58444 .01941 L
.58566 .01949 L
.58697 .01981 L
.5884 .02023 L
.58973 .02062 L
.59042 .02077 L
.59116 .02087 L
.5919 .02095 L
.59271 .021 L
.59341 .02102 L
.59416 .02101 L
.59488 .02096 L
Mistroke
.59553 .02086 L
.59677 .02051 L
.59813 .02008 L
.5988 .01988 L
.59953 .01967 L
.60022 .01949 L
.60086 .01943 L
.60215 .01943 L
.6028 .01947 L
.60351 .01953 L
.60475 .01971 L
.60592 .01996 L
.60736 .02038 L
.60874 .02076 L
.60997 .02103 L
.61067 .02113 L
.61131 .02106 L
.61251 .02084 L
.61358 .02056 L
.616 .01984 L
.61725 .0195 L
.6186 .0192 L
.61987 .01898 L
.62104 .01889 L
.62231 .01909 L
.62351 .01937 L
.62575 .01998 L
.62701 .02024 L
.62818 .02042 L
.62953 .0206 L
.6308 .02071 L
.63182 .02077 L
.63291 .0208 L
.63412 .0208 L
.63522 .02075 L
.63637 .02066 L
.63762 .02045 L
.63991 .01999 L
.64058 .01987 L
.64131 .01974 L
.64263 .01967 L
.64391 .01968 L
.6451 .0197 L
.64638 .01972 L
.64711 .01969 L
.64779 .01964 L
.65063 .01935 L
.6558 .01873 L
.65808 .01843 L
.65937 .01826 L
Mistroke
.66059 .01813 L
.66176 .01805 L
.66301 .01809 L
.66367 .01815 L
.66436 .01823 L
.66559 .01838 L
.66624 .01846 L
.66694 .01854 L
.66819 .01859 L
.66896 .01859 L
.66968 .01858 L
.67033 .01856 L
.67103 .01854 L
.67232 .0185 L
.67353 .01848 L
.67479 .01846 L
.67546 .01846 L
.67618 .01846 L
.67745 .01848 L
.67866 .01858 L
.67985 .01868 L
.68093 .01878 L
.68208 .01886 L
.68316 .01889 L
.6843 .01882 L
.68553 .01873 L
.68662 .01864 L
.68776 .01855 L
.68873 .01854 L
.6898 .01856 L
.69107 .01858 L
.69222 .01858 L
.69286 .01857 L
.69355 .01848 L
.69481 .01825 L
.69599 .01802 L
.69724 .01781 L
.69831 .01769 L
.69948 .0178 L
.70204 .01818 L
.70328 .01838 L
.70441 .01845 L
.70561 .01848 L
.70689 .01851 L
.70755 .01852 L
.70828 .01853 L
.70959 .01863 L
.7108 .01873 L
.71194 .0188 L
.71312 .01882 L
Mistroke
.71441 .01861 L
.71553 .01829 L
.71656 .018 L
.71765 .01772 L
.71885 .01751 L
.72014 .01784 L
.72152 .01828 L
.7228 .0187 L
.72398 .01901 L
.72465 .01895 L
.72536 .01885 L
.72608 .01872 L
.72686 .01854 L
.72827 .01818 L
.72956 .01792 L
.73087 .0178 L
.7321 .01772 L
.73482 .01756 L
.73972 .01728 L
.74096 .01735 L
.74213 .01742 L
.74278 .01745 L
.74349 .01746 L
.74473 .01741 L
.7459 .01714 L
.74716 .0168 L
.74824 .01649 L
.74942 .01618 L
.75074 .016 L
.75198 .01592 L
.75319 .01588 L
.75431 .01589 L
.75556 .01588 L
.75627 .01588 L
.75693 .01588 L
.75763 .0159 L
.75826 .01593 L
.759 .01598 L
.7597 .01605 L
.76075 .01625 L
.76192 .01656 L
.76428 .01723 L
.76534 .01751 L
.76647 .0177 L
.76853 .01801 L
.77094 .01836 L
.77351 .01883 L
.77814 .02 L
.77938 .02032 L
.78003 .02047 L
Mistroke
.78072 .02061 L
.78198 .02075 L
.78315 .02081 L
.78427 .0208 L
.78532 .02074 L
.78647 .02055 L
.78771 .02025 L
.78905 .01991 L
.78976 .01974 L
.79052 .01957 L
.79124 .01949 L
.7919 .0195 L
.79318 .01957 L
.79444 .01967 L
.79561 .01978 L
.79684 .01983 L
.79749 .01983 L
.79818 .01982 L
.79891 .0198 L
.79961 .01976 L
.8009 .01963 L
.8021 .01939 L
.80341 .01905 L
.80482 .01866 L
.80551 .01847 L
.80615 .0183 L
.80681 .01818 L
.80753 .01808 L
.80905 .01792 L
.8104 .01779 L
.81164 .01768 L
.81295 .01751 L
.81437 .01732 L
.81559 .01718 L
.81674 .01708 L
.81738 .01707 L
.81807 .01708 L
.81928 .0171 L
.8205 .01712 L
.82165 .01713 L
.82228 .01709 L
.82298 .01701 L
.82419 .01688 L
.82534 .01677 L
.82657 .01667 L
.82761 .01668 L
.82877 .01676 L
.82943 .01683 L
.83012 .01691 L
.83136 .01707 L
Mistroke
.83415 .01746 L
.83531 .01764 L
.83656 .01786 L
.83727 .018 L
.83792 .01821 L
.8392 .01861 L
.84051 .019 L
.84123 .01917 L
.8419 .0193 L
.84308 .0193 L
.84439 .01903 L
.84578 .01869 L
.84647 .01853 L
.84711 .01839 L
.84783 .01832 L
.84863 .0184 L
.84931 .0185 L
.85002 .01863 L
.85279 .01927 L
.85414 .01961 L
.85539 .01988 L
.85653 .02007 L
.85773 .02017 L
.85893 .02 L
.86025 .01968 L
.86277 .0189 L
.86409 .01852 L
.8655 .01817 L
.86673 .01792 L
.86738 .0178 L
.86808 .0177 L
.86932 .01766 L
.87047 .01769 L
.8716 .01776 L
.87284 .01787 L
.87413 .01804 L
.87533 .01822 L
.87644 .01836 L
.87748 .01846 L
.87869 .01848 L
.87978 .0183 L
.88232 .01777 L
.8836 .01754 L
.88433 .01755 L
.88501 .01758 L
.88619 .01767 L
.88748 .01779 L
.88869 .01791 L
.88982 .01788 L
.89052 .01785 L
Mistroke
.89115 .01782 L
.89183 .01779 L
.89256 .01776 L
.89385 .01774 L
.89507 .01788 L
.8965 .01808 L
.89728 .01818 L
.898 .01826 L
.89929 .01833 L
.89997 .01825 L
.9007 .01815 L
.90203 .01794 L
.90328 .01776 L
.90458 .01765 L
.90527 .01769 L
.90601 .01775 L
.90732 .01792 L
.90857 .01813 L
.91091 .01863 L
.91369 .0193 L
.91522 .01965 L
.91666 .01993 L
.91801 .02016 L
.91871 .02025 L
.91946 .02033 L
.92078 .02037 L
.922 .02034 L
.92314 .02028 L
.92437 .0202 L
.92659 .02009 L
.92794 .02004 L
.92922 .01999 L
.93037 .01996 L
.93163 .01998 L
.93288 .01997 L
.9336 .01995 L
.93427 .01992 L
.93498 .01986 L
.93563 .01972 L
.93709 .01929 L
.93836 .0189 L
.93955 .01858 L
.94078 .01842 L
.94144 .01844 L
.94214 .01849 L
.94315 .0186 L
.94426 .01876 L
.94651 .01912 L
.94862 .01941 L
.94954 .01953 L
Mistroke
.95054 .01964 L
.9517 .01971 L
.95281 .01975 L
.95399 .01979 L
.95525 .01984 L
.95645 .01993 L
.95753 .02004 L
.95965 .02027 L
.96069 .02038 L
.96179 .02046 L
.96272 .02052 L
.96375 .02056 L
.96485 .02057 L
.96604 .02055 L
.96715 .02044 L
.96817 .02032 L
.97619 .01932 L
Mfstroke
.9 0 0 r
.02381 .08713 m
.02499 .08716 L
.02605 .08747 L
.02729 .08803 L
.02846 .08864 L
.02954 .08887 L
.03053 .08893 L
.03163 .08897 L
.03279 .08896 L
.03395 .08894 L
.0352 .08891 L
.03638 .08889 L
.03746 .08889 L
.03873 .08894 L
.03944 .08901 L
.04011 .08911 L
.04262 .08964 L
.045 .09042 L
.04752 .09143 L
.04884 .09187 L
.04959 .09198 L
.05028 .09191 L
.05159 .09174 L
.05283 .09161 L
.05399 .0916 L
.05525 .09222 L
.0564 .09316 L
.05747 .09405 L
.05871 .095 L
.05988 .09556 L
.0611 .09535 L
.06175 .09516 L
.06244 .09492 L
.06385 .09436 L
.06516 .09397 L
.06582 .09392 L
.06653 .0939 L
.06731 .09394 L
.06802 .09403 L
.06929 .09431 L
.07 .09457 L
.07066 .09501 L
.07314 .09687 L
.07422 .09763 L
.07538 .09825 L
.07666 .09849 L
.07785 .09854 L
.07849 .0985 L
.07919 .09842 L
.08046 .09812 L
Mistroke
.08169 .09761 L
.08284 .0971 L
.08421 .09649 L
.08493 .09622 L
.08569 .09602 L
.08635 .09597 L
.08708 .09596 L
.08836 .09607 L
.08962 .09631 L
.09032 .09651 L
.09095 .09684 L
.09337 .09834 L
.09407 .0987 L
.0948 .09899 L
.09543 .09916 L
.09613 .09899 L
.09688 .09852 L
.09768 .09792 L
.09913 .09663 L
.10052 .09534 L
.10121 .09484 L
.10197 .09445 L
.10333 .09387 L
.10458 .09349 L
.10582 .09326 L
.10713 .09332 L
.10844 .0935 L
.10988 .09373 L
.11113 .09389 L
.11183 .09385 L
.11247 .09379 L
.11371 .0936 L
.11488 .09332 L
.11941 .09076 L
.12051 .09013 L
.1217 .08978 L
.123 .09015 L
.12423 .09063 L
.12555 .09118 L
.12622 .09142 L
.12695 .09148 L
.12824 .09119 L
.12944 .09081 L
.13064 .09039 L
.13177 .09002 L
.13308 .08997 L
.13427 .08996 L
.1349 .08996 L
.13559 .08996 L
.13631 .08994 L
Mistroke
.13699 .08988 L
.1382 .08952 L
.13951 .08911 L
.14024 .08889 L
.14103 .08868 L
.14178 .08853 L
.14248 .08855 L
.14379 .08881 L
.14519 .08917 L
.14644 .08949 L
.14714 .08964 L
.14778 .08957 L
.14903 .08938 L
.1502 .08921 L
.15141 .08909 L
.15272 .08922 L
.15342 .08951 L
.15416 .08986 L
.15549 .09057 L
.15682 .0913 L
.15751 .09167 L
.15825 .0919 L
.15906 .09213 L
.15981 .09232 L
.16129 .09268 L
.16387 .09345 L
.16528 .09396 L
.16662 .09438 L
.16788 .09466 L
.16858 .09466 L
.16924 .09463 L
.17039 .09455 L
.17161 .09444 L
.17276 .09436 L
.17383 .09448 L
.175 .09468 L
.17626 .09492 L
.17761 .09517 L
.17838 .09528 L
.17908 .09533 L
.18038 .09539 L
.18111 .09541 L
.18177 .09541 L
.18301 .0954 L
.18371 .09538 L
.18436 .09536 L
.18554 .09531 L
.1868 .09523 L
.18802 .09514 L
.18872 .09506 L
Mistroke
.18935 .09496 L
.19051 .09481 L
.19178 .09467 L
.19291 .09461 L
.19398 .0947 L
.1951 .095 L
.19631 .09536 L
.19761 .09571 L
.19835 .09587 L
.19903 .09591 L
.20029 .09577 L
.20099 .09564 L
.20162 .09551 L
.20649 .09451 L
.20763 .09437 L
.20871 .09427 L
.20996 .09436 L
.2111 .09451 L
.2121 .09465 L
.21316 .09477 L
.21433 .09483 L
.21541 .09471 L
.21651 .09452 L
.21755 .09428 L
.2199 .09351 L
.22248 .0924 L
.22361 .09196 L
.22484 .09163 L
.22605 .09155 L
.22719 .09155 L
.22838 .0916 L
.22966 .09168 L
.23033 .09171 L
.23106 .09173 L
.23238 .09174 L
.23367 .09172 L
.23486 .09161 L
.23596 .0913 L
.23699 .09099 L
.23821 .09066 L
.23933 .09043 L
.24051 .09046 L
.24162 .09074 L
.24408 .0916 L
.24658 .09237 L
.24798 .09269 L
.24924 .09292 L
.25043 .09304 L
.25171 .09297 L
.25291 .09288 L
Mistroke
.25403 .09281 L
.25535 .09279 L
.25604 .09295 L
.25679 .09314 L
.25828 .09357 L
.25969 .09399 L
.261 .09429 L
.26173 .09439 L
.26241 .09447 L
.26362 .09456 L
.26489 .09458 L
.26988 .09396 L
.27112 .09378 L
.2723 .09365 L
.27345 .09356 L
.27451 .09348 L
.27563 .09343 L
.27684 .09342 L
.27806 .09343 L
.27934 .09347 L
.28462 .0936 L
.28564 .09362 L
.28675 .09361 L
.2878 .09357 L
.28877 .09355 L
.2899 .09354 L
.2911 .09358 L
.29211 .0937 L
.29322 .09389 L
.29811 .09492 L
.30034 .09532 L
.30155 .09551 L
.30268 .09564 L
.30388 .09575 L
.30519 .09583 L
.3063 .09586 L
.30749 .09583 L
.30816 .09579 L
.30888 .09573 L
.3102 .09559 L
.31267 .09531 L
.31714 .09479 L
.31951 .09445 L
.32082 .09423 L
.32206 .094 L
.32274 .09382 L
.32348 .09359 L
.32478 .0932 L
.32612 .09285 L
.32733 .09261 L
Mistroke
.32805 .09263 L
.32873 .09269 L
.32945 .09278 L
.33022 .09289 L
.3315 .09311 L
.33218 .09322 L
.33291 .09328 L
.33422 .09325 L
.33545 .09321 L
.33617 .09319 L
.33685 .09318 L
.33813 .09324 L
.33932 .09345 L
.34043 .09366 L
.34164 .09389 L
.34293 .0941 L
.34408 .0941 L
.34534 .09408 L
.34649 .09406 L
.34756 .09406 L
.34883 .09421 L
.34998 .09443 L
.35132 .0947 L
.35256 .09493 L
.35364 .09504 L
.35479 .09504 L
.35594 .09499 L
.35721 .09489 L
.35948 .09466 L
.3616 .09438 L
.36426 .0939 L
.36557 .0936 L
.36679 .09335 L
.36789 .09318 L
.36906 .09315 L
.37036 .09337 L
.37153 .09363 L
.37282 .09392 L
.37352 .09407 L
.37417 .09416 L
.37488 .09421 L
.37566 .09424 L
.37632 .09425 L
.37703 .09424 L
.3777 .09422 L
.37842 .09417 L
.37974 .09395 L
.38102 .09366 L
.3822 .09338 L
.38344 .09311 L
Mistroke
.38463 .09299 L
.38569 .09302 L
.38685 .09308 L
.3881 .09319 L
.38927 .09328 L
.38992 .09331 L
.39063 .09333 L
.39186 .09335 L
.39304 .09334 L
.3943 .09328 L
.39537 .09313 L
.39655 .09293 L
.39762 .09274 L
.39879 .09254 L
.39989 .09238 L
.40091 .09231 L
.40221 .09224 L
.40287 .09221 L
.4036 .09219 L
.40488 .09216 L
.40605 .09214 L
.40672 .09213 L
.40742 .09212 L
.40812 .09213 L
.4089 .09213 L
.40957 .09215 L
.41028 .09218 L
.41157 .09227 L
.41286 .09236 L
.41353 .09241 L
.41425 .09245 L
.41557 .09247 L
.41678 .09243 L
.42153 .09229 L
.42265 .09232 L
.42384 .09235 L
.42515 .09236 L
.42636 .09229 L
.4275 .09219 L
.42872 .09209 L
.42988 .092 L
.43095 .09197 L
.4316 .09197 L
.4323 .09198 L
.43304 .092 L
.43373 .09202 L
.43494 .09205 L
.43624 .09206 L
.43754 .09203 L
.43878 .09199 L
Mistroke
.44108 .09191 L
.44329 .09182 L
.44441 .09178 L
.44564 .09176 L
.44669 .09175 L
.44781 .09177 L
.44888 .0918 L
.44985 .09184 L
.451 .0919 L
.45207 .09198 L
.4545 .09219 L
.45939 .09276 L
.46445 .09339 L
.46711 .09368 L
.46993 .09393 L
.47112 .09402 L
.47239 .09409 L
.47312 .09412 L
.47379 .09414 L
.4751 .09418 L
.47627 .0942 L
.47755 .09421 L
.47875 .09422 L
.47987 .09421 L
.48104 .09418 L
.48231 .09413 L
.4835 .09407 L
.4846 .09399 L
.48568 .09389 L
.48668 .09378 L
.48773 .09362 L
.48888 .0934 L
.49012 .09317 L
.4913 .09297 L
.49236 .09283 L
.49351 .0928 L
.49476 .09281 L
.49539 .09283 L
.49608 .09285 L
.49731 .09288 L
.49846 .09289 L
.49971 .09288 L
.5004 .09286 L
.50103 .09284 L
.50226 .09277 L
.50342 .09262 L
.50884 .09177 L
.51871 .09047 L
.52303 .08987 L
.5254 .08947 L
Mistroke
.52655 .0893 L
.5276 .08917 L
.52876 .08912 L
.52999 .08918 L
.53064 .08923 L
.53134 .08928 L
.53262 .08938 L
.53378 .08942 L
.53501 .08934 L
.53616 .08927 L
.53723 .08922 L
.53837 .0892 L
.53961 .08935 L
.54082 .08958 L
.54212 .08986 L
.54427 .09036 L
.5466 .09086 L
.54728 .09098 L
.54801 .0911 L
.54932 .09123 L
.55054 .09124 L
.55124 .09124 L
.55189 .09122 L
.55308 .09119 L
.55421 .09118 L
.55551 .09125 L
.5567 .09133 L
.56093 .09171 L
.56215 .09183 L
.5633 .09192 L
.56433 .09197 L
.56544 .09193 L
.5667 .09186 L
.56802 .09176 L
.56925 .09166 L
.57039 .0916 L
.57144 .09155 L
.57258 .09152 L
.57383 .09149 L
.57498 .09149 L
.57616 .09152 L
.57727 .09156 L
.57849 .09158 L
.5798 .09158 L
.5811 .09145 L
.58247 .0913 L
.58365 .09116 L
.58491 .09103 L
.5861 .09101 L
.58719 .09101 L
Mistroke
.58827 .09103 L
.5893 .09106 L
.59159 .09116 L
.5928 .09122 L
.59409 .09127 L
.5954 .09128 L
.59662 .09124 L
.59733 .0912 L
.59801 .09115 L
.59929 .09106 L
.6016 .09083 L
.60288 .09069 L
.60407 .09059 L
.60534 .09051 L
.60602 .09052 L
.60675 .09056 L
.60805 .09067 L
.60924 .09079 L
.61075 .09095 L
.61219 .09109 L
.61286 .09115 L
.61358 .09121 L
.61487 .09128 L
.61595 .09131 L
.61714 .09122 L
.6196 .09099 L
.62085 .09087 L
.62156 .09085 L
.62221 .09084 L
.62346 .09084 L
.62465 .09088 L
.62575 .09095 L
.62691 .0911 L
.62901 .09144 L
.63029 .09163 L
.6315 .09173 L
.63259 .09167 L
.63377 .09156 L
.64363 .09064 L
.64502 .09052 L
.64633 .09039 L
.64785 .09019 L
.64923 .08998 L
.65176 .08954 L
.65446 .08902 L
.65559 .08884 L
.65682 .08869 L
.65752 .08868 L
.65816 .08872 L
.65942 .08882 L
Mistroke
.66058 .08893 L
.66166 .08903 L
.66278 .08906 L
.66401 .08902 L
.66681 .08885 L
.66748 .08881 L
.66819 .08878 L
.66946 .08874 L
.67059 .08871 L
.67183 .08869 L
.67247 .08869 L
.67316 .0887 L
.67441 .08873 L
.67571 .08878 L
.6764 .08881 L
.67714 .08884 L
.67784 .08888 L
.67848 .08893 L
.67973 .08902 L
.68094 .08908 L
.68224 .0891 L
.68347 .08899 L
.68459 .08878 L
.68592 .08851 L
.68665 .08836 L
.68733 .08822 L
.68798 .08811 L
.68867 .08805 L
.68989 .08798 L
.69056 .08795 L
.69127 .08793 L
.69255 .0879 L
.69327 .08788 L
.69394 .08785 L
.69547 .08779 L
.69672 .08775 L
.6974 .08773 L
.69804 .08771 L
.6993 .0877 L
.70043 .08771 L
.70109 .08771 L
.70179 .08773 L
.70303 .08775 L
.70372 .08778 L
.70437 .0878 L
.70584 .08787 L
.70711 .08793 L
.70849 .08802 L
.711 .08823 L
.71219 .08832 L
Mistroke
.71345 .0884 L
.71452 .08839 L
.71571 .08834 L
.71686 .0883 L
.71793 .0883 L
.71909 .08837 L
.72032 .08864 L
.72241 .08914 L
.72358 .08938 L
.72464 .08945 L
.72586 .08939 L
.72701 .08928 L
.72922 .089 L
.73162 .08876 L
.73423 .08855 L
.73544 .08849 L
.73613 .08847 L
.73676 .08845 L
.73793 .08844 L
.73917 .08845 L
.73992 .0885 L
.74063 .08857 L
.74195 .0887 L
.74317 .08878 L
.74449 .08882 L
.74565 .08864 L
.74692 .08836 L
.74816 .08806 L
.74885 .08789 L
.74949 .08774 L
.75074 .08754 L
.75187 .08741 L
.75294 .08731 L
.75409 .08723 L
.75529 .08717 L
.75598 .08716 L
.75662 .08715 L
.75791 .08715 L
.75863 .08716 L
.7593 .08718 L
.76042 .08721 L
.76164 .08727 L
.76291 .08732 L
.76411 .08735 L
.7648 .08736 L
.76556 .08734 L
.76687 .08724 L
.7683 .08711 L
.76909 .08705 L
.76982 .08699 L
Mistroke
.77114 .08692 L
.77184 .08691 L
.77258 .08691 L
.77327 .08692 L
.77392 .08695 L
.77513 .08703 L
.77752 .08746 L
.77877 .08773 L
.78009 .088 L
.78125 .08815 L
.78253 .08823 L
.78368 .08827 L
.78476 .08828 L
.78731 .08831 L
.78842 .08833 L
.78963 .08834 L
.79032 .08834 L
.79096 .08834 L
.79222 .08832 L
.79357 .08829 L
.795 .08826 L
.79614 .08823 L
.79718 .08823 L
.79838 .08823 L
.79953 .08821 L
.80058 .08817 L
.80155 .0881 L
.80262 .08794 L
.80376 .08776 L
.80501 .08759 L
.80567 .0875 L
.80637 .08743 L
.80765 .08751 L
.80882 .08761 L
.80988 .08771 L
.81101 .08779 L
.81225 .08772 L
.81341 .08754 L
.81473 .08731 L
.81597 .08712 L
.81727 .08705 L
.81795 .08709 L
.8187 .08715 L
.82359 .08749 L
.82429 .08749 L
.82504 .08749 L
.82575 .0875 L
.8264 .0875 L
.82713 .08753 L
.82781 .0876 L
Mistroke
.82936 .08777 L
.83059 .0879 L
.8319 .08801 L
.83258 .088 L
.83333 .08795 L
.83465 .08783 L
.8353 .08778 L
.836 .08772 L
.83727 .08767 L
.83851 .08785 L
.83966 .08806 L
.84101 .0883 L
.84227 .08849 L
.84297 .08848 L
.84373 .08841 L
.84505 .08827 L
.84633 .08813 L
.84752 .08804 L
.84876 .08821 L
.85012 .08846 L
.85127 .08869 L
.85237 .08889 L
.85363 .08901 L
.85477 .08904 L
.85592 .08905 L
.85715 .08902 L
.85822 .089 L
.85938 .08897 L
.86067 .08893 L
.86138 .08889 L
.86203 .08886 L
.8632 .08878 L
.86446 .08863 L
.86579 .08847 L
.86649 .0884 L
.86723 .08833 L
.86788 .08828 L
.86859 .08827 L
.86984 .08835 L
.87115 .08845 L
.87239 .08855 L
.87351 .08861 L
.87473 .08856 L
.87588 .08849 L
.87711 .08839 L
.87932 .08814 L
.88055 .08797 L
.88187 .08781 L
.88311 .08769 L
.88426 .08766 L
Mistroke
.88524 .08769 L
.88632 .08775 L
.88849 .08791 L
.89091 .08805 L
.89316 .08815 L
.93218 .08974 L
.93714 .08945 L
.93835 .08938 L
.93965 .08933 L
.94039 .08932 L
.94107 .08934 L
.94175 .08937 L
.9424 .08941 L
.94516 .08962 L
.94817 .08988 L
.9535 .09039 L
.9561 .09065 L
.95856 .09089 L
.95992 .091 L
.96068 .09105 L
.96139 .09106 L
.96263 .09106 L
.96395 .09103 L
.96857 .09093 L
.96984 .09091 L
.97055 .09089 L
.9712 .09087 L
.97245 .09079 L
.97364 .09071 L
.97619 .09056 L
Mfstroke
.8 0 0 r
.02381 .16748 m
.02499 .16736 L
.02605 .16735 L
.02729 .16738 L
.02846 .16737 L
.02954 .16703 L
.03053 .16657 L
.03279 .16546 L
.03388 .16496 L
.03506 .16465 L
.03635 .16442 L
.03756 .16433 L
.03821 .16433 L
.03891 .16438 L
.0402 .16466 L
.04145 .16505 L
.04262 .16548 L
.04521 .16659 L
.04648 .16714 L
.04765 .16756 L
.04872 .16782 L
.04984 .16778 L
.05097 .16739 L
.05221 .16687 L
.05353 .16633 L
.05477 .16605 L
.05545 .16617 L
.0562 .16634 L
.05751 .16671 L
.05875 .16706 L
.06007 .16723 L
.0612 .16708 L
.06244 .16686 L
.06371 .16664 L
.06443 .16655 L
.0651 .16655 L
.06581 .16666 L
.06646 .16678 L
.0679 .16711 L
.06914 .16742 L
.06979 .16757 L
.07047 .16766 L
.07174 .16777 L
.0729 .16787 L
.07359 .16793 L
.07434 .16801 L
.07505 .16809 L
.07571 .16827 L
.07729 .16873 L
.07873 .16911 L
Mistroke
.07944 .16925 L
.08011 .16936 L
.08137 .16924 L
.08207 .16911 L
.08272 .16897 L
.08418 .16861 L
.08527 .16832 L
.08643 .16814 L
.08771 .16798 L
.0889 .16785 L
.09389 .16734 L
.09677 .1671 L
.09818 .167 L
.09949 .16693 L
.10067 .16688 L
.10193 .16685 L
.10319 .16684 L
.10391 .16684 L
.10458 .16684 L
.10576 .16685 L
.10702 .16689 L
.10929 .16697 L
.10996 .16699 L
.11068 .16701 L
.11199 .16701 L
.11326 .16699 L
.11444 .16697 L
.1156 .16694 L
.11684 .16692 L
.11755 .16692 L
.1182 .16692 L
.11948 .16692 L
.12078 .16692 L
.12152 .16692 L
.12221 .16696 L
.12347 .16701 L
.1241 .16701 L
.1248 .16699 L
.12597 .16689 L
.1272 .16652 L
.12825 .16599 L
.12939 .16537 L
.13063 .16472 L
.13132 .1644 L
.13196 .16419 L
.13321 .16409 L
.13435 .1641 L
.13544 .16417 L
.13659 .16426 L
.13757 .16427 L
Mistroke
.13865 .16423 L
.14106 .16412 L
.14332 .164 L
.14573 .16386 L
.14642 .16381 L
.14707 .16375 L
.14829 .16354 L
.14964 .16331 L
.15035 .16321 L
.1511 .16313 L
.15175 .16309 L
.15246 .1631 L
.15371 .16342 L
.15618 .16416 L
.15688 .16436 L
.15756 .1645 L
.15882 .16444 L
.16 .16432 L
.1611 .16418 L
.1623 .16403 L
.16358 .164 L
.16472 .16404 L
.16577 .16409 L
.16692 .16418 L
.16813 .16429 L
.17239 .16471 L
.17749 .16532 L
.17989 .16559 L
.18095 .16569 L
.18211 .16577 L
.18326 .16582 L
.18447 .16575 L
.1857 .16566 L
.18703 .16557 L
.18828 .1655 L
.18942 .16558 L
.19057 .16569 L
.19167 .16581 L
.19289 .16594 L
.1942 .166 L
.19543 .166 L
.19655 .16598 L
.1979 .16593 L
.19932 .16589 L
.20064 .16587 L
.20187 .16584 L
.20292 .16581 L
.20404 .16575 L
.20529 .16565 L
.20642 .16555 L
Mistroke
.20763 .16546 L
.20895 .16538 L
.21019 .16541 L
.21134 .16546 L
.21233 .1655 L
.21339 .16553 L
.21456 .16552 L
.21566 .16545 L
.21805 .16521 L
.22024 .16493 L
.22142 .16478 L
.22269 .16463 L
.22389 .16451 L
.225 .16448 L
.2263 .16451 L
.22695 .16454 L
.22766 .16458 L
.23008 .16468 L
.23922 .16499 L
.24051 .16505 L
.24116 .16505 L
.24188 .16505 L
.24266 .16504 L
.24339 .16504 L
.24406 .16503 L
.24478 .16503 L
.24542 .16506 L
.24612 .1651 L
.24753 .1652 L
.25005 .16534 L
.25133 .16528 L
.25272 .1652 L
.25402 .16514 L
.25523 .16512 L
.25632 .16528 L
.25752 .16551 L
.25878 .16574 L
.25994 .16592 L
.26115 .16593 L
.26246 .16578 L
.26482 .1654 L
.2661 .16526 L
.26682 .16524 L
.26749 .16523 L
.26873 .16522 L
.27004 .16522 L
.27126 .16521 L
.27258 .16516 L
.27374 .16511 L
.27497 .16507 L
Mistroke
.27608 .16504 L
.2773 .16506 L
.27832 .16509 L
.27944 .1651 L
.28017 .16511 L
.28084 .16511 L
.28149 .16507 L
.28217 .16501 L
.28466 .16478 L
.28532 .16473 L
.28603 .16468 L
.28732 .16469 L
.28807 .16472 L
.28885 .16476 L
.29026 .16486 L
.29259 .16505 L
.29387 .16515 L
.29508 .16523 L
.29577 .16527 L
.29651 .1653 L
.29781 .16529 L
.29913 .16524 L
.30035 .16518 L
.305 .16486 L
.30941 .16454 L
.31059 .16446 L
.31185 .1644 L
.3125 .1644 L
.31322 .16441 L
.3145 .16444 L
.31565 .16446 L
.31689 .16446 L
.31806 .16437 L
.31914 .16426 L
.32034 .16415 L
.32162 .16405 L
.32236 .16402 L
.32303 .16407 L
.32434 .16419 L
.32569 .16437 L
.32715 .16459 L
.32981 .16501 L
.33111 .1652 L
.33233 .16536 L
.3336 .16545 L
.33428 .16549 L
.335 .16551 L
.33628 .16554 L
.3375 .16556 L
.33979 .16558 L
Mistroke
.34216 .1656 L
.34341 .1656 L
.34473 .16561 L
.34588 .16562 L
.34715 .16563 L
.3483 .16565 L
.34938 .1657 L
.35008 .16573 L
.35073 .16575 L
.35197 .16577 L
.35266 .16577 L
.3533 .16575 L
.354 .16567 L
.35474 .16556 L
.35708 .16521 L
.3584 .16503 L
.3596 .165 L
.36065 .16498 L
.3618 .16498 L
.363 .16498 L
.36411 .16495 L
.36518 .1649 L
.36616 .16484 L
.36834 .16471 L
.37799 .16395 L
.3792 .16384 L
.3805 .16379 L
.3817 .16376 L
.38284 .16372 L
.38412 .16366 L
.38529 .16352 L
.38659 .16335 L
.38798 .16317 L
.38918 .16303 L
.39026 .16297 L
.39135 .16293 L
.39238 .16292 L
.39358 .16293 L
.39469 .16297 L
.3959 .16305 L
.39718 .16313 L
.39846 .16322 L
.39966 .16327 L
.40033 .16326 L
.40105 .16325 L
.40232 .16321 L
.40353 .16315 L
.40481 .16309 L
.40601 .16301 L
.4071 .16295 L
Mistroke
.40839 .16291 L
.4091 .16291 L
.40978 .16291 L
.41097 .16306 L
.41228 .16326 L
.41371 .16349 L
.41449 .1636 L
.41523 .16368 L
.41593 .16372 L
.41667 .16375 L
.41798 .16376 L
.41922 .16374 L
.42035 .16367 L
.42165 .16354 L
.42289 .16339 L
.42395 .16327 L
.42508 .16316 L
.42633 .16315 L
.42747 .16317 L
.42864 .16321 L
.42986 .16326 L
.4305 .16328 L
.4312 .16329 L
.43243 .16329 L
.43314 .16329 L
.43389 .16329 L
.4346 .16328 L
.43525 .16327 L
.4359 .16326 L
.43661 .16324 L
.4379 .1632 L
.43912 .16315 L
.44043 .16309 L
.44118 .16303 L
.44187 .16297 L
.44322 .16285 L
.44389 .1628 L
.4446 .16276 L
.44538 .16273 L
.44611 .16275 L
.44685 .16283 L
.44755 .16293 L
.44885 .16312 L
.45008 .16331 L
.45138 .16345 L
.45249 .16346 L
.45371 .16346 L
.45502 .16346 L
.45576 .16346 L
.45643 .16349 L
Mistroke
.45773 .16363 L
.45896 .16376 L
.4601 .16388 L
.46133 .16398 L
.46249 .16395 L
.46356 .16389 L
.46484 .16382 L
.46603 .16375 L
.46727 .16377 L
.46793 .16381 L
.46863 .16385 L
.46996 .16393 L
.47065 .16397 L
.47139 .164 L
.47204 .16399 L
.47275 .16395 L
.47401 .16387 L
.47522 .16378 L
.47653 .16368 L
.47776 .16366 L
.47889 .16367 L
.48003 .16367 L
.48124 .16367 L
.48238 .16362 L
.48342 .16353 L
.48579 .16327 L
.48835 .16301 L
.48952 .16292 L
.49076 .16283 L
.49181 .16277 L
.49297 .16272 L
.49406 .1627 L
.49522 .16269 L
.49632 .16269 L
.49732 .16271 L
.4985 .16276 L
.49962 .16281 L
.50094 .16287 L
.50215 .16291 L
.50341 .16287 L
.50462 .16279 L
.5059 .1627 L
.50661 .16265 L
.50727 .1626 L
.50846 .16257 L
.50955 .16257 L
.51056 .16257 L
.51166 .16258 L
.51288 .16258 L
.51416 .16254 L
Mistroke
.51646 .16243 L
.51893 .16229 L
.52023 .16221 L
.52161 .16211 L
.52414 .16187 L
.52649 .16158 L
.52778 .16144 L
.5285 .16138 L
.52916 .16135 L
.5299 .16133 L
.53068 .16131 L
.53137 .1613 L
.53211 .16129 L
.5334 .16128 L
.53412 .16125 L
.53477 .16121 L
.53595 .16116 L
.53724 .16113 L
.53847 .16111 L
.53976 .16119 L
.54096 .16129 L
.54209 .1614 L
.5435 .16154 L
.54483 .16163 L
.54613 .1617 L
.54734 .16176 L
.54849 .1618 L
.54954 .16183 L
.5507 .16186 L
.55194 .16188 L
.55451 .1619 L
.55564 .16192 L
.55688 .16194 L
.55802 .16195 L
.55909 .16195 L
.56021 .16193 L
.56142 .16189 L
.56274 .16185 L
.56398 .16182 L
.5651 .16181 L
.56632 .16181 L
.56739 .16181 L
.56856 .16181 L
.56979 .16179 L
.57094 .16176 L
.57521 .16159 L
.58506 .16124 L
.59543 .16098 L
.59971 .1608 L
.60094 .16076 L
Mistroke
.6021 .16072 L
.60315 .1607 L
.60428 .1607 L
.60554 .16072 L
.60618 .16076 L
.60688 .16081 L
.60929 .16101 L
.61045 .16111 L
.61169 .16118 L
.61287 .16122 L
.61394 .16124 L
.61512 .16126 L
.61622 .16125 L
.61743 .16122 L
.61874 .16117 L
.6214 .16104 L
.62384 .16088 L
.62487 .16081 L
.62597 .16075 L
.62718 .16074 L
.6283 .16073 L
.62957 .16072 L
.63076 .1607 L
.63184 .16063 L
.633 .1605 L
.63824 .15987 L
.64088 .15963 L
.64239 .15952 L
.64379 .15944 L
.64508 .15938 L
.6463 .15933 L
.64859 .15926 L
.65375 .15909 L
.66335 .15886 L
.67357 .15867 L
.69196 .15831 L
.71195 .158 L
.73356 .15753 L
.75267 .15656 L
.75536 .15627 L
.75668 .15614 L
.75791 .15605 L
.75857 .15601 L
.75931 .15597 L
.76005 .15595 L
.76084 .15595 L
.76151 .15597 L
.76222 .15599 L
.76352 .15604 L
.76475 .15609 L
Mistroke
.76544 .15611 L
.76609 .15611 L
.76682 .1561 L
.76751 .1561 L
.7688 .15609 L
.76992 .1561 L
.77114 .15614 L
.77244 .15622 L
.77364 .15631 L
.77822 .15677 L
.77954 .15691 L
.78079 .15701 L
.78192 .15704 L
.78314 .15705 L
.78384 .15706 L
.7845 .15706 L
.78526 .15707 L
.78594 .15709 L
.78719 .15718 L
.78854 .1573 L
.78982 .1574 L
.79052 .15745 L
.79117 .15748 L
.79233 .15751 L
.79359 .15752 L
.79423 .15751 L
.79492 .15751 L
.79618 .15749 L
.7973 .15748 L
.79853 .15746 L
.79922 .15745 L
.79987 .15743 L
.80061 .15741 L
.80128 .15739 L
.80251 .1573 L
.80383 .15721 L
.80449 .15717 L
.8052 .15713 L
.80648 .15709 L
.80726 .15715 L
.808 .1572 L
.80938 .15733 L
.8107 .15743 L
.81191 .15746 L
.81255 .15743 L
.81325 .15737 L
.81466 .15725 L
.81587 .15715 L
.81716 .15707 L
.81784 .15707 L
Mistroke
.81858 .15707 L
.81989 .15709 L
.82485 .15717 L
.83415 .15736 L
.85506 .15778 L
.89525 .15853 L
.91372 .15884 L
.91877 .15898 L
.92418 .1591 L
.9268 .15917 L
.92809 .15921 L
.92928 .15923 L
.93036 .15923 L
.93151 .15921 L
.93277 .15917 L
.93392 .15914 L
.93514 .15911 L
.9363 .15911 L
.93752 .15911 L
.93821 .15912 L
.93885 .15914 L
.94002 .15917 L
.94108 .15922 L
.94346 .15938 L
.94605 .15955 L
.94752 .15962 L
.94886 .15967 L
.95004 .1597 L
.95134 .15971 L
.95199 .1597 L
.95269 .15968 L
.95395 .15967 L
.95463 .15966 L
.95536 .15966 L
.95667 .15971 L
.95739 .15976 L
.95807 .15981 L
.95962 .15993 L
.96088 .16003 L
.96151 .16006 L
.9622 .16009 L
.96366 .16015 L
.96499 .16019 L
.96749 .16025 L
.96985 .1603 L
.97116 .16034 L
.9719 .16037 L
.97257 .1604 L
.97504 .16053 L
.97619 .1606 L
Mistroke
Mfstroke
.7 0 0 r
.02381 .24124 m
.02605 .24021 L
.02729 .23959 L
.02846 .23906 L
.02954 .23884 L
.03072 .23877 L
.0318 .23879 L
.03279 .23886 L
.03506 .23907 L
.03756 .23935 L
.03882 .23955 L
.03952 .23971 L
.04017 .23988 L
.04262 .24053 L
.04384 .2408 L
.04514 .24089 L
.04636 .24088 L
.04748 .24085 L
.04879 .2408 L
.04953 .2408 L
.05021 .24086 L
.05278 .24112 L
.05395 .24124 L
.05521 .24136 L
.0564 .24145 L
.05748 .2415 L
.0587 .24149 L
.05985 .24141 L
.06109 .24112 L
.06244 .24077 L
.0637 .24044 L
.06435 .24028 L
.06505 .24015 L
.06632 .24005 L
.06749 .24001 L
.06815 .24001 L
.06887 .24002 L
.07015 .24006 L
.07093 .24011 L
.07167 .24016 L
.07306 .24025 L
.07376 .2403 L
.07442 .24033 L
.07511 .24036 L
.07587 .24035 L
.07712 .2403 L
.07782 .24026 L
.07847 .24022 L
.08151 .23997 L
.08299 .23984 L
Mistroke
.08363 .23979 L
.08433 .23974 L
.08557 .2397 L
.08674 .23975 L
.08739 .23979 L
.08807 .23984 L
.0893 .23994 L
.09055 .24004 L
.09125 .24008 L
.09189 .2401 L
.09264 .24013 L
.09335 .24015 L
.09401 .24015 L
.09472 .24016 L
.0959 .24013 L
.09721 .24004 L
.09984 .23979 L
.1023 .23955 L
.10349 .23944 L
.10458 .23937 L
.10572 .23932 L
.10694 .23936 L
.10757 .2394 L
.10826 .23944 L
.10951 .23953 L
.11083 .23959 L
.11149 .23958 L
.11221 .23953 L
.1135 .23941 L
.1147 .23928 L
.12397 .23853 L
.12516 .23846 L
.12644 .23838 L
.1271 .2383 L
.12784 .23819 L
.12913 .23801 L
.13035 .23785 L
.13166 .2377 L
.1329 .23769 L
.13403 .23771 L
.13546 .23776 L
.13615 .23779 L
.13678 .23781 L
.13745 .23782 L
.13817 .23783 L
.13895 .23783 L
.13968 .23783 L
.14097 .23782 L
.14215 .2378 L
.14346 .23774 L
Mistroke
.14484 .23768 L
.14604 .23762 L
.14736 .23757 L
.1486 .23753 L
.14976 .23751 L
.1509 .23751 L
.15193 .23753 L
.15313 .23764 L
.15426 .23777 L
.15549 .23793 L
.15679 .23809 L
.1579 .23817 L
.15912 .23818 L
.16044 .23817 L
.16117 .23815 L
.16184 .23814 L
.16315 .23813 L
.16438 .23814 L
.16552 .23816 L
.16659 .23818 L
.16771 .23819 L
.16894 .23816 L
.16993 .23814 L
.17097 .23812 L
.17211 .2381 L
.17315 .23811 L
.1743 .23816 L
.17552 .23823 L
.17771 .23839 L
.18008 .23859 L
.18143 .2387 L
.18269 .23878 L
.18394 .23881 L
.18464 .2388 L
.18528 .23879 L
.1866 .23875 L
.18729 .23873 L
.18803 .23872 L
.18934 .23873 L
.19055 .23877 L
.19181 .23882 L
.19294 .23888 L
.19364 .23893 L
.19438 .239 L
.1957 .23912 L
.19723 .23925 L
.19798 .23931 L
.19867 .23935 L
.19991 .23936 L
.20059 .23935 L
Mistroke
.20124 .23934 L
.20194 .23931 L
.20259 .23929 L
.20405 .23922 L
.20629 .23907 L
.20753 .23899 L
.20871 .23892 L
.20937 .2389 L
.21009 .23889 L
.21135 .23889 L
.21264 .2389 L
.21383 .23892 L
.21519 .23893 L
.21647 .23894 L
.21761 .23895 L
.21885 .23894 L
.2195 .23893 L
.22021 .23889 L
.22164 .23881 L
.22297 .23873 L
.22421 .23868 L
.22542 .23868 L
.22672 .23871 L
.22812 .23874 L
.22944 .23878 L
.23058 .23878 L
.2318 .23877 L
.23246 .23877 L
.23316 .23876 L
.23441 .23875 L
.23552 .23875 L
.23671 .23875 L
.23773 .23875 L
.23885 .23876 L
.24016 .23875 L
.24139 .23873 L
.24371 .23869 L
.26462 .23819 L
.26957 .23785 L
.27025 .2378 L
.27099 .23776 L
.27169 .23773 L
.27234 .23771 L
.27357 .23768 L
.27488 .23766 L
.27613 .23765 L
.27683 .23766 L
.27748 .23767 L
.27864 .23769 L
.27992 .23771 L
Mistroke
.28107 .23773 L
.28214 .23774 L
.28327 .23774 L
.28449 .23774 L
.28578 .23773 L
.28651 .23772 L
.28718 .23772 L
.28839 .2377 L
.28908 .2377 L
.28973 .23769 L
.29084 .23769 L
.29205 .23772 L
.29333 .23778 L
.2945 .23784 L
.29575 .2379 L
.29643 .23793 L
.29707 .23795 L
.29783 .23796 L
.29852 .23797 L
.29917 .23797 L
.29988 .23797 L
.30056 .23797 L
.30131 .23796 L
.30209 .23795 L
.30282 .23793 L
.30413 .23789 L
.30553 .23785 L
.30676 .23782 L
.30746 .23782 L
.30812 .23782 L
.30927 .23783 L
.31052 .23784 L
.31123 .23785 L
.3119 .23785 L
.31259 .23785 L
.31335 .23783 L
.31595 .23777 L
.31862 .23773 L
.31993 .23771 L
.32113 .23768 L
.32223 .23766 L
.32339 .2376 L
.32457 .23753 L
.32584 .23746 L
.32699 .23742 L
.32805 .23744 L
.3291 .2375 L
.33011 .23756 L
.3312 .23762 L
.33235 .23767 L
Mistroke
.33363 .23761 L
.33481 .23753 L
.33605 .23742 L
.3367 .23737 L
.33739 .23731 L
.33866 .23727 L
.33983 .23727 L
.34096 .23727 L
.34201 .23728 L
.34316 .23726 L
.34439 .2372 L
.34571 .23712 L
.34695 .23706 L
.34825 .23703 L
.34894 .23706 L
.34968 .2371 L
.35092 .23716 L
.35223 .23721 L
.35335 .23722 L
.35457 .23711 L
.35599 .23696 L
.35734 .23683 L
.35808 .23676 L
.35889 .23675 L
.35963 .23676 L
.3603 .23678 L
.36163 .23684 L
.36306 .23692 L
.36375 .23695 L
.36441 .23697 L
.36564 .23701 L
.36679 .23703 L
.36786 .23704 L
.36904 .23703 L
.37029 .23698 L
.37541 .23683 L
.38576 .23644 L
.39607 .23601 L
.39677 .23602 L
.39743 .23602 L
.39819 .23602 L
.39888 .23602 L
.40013 .23596 L
.40084 .23589 L
.4015 .23582 L
.4028 .23568 L
.40348 .23561 L
.40423 .23554 L
.40498 .2355 L
.40568 .23549 L
Mistroke
.40648 .23549 L
.40722 .23549 L
.40786 .2355 L
.40855 .23552 L
.40979 .23557 L
.41261 .23569 L
.41327 .23572 L
.41399 .23574 L
.4153 .23578 L
.41657 .23577 L
.41774 .23576 L
.41891 .23575 L
.42017 .23573 L
.42135 .23572 L
.42243 .23572 L
.42365 .23573 L
.4248 .23575 L
.42605 .23581 L
.42675 .23586 L
.4274 .23591 L
.42965 .23608 L
.43079 .23614 L
.43203 .23618 L
.43268 .23619 L
.43337 .23619 L
.43463 .23619 L
.43588 .23617 L
.43702 .23612 L
.4393 .23601 L
.44054 .23595 L
.44171 .2359 L
.44378 .23584 L
.44487 .23581 L
.44605 .2358 L
.4467 .2358 L
.44741 .23581 L
.4487 .23583 L
.44996 .23584 L
.45113 .23585 L
.45185 .23583 L
.45253 .2358 L
.4538 .23576 L
.45518 .2357 L
.45593 .23567 L
.45664 .23565 L
.45783 .23563 L
.45914 .23562 L
.46033 .2356 L
.46145 .23558 L
.46276 .23553 L
Mistroke
.46395 .23549 L
.46664 .23542 L
.505 .23409 L
.54581 .23286 L
.55557 .23269 L
.56069 .23263 L
.56204 .23261 L
.56279 .23259 L
.56349 .23258 L
.56414 .23257 L
.56485 .23257 L
.56608 .23257 L
.56728 .23256 L
.56855 .23254 L
.56963 .23252 L
.57083 .23247 L
.57601 .23222 L
.57824 .23215 L
.58068 .23206 L
.58282 .23194 L
.584 .23188 L
.5851 .23183 L
.58575 .2318 L
.58644 .23178 L
.58766 .23175 L
.58889 .23173 L
.59003 .23171 L
.59107 .23171 L
.59221 .23171 L
.59341 .23171 L
.59452 .23171 L
.59583 .23169 L
.59708 .23167 L
.5994 .23162 L
.60194 .23155 L
.60261 .23153 L
.60333 .23151 L
.60463 .23149 L
.60576 .23148 L
.60679 .23152 L
.60793 .23156 L
.60918 .23161 L
.6103 .23164 L
.61133 .23166 L
.61232 .23165 L
.61338 .23164 L
.61461 .23161 L
.61595 .23157 L
.61836 .23146 L
.62288 .23125 L
Mistroke
.64282 .23038 L
.65286 .23006 L
.65427 .23001 L
.65561 .22996 L
.65635 .22994 L
.65715 .22992 L
.65788 .22992 L
.65856 .22991 L
.65978 .22992 L
.66048 .22992 L
.66114 .22993 L
.66246 .22995 L
.6632 .22997 L
.66388 .22998 L
.66516 .23001 L
.66636 .23003 L
.66744 .23003 L
.66862 .22996 L
.67108 .22981 L
.67232 .22975 L
.67302 .22974 L
.67368 .22975 L
.67488 .22979 L
.67597 .22982 L
.67714 .22986 L
.67843 .22989 L
.67959 .22991 L
.68067 .22991 L
.6817 .2299 L
.6828 .22988 L
.68552 .22971 L
.68684 .22962 L
.68805 .22954 L
.68932 .22948 L
.69069 .22943 L
.6914 .22941 L
.69218 .22939 L
.69291 .22938 L
.69359 .22938 L
.69477 .22939 L
.69587 .2294 L
.69719 .22942 L
.6984 .22942 L
.69959 .2294 L
.70085 .22938 L
.7035 .2293 L
.70588 .2292 L
.70719 .22916 L
.70843 .22913 L
.70913 .22913 L
Mistroke
.70989 .22914 L
.71122 .22916 L
.71186 .22917 L
.71256 .22918 L
.71381 .22919 L
.71451 .22917 L
.71515 .22916 L
.71663 .22911 L
.71805 .22907 L
.71886 .22904 L
.71961 .22904 L
.72024 .22903 L
.72094 .22903 L
.72166 .22903 L
.72235 .22903 L
.7236 .22903 L
.7243 .22903 L
.72495 .22903 L
.72721 .22901 L
.72848 .229 L
.72964 .229 L
.73029 .229 L
.73101 .229 L
.7323 .22901 L
.73359 .22901 L
.73477 .229 L
.73601 .22899 L
.73717 .22897 L
.73844 .22896 L
.73915 .22896 L
.7398 .22896 L
.74111 .229 L
.74253 .22903 L
.74319 .22905 L
.74388 .22906 L
.74513 .22905 L
.75016 .22887 L
.75485 .2287 L
.75721 .22864 L
.75854 .22862 L
.75974 .2286 L
.76107 .22859 L
.76181 .22859 L
.7625 .22859 L
.76377 .2286 L
.76441 .2286 L
.76512 .22861 L
.76583 .22861 L
.76657 .22861 L
.76721 .22861 L
Mistroke
.76791 .22862 L
.76867 .22862 L
.76947 .22863 L
.77023 .22865 L
.77092 .22866 L
.77373 .22875 L
.77637 .22886 L
.77879 .22897 L
.78 .22901 L
.7807 .22903 L
.78134 .22903 L
.78205 .22903 L
.78269 .22903 L
.78344 .22902 L
.78414 .22901 L
.78673 .22898 L
.79152 .22895 L
.79386 .22892 L
.79489 .22891 L
.79602 .2289 L
.79723 .22891 L
.79851 .22891 L
.79919 .22891 L
.79991 .22891 L
.80121 .22891 L
.80247 .22885 L
.80367 .2288 L
.80473 .22875 L
.80591 .22872 L
.80722 .22873 L
.80794 .22876 L
.80861 .22879 L
.81111 .22893 L
.81383 .22904 L
.81675 .22913 L
.81804 .22916 L
.81872 .22917 L
.81945 .22919 L
.82014 .2292 L
.82077 .2292 L
.822 .22921 L
.82319 .22919 L
.82448 .22917 L
.82569 .22915 L
.82681 .22915 L
.82807 .22918 L
.82926 .22923 L
.83035 .22927 L
.8315 .22932 L
.83275 .22935 L
Mistroke
.83391 .22936 L
.83517 .22937 L
.83588 .22937 L
.83654 .22937 L
.83762 .22939 L
.83876 .22943 L
.84085 .22952 L
.84562 .22968 L
.84689 .22973 L
.84809 .22979 L
.84947 .22989 L
.85073 .22999 L
.85548 .23034 L
.858 .23051 L
.86066 .23068 L
.86205 .23075 L
.86284 .23078 L
.86358 .2308 L
.86488 .23081 L
.86561 .23081 L
.86628 .23081 L
.86757 .23081 L
.86878 .23082 L
.86988 .23085 L
.87105 .23088 L
.87371 .23099 L
.87614 .23112 L
.87717 .23117 L
.87826 .23122 L
.87947 .23124 L
.88059 .23125 L
.88185 .23126 L
.88305 .23126 L
.88412 .23127 L
.88529 .2313 L
.89515 .23162 L
.90602 .23192 L
.91624 .23215 L
.92091 .23224 L
.92326 .23228 L
.9239 .23229 L
.92459 .2323 L
.92582 .23231 L
.92651 .23231 L
.92725 .23231 L
.92795 .23231 L
.92859 .23231 L
.92981 .23231 L
.9311 .2323 L
.93222 .2323 L
Mistroke
.93341 .2323 L
.93472 .2323 L
.93594 .23231 L
.93667 .23232 L
.93734 .23233 L
.93887 .23235 L
.94021 .23238 L
.94164 .23242 L
.94684 .23254 L
.97619 .23341 L
Mfstroke
.6 0 0 r
.02381 .31297 m
.02605 .31281 L
.02729 .31274 L
.02846 .31267 L
.02954 .31251 L
.03072 .3123 L
.03179 .31212 L
.03279 .31197 L
.03397 .31186 L
.03527 .31194 L
.03653 .31207 L
.0379 .31225 L
.04262 .31271 L
.04516 .31293 L
.0465 .31306 L
.04793 .31317 L
.04863 .31322 L
.0493 .31326 L
.05054 .31322 L
.05172 .31316 L
.05297 .31312 L
.0541 .31311 L
.05534 .31326 L
.05647 .31348 L
.05752 .31369 L
.05876 .3139 L
.0599 .31399 L
.06121 .31387 L
.06244 .3137 L
.06371 .31349 L
.06437 .31338 L
.06507 .31328 L
.06635 .31316 L
.06753 .31308 L
.06875 .31301 L
.06945 .31299 L
.07009 .31298 L
.07081 .31299 L
.07146 .31301 L
.07293 .31307 L
.07409 .31313 L
.07532 .31318 L
.07596 .31319 L
.07667 .31321 L
.07792 .31322 L
.07909 .3132 L
.08035 .31315 L
.08154 .31302 L
.08263 .31288 L
.08398 .31272 L
Mistroke
.08472 .31264 L
.08542 .31258 L
.08608 .31259 L
.08678 .31261 L
.08801 .31267 L
.08949 .31276 L
.09087 .31285 L
.09157 .31288 L
.09231 .31291 L
.09314 .31294 L
.09389 .31295 L
.0946 .31296 L
.09526 .31296 L
.09598 .31293 L
.09675 .31287 L
.09946 .31262 L
.10063 .3125 L
.1019 .31241 L
.10328 .31234 L
.10458 .31228 L
.10584 .31224 L
.10699 .31223 L
.10831 .31223 L
.10955 .31223 L
.11071 .31223 L
.11177 .31221 L
.11294 .31216 L
.11418 .31211 L
.11659 .312 L
.11917 .31188 L
.11993 .31185 L
.12065 .31183 L
.1213 .31181 L
.12201 .31182 L
.12268 .31184 L
.12338 .31185 L
.12466 .31189 L
.12596 .31191 L
.12715 .31187 L
.12845 .31177 L
.12983 .31165 L
.13095 .31155 L
.13215 .31147 L
.13347 .31143 L
.13469 .3114 L
.13767 .31136 L
.13914 .31133 L
.14049 .31131 L
.14172 .3113 L
.14303 .31128 L
Mistroke
.14433 .31128 L
.14508 .31127 L
.14577 .31127 L
.14702 .31127 L
.14772 .31126 L
.14835 .31125 L
.14958 .31124 L
.15074 .31124 L
.1514 .31125 L
.1521 .31126 L
.15335 .31134 L
.15471 .31146 L
.15616 .31159 L
.15744 .31168 L
.1586 .3117 L
.15976 .31171 L
.16087 .3117 L
.16207 .31169 L
.16334 .31169 L
.16401 .3117 L
.16474 .31171 L
.16603 .31172 L
.1672 .31173 L
.16844 .31173 L
.16949 .31172 L
.17064 .3117 L
.17188 .31168 L
.17257 .31168 L
.1732 .31167 L
.17443 .31168 L
.17559 .31169 L
.17769 .31172 L
.1799 .31175 L
.18106 .31176 L
.18233 .31177 L
.18348 .31177 L
.18456 .31175 L
.1868 .31171 L
.18797 .31169 L
.18921 .31167 L
.19029 .31165 L
.19148 .31164 L
.19256 .31163 L
.19357 .31163 L
.19484 .31166 L
.196 .31169 L
.19664 .31171 L
.19734 .31172 L
.1986 .31174 L
.19975 .31171 L
Mistroke
.20097 .31167 L
.20315 .31157 L
.20556 .31148 L
.20689 .31144 L
.20815 .31141 L
.20887 .3114 L
.20964 .31139 L
.21035 .31139 L
.211 .3114 L
.21229 .3114 L
.21301 .3114 L
.21367 .3114 L
.21492 .31138 L
.21607 .31135 L
.21868 .31125 L
.22096 .31116 L
.22222 .31111 L
.22341 .31107 L
.22404 .31106 L
.22474 .31105 L
.22595 .31106 L
.22718 .31107 L
.22832 .31109 L
.22956 .31111 L
.23027 .3111 L
.23093 .3111 L
.23227 .31108 L
.23371 .31105 L
.23648 .31099 L
.23721 .31097 L
.23798 .31095 L
.23871 .31094 L
.23939 .31093 L
.24069 .31094 L
.24188 .31097 L
.24317 .31101 L
.24386 .31103 L
.2446 .31105 L
.24586 .31106 L
.24703 .31105 L
.24773 .31105 L
.24838 .31104 L
.24962 .31101 L
.25076 .31098 L
.25183 .31094 L
.25424 .31084 L
.2549 .31081 L
.25561 .3108 L
.2569 .31078 L
.25816 .31077 L
Mistroke
.25931 .31076 L
.26056 .31075 L
.26127 .31074 L
.26193 .31073 L
.2647 .31068 L
.30365 .30997 L
.34505 .30912 L
.38494 .30831 L
.42331 .30748 L
.44272 .30717 L
.44407 .30712 L
.44531 .30707 L
.44662 .30704 L
.44731 .30704 L
.44804 .30703 L
.44885 .30703 L
.44961 .30703 L
.45029 .30703 L
.45103 .30703 L
.45172 .30701 L
.45246 .30699 L
.45377 .30695 L
.46413 .30663 L
.50344 .3054 L
.52326 .30467 L
.53193 .30437 L
.5365 .30415 L
.53761 .3041 L
.53881 .30406 L
.54013 .30404 L
.54136 .30403 L
.54268 .30403 L
.5434 .30402 L
.54407 .30402 L
.54526 .30401 L
.54655 .30399 L
.54777 .30397 L
.54888 .30395 L
.55015 .3039 L
.55136 .30385 L
.5525 .30381 L
.55357 .30377 L
.55468 .30374 L
.55591 .30371 L
.55847 .30368 L
.56084 .30365 L
.58174 .30339 L
.62052 .30286 L
.64024 .30259 L
.65065 .30239 L
Mistroke
.65209 .30236 L
.65365 .30233 L
.65503 .30232 L
.65648 .3023 L
.65779 .30229 L
.65848 .30229 L
.65923 .30228 L
.66053 .30228 L
.66175 .30228 L
.66242 .30228 L
.66313 .30228 L
.66441 .30229 L
.66589 .3023 L
.66662 .30231 L
.66729 .30231 L
.66849 .30231 L
.66978 .30231 L
.67112 .3023 L
.67253 .30229 L
.67371 .30229 L
.67496 .30228 L
.67615 .30228 L
.67722 .30228 L
.67849 .30229 L
.6792 .3023 L
.67986 .30231 L
.68107 .30232 L
.68235 .30233 L
.68354 .30232 L
.68462 .30229 L
.68579 .30226 L
.68706 .30222 L
.68823 .30219 L
.68931 .30217 L
.69035 .30216 L
.69146 .30215 L
.69417 .30213 L
.69481 .30212 L
.69549 .30211 L
.69671 .30211 L
.6978 .3021 L
.699 .30212 L
.70028 .30214 L
.70147 .30217 L
.70274 .30219 L
.70338 .3022 L
.70408 .30221 L
.70533 .30221 L
.7065 .3022 L
.7072 .3022 L
Mistroke
.70787 .3022 L
.70912 .30221 L
.70983 .30222 L
.71048 .30223 L
.71195 .30225 L
.71325 .30227 L
.71447 .30228 L
.71557 .30228 L
.71675 .30228 L
.71805 .30228 L
.7187 .30228 L
.71942 .30228 L
.72068 .3023 L
.72187 .30232 L
.72303 .30233 L
.72429 .30234 L
.72544 .30233 L
.7265 .30231 L
.72774 .3023 L
.72891 .30228 L
.73013 .30229 L
.73077 .30229 L
.73147 .3023 L
.74044 .30238 L
.74506 .30244 L
.74628 .30244 L
.7476 .30245 L
.74885 .30247 L
.75 .30248 L
.75065 .3025 L
.75138 .30251 L
.75284 .30255 L
.75542 .30261 L
.75665 .30263 L
.758 .30265 L
.75919 .30267 L
.76046 .30271 L
.76121 .30274 L
.76188 .30276 L
.7632 .30281 L
.76451 .30287 L
.76571 .3029 L
.76711 .30294 L
.76862 .30297 L
.77136 .30303 L
.78155 .30333 L
.82107 .30482 L
.84095 .30587 L
.84963 .30621 L
.85454 .30647 L
Mistroke
.85687 .30662 L
.85802 .30669 L
.85907 .30673 L
.86018 .30676 L
.86138 .3068 L
.86394 .30686 L
.8664 .30691 L
.8691 .30698 L
.87373 .30716 L
.87624 .30727 L
.87747 .30732 L
.8786 .30736 L
.87992 .30738 L
.88061 .30739 L
.88135 .3074 L
.88255 .30741 L
.88384 .30742 L
.88456 .30744 L
.88522 .30747 L
.88651 .30751 L
.88944 .30762 L
.89432 .30782 L
.89705 .30791 L
.89952 .30796 L
.90941 .30816 L
.91856 .30833 L
.93931 .30869 L
.94794 .30887 L
.95265 .30897 L
.95704 .3091 L
.96181 .3093 L
.96703 .30947 L
.97619 .30976 L
Mfstroke
.5 0 0 r
.02381 .38648 m
.02605 .38628 L
.02729 .38617 L
.02846 .38608 L
.02954 .38602 L
.03072 .38597 L
.0318 .38594 L
.03279 .38592 L
.03396 .38591 L
.03506 .38594 L
.03636 .38599 L
.03756 .38604 L
.03881 .38609 L
.04 .38608 L
.04125 .38606 L
.04262 .38604 L
.04326 .38603 L
.04396 .38602 L
.04523 .38605 L
.04646 .38609 L
.04759 .38613 L
.04882 .38617 L
.04952 .38617 L
.05017 .38616 L
.05157 .38611 L
.0529 .38606 L
.05405 .38603 L
.05531 .38603 L
.05645 .38606 L
.05751 .38609 L
.05864 .38611 L
.0599 .38612 L
.06121 .38606 L
.06244 .386 L
.06374 .38593 L
.06444 .38589 L
.06511 .38585 L
.06642 .38581 L
.0676 .38577 L
.07019 .3857 L
.07157 .38567 L
.07302 .38564 L
.07418 .38562 L
.07544 .38561 L
.0766 .38561 L
.07768 .38561 L
.07895 .38561 L
.08011 .3856 L
.08075 .38559 L
.08145 .38556 L
Mistroke
.08272 .38552 L
.08421 .38546 L
.08494 .38543 L
.0856 .38542 L
.08686 .3854 L
.08752 .38539 L
.08821 .38539 L
.08891 .38539 L
.08966 .38539 L
.09036 .38539 L
.09101 .3854 L
.09178 .38541 L
.09259 .38543 L
.09329 .38544 L
.09406 .38544 L
.09471 .38544 L
.0954 .38544 L
.09665 .38537 L
.09737 .38532 L
.09812 .38526 L
.09947 .38515 L
.10065 .38506 L
.10191 .38501 L
.10264 .38499 L
.10329 .38498 L
.10458 .38496 L
.14461 .38451 L
.18313 .38399 L
.2241 .38329 L
.26356 .38242 L
.3015 .38153 L
.34189 .38071 L
.38077 .37971 L
.4221 .37888 L
.46191 .37811 L
.50021 .37727 L
.51996 .37686 L
.52476 .37678 L
.52728 .37673 L
.52854 .37671 L
.52926 .3767 L
.52993 .37669 L
.53137 .37668 L
.5329 .37667 L
.53562 .37665 L
.53631 .37665 L
.53705 .37665 L
.53776 .37664 L
.53841 .37664 L
.53965 .37665 L
Mistroke
.54096 .37666 L
.57881 .3769 L
.58357 .37689 L
.58488 .37689 L
.58561 .37689 L
.58627 .37689 L
.58756 .37689 L
.58877 .3769 L
.58992 .37691 L
.59114 .37693 L
.59332 .37696 L
.59823 .37702 L
.59952 .37703 L
.60075 .37704 L
.60142 .37704 L
.60215 .37705 L
.60344 .37705 L
.60418 .37706 L
.60497 .37706 L
.60564 .37707 L
.60639 .37709 L
.60914 .37715 L
.61912 .37734 L
.65934 .37804 L
.69805 .37883 L
.73921 .37993 L
.77885 .38126 L
.81698 .38218 L
.82792 .38246 L
.8333 .38261 L
.83825 .38271 L
.84752 .38285 L
.85271 .38295 L
.85524 .38299 L
.85635 .38301 L
.85756 .38303 L
.85872 .38304 L
.8598 .38304 L
.86083 .38304 L
.86192 .38304 L
.86319 .38304 L
.86438 .38303 L
.8666 .38302 L
.86781 .38301 L
.86909 .38301 L
.87019 .38301 L
.87138 .38301 L
.87267 .38301 L
.87339 .38301 L
.87405 .38301 L
Mistroke
.87533 .38301 L
.87654 .383 L
.8777 .383 L
.87897 .38299 L
.87961 .38298 L
.8803 .38297 L
.88155 .38295 L
.88617 .38289 L
.89159 .38285 L
.89663 .3828 L
.90151 .38273 L
.90673 .38264 L
.91775 .38244 L
.92244 .38236 L
.9274 .38227 L
.92999 .38223 L
.93146 .38222 L
.93284 .38221 L
.93784 .38217 L
.95758 .382 L
.97619 .38184 L
Mfstroke
.4 0 0 r
.02381 .45926 m
.06244 .45817 L
.10458 .4569 L
.14415 .45597 L
.18221 .45532 L
.20178 .45486 L
.22272 .45434 L
.26416 .45342 L
.27424 .45318 L
.28492 .45295 L
.29405 .45279 L
.29923 .45272 L
.30409 .45267 L
.34251 .4524 L
.35148 .45233 L
.35263 .45233 L
.35384 .45233 L
.35448 .45232 L
.35518 .45232 L
.3564 .45231 L
.36104 .45226 L
.36242 .45225 L
.36317 .45225 L
.36389 .45224 L
.36456 .45224 L
.36528 .45224 L
.36655 .45224 L
.3678 .45224 L
.36844 .45224 L
.36914 .45224 L
.37038 .45224 L
.37154 .45224 L
.37273 .45223 L
.37398 .45223 L
.37505 .45222 L
.37622 .45221 L
.37747 .4522 L
.37813 .45219 L
.37882 .45219 L
.3801 .45218 L
.38128 .45218 L
.3826 .45218 L
.38335 .45218 L
.38405 .45217 L
.38527 .45217 L
.38657 .45217 L
.3873 .45218 L
.38809 .45218 L
.38883 .45218 L
.38953 .45218 L
Mistroke
.39083 .45217 L
.39156 .45217 L
.39223 .45217 L
.39287 .45217 L
.39355 .45217 L
.39423 .45217 L
.39498 .45217 L
.39563 .45218 L
.39632 .45218 L
.39757 .45219 L
.40241 .45221 L
.41285 .45227 L
.4225 .45233 L
.42373 .45234 L
.42438 .45234 L
.42506 .45235 L
.42631 .45236 L
.42745 .45238 L
.42995 .45242 L
.4327 .45246 L
.43545 .45249 L
.438 .45251 L
.43944 .45252 L
.44015 .45252 L
.4408 .45252 L
.44155 .45252 L
.44236 .45253 L
.44378 .45253 L
.44495 .45253 L
.44619 .45254 L
.44737 .45256 L
.44845 .45257 L
.4497 .45259 L
.45037 .45259 L
.45108 .4526 L
.45237 .45261 L
.45357 .45261 L
.45472 .45262 L
.45593 .45262 L
.45657 .45263 L
.45726 .45263 L
.45848 .45264 L
.46128 .45267 L
.46392 .45269 L
.50444 .45309 L
.54346 .45354 L
.55368 .45363 L
.56478 .45373 L
.56741 .45374 L
.56869 .45374 L
Mistroke
.56987 .45375 L
.5711 .45376 L
.57243 .45378 L
.57526 .4538 L
.57763 .45382 L
.57897 .45383 L
.58021 .45384 L
.58141 .45384 L
.58249 .45384 L
.58374 .45384 L
.58492 .45384 L
.58609 .45384 L
.58733 .45384 L
.58851 .45385 L
.58958 .45385 L
.59084 .45385 L
.59221 .45386 L
.59349 .45386 L
.5947 .45387 L
.59593 .45387 L
.59659 .45387 L
.5973 .45387 L
.59874 .45386 L
.60006 .45386 L
.60247 .45385 L
.60369 .45385 L
.60438 .45385 L
.60502 .45385 L
.60932 .45386 L
.61037 .45386 L
.6115 .45386 L
.61273 .45386 L
.61388 .45386 L
.61453 .45386 L
.61523 .45386 L
.6165 .45385 L
.61774 .45385 L
.61889 .45384 L
.62004 .45384 L
.62112 .45383 L
.62236 .45383 L
.62349 .45383 L
.62478 .45383 L
.62543 .45383 L
.62613 .45383 L
.62739 .45383 L
.62856 .45383 L
.62927 .45383 L
.62994 .45383 L
.6312 .45383 L
Mistroke
.6319 .45383 L
.63256 .45382 L
.63403 .45381 L
.64397 .45374 L
.66256 .45358 L
.7019 .45324 L
.73972 .45295 L
.74966 .45288 L
.75204 .45286 L
.75457 .45284 L
.75695 .45283 L
.75808 .45282 L
.75912 .45282 L
.76041 .45282 L
.76109 .45282 L
.7618 .45282 L
.76302 .45281 L
.76433 .45281 L
.76506 .45281 L
.76573 .45281 L
.76704 .4528 L
.76859 .45279 L
.76927 .45279 L
.77002 .45279 L
.77121 .45278 L
.77247 .45278 L
.77313 .45278 L
.77385 .45278 L
.77514 .45278 L
.77637 .45278 L
.77767 .45278 L
.78 .45278 L
.78123 .45278 L
.78239 .45278 L
.78359 .45278 L
.78492 .45278 L
.7877 .45277 L
.78901 .45277 L
.79026 .45277 L
.79143 .45277 L
.7927 .45277 L
.79493 .45277 L
.79619 .45277 L
.7969 .45278 L
.79754 .45278 L
.79871 .45278 L
.79995 .45278 L
.80107 .45278 L
.80229 .45278 L
.80341 .45278 L
Mistroke
.80444 .45278 L
.80567 .45278 L
.80679 .45278 L
.80808 .45279 L
.8093 .4528 L
.81036 .45281 L
.81149 .45282 L
.81245 .45282 L
.81351 .45282 L
.81465 .45282 L
.81587 .45282 L
.81703 .45282 L
.81809 .45283 L
.82746 .4529 L
.83276 .45294 L
.83398 .45295 L
.8353 .45295 L
.83655 .45296 L
.83769 .45297 L
.83895 .45299 L
.84028 .45301 L
.84141 .45303 L
.84263 .45305 L
.84393 .45306 L
.84514 .45307 L
.84658 .45308 L
.84721 .45308 L
.8479 .45309 L
.84857 .45309 L
.84928 .4531 L
.85078 .45312 L
.85352 .45316 L
.85864 .45323 L
.8988 .45371 L
.93744 .45403 L
.94721 .45409 L
.95197 .45412 L
.95405 .45413 L
.95631 .45415 L
.95866 .45416 L
.95972 .45416 L
.96089 .45417 L
.96213 .45417 L
.96344 .45417 L
.96465 .45417 L
.9658 .45417 L
.96644 .45417 L
.96715 .45417 L
.96838 .45418 L
.97116 .45419 L
Mistroke
.97377 .4542 L
.97619 .45421 L
Mfstroke
.3 0 0 r
.02381 .53163 m
.06244 .52995 L
.07216 .52953 L
.08255 .52911 L
.08403 .52904 L
.0848 .52901 L
.08562 .52899 L
.08713 .52895 L
.08852 .52892 L
.09133 .52886 L
.09396 .52881 L
.09639 .52875 L
.09901 .52866 L
.10458 .52851 L
.1235 .52801 L
.14415 .52759 L
.15511 .52739 L
.16529 .52725 L
.18538 .52703 L
.18784 .52699 L
.18909 .52697 L
.19045 .52696 L
.19331 .52694 L
.19594 .52692 L
.20075 .52689 L
.2059 .52686 L
.20714 .52685 L
.20779 .52684 L
.20848 .52684 L
.20976 .52683 L
.21093 .52683 L
.21206 .52683 L
.21311 .52683 L
.21427 .52683 L
.21552 .52683 L
.21661 .52683 L
.2178 .52683 L
.21905 .52683 L
.22021 .52683 L
.2213 .52683 L
.22229 .52682 L
.22451 .52682 L
.2257 .52682 L
.22681 .52682 L
.22804 .52682 L
.22935 .52682 L
.23001 .52682 L
.23073 .52681 L
.23204 .52681 L
.23331 .52682 L
Mistroke
.23449 .52682 L
.23569 .52682 L
.23683 .52682 L
.23895 .52683 L
.24123 .52684 L
.24369 .52686 L
.26449 .52699 L
.28407 .52714 L
.29444 .52719 L
.30015 .52723 L
.30295 .52725 L
.30418 .52726 L
.30554 .52727 L
.30683 .52727 L
.30803 .52727 L
.30931 .52728 L
.31002 .52728 L
.31068 .52728 L
.31198 .52727 L
.31271 .52728 L
.31339 .52728 L
.31487 .52728 L
.31625 .52728 L
.31744 .52728 L
.31873 .52728 L
.3199 .52728 L
.32097 .52728 L
.32214 .52728 L
.32342 .52728 L
.32406 .52728 L
.32476 .52728 L
.32601 .52727 L
.32846 .52726 L
.32975 .52726 L
.33113 .52726 L
.33232 .52725 L
.33301 .52725 L
.33365 .52725 L
.33477 .52725 L
.33598 .52725 L
.33708 .52725 L
.33829 .52725 L
.33947 .52725 L
.34073 .52725 L
.34191 .52725 L
.34298 .52725 L
.34406 .52724 L
.34508 .52724 L
.34613 .52723 L
.34724 .52723 L
Mistroke
.34847 .52722 L
.3496 .52722 L
.35076 .52722 L
.35186 .52722 L
.35284 .52722 L
.3539 .52722 L
.35515 .52721 L
.35648 .5272 L
.35885 .52718 L
.36338 .52715 L
.37378 .52707 L
.38352 .52697 L
.40337 .52674 L
.4244 .52651 L
.4624 .52618 L
.48192 .52606 L
.48461 .52604 L
.48603 .52602 L
.48754 .52602 L
.48886 .52601 L
.49031 .526 L
.49286 .52599 L
.49534 .52598 L
.49602 .52598 L
.49673 .52597 L
.49801 .52597 L
.49921 .52597 L
.50032 .52597 L
.50154 .52597 L
.50284 .52597 L
.50407 .52596 L
.50543 .52596 L
.50612 .52596 L
.50685 .52595 L
.50754 .52595 L
.50818 .52595 L
.50938 .52595 L
.5107 .52595 L
.51309 .52596 L
.51378 .52596 L
.51453 .52596 L
.51524 .52596 L
.51589 .52596 L
.51664 .52596 L
.51745 .52596 L
.51812 .52596 L
.51886 .52596 L
.5242 .52599 L
.52924 .52602 L
.53463 .52606 L
Mistroke
.54436 .52614 L
.56422 .5263 L
.58579 .52646 L
.58829 .52648 L
.58968 .52649 L
.59099 .52649 L
.59353 .52651 L
.59586 .52652 L
.60094 .52654 L
.60654 .52656 L
.60884 .52657 L
.61013 .52658 L
.61129 .52658 L
.61238 .52658 L
.61356 .52658 L
.61468 .52658 L
.6157 .52658 L
.6169 .52658 L
.61802 .52658 L
.61935 .52657 L
.62057 .52657 L
.62184 .52657 L
.62305 .52657 L
.62432 .52657 L
.62504 .52657 L
.62571 .52657 L
.62688 .52657 L
.62812 .52657 L
.62918 .52657 L
.63034 .52657 L
.63159 .52657 L
.63229 .52656 L
.63292 .52656 L
.63533 .52655 L
.64436 .52653 L
.66496 .52645 L
.68414 .52635 L
.69404 .52628 L
.70493 .52621 L
.7248 .52613 L
.73004 .52611 L
.73292 .5261 L
.73567 .52609 L
.74098 .52608 L
.74584 .52607 L
.75079 .52606 L
.75197 .52606 L
.75321 .52606 L
.75428 .52605 L
.75544 .52605 L
Mistroke
.75609 .52605 L
.75678 .52605 L
.75802 .52605 L
.75877 .52606 L
.75948 .52606 L
.76012 .52606 L
.76081 .52606 L
.76567 .52608 L
.78407 .52617 L
.80387 .5263 L
.82489 .52647 L
.84462 .52661 L
.85325 .52665 L
.8556 .52667 L
.85781 .52668 L
.85904 .52669 L
.86037 .52669 L
.86268 .5267 L
.86523 .52671 L
.86758 .52671 L
.86993 .52671 L
.87213 .52672 L
.87324 .52672 L
.87443 .52672 L
.87564 .52673 L
.87695 .52673 L
.87767 .52673 L
.87832 .52673 L
.87962 .52673 L
.8808 .52673 L
.88206 .52673 L
.88326 .52672 L
.88452 .52672 L
.88518 .52672 L
.8859 .52672 L
.88717 .52672 L
.88837 .52672 L
.88966 .52672 L
.89197 .52672 L
.89474 .52671 L
.89625 .52671 L
.89767 .52671 L
.89887 .52671 L
.90017 .52671 L
.90293 .5267 L
.90566 .5267 L
.90826 .52669 L
.91315 .52667 L
.9189 .52665 L
.9217 .52664 L
Mistroke
.92292 .52664 L
.92424 .52663 L
.92549 .52663 L
.92664 .52662 L
.9289 .5266 L
.93387 .52658 L
.94438 .52652 L
.97619 .52635 L
Mfstroke
.2 0 0 r
.02381 .60332 m
.03279 .60281 L
.04262 .60231 L
.053 .6019 L
.06244 .60159 L
.07298 .60132 L
.07839 .60123 L
.08124 .60117 L
.0828 .60113 L
.08426 .6011 L
.0855 .60108 L
.0862 .60107 L
.08684 .60106 L
.08969 .60105 L
.0947 .60101 L
.09948 .60098 L
.10216 .60095 L
.10458 .60092 L
.10585 .60091 L
.10701 .60091 L
.1083 .60091 L
.10894 .60091 L
.10965 .60091 L
.11084 .60091 L
.11212 .6009 L
.11333 .6009 L
.11442 .60089 L
.11667 .60088 L
.11794 .60088 L
.11912 .60088 L
.12357 .60087 L
.14429 .60082 L
.14675 .60082 L
.14904 .60081 L
.15019 .60081 L
.15142 .60081 L
.15213 .60081 L
.15279 .60081 L
.15403 .60081 L
.15531 .60082 L
.15666 .60082 L
.15737 .60082 L
.15815 .60082 L
.15885 .60082 L
.15952 .60082 L
.16075 .60082 L
.1614 .60082 L
.16209 .60082 L
.16336 .60082 L
.16454 .60082 L
Mistroke
.16584 .60082 L
.16705 .60082 L
.16815 .60082 L
.16933 .60081 L
.17371 .6008 L
.175 .6008 L
.1762 .6008 L
.17746 .6008 L
.17813 .6008 L
.17884 .60079 L
.18131 .60078 L
.18355 .60076 L
.22131 .60038 L
.23137 .60027 L
.23688 .60021 L
.24204 .60017 L
.24643 .60015 L
.25116 .60013 L
.25348 .60011 L
.25475 .6001 L
.25596 .60009 L
.25664 .60009 L
.25738 .60009 L
.25868 .60009 L
.2612 .60008 L
.26367 .60007 L
.26492 .60007 L
.26563 .60007 L
.26629 .60007 L
.26747 .60007 L
.26855 .60007 L
.26979 .60007 L
.27097 .60007 L
.27221 .60007 L
.27352 .60006 L
.27466 .60006 L
.27589 .60006 L
.2772 .60006 L
.27843 .60006 L
.28124 .60007 L
.29958 .6001 L
.3042 .60011 L
.30674 .60012 L
.30799 .60012 L
.30914 .60012 L
.3098 .60012 L
.3105 .60012 L
.3112 .60012 L
.31198 .60012 L
.31262 .60012 L
Mistroke
.31331 .60012 L
.31456 .60012 L
.3196 .60011 L
.3249 .6001 L
.3278 .6001 L
.32923 .6001 L
.33054 .60009 L
.33179 .60009 L
.3331 .60009 L
.33442 .60008 L
.33587 .60007 L
.33707 .60007 L
.33836 .60006 L
.33958 .60006 L
.34069 .60006 L
.34199 .60006 L
.34318 .60006 L
.34449 .60005 L
.34589 .60004 L
.35081 .60001 L
.36184 .59994 L
.38194 .59979 L
.39132 .59972 L
.39659 .59969 L
.40142 .59967 L
.40597 .59965 L
.40821 .59964 L
.40919 .59963 L
.41027 .59963 L
.41142 .59963 L
.41264 .59962 L
.41397 .59962 L
.41521 .59962 L
.41635 .59962 L
.41738 .59962 L
.41851 .59962 L
.41971 .59962 L
.42096 .59961 L
.42212 .59961 L
.42347 .59961 L
.42474 .5996 L
.42595 .5996 L
.42725 .5996 L
.42843 .5996 L
.42952 .5996 L
.43062 .5996 L
.43164 .5996 L
.43396 .59961 L
.43512 .59961 L
.43622 .59961 L
Mistroke
.43749 .59961 L
.43865 .59961 L
.43984 .59961 L
.44115 .59961 L
.44181 .59961 L
.44252 .59961 L
.44381 .59961 L
.44508 .59962 L
.4463 .59962 L
.44857 .59963 L
.45935 .59966 L
.46893 .59968 L
.47026 .59968 L
.47095 .59968 L
.47169 .59969 L
.47233 .59969 L
.47304 .59969 L
.47429 .59969 L
.4755 .59969 L
.4768 .59969 L
.47803 .59969 L
.47915 .59969 L
.48029 .59969 L
.4815 .59969 L
.48253 .59969 L
.48367 .59969 L
.4862 .59969 L
.48859 .59968 L
.49068 .59968 L
.49289 .59968 L
.49531 .59967 L
.49753 .59966 L
.50253 .59964 L
.50707 .59962 L
.51231 .59959 L
.51726 .59955 L
.52601 .59948 L
.53563 .59942 L
.54534 .59937 L
.55563 .59933 L
.55799 .59932 L
.55915 .59932 L
.56023 .59932 L
.56146 .59931 L
.56281 .59931 L
.56516 .59931 L
.56739 .5993 L
.56848 .5993 L
.56948 .5993 L
.57064 .5993 L
Mistroke
.5719 .5993 L
.57296 .5993 L
.57408 .5993 L
.57531 .5993 L
.576 .5993 L
.57664 .5993 L
.57781 .5993 L
.57905 .5993 L
.58016 .5993 L
.58121 .59931 L
.58358 .59931 L
.59375 .59935 L
.60252 .59937 L
.60715 .59938 L
.61209 .5994 L
.61477 .59941 L
.6172 .59941 L
.62195 .59942 L
.62692 .59943 L
.62954 .59943 L
.63086 .59944 L
.63161 .59944 L
.63231 .59944 L
.63356 .59944 L
.6347 .59944 L
.63602 .59943 L
.63727 .59943 L
.64183 .59943 L
.64292 .59943 L
.64406 .59943 L
.64532 .59943 L
.64647 .59942 L
.64754 .59942 L
.64855 .59942 L
.65082 .59941 L
.6554 .5994 L
.66045 .59939 L
.6707 .59936 L
.68911 .59929 L
.69414 .59927 L
.69961 .59925 L
.70211 .59924 L
.70348 .59924 L
.70477 .59924 L
.70703 .59923 L
.70953 .59923 L
.71193 .59923 L
.7142 .59922 L
.71519 .59922 L
.71625 .59922 L
Mistroke
.71741 .59922 L
.71848 .59922 L
.71973 .59922 L
.72043 .59922 L
.72108 .59922 L
.72225 .59923 L
.72353 .59923 L
.72468 .59923 L
.72576 .59923 L
.72687 .59923 L
.72811 .59923 L
.72937 .59923 L
.73006 .59923 L
.73071 .59923 L
.73311 .59923 L
.73574 .59923 L
.73709 .59924 L
.7378 .59924 L
.73856 .59924 L
.73987 .59924 L
.74108 .59924 L
.74373 .59925 L
.74846 .59927 L
.75812 .59929 L
.76236 .5993 L
.76351 .59931 L
.76461 .59931 L
.76587 .59931 L
.76702 .59931 L
.76959 .59932 L
.772 .59932 L
.77727 .59933 L
.77984 .59933 L
.78058 .59934 L
.78128 .59934 L
.78258 .59934 L
.78334 .59934 L
.78403 .59934 L
.78479 .59934 L
.78559 .59934 L
.78628 .59934 L
.78692 .59934 L
.78762 .59934 L
.78837 .59934 L
.78903 .59934 L
.78973 .59934 L
.79097 .59934 L
.7938 .59933 L
.79644 .59933 L
.79892 .59933 L
Mistroke
.80112 .59933 L
.80236 .59932 L
.80349 .59932 L
.80853 .59931 L
.8291 .59928 L
.83426 .59927 L
.83549 .59926 L
.83679 .59926 L
.8379 .59926 L
.83912 .59926 L
.84123 .59926 L
.84241 .59926 L
.84349 .59926 L
.84593 .59925 L
.84821 .59925 L
.84935 .59925 L
.85057 .59925 L
.85161 .59925 L
.85275 .59925 L
.85398 .59925 L
.8553 .59925 L
.85655 .59925 L
.85769 .59925 L
.85996 .59925 L
.86106 .59925 L
.86207 .59925 L
.86313 .59925 L
.86427 .59925 L
.86551 .59925 L
.86668 .59925 L
.86782 .59925 L
.86907 .59925 L
.87037 .59925 L
.8716 .59926 L
.87274 .59926 L
.87378 .59926 L
.87613 .59926 L
.87735 .59927 L
.87864 .59927 L
.87939 .59927 L
.88007 .59927 L
.88139 .59927 L
.88262 .59927 L
.88396 .59927 L
.88523 .59927 L
.88638 .59927 L
.8876 .59927 L
.88876 .59927 L
.88998 .59927 L
.8913 .59928 L
Mistroke
.8959 .59928 L
.89726 .59929 L
.89853 .59929 L
.89917 .59929 L
.89986 .59929 L
.90062 .59929 L
.90132 .59929 L
.90249 .59929 L
.90377 .59929 L
.90441 .59929 L
.9051 .59929 L
.90634 .59929 L
.90766 .59929 L
.90839 .59929 L
.90907 .59929 L
.9098 .59929 L
.91061 .59929 L
.91129 .59929 L
.91202 .59929 L
.91271 .59929 L
.91346 .59929 L
.91417 .59929 L
.91482 .59928 L
.91606 .59928 L
.91738 .59928 L
.92741 .59927 L
.93774 .59926 L
.94057 .59925 L
.94211 .59925 L
.94355 .59924 L
.94423 .59924 L
.94488 .59924 L
.9461 .59924 L
.94744 .59923 L
.94888 .59923 L
.95938 .5992 L
.96409 .59919 L
.96907 .59917 L
.9707 .59917 L
.97162 .59917 L
.97246 .59917 L
.97439 .59917 L
.97619 .59916 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{578.5, 357.563},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{57.1875, 518.938}, {631.813, 346.813}} -> {-53.1665, \
2.11933, 0.404509, 0.00862508}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot of Step Data (at 50 MHz)", "Subtitle"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"taploss", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"dtapx", ",", "dtaploss"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tapphase", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"dtapx", ",", 
      RowBox[{
       RowBox[{"unwrap", "[", "dtapphase", "]"}], "-", 
       RowBox[{
       "dtapphase", "\[LeftDoubleBracket]", "1", 
        "\[RightDoubleBracket]"}]}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dtapdelay", "=", 
   RowBox[{"1*^9", 
    FractionBox["1", "50*^6"], 
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       RowBox[{"unwrap", "[", "dtapphase", "]"}]}], "+", 
      RowBox[{
      "dtapphase", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
     "360"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tapdelay", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"dtapx", ",", "dtapdelay"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"difftapdelay", "=", 
   RowBox[{
    RowBox[{"Drop", "[", 
     RowBox[{"dtapdelay", ",", "1"}], "]"}], "-", 
    RowBox[{"Drop", "[", 
     RowBox[{"dtapdelay", ",", 
      RowBox[{"-", "1"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"tapslope", "=", 
  RowBox[{
   RowBox[{"Fit", "[", 
    RowBox[{"tapdelay", ",", 
     RowBox[{"{", "ns", "}"}], ",", "ns"}], "]"}], "/.", 
   RowBox[{"ns", "\[Rule]", "1"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dnldelay", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Range", "[", 
       RowBox[{"0", ",", " ", 
        RowBox[{
         RowBox[{"Length", "[", "dtapdelay", "]"}], "-", "1"}]}], "]"}], " ", 
      "tapslope"}], ")"}], "-", "dtapdelay"}]}], ";"}]}], "Input"],

Cell[BoxData["0.060210604288138944`"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Insertion Loss as Function of Steps", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"taploss", ",", "\[IndentingNewLine]", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
   RowBox[{
   "PlotLabel", "\[Rule]", 
    "\"\<Insertion Loss as Function of Steps at 50 MHz\>\""}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Steps\>\"", ",", "\"\<Insertion Loss (dB)\>\""}], "}"}]}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", 
      RowBox[{"RGBColor", " ", "[", 
       RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "}"}]}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.442868190849375*^9, 3.44286819614625*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00186376 1.51298 0.334434 [
[.02381 -0.0125 -5.59375 -16.375 ]
[.02381 -0.0125 5.59375 0 ]
[.21019 -0.0125 -12.7813 -16.375 ]
[.21019 -0.0125 12.7813 0 ]
[.39656 -0.0125 -12.7813 -16.375 ]
[.39656 -0.0125 12.7813 0 ]
[.58294 -0.0125 -12.7813 -16.375 ]
[.58294 -0.0125 12.7813 0 ]
[.76931 -0.0125 -12.7813 -16.375 ]
[.76931 -0.0125 12.7813 0 ]
[.95569 -0.0125 -12.7813 -16.375 ]
[.95569 -0.0125 12.7813 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -18.5 -32.75 ]
[.5 -0.0125 18.5 -16.375 ]
[-0.0125 .00803 -30.9375 -8.1875 ]
[-0.0125 .00803 0 8.1875 ]
[-0.0125 .09163 -38.125 -8.1875 ]
[-0.0125 .09163 0 8.1875 ]
[-0.0125 .17524 -20.1875 -8.1875 ]
[-0.0125 .17524 0 8.1875 ]
[-0.0125 .25885 -38.125 -8.1875 ]
[-0.0125 .25885 0 8.1875 ]
[-0.0125 .34246 -30.9375 -8.1875 ]
[-0.0125 .34246 0 8.1875 ]
[-0.0125 .42607 -38.125 -8.1875 ]
[-0.0125 .42607 0 8.1875 ]
[-0.0125 .50968 -20.1875 -8.1875 ]
[-0.0125 .50968 0 8.1875 ]
[-0.0125 .59329 -38.125 -8.1875 ]
[-0.0125 .59329 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -54.5 -56.0313 ]
[-0.01875 .30902 -38.125 56.0313 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -134.156 0 ]
[.5 .63053 134.156 16.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.21019 0 m
.21019 .61803 L
s
.39656 0 m
.39656 .61803 L
s
.58294 0 m
.58294 .61803 L
s
.76931 0 m
.76931 .61803 L
s
0 .09163 m
1 .09163 L
s
0 .17524 m
1 .17524 L
s
0 .25885 m
1 .25885 L
s
0 .34246 m
1 .34246 L
s
0 .42607 m
1 .42607 L
s
0 .50968 m
1 .50968 L
s
0 .59329 m
1 .59329 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21019 0 m
.21019 .00625 L
s
gsave
.21019 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.39656 0 m
.39656 .00625 L
s
gsave
.39656 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.58294 0 m
.58294 .00625 L
s
gsave
.58294 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300) show
1.000 setlinewidth
grestore
.76931 0 m
.76931 .00625 L
s
gsave
.76931 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(400) show
1.000 setlinewidth
grestore
.95569 0 m
.95569 .00625 L
s
gsave
.95569 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
1.000 setlinewidth
grestore
.125 Mabswid
.06108 0 m
.06108 .00375 L
s
.09836 0 m
.09836 .00375 L
s
.13564 0 m
.13564 .00375 L
s
.17291 0 m
.17291 .00375 L
s
.24746 0 m
.24746 .00375 L
s
.28474 0 m
.28474 .00375 L
s
.32201 0 m
.32201 .00375 L
s
.35929 0 m
.35929 .00375 L
s
.43384 0 m
.43384 .00375 L
s
.47111 0 m
.47111 .00375 L
s
.50839 0 m
.50839 .00375 L
s
.54566 0 m
.54566 .00375 L
s
.62021 0 m
.62021 .00375 L
s
.65749 0 m
.65749 .00375 L
s
.69476 0 m
.69476 .00375 L
s
.73204 0 m
.73204 .00375 L
s
.80659 0 m
.80659 .00375 L
s
.84386 0 m
.84386 .00375 L
s
.88114 0 m
.88114 .00375 L
s
.91841 0 m
.91841 .00375 L
s
.99296 0 m
.99296 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -79.5 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Steps) show
96.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .00803 m
.00625 .00803 L
s
gsave
-0.0125 .00803 -91.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.5) show
1.000 setlinewidth
grestore
0 .09163 m
.00625 .09163 L
s
gsave
-0.0125 .09163 -99.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.25) show
1.000 setlinewidth
grestore
0 .17524 m
.00625 .17524 L
s
gsave
-0.0125 .17524 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .25885 m
.00625 .25885 L
s
gsave
-0.0125 .25885 -99.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.75) show
1.000 setlinewidth
grestore
0 .34246 m
.00625 .34246 L
s
gsave
-0.0125 .34246 -91.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
1.000 setlinewidth
grestore
0 .42607 m
.00625 .42607 L
s
gsave
-0.0125 .42607 -99.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.25) show
1.000 setlinewidth
grestore
0 .50968 m
.00625 .50968 L
s
gsave
-0.0125 .50968 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
0 .59329 m
.00625 .59329 L
s
gsave
-0.0125 .59329 -99.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.75) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02475 m
.00375 .02475 L
s
0 .04147 m
.00375 .04147 L
s
0 .05819 m
.00375 .05819 L
s
0 .07491 m
.00375 .07491 L
s
0 .10836 m
.00375 .10836 L
s
0 .12508 m
.00375 .12508 L
s
0 .1418 m
.00375 .1418 L
s
0 .15852 m
.00375 .15852 L
s
0 .19197 m
.00375 .19197 L
s
0 .20869 m
.00375 .20869 L
s
0 .22541 m
.00375 .22541 L
s
0 .24213 m
.00375 .24213 L
s
0 .27557 m
.00375 .27557 L
s
0 .2923 m
.00375 .2923 L
s
0 .30902 m
.00375 .30902 L
s
0 .32574 m
.00375 .32574 L
s
0 .35918 m
.00375 .35918 L
s
0 .3759 m
.00375 .3759 L
s
0 .39263 m
.00375 .39263 L
s
0 .40935 m
.00375 .40935 L
s
0 .44279 m
.00375 .44279 L
s
0 .45951 m
.00375 .45951 L
s
0 .47623 m
.00375 .47623 L
s
0 .49296 m
.00375 .49296 L
s
0 .5264 m
.00375 .5264 L
s
0 .54312 m
.00375 .54312 L
s
0 .55984 m
.00375 .55984 L
s
0 .57656 m
.00375 .57656 L
s
0 .61001 m
.00375 .61001 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -163.344 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
117.031 12.1875 translate
90 rotate
-117.031 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Insertion) show
116.063 16.625 moveto
(Loss) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
146.875 16.625 moveto
(H) show
151.063 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dB) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
166.875 16.625 moveto
(L) show
171.063 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21019 .61178 m
.21019 .61803 L
s
.39656 .61178 m
.39656 .61803 L
s
.58294 .61178 m
.58294 .61803 L
s
.76931 .61178 m
.76931 .61803 L
s
.95569 .61178 m
.95569 .61803 L
s
.125 Mabswid
.06108 .61428 m
.06108 .61803 L
s
.09836 .61428 m
.09836 .61803 L
s
.13564 .61428 m
.13564 .61803 L
s
.17291 .61428 m
.17291 .61803 L
s
.24746 .61428 m
.24746 .61803 L
s
.28474 .61428 m
.28474 .61803 L
s
.32201 .61428 m
.32201 .61803 L
s
.35929 .61428 m
.35929 .61803 L
s
.43384 .61428 m
.43384 .61803 L
s
.47111 .61428 m
.47111 .61803 L
s
.50839 .61428 m
.50839 .61803 L
s
.54566 .61428 m
.54566 .61803 L
s
.62021 .61428 m
.62021 .61803 L
s
.65749 .61428 m
.65749 .61803 L
s
.69476 .61428 m
.69476 .61803 L
s
.73204 .61428 m
.73204 .61803 L
s
.80659 .61428 m
.80659 .61803 L
s
.84386 .61428 m
.84386 .61803 L
s
.88114 .61428 m
.88114 .61803 L
s
.91841 .61428 m
.91841 .61803 L
s
.99296 .61428 m
.99296 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00803 m
1 .00803 L
s
.99375 .09163 m
1 .09163 L
s
.99375 .17524 m
1 .17524 L
s
.99375 .25885 m
1 .25885 L
s
.99375 .34246 m
1 .34246 L
s
.99375 .42607 m
1 .42607 L
s
.99375 .50968 m
1 .50968 L
s
.99375 .59329 m
1 .59329 L
s
.125 Mabswid
.99625 .02475 m
1 .02475 L
s
.99625 .04147 m
1 .04147 L
s
.99625 .05819 m
1 .05819 L
s
.99625 .07491 m
1 .07491 L
s
.99625 .10836 m
1 .10836 L
s
.99625 .12508 m
1 .12508 L
s
.99625 .1418 m
1 .1418 L
s
.99625 .15852 m
1 .15852 L
s
.99625 .19197 m
1 .19197 L
s
.99625 .20869 m
1 .20869 L
s
.99625 .22541 m
1 .22541 L
s
.99625 .24213 m
1 .24213 L
s
.99625 .27557 m
1 .27557 L
s
.99625 .2923 m
1 .2923 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32574 m
1 .32574 L
s
.99625 .35918 m
1 .35918 L
s
.99625 .3759 m
1 .3759 L
s
.99625 .39263 m
1 .39263 L
s
.99625 .40935 m
1 .40935 L
s
.99625 .44279 m
1 .44279 L
s
.99625 .45951 m
1 .45951 L
s
.99625 .47623 m
1 .47623 L
s
.99625 .49296 m
1 .49296 L
s
.99625 .5264 m
1 .5264 L
s
.99625 .54312 m
1 .54312 L
s
.99625 .55984 m
1 .55984 L
s
.99625 .57656 m
1 .57656 L
s
.99625 .61001 m
1 .61001 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -195.156 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Insertion) show
116.063 16.625 moveto
(Loss) show
146.875 16.625 moveto
(as) show
164.063 16.625 moveto
(Function) show
217.188 16.625 moveto
(of) show
232.000 16.625 moveto
(Steps) show
268.563 16.625 moveto
(at) show
282.875 16.625 moveto
(50) show
300.813 16.625 moveto
(MHz) show
327.313 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 0 r
.007 w
.02381 .59997 m
.02567 .60332 L
.02754 .60332 L
.0294 .60332 L
.03126 .59663 L
.03313 .59663 L
.03499 .59663 L
.03686 .59329 L
.03872 .5866 L
.04058 .5866 L
.04245 .58325 L
.04431 .58325 L
.04617 .57991 L
.04804 .57991 L
.0499 .57991 L
.05177 .57656 L
.05363 .56653 L
.05549 .56653 L
.05736 .56319 L
.05922 .56319 L
.06108 .55984 L
.06295 .5565 L
.06481 .5565 L
.06668 .55315 L
.06854 .54647 L
.0704 .54647 L
.07227 .54312 L
.07413 .54312 L
.07599 .53978 L
.07786 .53643 L
.07972 .53309 L
.08159 .53309 L
.08345 .51637 L
.08531 .51637 L
.08718 .51302 L
.08904 .51302 L
.0909 .50968 L
.09277 .50968 L
.09463 .50633 L
.0965 .50633 L
.09836 .49964 L
.10022 .4963 L
.10209 .4963 L
.10395 .49296 L
.10581 .49296 L
.10768 .48961 L
.10954 .48627 L
.11141 .48627 L
.11327 .47958 L
.11513 .47623 L
Mistroke
.117 .47289 L
.11886 .47289 L
.12073 .46955 L
.12259 .46955 L
.12445 .4662 L
.12632 .4662 L
.12818 .46286 L
.13004 .45951 L
.13191 .45951 L
.13377 .45951 L
.13564 .45617 L
.1375 .45617 L
.13936 .45282 L
.14123 .45282 L
.14309 .45282 L
.14495 .45282 L
.14682 .45282 L
.14868 .44948 L
.15055 .44948 L
.15241 .44948 L
.15427 .44613 L
.15614 .44613 L
.158 .44279 L
.15986 .44279 L
.16173 .43945 L
.16359 .43945 L
.16546 .4361 L
.16732 .4361 L
.16918 .4361 L
.17105 .4361 L
.17291 .43276 L
.17477 .43276 L
.17664 .43276 L
.1785 .43276 L
.18037 .42941 L
.18223 .42941 L
.18409 .42941 L
.18596 .42607 L
.18782 .42607 L
.18968 .42607 L
.19155 .42607 L
.19341 .42272 L
.19528 .42272 L
.19714 .41938 L
.199 .41938 L
.20087 .41938 L
.20273 .42607 L
.20459 .42607 L
.20646 .42607 L
.20832 .42607 L
Mistroke
.21019 .42607 L
.21205 .42272 L
.21391 .42272 L
.21578 .42272 L
.21764 .42272 L
.2195 .42272 L
.22137 .41938 L
.22323 .41938 L
.2251 .41938 L
.22696 .41938 L
.22882 .41938 L
.23069 .41604 L
.23255 .41938 L
.23441 .41938 L
.23628 .41938 L
.23814 .41938 L
.24001 .41604 L
.24187 .41604 L
.24373 .41604 L
.2456 .41604 L
.24746 .41604 L
.24932 .41269 L
.25119 .41269 L
.25305 .41269 L
.25492 .40935 L
.25678 .40935 L
.25864 .40935 L
.26051 .40935 L
.26237 .45617 L
.26423 .45617 L
.2661 .45282 L
.26796 .45282 L
.26983 .45282 L
.27169 .45282 L
.27355 .44948 L
.27542 .44948 L
.27728 .44613 L
.27914 .44613 L
.28101 .44613 L
.28287 .44613 L
.28474 .44279 L
.2866 .44279 L
.28846 .44279 L
.29033 .43945 L
.29219 .43276 L
.29405 .43276 L
.29592 .43276 L
.29778 .43276 L
.29965 .42941 L
.30151 .42941 L
Mistroke
.30337 .42607 L
.30524 .42607 L
.3071 .41938 L
.30896 .41938 L
.31083 .41604 L
.31269 .41604 L
.31456 .41269 L
.31642 .41269 L
.31828 .40935 L
.32015 .40935 L
.32201 .406 L
.32387 .406 L
.32574 .40266 L
.3276 .40266 L
.32947 .39931 L
.33133 .39931 L
.33319 .39597 L
.33506 .39597 L
.33692 .38928 L
.33878 .38928 L
.34065 .38594 L
.34251 .38594 L
.34438 .38259 L
.34624 .38259 L
.3481 .38259 L
.34997 .37925 L
.35183 .36922 L
.35369 .36922 L
.35556 .36922 L
.35742 .36587 L
.35929 .36253 L
.36115 .36253 L
.36301 .35918 L
.36488 .35918 L
.36674 .35249 L
.3686 .35249 L
.37047 .34915 L
.37233 .34915 L
.3742 .3458 L
.37606 .3458 L
.37792 .34246 L
.37979 .34246 L
.38165 .35249 L
.38352 .35249 L
.38538 .34915 L
.38724 .34915 L
.38911 .3458 L
.39097 .3458 L
.39283 .34246 L
.3947 .34246 L
Mistroke
.39656 .33912 L
.39843 .33912 L
.40029 .33577 L
.40215 .33577 L
.40402 .33243 L
.40588 .32908 L
.40774 .32908 L
.40961 .32908 L
.41147 .31905 L
.41334 .31905 L
.4152 .31905 L
.41706 .31905 L
.41893 .31571 L
.42079 .31571 L
.42265 .31236 L
.42452 .31236 L
.42638 .30902 L
.42825 .30902 L
.43011 .30567 L
.43197 .30233 L
.43384 .30233 L
.4357 .29898 L
.43756 .29898 L
.43943 .29898 L
.44129 .2923 L
.44316 .28895 L
.44502 .28895 L
.44688 .28895 L
.44875 .28561 L
.45061 .28561 L
.45247 .28561 L
.45434 .28226 L
.4562 .28226 L
.45807 .27892 L
.45993 .27892 L
.46179 .27892 L
.46366 .27557 L
.46552 .27557 L
.46738 .27557 L
.46925 .27557 L
.47111 .27223 L
.47298 .27223 L
.47484 .26888 L
.4767 .26888 L
.47857 .26888 L
.48043 .26888 L
.48229 .26554 L
.48416 .26554 L
.48602 .2622 L
.48789 .2622 L
Mistroke
.48975 .2622 L
.49161 .2622 L
.49348 .25885 L
.49534 .25885 L
.4972 .25885 L
.49907 .25885 L
.50093 .30567 L
.5028 .30567 L
.50466 .30233 L
.50652 .30233 L
.50839 .29898 L
.51025 .29898 L
.51211 .29898 L
.51398 .29898 L
.51584 .2923 L
.51771 .2923 L
.51957 .28895 L
.52143 .28895 L
.5233 .28895 L
.52516 .28895 L
.52702 .28561 L
.52889 .28561 L
.53075 .27892 L
.53262 .27892 L
.53448 .27557 L
.53634 .27557 L
.53821 .27223 L
.54007 .27223 L
.54193 .26888 L
.5438 .26888 L
.54566 .26554 L
.54753 .2622 L
.54939 .2622 L
.55125 .2622 L
.55312 .25885 L
.55498 .25885 L
.55684 .25551 L
.55871 .25551 L
.56057 .24882 L
.56244 .24882 L
.5643 .24882 L
.56616 .24547 L
.56803 .24213 L
.56989 .24213 L
.57175 .24213 L
.57362 .23879 L
.57548 .23544 L
.57735 .23544 L
.57921 .2321 L
.58107 .2321 L
Mistroke
.58294 .22875 L
.5848 .22875 L
.58666 .22541 L
.58853 .22541 L
.59039 .21872 L
.59226 .21872 L
.59412 .21538 L
.59598 .21538 L
.59785 .21538 L
.59971 .21538 L
.60157 .21203 L
.60344 .21203 L
.6053 .20869 L
.60717 .20869 L
.60903 .20534 L
.61089 .20534 L
.61276 .202 L
.61462 .202 L
.61648 .19865 L
.61835 .19865 L
.62021 .21872 L
.62208 .21872 L
.62394 .21872 L
.6258 .21538 L
.62767 .21203 L
.62953 .21203 L
.6314 .21203 L
.63326 .21203 L
.63512 .20869 L
.63699 .20869 L
.63885 .20534 L
.64071 .20534 L
.64258 .202 L
.64444 .202 L
.64631 .19865 L
.64817 .19865 L
.65003 .19531 L
.6519 .19531 L
.65376 .19197 L
.65562 .19197 L
.65749 .19197 L
.65935 .19197 L
.66122 .18862 L
.66308 .18862 L
.66494 .18528 L
.66681 .18528 L
.66867 .18193 L
.67053 .18193 L
.6724 .18193 L
.67426 .17859 L
Mistroke
.67613 .17859 L
.67799 .17859 L
.67985 .17859 L
.68172 .17859 L
.68358 .17524 L
.68544 .17524 L
.68731 .17524 L
.68917 .17524 L
.69104 .17524 L
.6929 .1719 L
.69476 .1719 L
.69663 .16855 L
.69849 .16521 L
.70035 .16521 L
.70222 .16521 L
.70408 .16521 L
.70595 .16187 L
.70781 .16187 L
.70967 .15852 L
.71154 .15852 L
.7134 .15852 L
.71526 .15852 L
.71713 .15518 L
.71899 .15518 L
.72086 .15518 L
.72272 .15183 L
.72458 .14849 L
.72645 .14849 L
.72831 .14849 L
.73017 .14849 L
.73204 .14514 L
.7339 .14514 L
.73577 .1418 L
.73763 .1418 L
.73949 .17524 L
.74136 .17524 L
.74322 .17524 L
.74508 .17524 L
.74695 .1719 L
.74881 .1719 L
.75068 .16855 L
.75254 .16855 L
.7544 .16521 L
.75627 .16521 L
.75813 .16187 L
.75999 .16187 L
.76186 .15852 L
.76372 .15852 L
.76559 .15518 L
.76745 .15518 L
Mistroke
.76931 .14849 L
.77118 .14849 L
.77304 .14514 L
.7749 .14514 L
.77677 .14514 L
.77863 .1418 L
.7805 .1418 L
.78236 .1418 L
.78422 .13511 L
.78609 .13511 L
.78795 .13177 L
.78981 .13177 L
.79168 .12842 L
.79354 .12842 L
.79541 .12508 L
.79727 .12508 L
.79913 .11839 L
.801 .11839 L
.80286 .11505 L
.80472 .11505 L
.80659 .1117 L
.80845 .1117 L
.81032 .10836 L
.81218 .10836 L
.81404 .10501 L
.81591 .10501 L
.81777 .10167 L
.81963 .10167 L
.8215 .09832 L
.82336 .09832 L
.82523 .09832 L
.82709 .09498 L
.82895 .09163 L
.83082 .08829 L
.83268 .08829 L
.83454 .08829 L
.83641 .08495 L
.83827 .08495 L
.84014 .0816 L
.842 .0816 L
.84386 .07826 L
.84573 .07826 L
.84759 .07491 L
.84945 .07491 L
.85132 .07157 L
.85318 .07157 L
.85505 .06822 L
.85691 .06822 L
.85877 .08829 L
.86064 .08829 L
Mistroke
.8625 .08495 L
.86436 .08495 L
.86623 .08495 L
.86809 .0816 L
.86996 .0816 L
.87182 .0816 L
.87368 .07826 L
.87555 .07826 L
.87741 .07826 L
.87927 .07491 L
.88114 .07491 L
.883 .07157 L
.88487 .07157 L
.88673 .07157 L
.88859 .06488 L
.89046 .06488 L
.89232 .06488 L
.89419 .06488 L
.89605 .06154 L
.89791 .06154 L
.89978 .05819 L
.90164 .05819 L
.9035 .05485 L
.90537 .05485 L
.90723 .05485 L
.9091 .0515 L
.91096 .0515 L
.91282 .0515 L
.91469 .04816 L
.91655 .04816 L
.91841 .0515 L
.92028 .04816 L
.92214 .04816 L
.92401 .04816 L
.92587 .04481 L
.92773 .04481 L
.9296 .04481 L
.93146 .04481 L
.93332 .04147 L
.93519 .04147 L
.93705 .04147 L
.93892 .04147 L
.94078 .03813 L
.94264 .03478 L
.94451 .03478 L
.94637 .03478 L
.94823 .03144 L
.9501 .03144 L
.95196 .02809 L
.95383 .02809 L
Mistroke
.95569 .02809 L
.95755 .02809 L
.95942 .02475 L
.96128 .02475 L
.96314 .0214 L
.96501 .0214 L
.96687 .01806 L
.96874 .01806 L
.9706 .01806 L
.97246 .01472 L
.97433 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{579.625, 358.25},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{57.1875, 519.875}, {639.313, 353.75}} -> {-184.243, \
-2.00395, 1.12082, 0.00624621}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Phase Shift as Function of Steps", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"tapphase", ",", "\[IndentingNewLine]", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
   RowBox[{
   "PlotLabel", "\[Rule]", "\"\<Phase as Function of Steps at 50 MHz\>\""}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Steps\>\"", ",", "\"\<Phase (\[Degree])\>\""}], "}"}]}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", 
      RowBox[{"RGBColor", " ", "[", 
       RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "}"}]}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.44286820974*^9, 3.44286821274*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00186376 0.603319 0.00106265 [
[.02381 -0.0125 -5.59375 -16.375 ]
[.02381 -0.0125 5.59375 0 ]
[.21019 -0.0125 -12.7813 -16.375 ]
[.21019 -0.0125 12.7813 0 ]
[.39656 -0.0125 -12.7813 -16.375 ]
[.39656 -0.0125 12.7813 0 ]
[.58294 -0.0125 -12.7813 -16.375 ]
[.58294 -0.0125 12.7813 0 ]
[.76931 -0.0125 -12.7813 -16.375 ]
[.76931 -0.0125 12.7813 0 ]
[.95569 -0.0125 -12.7813 -16.375 ]
[.95569 -0.0125 12.7813 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -18.5 -32.75 ]
[.5 -0.0125 18.5 -16.375 ]
[-0.0125 .07199 -34.5625 -8.1875 ]
[-0.0125 .07199 0 8.1875 ]
[-0.0125 .17826 -34.5625 -8.1875 ]
[-0.0125 .17826 0 8.1875 ]
[-0.0125 .28452 -34.5625 -8.1875 ]
[-0.0125 .28452 0 8.1875 ]
[-0.0125 .39079 -34.5625 -8.1875 ]
[-0.0125 .39079 0 8.1875 ]
[-0.0125 .49705 -34.5625 -8.1875 ]
[-0.0125 .49705 0 8.1875 ]
[-0.0125 .60332 -11.1875 -8.1875 ]
[-0.0125 .60332 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -50.9375 -27.5625 ]
[-0.01875 .30902 -34.5625 27.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -112.313 0 ]
[.5 .63053 112.313 16.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.21019 0 m
.21019 .61803 L
s
.39656 0 m
.39656 .61803 L
s
.58294 0 m
.58294 .61803 L
s
.76931 0 m
.76931 .61803 L
s
0 .07199 m
1 .07199 L
s
0 .17826 m
1 .17826 L
s
0 .28452 m
1 .28452 L
s
0 .39079 m
1 .39079 L
s
0 .49705 m
1 .49705 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21019 0 m
.21019 .00625 L
s
gsave
.21019 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.39656 0 m
.39656 .00625 L
s
gsave
.39656 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.58294 0 m
.58294 .00625 L
s
gsave
.58294 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300) show
1.000 setlinewidth
grestore
.76931 0 m
.76931 .00625 L
s
gsave
.76931 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(400) show
1.000 setlinewidth
grestore
.95569 0 m
.95569 .00625 L
s
gsave
.95569 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
1.000 setlinewidth
grestore
.125 Mabswid
.06108 0 m
.06108 .00375 L
s
.09836 0 m
.09836 .00375 L
s
.13564 0 m
.13564 .00375 L
s
.17291 0 m
.17291 .00375 L
s
.24746 0 m
.24746 .00375 L
s
.28474 0 m
.28474 .00375 L
s
.32201 0 m
.32201 .00375 L
s
.35929 0 m
.35929 .00375 L
s
.43384 0 m
.43384 .00375 L
s
.47111 0 m
.47111 .00375 L
s
.50839 0 m
.50839 .00375 L
s
.54566 0 m
.54566 .00375 L
s
.62021 0 m
.62021 .00375 L
s
.65749 0 m
.65749 .00375 L
s
.69476 0 m
.69476 .00375 L
s
.73204 0 m
.73204 .00375 L
s
.80659 0 m
.80659 .00375 L
s
.84386 0 m
.84386 .00375 L
s
.88114 0 m
.88114 .00375 L
s
.91841 0 m
.91841 .00375 L
s
.99296 0 m
.99296 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -79.5 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Steps) show
96.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07199 m
.00625 .07199 L
s
gsave
-0.0125 .07199 -95.5625 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
1.000 setlinewidth
grestore
0 .17826 m
.00625 .17826 L
s
gsave
-0.0125 .17826 -95.5625 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(400) show
1.000 setlinewidth
grestore
0 .28452 m
.00625 .28452 L
s
gsave
-0.0125 .28452 -95.5625 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300) show
1.000 setlinewidth
grestore
0 .39079 m
.00625 .39079 L
s
gsave
-0.0125 .39079 -95.5625 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
0 .49705 m
.00625 .49705 L
s
gsave
-0.0125 .49705 -95.5625 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .09325 m
.00375 .09325 L
s
0 .1145 m
.00375 .1145 L
s
0 .13575 m
.00375 .13575 L
s
0 .157 m
.00375 .157 L
s
0 .19951 m
.00375 .19951 L
s
0 .22076 m
.00375 .22076 L
s
0 .24202 m
.00375 .24202 L
s
0 .26327 m
.00375 .26327 L
s
0 .30578 m
.00375 .30578 L
s
0 .32703 m
.00375 .32703 L
s
0 .34828 m
.00375 .34828 L
s
0 .36954 m
.00375 .36954 L
s
0 .41204 m
.00375 .41204 L
s
0 .43329 m
.00375 .43329 L
s
0 .45455 m
.00375 .45455 L
s
0 .4758 m
.00375 .4758 L
s
0 .51831 m
.00375 .51831 L
s
0 .53956 m
.00375 .53956 L
s
0 .56081 m
.00375 .56081 L
s
0 .58207 m
.00375 .58207 L
s
0 .05074 m
.00375 .05074 L
s
0 .02949 m
.00375 .02949 L
s
0 .00823 m
.00375 .00823 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -131.313 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
88.5625 12.1875 translate
90 rotate
-88.5625 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Phase) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 16.625 moveto
(H) show
107.375 16.625 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\260) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.938 16.625 moveto
(L) show
114.125 16.625 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21019 .61178 m
.21019 .61803 L
s
.39656 .61178 m
.39656 .61803 L
s
.58294 .61178 m
.58294 .61803 L
s
.76931 .61178 m
.76931 .61803 L
s
.95569 .61178 m
.95569 .61803 L
s
.125 Mabswid
.06108 .61428 m
.06108 .61803 L
s
.09836 .61428 m
.09836 .61803 L
s
.13564 .61428 m
.13564 .61803 L
s
.17291 .61428 m
.17291 .61803 L
s
.24746 .61428 m
.24746 .61803 L
s
.28474 .61428 m
.28474 .61803 L
s
.32201 .61428 m
.32201 .61803 L
s
.35929 .61428 m
.35929 .61803 L
s
.43384 .61428 m
.43384 .61803 L
s
.47111 .61428 m
.47111 .61803 L
s
.50839 .61428 m
.50839 .61803 L
s
.54566 .61428 m
.54566 .61803 L
s
.62021 .61428 m
.62021 .61803 L
s
.65749 .61428 m
.65749 .61803 L
s
.69476 .61428 m
.69476 .61803 L
s
.73204 .61428 m
.73204 .61803 L
s
.80659 .61428 m
.80659 .61803 L
s
.84386 .61428 m
.84386 .61803 L
s
.88114 .61428 m
.88114 .61803 L
s
.91841 .61428 m
.91841 .61803 L
s
.99296 .61428 m
.99296 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07199 m
1 .07199 L
s
.99375 .17826 m
1 .17826 L
s
.99375 .28452 m
1 .28452 L
s
.99375 .39079 m
1 .39079 L
s
.99375 .49705 m
1 .49705 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .09325 m
1 .09325 L
s
.99625 .1145 m
1 .1145 L
s
.99625 .13575 m
1 .13575 L
s
.99625 .157 m
1 .157 L
s
.99625 .19951 m
1 .19951 L
s
.99625 .22076 m
1 .22076 L
s
.99625 .24202 m
1 .24202 L
s
.99625 .26327 m
1 .26327 L
s
.99625 .30578 m
1 .30578 L
s
.99625 .32703 m
1 .32703 L
s
.99625 .34828 m
1 .34828 L
s
.99625 .36954 m
1 .36954 L
s
.99625 .41204 m
1 .41204 L
s
.99625 .43329 m
1 .43329 L
s
.99625 .45455 m
1 .45455 L
s
.99625 .4758 m
1 .4758 L
s
.99625 .51831 m
1 .51831 L
s
.99625 .53956 m
1 .53956 L
s
.99625 .56081 m
1 .56081 L
s
.99625 .58207 m
1 .58207 L
s
.99625 .05074 m
1 .05074 L
s
.99625 .02949 m
1 .02949 L
s
.99625 .00823 m
1 .00823 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -173.313 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Phase) show
103.188 16.625 moveto
(as) show
120.375 16.625 moveto
(Function) show
173.500 16.625 moveto
(of) show
188.313 16.625 moveto
(Steps) show
224.875 16.625 moveto
(at) show
239.188 16.625 moveto
(50) show
257.125 16.625 moveto
(MHz) show
283.625 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 0 r
.007 w
.02381 .60332 m
.02567 .60204 L
.02754 .60098 L
.0294 .59971 L
.03126 .59854 L
.03313 .59737 L
.03499 .59609 L
.03686 .59492 L
.03872 .59376 L
.04058 .59259 L
.04245 .59142 L
.04431 .59025 L
.04617 .58897 L
.04804 .5878 L
.0499 .58664 L
.05177 .58547 L
.05363 .5843 L
.05549 .58313 L
.05736 .58196 L
.05922 .58079 L
.06108 .57962 L
.06295 .57845 L
.06481 .57728 L
.06668 .57601 L
.06854 .57495 L
.0704 .57378 L
.07227 .57261 L
.07413 .57144 L
.07599 .57027 L
.07786 .5691 L
.07972 .56793 L
.08159 .56666 L
.08345 .56581 L
.08531 .56464 L
.08718 .56347 L
.08904 .56219 L
.0909 .56103 L
.09277 .55986 L
.09463 .55869 L
.0965 .55752 L
.09836 .55646 L
.10022 .55529 L
.10209 .55412 L
.10395 .55295 L
.10581 .55178 L
.10768 .55061 L
.10954 .54944 L
.11141 .54827 L
.11327 .54742 L
.11513 .54625 L
Mistroke
.117 .54509 L
.11886 .54392 L
.12073 .54275 L
.12259 .54158 L
.12445 .54041 L
.12632 .53924 L
.12818 .53828 L
.13004 .53712 L
.13191 .53595 L
.13377 .53478 L
.13564 .53361 L
.1375 .53244 L
.13936 .53127 L
.14123 .5301 L
.14309 .52968 L
.14495 .52851 L
.14682 .52734 L
.14868 .52617 L
.15055 .525 L
.15241 .52383 L
.15427 .52266 L
.15614 .52149 L
.158 .52043 L
.15986 .51926 L
.16173 .51809 L
.16359 .51693 L
.16546 .51576 L
.16732 .51459 L
.16918 .51342 L
.17105 .51225 L
.17291 .5114 L
.17477 .51023 L
.17664 .50906 L
.1785 .50789 L
.18037 .50672 L
.18223 .50555 L
.18409 .50439 L
.18596 .50322 L
.18782 .50215 L
.18968 .50099 L
.19155 .49982 L
.19341 .49865 L
.19528 .49748 L
.19714 .49631 L
.199 .49514 L
.20087 .49397 L
.20273 .49333 L
.20459 .49217 L
.20646 .491 L
.20832 .48983 L
Mistroke
.21019 .48866 L
.21205 .48749 L
.21391 .48632 L
.21578 .48515 L
.21764 .48409 L
.2195 .48292 L
.22137 .48175 L
.22323 .48058 L
.2251 .47941 L
.22696 .47824 L
.22882 .47708 L
.23069 .4758 L
.23255 .47484 L
.23441 .47368 L
.23628 .47251 L
.23814 .47134 L
.24001 .47017 L
.24187 .469 L
.24373 .46783 L
.2456 .46666 L
.24746 .46549 L
.24932 .46432 L
.25119 .46315 L
.25305 .46199 L
.25492 .46082 L
.25678 .45965 L
.25864 .45848 L
.26051 .45731 L
.26237 .45657 L
.26423 .4554 L
.2661 .45423 L
.26796 .45306 L
.26983 .45178 L
.27169 .45062 L
.27355 .44945 L
.27542 .44828 L
.27728 .44711 L
.27914 .44594 L
.28101 .44477 L
.28287 .4436 L
.28474 .44233 L
.2866 .44116 L
.28846 .43999 L
.29033 .43882 L
.29219 .43765 L
.29405 .43648 L
.29592 .43531 L
.29778 .43404 L
.29965 .43287 L
.30151 .4317 L
Mistroke
.30337 .43053 L
.30524 .42926 L
.3071 .42819 L
.30896 .42702 L
.31083 .42586 L
.31269 .42469 L
.31456 .42341 L
.31642 .42224 L
.31828 .42107 L
.32015 .4199 L
.32201 .41884 L
.32387 .41767 L
.32574 .4165 L
.3276 .41523 L
.32947 .41406 L
.33133 .41289 L
.33319 .41172 L
.33506 .41045 L
.33692 .40938 L
.33878 .40822 L
.34065 .40705 L
.34251 .40588 L
.34438 .4046 L
.34624 .40343 L
.3481 .40226 L
.34997 .4011 L
.35183 .40014 L
.35369 .39897 L
.35556 .3978 L
.35742 .39663 L
.35929 .39546 L
.36115 .39419 L
.36301 .39302 L
.36488 .39185 L
.36674 .39079 L
.3686 .38962 L
.37047 .38845 L
.37233 .38728 L
.3742 .38611 L
.37606 .38494 L
.37792 .38377 L
.37979 .38261 L
.38165 .38176 L
.38352 .38059 L
.38538 .37942 L
.38724 .37825 L
.38911 .37708 L
.39097 .37591 L
.39283 .37474 L
.3947 .37357 L
Mistroke
.39656 .37251 L
.39843 .37134 L
.40029 .37017 L
.40215 .369 L
.40402 .36773 L
.40588 .36656 L
.40774 .36539 L
.40961 .36422 L
.41147 .36327 L
.41334 .3621 L
.4152 .36093 L
.41706 .35976 L
.41893 .35859 L
.42079 .35742 L
.42265 .35625 L
.42452 .35508 L
.42638 .35402 L
.42825 .35285 L
.43011 .35168 L
.43197 .35051 L
.43384 .34934 L
.4357 .34818 L
.43756 .34701 L
.43943 .34584 L
.44129 .34509 L
.44316 .34403 L
.44502 .34286 L
.44688 .34169 L
.44875 .34052 L
.45061 .33925 L
.45247 .33808 L
.45434 .33691 L
.4562 .33596 L
.45807 .33479 L
.45993 .33362 L
.46179 .33245 L
.46366 .33128 L
.46552 .33011 L
.46738 .32894 L
.46925 .32777 L
.47111 .32682 L
.47298 .32565 L
.47484 .32448 L
.4767 .32331 L
.47857 .32214 L
.48043 .32097 L
.48229 .3198 L
.48416 .31863 L
.48602 .31768 L
.48789 .31651 L
Mistroke
.48975 .31534 L
.49161 .31417 L
.49348 .313 L
.49534 .31183 L
.4972 .31066 L
.49907 .30939 L
.50093 .30896 L
.5028 .30779 L
.50466 .30652 L
.50652 .30535 L
.50839 .30418 L
.51025 .30301 L
.51211 .30184 L
.51398 .30068 L
.51584 .29951 L
.51771 .29834 L
.51957 .29717 L
.52143 .296 L
.5233 .29483 L
.52516 .29366 L
.52702 .29249 L
.52889 .29122 L
.53075 .29015 L
.53262 .28899 L
.53448 .28782 L
.53634 .28665 L
.53821 .28548 L
.54007 .28431 L
.54193 .28314 L
.5438 .28197 L
.54566 .2808 L
.54753 .27963 L
.54939 .27847 L
.55125 .2773 L
.55312 .27613 L
.55498 .27496 L
.55684 .27379 L
.55871 .27262 L
.56057 .27177 L
.56244 .2706 L
.5643 .26943 L
.56616 .26826 L
.56803 .26699 L
.56989 .26582 L
.57175 .26465 L
.57362 .26348 L
.57548 .26242 L
.57735 .26125 L
.57921 .26008 L
.58107 .25891 L
Mistroke
.58294 .25774 L
.5848 .25658 L
.58666 .25541 L
.58853 .25424 L
.59039 .25328 L
.59226 .25211 L
.59412 .25094 L
.59598 .24977 L
.59785 .24861 L
.59971 .24744 L
.60157 .24627 L
.60344 .2451 L
.6053 .24404 L
.60717 .24287 L
.60903 .2417 L
.61089 .24053 L
.61276 .23936 L
.61462 .23819 L
.61648 .23702 L
.61835 .23585 L
.62021 .23532 L
.62208 .23415 L
.62394 .23298 L
.6258 .23182 L
.62767 .23054 L
.62953 .22937 L
.6314 .2282 L
.63326 .22703 L
.63512 .22597 L
.63699 .2248 L
.63885 .22363 L
.64071 .22246 L
.64258 .22129 L
.64444 .22013 L
.64631 .21896 L
.64817 .21768 L
.65003 .21673 L
.6519 .21556 L
.65376 .21439 L
.65562 .21322 L
.65749 .21205 L
.65935 .21077 L
.66122 .20961 L
.66308 .20844 L
.66494 .20737 L
.66681 .20621 L
.66867 .20504 L
.67053 .20387 L
.6724 .2027 L
.67426 .20153 L
Mistroke
.67613 .20036 L
.67799 .19919 L
.67985 .19834 L
.68172 .19717 L
.68358 .196 L
.68544 .19483 L
.68731 .19367 L
.68917 .1925 L
.69104 .19133 L
.6929 .19016 L
.69476 .1891 L
.69663 .18793 L
.69849 .18676 L
.70035 .18559 L
.70222 .18442 L
.70408 .18315 L
.70595 .18198 L
.70781 .18081 L
.70967 .18006 L
.71154 .17868 L
.7134 .17751 L
.71526 .17634 L
.71713 .17518 L
.71899 .17401 L
.72086 .17284 L
.72272 .17167 L
.72458 .1705 L
.72645 .16933 L
.72831 .16816 L
.73017 .16699 L
.73204 .16582 L
.7339 .16466 L
.73577 .16349 L
.73763 .16232 L
.73949 .16136 L
.74136 .16019 L
.74322 .15902 L
.74508 .15785 L
.74695 .15669 L
.74881 .15541 L
.75068 .15424 L
.75254 .15307 L
.7544 .15201 L
.75627 .15084 L
.75813 .14957 L
.75999 .1484 L
.76186 .14723 L
.76372 .14606 L
.76559 .14489 L
.76745 .14372 L
Mistroke
.76931 .14266 L
.77118 .14149 L
.77304 .14032 L
.7749 .13905 L
.77677 .13788 L
.77863 .13671 L
.7805 .13554 L
.78236 .13437 L
.78422 .13331 L
.78609 .13214 L
.78795 .13097 L
.78981 .1298 L
.79168 .12853 L
.79354 .12736 L
.79541 .12619 L
.79727 .12502 L
.79913 .12417 L
.801 .123 L
.80286 .12183 L
.80472 .12066 L
.80659 .11949 L
.80845 .11822 L
.81032 .11705 L
.81218 .11588 L
.81404 .11482 L
.81591 .11365 L
.81777 .11248 L
.81963 .11131 L
.8215 .11014 L
.82336 .10897 L
.82523 .1078 L
.82709 .10663 L
.82895 .10568 L
.83082 .10451 L
.83268 .10334 L
.83454 .10217 L
.83641 .101 L
.83827 .09983 L
.84014 .09866 L
.842 .0975 L
.84386 .09643 L
.84573 .09526 L
.84759 .0941 L
.84945 .09293 L
.85132 .09176 L
.85318 .09059 L
.85505 .08942 L
.85691 .08825 L
.85877 .08772 L
.86064 .08655 L
Mistroke
.8625 .08538 L
.86436 .08421 L
.86623 .08294 L
.86809 .08177 L
.86996 .0806 L
.87182 .07943 L
.87368 .07837 L
.87555 .0772 L
.87741 .07603 L
.87927 .07486 L
.88114 .07359 L
.883 .07242 L
.88487 .07125 L
.88673 .07008 L
.88859 .06912 L
.89046 .06795 L
.89232 .06679 L
.89419 .06562 L
.89605 .06445 L
.89791 .06328 L
.89978 .06211 L
.90164 .06083 L
.9035 .05977 L
.90537 .0586 L
.90723 .05743 L
.9091 .05626 L
.91096 .0551 L
.91282 .05393 L
.91469 .05276 L
.91655 .05159 L
.91841 .05074 L
.92028 .04957 L
.92214 .0484 L
.92401 .04723 L
.92587 .04606 L
.92773 .04489 L
.9296 .04373 L
.93146 .04256 L
.93332 .04149 L
.93519 .04033 L
.93705 .03916 L
.93892 .03799 L
.94078 .03671 L
.94264 .03554 L
.94451 .03437 L
.94637 .03321 L
.94823 .03225 L
.9501 .03108 L
.95196 .02991 L
.95383 .02874 L
Mistroke
.95569 .02757 L
.95755 .0264 L
.95942 .02513 L
.96128 .02396 L
.96314 .0229 L
.96501 .02173 L
.96687 .02056 L
.96874 .01939 L
.9706 .01822 L
.97246 .01705 L
.97433 .01588 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{579.313, 358.063},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{57.1875, 519.625}, {475.438, 190}} -> {-182.292, \
-176.816, 1.12139, 1.96679}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Delay as Function of Steps", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"tapdelay", ",", "\[IndentingNewLine]", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
   RowBox[{
   "PlotLabel", "\[Rule]", "\"\<Delay as Function of Steps at 50 MHz\>\""}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Steps\>\"", ",", "\"\<Delay (ns)\>\""}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", 
      RowBox[{"RGBColor", " ", "[", 
       RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "}"}]}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.442868218615*^9, 3.442868220318125*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00186376 0.0147151 0.0191278 [
[.02381 -0.0125 -5.59375 -16.375 ]
[.02381 -0.0125 5.59375 0 ]
[.21019 -0.0125 -12.7813 -16.375 ]
[.21019 -0.0125 12.7813 0 ]
[.39656 -0.0125 -12.7813 -16.375 ]
[.39656 -0.0125 12.7813 0 ]
[.58294 -0.0125 -12.7813 -16.375 ]
[.58294 -0.0125 12.7813 0 ]
[.76931 -0.0125 -12.7813 -16.375 ]
[.76931 -0.0125 12.7813 0 ]
[.95569 -0.0125 -12.7813 -16.375 ]
[.95569 -0.0125 12.7813 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -18.5 -32.75 ]
[.5 -0.0125 18.5 -16.375 ]
[-0.0125 .01472 -11.1875 -8.1875 ]
[-0.0125 .01472 0 8.1875 ]
[-0.0125 .11035 -11.1875 -8.1875 ]
[-0.0125 .11035 0 8.1875 ]
[-0.0125 .20599 -18.375 -8.1875 ]
[-0.0125 .20599 0 8.1875 ]
[-0.0125 .30163 -18.375 -8.1875 ]
[-0.0125 .30163 0 8.1875 ]
[-0.0125 .39727 -18.375 -8.1875 ]
[-0.0125 .39727 0 8.1875 ]
[-0.0125 .49291 -18.375 -8.1875 ]
[-0.0125 .49291 0 8.1875 ]
[-0.0125 .58855 -18.375 -8.1875 ]
[-0.0125 .58855 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -34.75 -31.2813 ]
[-0.01875 .30902 -18.375 31.2813 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -110.5 0 ]
[.5 .63053 110.5 16.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.21019 0 m
.21019 .61803 L
s
.39656 0 m
.39656 .61803 L
s
.58294 0 m
.58294 .61803 L
s
.76931 0 m
.76931 .61803 L
s
0 .11035 m
1 .11035 L
s
0 .20599 m
1 .20599 L
s
0 .30163 m
1 .30163 L
s
0 .39727 m
1 .39727 L
s
0 .49291 m
1 .49291 L
s
0 .58855 m
1 .58855 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21019 0 m
.21019 .00625 L
s
gsave
.21019 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.39656 0 m
.39656 .00625 L
s
gsave
.39656 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.58294 0 m
.58294 .00625 L
s
gsave
.58294 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300) show
1.000 setlinewidth
grestore
.76931 0 m
.76931 .00625 L
s
gsave
.76931 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(400) show
1.000 setlinewidth
grestore
.95569 0 m
.95569 .00625 L
s
gsave
.95569 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
1.000 setlinewidth
grestore
.125 Mabswid
.06108 0 m
.06108 .00375 L
s
.09836 0 m
.09836 .00375 L
s
.13564 0 m
.13564 .00375 L
s
.17291 0 m
.17291 .00375 L
s
.24746 0 m
.24746 .00375 L
s
.28474 0 m
.28474 .00375 L
s
.32201 0 m
.32201 .00375 L
s
.35929 0 m
.35929 .00375 L
s
.43384 0 m
.43384 .00375 L
s
.47111 0 m
.47111 .00375 L
s
.50839 0 m
.50839 .00375 L
s
.54566 0 m
.54566 .00375 L
s
.62021 0 m
.62021 .00375 L
s
.65749 0 m
.65749 .00375 L
s
.69476 0 m
.69476 .00375 L
s
.73204 0 m
.73204 .00375 L
s
.80659 0 m
.80659 .00375 L
s
.84386 0 m
.84386 .00375 L
s
.88114 0 m
.88114 .00375 L
s
.91841 0 m
.91841 .00375 L
s
.99296 0 m
.99296 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -79.5 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Steps) show
96.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .11035 m
.00625 .11035 L
s
gsave
-0.0125 .11035 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .20599 m
.00625 .20599 L
s
gsave
-0.0125 .20599 -79.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .30163 m
.00625 .30163 L
s
gsave
-0.0125 .30163 -79.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
0 .39727 m
.00625 .39727 L
s
gsave
-0.0125 .39727 -79.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .49291 m
.00625 .49291 L
s
gsave
-0.0125 .49291 -79.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
0 .58855 m
.00625 .58855 L
s
gsave
-0.0125 .58855 -79.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03384 m
.00375 .03384 L
s
0 .05297 m
.00375 .05297 L
s
0 .0721 m
.00375 .0721 L
s
0 .09123 m
.00375 .09123 L
s
0 .12948 m
.00375 .12948 L
s
0 .14861 m
.00375 .14861 L
s
0 .16774 m
.00375 .16774 L
s
0 .18686 m
.00375 .18686 L
s
0 .22512 m
.00375 .22512 L
s
0 .24425 m
.00375 .24425 L
s
0 .26338 m
.00375 .26338 L
s
0 .2825 m
.00375 .2825 L
s
0 .32076 m
.00375 .32076 L
s
0 .33989 m
.00375 .33989 L
s
0 .35901 m
.00375 .35901 L
s
0 .37814 m
.00375 .37814 L
s
0 .4164 m
.00375 .4164 L
s
0 .43553 m
.00375 .43553 L
s
0 .45465 m
.00375 .45465 L
s
0 .47378 m
.00375 .47378 L
s
0 .51204 m
.00375 .51204 L
s
0 .53116 m
.00375 .53116 L
s
0 .55029 m
.00375 .55029 L
s
0 .56942 m
.00375 .56942 L
s
0 .60768 m
.00375 .60768 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -118.844 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
92.2813 12.1875 translate
90 rotate
-92.2813 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Delay) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.563 16.625 moveto
(H) show
103.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ns) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.375 16.625 moveto
(L) show
121.563 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21019 .61178 m
.21019 .61803 L
s
.39656 .61178 m
.39656 .61803 L
s
.58294 .61178 m
.58294 .61803 L
s
.76931 .61178 m
.76931 .61803 L
s
.95569 .61178 m
.95569 .61803 L
s
.125 Mabswid
.06108 .61428 m
.06108 .61803 L
s
.09836 .61428 m
.09836 .61803 L
s
.13564 .61428 m
.13564 .61803 L
s
.17291 .61428 m
.17291 .61803 L
s
.24746 .61428 m
.24746 .61803 L
s
.28474 .61428 m
.28474 .61803 L
s
.32201 .61428 m
.32201 .61803 L
s
.35929 .61428 m
.35929 .61803 L
s
.43384 .61428 m
.43384 .61803 L
s
.47111 .61428 m
.47111 .61803 L
s
.50839 .61428 m
.50839 .61803 L
s
.54566 .61428 m
.54566 .61803 L
s
.62021 .61428 m
.62021 .61803 L
s
.65749 .61428 m
.65749 .61803 L
s
.69476 .61428 m
.69476 .61803 L
s
.73204 .61428 m
.73204 .61803 L
s
.80659 .61428 m
.80659 .61803 L
s
.84386 .61428 m
.84386 .61803 L
s
.88114 .61428 m
.88114 .61803 L
s
.91841 .61428 m
.91841 .61803 L
s
.99296 .61428 m
.99296 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11035 m
1 .11035 L
s
.99375 .20599 m
1 .20599 L
s
.99375 .30163 m
1 .30163 L
s
.99375 .39727 m
1 .39727 L
s
.99375 .49291 m
1 .49291 L
s
.99375 .58855 m
1 .58855 L
s
.125 Mabswid
.99625 .03384 m
1 .03384 L
s
.99625 .05297 m
1 .05297 L
s
.99625 .0721 m
1 .0721 L
s
.99625 .09123 m
1 .09123 L
s
.99625 .12948 m
1 .12948 L
s
.99625 .14861 m
1 .14861 L
s
.99625 .16774 m
1 .16774 L
s
.99625 .18686 m
1 .18686 L
s
.99625 .22512 m
1 .22512 L
s
.99625 .24425 m
1 .24425 L
s
.99625 .26338 m
1 .26338 L
s
.99625 .2825 m
1 .2825 L
s
.99625 .32076 m
1 .32076 L
s
.99625 .33989 m
1 .33989 L
s
.99625 .35901 m
1 .35901 L
s
.99625 .37814 m
1 .37814 L
s
.99625 .4164 m
1 .4164 L
s
.99625 .43553 m
1 .43553 L
s
.99625 .45465 m
1 .45465 L
s
.99625 .47378 m
1 .47378 L
s
.99625 .51204 m
1 .51204 L
s
.99625 .53116 m
1 .53116 L
s
.99625 .55029 m
1 .55029 L
s
.99625 .56942 m
1 .56942 L
s
.99625 .60768 m
1 .60768 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -171.5 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Delay) show
99.563 16.625 moveto
(as) show
116.750 16.625 moveto
(Function) show
169.875 16.625 moveto
(of) show
184.688 16.625 moveto
(Steps) show
221.250 16.625 moveto
(at) show
235.563 16.625 moveto
(50) show
253.500 16.625 moveto
(MHz) show
280.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 0 r
.007 w
.02381 .01472 m
.02567 .01599 L
.02754 .01705 L
.0294 .01833 L
.03126 .0195 L
.03313 .02067 L
.03499 .02194 L
.03686 .02311 L
.03872 .02428 L
.04058 .02545 L
.04245 .02662 L
.04431 .02779 L
.04617 .02906 L
.04804 .03023 L
.0499 .0314 L
.05177 .03257 L
.05363 .03374 L
.05549 .03491 L
.05736 .03607 L
.05922 .03724 L
.06108 .03841 L
.06295 .03958 L
.06481 .04075 L
.06668 .04203 L
.06854 .04309 L
.0704 .04426 L
.07227 .04543 L
.07413 .04659 L
.07599 .04776 L
.07786 .04893 L
.07972 .0501 L
.08159 .05138 L
.08345 .05223 L
.08531 .0534 L
.08718 .05456 L
.08904 .05584 L
.0909 .05701 L
.09277 .05818 L
.09463 .05935 L
.0965 .06052 L
.09836 .06158 L
.10022 .06275 L
.10209 .06392 L
.10395 .06508 L
.10581 .06625 L
.10768 .06742 L
.10954 .06859 L
.11141 .06976 L
.11327 .07061 L
.11513 .07178 L
Mistroke
.117 .07295 L
.11886 .07412 L
.12073 .07529 L
.12259 .07646 L
.12445 .07762 L
.12632 .07879 L
.12818 .07975 L
.13004 .08092 L
.13191 .08209 L
.13377 .08326 L
.13564 .08443 L
.1375 .08559 L
.13936 .08676 L
.14123 .08793 L
.14309 .08836 L
.14495 .08953 L
.14682 .09069 L
.14868 .09186 L
.15055 .09303 L
.15241 .0942 L
.15427 .09537 L
.15614 .09654 L
.158 .0976 L
.15986 .09877 L
.16173 .09994 L
.16359 .10111 L
.16546 .10228 L
.16732 .10345 L
.16918 .10462 L
.17105 .10578 L
.17291 .10663 L
.17477 .1078 L
.17664 .10897 L
.1785 .11014 L
.18037 .11131 L
.18223 .11248 L
.18409 .11365 L
.18596 .11482 L
.18782 .11588 L
.18968 .11705 L
.19155 .11822 L
.19341 .11939 L
.19528 .12056 L
.19714 .12172 L
.199 .12289 L
.20087 .12406 L
.20273 .1247 L
.20459 .12587 L
.20646 .12704 L
.20832 .12821 L
Mistroke
.21019 .12938 L
.21205 .13054 L
.21391 .13171 L
.21578 .13288 L
.21764 .13394 L
.2195 .13511 L
.22137 .13628 L
.22323 .13745 L
.2251 .13862 L
.22696 .13979 L
.22882 .14096 L
.23069 .14223 L
.23255 .14319 L
.23441 .14436 L
.23628 .14553 L
.23814 .1467 L
.24001 .14787 L
.24187 .14903 L
.24373 .1502 L
.2456 .15137 L
.24746 .15254 L
.24932 .15371 L
.25119 .15488 L
.25305 .15605 L
.25492 .15722 L
.25678 .15839 L
.25864 .15955 L
.26051 .16072 L
.26237 .16147 L
.26423 .16264 L
.2661 .16381 L
.26796 .16497 L
.26983 .16625 L
.27169 .16742 L
.27355 .16859 L
.27542 .16976 L
.27728 .17093 L
.27914 .17209 L
.28101 .17326 L
.28287 .17443 L
.28474 .17571 L
.2866 .17688 L
.28846 .17804 L
.29033 .17921 L
.29219 .18038 L
.29405 .18155 L
.29592 .18272 L
.29778 .184 L
.29965 .18516 L
.30151 .18633 L
Mistroke
.30337 .1875 L
.30524 .18878 L
.3071 .18984 L
.30896 .19101 L
.31083 .19218 L
.31269 .19335 L
.31456 .19462 L
.31642 .19579 L
.31828 .19696 L
.32015 .19813 L
.32201 .19919 L
.32387 .20036 L
.32574 .20153 L
.3276 .2028 L
.32947 .20397 L
.33133 .20514 L
.33319 .20631 L
.33506 .20759 L
.33692 .20865 L
.33878 .20982 L
.34065 .21099 L
.34251 .21216 L
.34438 .21343 L
.34624 .2146 L
.3481 .21577 L
.34997 .21694 L
.35183 .21789 L
.35369 .21906 L
.35556 .22023 L
.35742 .2214 L
.35929 .22257 L
.36115 .22385 L
.36301 .22501 L
.36488 .22618 L
.36674 .22725 L
.3686 .22841 L
.37047 .22958 L
.37233 .23075 L
.3742 .23192 L
.37606 .23309 L
.37792 .23426 L
.37979 .23543 L
.38165 .23628 L
.38352 .23745 L
.38538 .23862 L
.38724 .23979 L
.38911 .24095 L
.39097 .24212 L
.39283 .24329 L
.3947 .24446 L
Mistroke
.39656 .24552 L
.39843 .24669 L
.40029 .24786 L
.40215 .24903 L
.40402 .25031 L
.40588 .25147 L
.40774 .25264 L
.40961 .25381 L
.41147 .25477 L
.41334 .25594 L
.4152 .25711 L
.41706 .25828 L
.41893 .25944 L
.42079 .26061 L
.42265 .26178 L
.42452 .26295 L
.42638 .26401 L
.42825 .26518 L
.43011 .26635 L
.43197 .26752 L
.43384 .26869 L
.4357 .26986 L
.43756 .27103 L
.43943 .2722 L
.44129 .27294 L
.44316 .274 L
.44502 .27517 L
.44688 .27634 L
.44875 .27751 L
.45061 .27878 L
.45247 .27995 L
.45434 .28112 L
.4562 .28208 L
.45807 .28325 L
.45993 .28442 L
.46179 .28559 L
.46366 .28675 L
.46552 .28792 L
.46738 .28909 L
.46925 .29026 L
.47111 .29122 L
.47298 .29239 L
.47484 .29356 L
.4767 .29472 L
.47857 .29589 L
.48043 .29706 L
.48229 .29823 L
.48416 .2994 L
.48602 .30036 L
.48789 .30153 L
Mistroke
.48975 .30269 L
.49161 .30386 L
.49348 .30503 L
.49534 .3062 L
.4972 .30737 L
.49907 .30865 L
.50093 .30907 L
.5028 .31024 L
.50466 .31151 L
.50652 .31268 L
.50839 .31385 L
.51025 .31502 L
.51211 .31619 L
.51398 .31736 L
.51584 .31853 L
.51771 .3197 L
.51957 .32087 L
.52143 .32203 L
.5233 .3232 L
.52516 .32437 L
.52702 .32554 L
.52889 .32682 L
.53075 .32788 L
.53262 .32905 L
.53448 .33022 L
.53634 .33139 L
.53821 .33255 L
.54007 .33372 L
.54193 .33489 L
.5438 .33606 L
.54566 .33723 L
.54753 .3384 L
.54939 .33957 L
.55125 .34074 L
.55312 .34191 L
.55498 .34308 L
.55684 .34424 L
.55871 .34541 L
.56057 .34626 L
.56244 .34743 L
.5643 .3486 L
.56616 .34977 L
.56803 .35104 L
.56989 .35221 L
.57175 .35338 L
.57362 .35455 L
.57548 .35561 L
.57735 .35678 L
.57921 .35795 L
.58107 .35912 L
Mistroke
.58294 .36029 L
.5848 .36146 L
.58666 .36263 L
.58853 .3638 L
.59039 .36475 L
.59226 .36592 L
.59412 .36709 L
.59598 .36826 L
.59785 .36943 L
.59971 .3706 L
.60157 .37177 L
.60344 .37294 L
.6053 .374 L
.60717 .37517 L
.60903 .37634 L
.61089 .37751 L
.61276 .37867 L
.61462 .37984 L
.61648 .38101 L
.61835 .38218 L
.62021 .38271 L
.62208 .38388 L
.62394 .38505 L
.6258 .38622 L
.62767 .38749 L
.62953 .38866 L
.6314 .38983 L
.63326 .391 L
.63512 .39206 L
.63699 .39323 L
.63885 .3944 L
.64071 .39557 L
.64258 .39674 L
.64444 .39791 L
.64631 .39908 L
.64817 .40035 L
.65003 .40131 L
.6519 .40248 L
.65376 .40365 L
.65562 .40482 L
.65749 .40598 L
.65935 .40726 L
.66122 .40843 L
.66308 .4096 L
.66494 .41066 L
.66681 .41183 L
.66867 .413 L
.67053 .41417 L
.6724 .41534 L
.67426 .4165 L
Mistroke
.67613 .41767 L
.67799 .41884 L
.67985 .41969 L
.68172 .42086 L
.68358 .42203 L
.68544 .4232 L
.68731 .42437 L
.68917 .42554 L
.69104 .42671 L
.6929 .42787 L
.69476 .42894 L
.69663 .43011 L
.69849 .43128 L
.70035 .43244 L
.70222 .43361 L
.70408 .43489 L
.70595 .43606 L
.70781 .43723 L
.70967 .43797 L
.71154 .43935 L
.7134 .44052 L
.71526 .44169 L
.71713 .44286 L
.71899 .44403 L
.72086 .4452 L
.72272 .44636 L
.72458 .44753 L
.72645 .4487 L
.72831 .44987 L
.73017 .45104 L
.73204 .45221 L
.7339 .45338 L
.73577 .45455 L
.73763 .45572 L
.73949 .45667 L
.74136 .45784 L
.74322 .45901 L
.74508 .46018 L
.74695 .46135 L
.74881 .46262 L
.75068 .46379 L
.75254 .46496 L
.7544 .46602 L
.75627 .46719 L
.75813 .46847 L
.75999 .46964 L
.76186 .47081 L
.76372 .47197 L
.76559 .47314 L
.76745 .47431 L
Mistroke
.76931 .47538 L
.77118 .47654 L
.77304 .47771 L
.7749 .47899 L
.77677 .48016 L
.77863 .48133 L
.7805 .4825 L
.78236 .48366 L
.78422 .48473 L
.78609 .4859 L
.78795 .48706 L
.78981 .48823 L
.79168 .48951 L
.79354 .49068 L
.79541 .49185 L
.79727 .49302 L
.79913 .49387 L
.801 .49503 L
.80286 .4962 L
.80472 .49737 L
.80659 .49854 L
.80845 .49982 L
.81032 .50099 L
.81218 .50215 L
.81404 .50322 L
.81591 .50439 L
.81777 .50555 L
.81963 .50672 L
.8215 .50789 L
.82336 .50906 L
.82523 .51023 L
.82709 .5114 L
.82895 .51236 L
.83082 .51352 L
.83268 .51469 L
.83454 .51586 L
.83641 .51703 L
.83827 .5182 L
.84014 .51937 L
.842 .52054 L
.84386 .5216 L
.84573 .52277 L
.84759 .52394 L
.84945 .52511 L
.85132 .52628 L
.85318 .52745 L
.85505 .52861 L
.85691 .52978 L
.85877 .53031 L
.86064 .53148 L
Mistroke
.8625 .53265 L
.86436 .53382 L
.86623 .5351 L
.86809 .53627 L
.86996 .53743 L
.87182 .5386 L
.87368 .53967 L
.87555 .54083 L
.87741 .542 L
.87927 .54317 L
.88114 .54445 L
.883 .54562 L
.88487 .54679 L
.88673 .54795 L
.88859 .54891 L
.89046 .55008 L
.89232 .55125 L
.89419 .55242 L
.89605 .55359 L
.89791 .55476 L
.89978 .55592 L
.90164 .5572 L
.9035 .55826 L
.90537 .55943 L
.90723 .5606 L
.9091 .56177 L
.91096 .56294 L
.91282 .56411 L
.91469 .56528 L
.91655 .56644 L
.91841 .56729 L
.92028 .56846 L
.92214 .56963 L
.92401 .5708 L
.92587 .57197 L
.92773 .57314 L
.9296 .57431 L
.93146 .57548 L
.93332 .57654 L
.93519 .57771 L
.93705 .57888 L
.93892 .58005 L
.94078 .58132 L
.94264 .58249 L
.94451 .58366 L
.94637 .58483 L
.94823 .58579 L
.9501 .58695 L
.95196 .58812 L
.95383 .58929 L
Mistroke
.95569 .59046 L
.95755 .59163 L
.95942 .5929 L
.96128 .59407 L
.96314 .59514 L
.96501 .59631 L
.96687 .59747 L
.96874 .59864 L
.9706 .59981 L
.97246 .60098 L
.97433 .60215 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{578.188, 357.375},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{57.1875, 518.688}, {474.875, 190}} -> {-173.527, \
21.0004, 1.12396, 0.109516}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Differential Non-Linearity", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"difftapdelay", ",", "\[IndentingNewLine]", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
   RowBox[{
   "PlotLabel", "\[Rule]", 
    "\"\<Delay Step as Function of Steps at 50 MHz\>\""}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Steps\>\"", ",", "\"\<\[CapitalDelta] Delay (ns)\>\""}], 
     "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0.08"}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", 
      RowBox[{"RGBColor", " ", "[", 
       RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "}"}]}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.44286822499*^9, 3.44286822670875*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00186376 9.1073e-018 7.72542 [
[.02381 -0.0125 -5.59375 -16.375 ]
[.02381 -0.0125 5.59375 0 ]
[.21019 -0.0125 -12.7813 -16.375 ]
[.21019 -0.0125 12.7813 0 ]
[.39656 -0.0125 -12.7813 -16.375 ]
[.39656 -0.0125 12.7813 0 ]
[.58294 -0.0125 -12.7813 -16.375 ]
[.58294 -0.0125 12.7813 0 ]
[.76931 -0.0125 -12.7813 -16.375 ]
[.76931 -0.0125 12.7813 0 ]
[.95569 -0.0125 -12.7813 -16.375 ]
[.95569 -0.0125 12.7813 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -18.5 -32.75 ]
[.5 -0.0125 18.5 -16.375 ]
[-0.0125 .07725 -29.125 -8.1875 ]
[-0.0125 .07725 0 8.1875 ]
[-0.0125 .15451 -29.125 -8.1875 ]
[-0.0125 .15451 0 8.1875 ]
[-0.0125 .23176 -29.125 -8.1875 ]
[-0.0125 .23176 0 8.1875 ]
[-0.0125 .30902 -29.125 -8.1875 ]
[-0.0125 .30902 0 8.1875 ]
[-0.0125 .38627 -29.125 -8.1875 ]
[-0.0125 .38627 0 8.1875 ]
[-0.0125 .46353 -29.125 -8.1875 ]
[-0.0125 .46353 0 8.1875 ]
[-0.0125 .54078 -29.125 -8.1875 ]
[-0.0125 .54078 0 8.1875 ]
[-0.0125 .61803 -29.125 -8.1875 ]
[-0.0125 .61803 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -45.5 -37.1875 ]
[-0.01875 .30902 -29.125 37.1875 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -125.563 0 ]
[.5 .63053 125.563 16.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.21019 0 m
.21019 .61803 L
s
.39656 0 m
.39656 .61803 L
s
.58294 0 m
.58294 .61803 L
s
.76931 0 m
.76931 .61803 L
s
0 .07725 m
1 .07725 L
s
0 .15451 m
1 .15451 L
s
0 .23176 m
1 .23176 L
s
0 .30902 m
1 .30902 L
s
0 .38627 m
1 .38627 L
s
0 .46353 m
1 .46353 L
s
0 .54078 m
1 .54078 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21019 0 m
.21019 .00625 L
s
gsave
.21019 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.39656 0 m
.39656 .00625 L
s
gsave
.39656 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.58294 0 m
.58294 .00625 L
s
gsave
.58294 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300) show
1.000 setlinewidth
grestore
.76931 0 m
.76931 .00625 L
s
gsave
.76931 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(400) show
1.000 setlinewidth
grestore
.95569 0 m
.95569 .00625 L
s
gsave
.95569 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
1.000 setlinewidth
grestore
.125 Mabswid
.06108 0 m
.06108 .00375 L
s
.09836 0 m
.09836 .00375 L
s
.13564 0 m
.13564 .00375 L
s
.17291 0 m
.17291 .00375 L
s
.24746 0 m
.24746 .00375 L
s
.28474 0 m
.28474 .00375 L
s
.32201 0 m
.32201 .00375 L
s
.35929 0 m
.35929 .00375 L
s
.43384 0 m
.43384 .00375 L
s
.47111 0 m
.47111 .00375 L
s
.50839 0 m
.50839 .00375 L
s
.54566 0 m
.54566 .00375 L
s
.62021 0 m
.62021 .00375 L
s
.65749 0 m
.65749 .00375 L
s
.69476 0 m
.69476 .00375 L
s
.73204 0 m
.73204 .00375 L
s
.80659 0 m
.80659 .00375 L
s
.84386 0 m
.84386 .00375 L
s
.88114 0 m
.88114 .00375 L
s
.91841 0 m
.91841 .00375 L
s
.99296 0 m
.99296 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -79.5 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Steps) show
96.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
gsave
-0.0125 .07725 -90.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
1.000 setlinewidth
grestore
0 .15451 m
.00625 .15451 L
s
gsave
-0.0125 .15451 -90.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
1.000 setlinewidth
grestore
0 .23176 m
.00625 .23176 L
s
gsave
-0.0125 .23176 -90.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.03) show
1.000 setlinewidth
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -90.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
1.000 setlinewidth
grestore
0 .38627 m
.00625 .38627 L
s
gsave
-0.0125 .38627 -90.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
0 .46353 m
.00625 .46353 L
s
gsave
-0.0125 .46353 -90.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
1.000 setlinewidth
grestore
0 .54078 m
.00625 .54078 L
s
gsave
-0.0125 .54078 -90.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.07) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -90.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -135.5 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
98.1875 12.1875 translate
90 rotate
-98.1875 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
74.813 16.625 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Delay) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.375 16.625 moveto
(H) show
115.563 16.625 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ns) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
129.188 16.625 moveto
(L) show
133.375 16.625 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21019 .61178 m
.21019 .61803 L
s
.39656 .61178 m
.39656 .61803 L
s
.58294 .61178 m
.58294 .61803 L
s
.76931 .61178 m
.76931 .61803 L
s
.95569 .61178 m
.95569 .61803 L
s
.125 Mabswid
.06108 .61428 m
.06108 .61803 L
s
.09836 .61428 m
.09836 .61803 L
s
.13564 .61428 m
.13564 .61803 L
s
.17291 .61428 m
.17291 .61803 L
s
.24746 .61428 m
.24746 .61803 L
s
.28474 .61428 m
.28474 .61803 L
s
.32201 .61428 m
.32201 .61803 L
s
.35929 .61428 m
.35929 .61803 L
s
.43384 .61428 m
.43384 .61803 L
s
.47111 .61428 m
.47111 .61803 L
s
.50839 .61428 m
.50839 .61803 L
s
.54566 .61428 m
.54566 .61803 L
s
.62021 .61428 m
.62021 .61803 L
s
.65749 .61428 m
.65749 .61803 L
s
.69476 .61428 m
.69476 .61803 L
s
.73204 .61428 m
.73204 .61803 L
s
.80659 .61428 m
.80659 .61803 L
s
.84386 .61428 m
.84386 .61803 L
s
.88114 .61428 m
.88114 .61803 L
s
.91841 .61428 m
.91841 .61803 L
s
.99296 .61428 m
.99296 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .07725 m
1 .07725 L
s
.99375 .15451 m
1 .15451 L
s
.99375 .23176 m
1 .23176 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .38627 m
1 .38627 L
s
.99375 .46353 m
1 .46353 L
s
.99375 .54078 m
1 .54078 L
s
.125 Mabswid
.99625 .01545 m
1 .01545 L
s
.99625 .0309 m
1 .0309 L
s
.99625 .04635 m
1 .04635 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .10816 m
1 .10816 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .13906 m
1 .13906 L
s
.99625 .16996 m
1 .16996 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .20086 m
1 .20086 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26266 m
1 .26266 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .29357 m
1 .29357 L
s
.99625 .32447 m
1 .32447 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .35537 m
1 .35537 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .41717 m
1 .41717 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .44807 m
1 .44807 L
s
.99625 .47898 m
1 .47898 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .50988 m
1 .50988 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57168 m
1 .57168 L
s
.99625 .58713 m
1 .58713 L
s
.99625 .60258 m
1 .60258 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -186.563 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Delay) show
99.563 16.625 moveto
(Step) show
129.688 16.625 moveto
(as) show
146.875 16.625 moveto
(Function) show
200.000 16.625 moveto
(of) show
214.813 16.625 moveto
(Steps) show
251.375 16.625 moveto
(at) show
265.688 16.625 moveto
(50) show
283.625 16.625 moveto
(MHz) show
310.125 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.007 w
.02567 .51503 m
.02754 .42919 L
.0294 .51503 L
.03126 .47211 L
.03313 .47211 L
.03499 .51503 L
.03686 .47211 L
.03872 .47211 L
.04058 .47211 L
.04245 .47211 L
.04431 .47211 L
.04617 .51503 L
.04804 .47211 L
.0499 .47211 L
.05177 .47211 L
.05363 .47211 L
.05549 .47211 L
.05736 .47211 L
.05922 .47211 L
.06108 .47211 L
.06295 .47211 L
.06481 .47211 L
.06668 .51503 L
.06854 .42919 L
.0704 .47211 L
.07227 .47211 L
.07413 .47211 L
.07599 .47211 L
.07786 .47211 L
.07972 .47211 L
.08159 .51503 L
.08345 .34335 L
.08531 .47211 L
.08718 .47211 L
.08904 .51503 L
.0909 .47211 L
.09277 .47211 L
.09463 .47211 L
.0965 .47211 L
.09836 .42919 L
.10022 .47211 L
.10209 .47211 L
.10395 .47211 L
.10581 .47211 L
.10768 .47211 L
.10954 .47211 L
.11141 .47211 L
.11327 .34335 L
.11513 .47211 L
.117 .47211 L
Mistroke
.11886 .47211 L
.12073 .47211 L
.12259 .47211 L
.12445 .47211 L
.12632 .47211 L
.12818 .38627 L
.13004 .47211 L
.13191 .47211 L
.13377 .47211 L
.13564 .47211 L
.1375 .47211 L
.13936 .47211 L
.14123 .47211 L
.14309 .17168 L
.14495 .47211 L
.14682 .47211 L
.14868 .47211 L
.15055 .47211 L
.15241 .47211 L
.15427 .47211 L
.15614 .47211 L
.158 .42919 L
.15986 .47211 L
.16173 .47211 L
.16359 .47211 L
.16546 .47211 L
.16732 .47211 L
.16918 .47211 L
.17105 .47211 L
.17291 .34335 L
.17477 .47211 L
.17664 .47211 L
.1785 .47211 L
.18037 .47211 L
.18223 .47211 L
.18409 .47211 L
.18596 .47211 L
.18782 .42919 L
.18968 .47211 L
.19155 .47211 L
.19341 .47211 L
.19528 .47211 L
.19714 .47211 L
.199 .47211 L
.20087 .47211 L
.20273 .25751 L
.20459 .47211 L
.20646 .47211 L
.20832 .47211 L
.21019 .47211 L
Mistroke
.21205 .47211 L
.21391 .47211 L
.21578 .47211 L
.21764 .42919 L
.2195 .47211 L
.22137 .47211 L
.22323 .47211 L
.2251 .47211 L
.22696 .47211 L
.22882 .47211 L
.23069 .51503 L
.23255 .38627 L
.23441 .47211 L
.23628 .47211 L
.23814 .47211 L
.24001 .47211 L
.24187 .47211 L
.24373 .47211 L
.2456 .47211 L
.24746 .47211 L
.24932 .47211 L
.25119 .47211 L
.25305 .47211 L
.25492 .47211 L
.25678 .47211 L
.25864 .47211 L
.26051 .47211 L
.26237 .30043 L
.26423 .47211 L
.2661 .47211 L
.26796 .47211 L
.26983 .51503 L
.27169 .47211 L
.27355 .47211 L
.27542 .47211 L
.27728 .47211 L
.27914 .47211 L
.28101 .47211 L
.28287 .47211 L
.28474 .51503 L
.2866 .47211 L
.28846 .47211 L
.29033 .47211 L
.29219 .47211 L
.29405 .47211 L
.29592 .47211 L
.29778 .51503 L
.29965 .47211 L
.30151 .47211 L
.30337 .47211 L
Mistroke
.30524 .51503 L
.3071 .42919 L
.30896 .47211 L
.31083 .47211 L
.31269 .47211 L
.31456 .51503 L
.31642 .47211 L
.31828 .47211 L
.32015 .47211 L
.32201 .42919 L
.32387 .47211 L
.32574 .47211 L
.3276 .51503 L
.32947 .47211 L
.33133 .47211 L
.33319 .47211 L
.33506 .51503 L
.33692 .42919 L
.33878 .47211 L
.34065 .47211 L
.34251 .47211 L
.34438 .51503 L
.34624 .47211 L
.3481 .47211 L
.34997 .47211 L
.35183 .38627 L
.35369 .47211 L
.35556 .47211 L
.35742 .47211 L
.35929 .47211 L
.36115 .51503 L
.36301 .47211 L
.36488 .47211 L
.36674 .42919 L
.3686 .47211 L
.37047 .47211 L
.37233 .47211 L
.3742 .47211 L
.37606 .47211 L
.37792 .47211 L
.37979 .47211 L
.38165 .34335 L
.38352 .47211 L
.38538 .47211 L
.38724 .47211 L
.38911 .47211 L
.39097 .47211 L
.39283 .47211 L
.3947 .47211 L
.39656 .42919 L
Mistroke
.39843 .47211 L
.40029 .47211 L
.40215 .47211 L
.40402 .51503 L
.40588 .47211 L
.40774 .47211 L
.40961 .47211 L
.41147 .38627 L
.41334 .47211 L
.4152 .47211 L
.41706 .47211 L
.41893 .47211 L
.42079 .47211 L
.42265 .47211 L
.42452 .47211 L
.42638 .42919 L
.42825 .47211 L
.43011 .47211 L
.43197 .47211 L
.43384 .47211 L
.4357 .47211 L
.43756 .47211 L
.43943 .47211 L
.44129 .30043 L
.44316 .42919 L
.44502 .47211 L
.44688 .47211 L
.44875 .47211 L
.45061 .51503 L
.45247 .47211 L
.45434 .47211 L
.4562 .38627 L
.45807 .47211 L
.45993 .47211 L
.46179 .47211 L
.46366 .47211 L
.46552 .47211 L
.46738 .47211 L
.46925 .47211 L
.47111 .38627 L
.47298 .47211 L
.47484 .47211 L
.4767 .47211 L
.47857 .47211 L
.48043 .47211 L
.48229 .47211 L
.48416 .47211 L
.48602 .38627 L
.48789 .47211 L
.48975 .47211 L
Mistroke
.49161 .47211 L
.49348 .47211 L
.49534 .47211 L
.4972 .47211 L
.49907 .51503 L
.50093 .17168 L
.5028 .47211 L
.50466 .51503 L
.50652 .47211 L
.50839 .47211 L
.51025 .47211 L
.51211 .47211 L
.51398 .47211 L
.51584 .47211 L
.51771 .47211 L
.51957 .47211 L
.52143 .47211 L
.5233 .47211 L
.52516 .47211 L
.52702 .47211 L
.52889 .51503 L
.53075 .42919 L
.53262 .47211 L
.53448 .47211 L
.53634 .47211 L
.53821 .47211 L
.54007 .47211 L
.54193 .47211 L
.5438 .47211 L
.54566 .47211 L
.54753 .47211 L
.54939 .47211 L
.55125 .47211 L
.55312 .47211 L
.55498 .47211 L
.55684 .47211 L
.55871 .47211 L
.56057 .34335 L
.56244 .47211 L
.5643 .47211 L
.56616 .47211 L
.56803 .51503 L
.56989 .47211 L
.57175 .47211 L
.57362 .47211 L
.57548 .42919 L
.57735 .47211 L
.57921 .47211 L
.58107 .47211 L
.58294 .47211 L
Mistroke
.5848 .47211 L
.58666 .47211 L
.58853 .47211 L
.59039 .38627 L
.59226 .47211 L
.59412 .47211 L
.59598 .47211 L
.59785 .47211 L
.59971 .47211 L
.60157 .47211 L
.60344 .47211 L
.6053 .42919 L
.60717 .47211 L
.60903 .47211 L
.61089 .47211 L
.61276 .47211 L
.61462 .47211 L
.61648 .47211 L
.61835 .47211 L
.62021 .2146 L
.62208 .47211 L
.62394 .47211 L
.6258 .47211 L
.62767 .51503 L
.62953 .47211 L
.6314 .47211 L
.63326 .47211 L
.63512 .42919 L
.63699 .47211 L
.63885 .47211 L
.64071 .47211 L
.64258 .47211 L
.64444 .47211 L
.64631 .47211 L
.64817 .51503 L
.65003 .38627 L
.6519 .47211 L
.65376 .47211 L
.65562 .47211 L
.65749 .47211 L
.65935 .51503 L
.66122 .47211 L
.66308 .47211 L
.66494 .42919 L
.66681 .47211 L
.66867 .47211 L
.67053 .47211 L
.6724 .47211 L
.67426 .47211 L
.67613 .47211 L
Mistroke
.67799 .47211 L
.67985 .34335 L
.68172 .47211 L
.68358 .47211 L
.68544 .47211 L
.68731 .47211 L
.68917 .47211 L
.69104 .47211 L
.6929 .47211 L
.69476 .42919 L
.69663 .47211 L
.69849 .47211 L
.70035 .47211 L
.70222 .47211 L
.70408 .51503 L
.70595 .47211 L
.70781 .47211 L
.70967 .30043 L
.71154 .55795 L
.7134 .47211 L
.71526 .47211 L
.71713 .47211 L
.71899 .47211 L
.72086 .47211 L
.72272 .47211 L
.72458 .47211 L
.72645 .47211 L
.72831 .47211 L
.73017 .47211 L
.73204 .47211 L
.7339 .47211 L
.73577 .47211 L
.73763 .47211 L
.73949 .38627 L
.74136 .47211 L
.74322 .47211 L
.74508 .47211 L
.74695 .47211 L
.74881 .51503 L
.75068 .47211 L
.75254 .47211 L
.7544 .42919 L
.75627 .47211 L
.75813 .51503 L
.75999 .47211 L
.76186 .47211 L
.76372 .47211 L
.76559 .47211 L
.76745 .47211 L
.76931 .42919 L
Mistroke
.77118 .47211 L
.77304 .47211 L
.7749 .51503 L
.77677 .47211 L
.77863 .47211 L
.7805 .47211 L
.78236 .47211 L
.78422 .42919 L
.78609 .47211 L
.78795 .47211 L
.78981 .47211 L
.79168 .51503 L
.79354 .47211 L
.79541 .47211 L
.79727 .47211 L
.79913 .34335 L
.801 .47211 L
.80286 .47211 L
.80472 .47211 L
.80659 .47211 L
.80845 .51503 L
.81032 .47211 L
.81218 .47211 L
.81404 .42919 L
.81591 .47211 L
.81777 .47211 L
.81963 .47211 L
.8215 .47211 L
.82336 .47211 L
.82523 .47211 L
.82709 .47211 L
.82895 .38627 L
.83082 .47211 L
.83268 .47211 L
.83454 .47211 L
.83641 .47211 L
.83827 .47211 L
.84014 .47211 L
.842 .47211 L
.84386 .42919 L
.84573 .47211 L
.84759 .47211 L
.84945 .47211 L
.85132 .47211 L
.85318 .47211 L
.85505 .47211 L
.85691 .47211 L
.85877 .2146 L
.86064 .47211 L
.8625 .47211 L
Mistroke
.86436 .47211 L
.86623 .51503 L
.86809 .47211 L
.86996 .47211 L
.87182 .47211 L
.87368 .42919 L
.87555 .47211 L
.87741 .47211 L
.87927 .47211 L
.88114 .51503 L
.883 .47211 L
.88487 .47211 L
.88673 .47211 L
.88859 .38627 L
.89046 .47211 L
.89232 .47211 L
.89419 .47211 L
.89605 .47211 L
.89791 .47211 L
.89978 .47211 L
.90164 .51503 L
.9035 .42919 L
.90537 .47211 L
.90723 .47211 L
.9091 .47211 L
.91096 .47211 L
.91282 .47211 L
.91469 .47211 L
.91655 .47211 L
.91841 .34335 L
.92028 .47211 L
.92214 .47211 L
.92401 .47211 L
.92587 .47211 L
.92773 .47211 L
.9296 .47211 L
.93146 .47211 L
.93332 .42919 L
.93519 .47211 L
.93705 .47211 L
.93892 .47211 L
.94078 .51503 L
.94264 .47211 L
.94451 .47211 L
.94637 .47211 L
.94823 .38627 L
.9501 .47211 L
.95196 .47211 L
.95383 .47211 L
.95569 .47211 L
Mistroke
.95755 .47211 L
.95942 .51503 L
.96128 .47211 L
.96314 .42919 L
.96501 .47211 L
.96687 .47211 L
.96874 .47211 L
.9706 .47211 L
.97246 .47211 L
.97433 .47211 L
.97619 .47211 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{575.813, 355.875},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{57.1875, 516.813}, {473.688, 190}} -> {-180.334, \
0.0541705, 1.12942, 0.000272474}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"dnldelay", ",", "\[IndentingNewLine]", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
   RowBox[{
   "PlotLabel", "\[Rule]", "\"\<Differential Non-Linearity at 50 MHz\>\""}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Steps\>\"", ",", "\"\<\[CapitalDelta] Delay (ns)\>\""}], 
     "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.06"}], ",", "0.06"}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", 
      RowBox[{"RGBColor", " ", "[", 
       RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "}"}]}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.442868230943125*^9, 3.44286823264625*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00186012 0.309017 5.15028 [
[.02381 -0.0125 -5.59375 -16.375 ]
[.02381 -0.0125 5.59375 0 ]
[.20982 -0.0125 -12.7813 -16.375 ]
[.20982 -0.0125 12.7813 0 ]
[.39583 -0.0125 -12.7813 -16.375 ]
[.39583 -0.0125 12.7813 0 ]
[.58185 -0.0125 -12.7813 -16.375 ]
[.58185 -0.0125 12.7813 0 ]
[.76786 -0.0125 -12.7813 -16.375 ]
[.76786 -0.0125 12.7813 0 ]
[.95387 -0.0125 -12.7813 -16.375 ]
[.95387 -0.0125 12.7813 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -18.5 -32.75 ]
[.5 -0.0125 18.5 -16.375 ]
[-0.0125 .10301 -38.125 -8.1875 ]
[-0.0125 .10301 0 8.1875 ]
[-0.0125 .20601 -38.125 -8.1875 ]
[-0.0125 .20601 0 8.1875 ]
[-0.0125 .30902 -11.1875 -8.1875 ]
[-0.0125 .30902 0 8.1875 ]
[-0.0125 .41202 -29.125 -8.1875 ]
[-0.0125 .41202 0 8.1875 ]
[-0.0125 .51503 -29.125 -8.1875 ]
[-0.0125 .51503 0 8.1875 ]
[-0.0125 .61803 -29.125 -8.1875 ]
[-0.0125 .61803 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -54.5 -37.1875 ]
[-0.01875 .30902 -38.125 37.1875 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -106.25 0 ]
[.5 .63053 106.25 16.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.20982 0 m
.20982 .61803 L
s
.39583 0 m
.39583 .61803 L
s
.58185 0 m
.58185 .61803 L
s
.76786 0 m
.76786 .61803 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.20982 0 m
.20982 .00625 L
s
gsave
.20982 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.39583 0 m
.39583 .00625 L
s
gsave
.39583 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.58185 0 m
.58185 .00625 L
s
gsave
.58185 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300) show
1.000 setlinewidth
grestore
.76786 0 m
.76786 .00625 L
s
gsave
.76786 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(400) show
1.000 setlinewidth
grestore
.95387 0 m
.95387 .00625 L
s
gsave
.95387 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
1.000 setlinewidth
grestore
.125 Mabswid
.06101 0 m
.06101 .00375 L
s
.09821 0 m
.09821 .00375 L
s
.13542 0 m
.13542 .00375 L
s
.17262 0 m
.17262 .00375 L
s
.24702 0 m
.24702 .00375 L
s
.28423 0 m
.28423 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.35863 0 m
.35863 .00375 L
s
.43304 0 m
.43304 .00375 L
s
.47024 0 m
.47024 .00375 L
s
.50744 0 m
.50744 .00375 L
s
.54464 0 m
.54464 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65625 0 m
.65625 .00375 L
s
.69345 0 m
.69345 .00375 L
s
.73065 0 m
.73065 .00375 L
s
.80506 0 m
.80506 .00375 L
s
.84226 0 m
.84226 .00375 L
s
.87946 0 m
.87946 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.99107 0 m
.99107 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -79.5 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Steps) show
96.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
gsave
-0.0125 .10301 -99.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
1.000 setlinewidth
grestore
0 .20601 m
.00625 .20601 L
s
gsave
-0.0125 .20601 -99.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
1.000 setlinewidth
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .41202 m
.00625 .41202 L
s
gsave
-0.0125 .41202 -90.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
1.000 setlinewidth
grestore
0 .51503 m
.00625 .51503 L
s
gsave
-0.0125 .51503 -90.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -90.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02575 m
.00375 .02575 L
s
0 .0515 m
.00375 .0515 L
s
0 .07725 m
.00375 .07725 L
s
0 .12876 m
.00375 .12876 L
s
0 .15451 m
.00375 .15451 L
s
0 .18026 m
.00375 .18026 L
s
0 .23176 m
.00375 .23176 L
s
0 .25751 m
.00375 .25751 L
s
0 .28327 m
.00375 .28327 L
s
0 .33477 m
.00375 .33477 L
s
0 .36052 m
.00375 .36052 L
s
0 .38627 m
.00375 .38627 L
s
0 .43777 m
.00375 .43777 L
s
0 .46353 m
.00375 .46353 L
s
0 .48928 m
.00375 .48928 L
s
0 .54078 m
.00375 .54078 L
s
0 .56653 m
.00375 .56653 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -144.5 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
98.1875 12.1875 translate
90 rotate
-98.1875 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
74.813 16.625 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Delay) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.375 16.625 moveto
(H) show
115.563 16.625 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ns) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
129.188 16.625 moveto
(L) show
133.375 16.625 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.20982 .61178 m
.20982 .61803 L
s
.39583 .61178 m
.39583 .61803 L
s
.58185 .61178 m
.58185 .61803 L
s
.76786 .61178 m
.76786 .61803 L
s
.95387 .61178 m
.95387 .61803 L
s
.125 Mabswid
.06101 .61428 m
.06101 .61803 L
s
.09821 .61428 m
.09821 .61803 L
s
.13542 .61428 m
.13542 .61803 L
s
.17262 .61428 m
.17262 .61803 L
s
.24702 .61428 m
.24702 .61803 L
s
.28423 .61428 m
.28423 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.35863 .61428 m
.35863 .61803 L
s
.43304 .61428 m
.43304 .61803 L
s
.47024 .61428 m
.47024 .61803 L
s
.50744 .61428 m
.50744 .61803 L
s
.54464 .61428 m
.54464 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.65625 .61428 m
.65625 .61803 L
s
.69345 .61428 m
.69345 .61803 L
s
.73065 .61428 m
.73065 .61803 L
s
.80506 .61428 m
.80506 .61803 L
s
.84226 .61428 m
.84226 .61803 L
s
.87946 .61428 m
.87946 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.99107 .61428 m
.99107 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .10301 m
1 .10301 L
s
.99375 .20601 m
1 .20601 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .41202 m
1 .41202 L
s
.99375 .51503 m
1 .51503 L
s
.125 Mabswid
.99625 .02575 m
1 .02575 L
s
.99625 .0515 m
1 .0515 L
s
.99625 .07725 m
1 .07725 L
s
.99625 .12876 m
1 .12876 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18026 m
1 .18026 L
s
.99625 .23176 m
1 .23176 L
s
.99625 .25751 m
1 .25751 L
s
.99625 .28327 m
1 .28327 L
s
.99625 .33477 m
1 .33477 L
s
.99625 .36052 m
1 .36052 L
s
.99625 .38627 m
1 .38627 L
s
.99625 .43777 m
1 .43777 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .48928 m
1 .48928 L
s
.99625 .54078 m
1 .54078 L
s
.99625 .56653 m
1 .56653 L
s
.99625 .59228 m
1 .59228 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
gsave
.5 .63053 -167.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Differential) show
128.313 16.625 moveto
(Non) show
152.063 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
160.438 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Linearity) show
212.750 16.625 moveto
(at) show
227.063 16.625 moveto
(50) show
245.000 16.625 moveto
(MHz) show
271.500 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.007 w
.02567 .30902 m
.02753 .27577 L
.02939 .29974 L
.03125 .26649 L
.03311 .26185 L
.03497 .25721 L
.03683 .22396 L
.03869 .21933 L
.04055 .21469 L
.04241 .21005 L
.04427 .20541 L
.04613 .20078 L
.04799 .16752 L
.04985 .16289 L
.05171 .15825 L
.05357 .15361 L
.05543 .14897 L
.05729 .14434 L
.05915 .1397 L
.06101 .13506 L
.06287 .13042 L
.06473 .12578 L
.06659 .12115 L
.06845 .0879 L
.07031 .11187 L
.07217 .10723 L
.07403 .10259 L
.07589 .09796 L
.07775 .09332 L
.07961 .08868 L
.08147 .08404 L
.08333 .05079 L
.08519 .13199 L
.08705 .12735 L
.08891 .12272 L
.09077 .08947 L
.09263 .08483 L
.09449 .08019 L
.09635 .07555 L
.09821 .07091 L
.10007 .09489 L
.10193 .09025 L
.10379 .08561 L
.10565 .08098 L
.10751 .07634 L
.10938 .0717 L
.11124 .06706 L
.1131 .06242 L
.11496 .14362 L
.11682 .13899 L
Mistroke
.11868 .13435 L
.12054 .12971 L
.1224 .12507 L
.12426 .12044 L
.12612 .1158 L
.12798 .11116 L
.12984 .16375 L
.1317 .15911 L
.13356 .15447 L
.13542 .14983 L
.13728 .1452 L
.13914 .14056 L
.141 .13592 L
.14286 .13128 L
.14472 .32693 L
.14658 .3223 L
.14844 .31766 L
.1503 .31302 L
.15216 .30838 L
.15402 .30374 L
.15588 .29911 L
.15774 .29447 L
.1596 .31844 L
.16146 .31381 L
.16332 .30917 L
.16518 .30453 L
.16704 .29989 L
.1689 .29525 L
.17076 .29062 L
.17262 .28598 L
.17448 .36718 L
.17634 .36254 L
.1782 .3579 L
.18006 .35326 L
.18192 .34863 L
.18378 .34399 L
.18564 .33935 L
.1875 .33471 L
.18936 .35869 L
.19122 .35405 L
.19308 .34941 L
.19494 .34477 L
.1968 .34014 L
.19866 .3355 L
.20052 .33086 L
.20238 .32622 L
.20424 .46465 L
.2061 .46001 L
.20796 .45537 L
.20982 .45073 L
Mistroke
.21168 .4461 L
.21354 .44146 L
.2154 .43682 L
.21726 .43218 L
.21912 .45616 L
.22098 .45152 L
.22284 .44688 L
.2247 .44224 L
.22656 .43761 L
.22842 .43297 L
.23028 .42833 L
.23214 .39508 L
.234 .44767 L
.23586 .44303 L
.23772 .43839 L
.23958 .43375 L
.24144 .42912 L
.2433 .42448 L
.24516 .41984 L
.24702 .4152 L
.24888 .41056 L
.25074 .40593 L
.2526 .40129 L
.25446 .39665 L
.25632 .39201 L
.25818 .38738 L
.26004 .38274 L
.2619 .3781 L
.26376 .48791 L
.26563 .48327 L
.26749 .47864 L
.26935 .474 L
.27121 .44075 L
.27307 .43611 L
.27493 .43147 L
.27679 .42683 L
.27865 .4222 L
.28051 .41756 L
.28237 .41292 L
.28423 .40828 L
.28609 .37503 L
.28795 .3704 L
.28981 .36576 L
.29167 .36112 L
.29353 .35648 L
.29539 .35184 L
.29725 .34721 L
.29911 .31396 L
.30097 .30932 L
.30283 .30468 L
Mistroke
.30469 .30004 L
.30655 .26679 L
.30841 .29077 L
.31027 .28613 L
.31213 .28149 L
.31399 .27685 L
.31585 .2436 L
.31771 .23896 L
.31957 .23433 L
.32143 .22969 L
.32329 .25366 L
.32515 .24903 L
.32701 .24439 L
.32887 .21114 L
.33073 .2065 L
.33259 .20186 L
.33445 .19722 L
.33631 .16397 L
.33817 .18795 L
.34003 .18331 L
.34189 .17867 L
.34375 .17403 L
.34561 .14078 L
.34747 .13615 L
.34933 .13151 L
.35119 .12687 L
.35305 .17946 L
.35491 .17482 L
.35677 .17018 L
.35863 .16554 L
.36049 .16091 L
.36235 .12766 L
.36421 .12302 L
.36607 .11838 L
.36793 .14235 L
.36979 .13772 L
.37165 .13308 L
.37351 .12844 L
.37537 .1238 L
.37723 .11916 L
.37909 .11453 L
.38095 .10989 L
.38281 .19109 L
.38467 .18645 L
.38653 .18181 L
.38839 .17718 L
.39025 .17254 L
.39211 .1679 L
.39397 .16326 L
.39583 .15862 L
Mistroke
.39769 .1826 L
.39955 .17796 L
.40141 .17332 L
.40327 .16869 L
.40513 .13543 L
.40699 .1308 L
.40885 .12616 L
.41071 .12152 L
.41257 .17411 L
.41443 .16947 L
.41629 .16483 L
.41815 .1602 L
.42001 .15556 L
.42188 .15092 L
.42374 .14628 L
.4256 .14164 L
.42746 .16562 L
.42932 .16098 L
.43118 .15634 L
.43304 .15171 L
.4349 .14707 L
.43676 .14243 L
.43862 .13779 L
.44048 .13315 L
.44234 .24297 L
.4442 .26694 L
.44606 .2623 L
.44792 .25767 L
.44978 .25303 L
.45164 .21978 L
.4535 .21514 L
.45536 .2105 L
.45722 .26309 L
.45908 .25845 L
.46094 .25381 L
.4628 .24918 L
.46466 .24454 L
.46652 .2399 L
.46838 .23526 L
.47024 .23062 L
.4721 .28321 L
.47396 .27857 L
.47582 .27394 L
.47768 .2693 L
.47954 .26466 L
.4814 .26002 L
.48326 .25538 L
.48512 .25075 L
.48698 .30333 L
.48884 .2987 L
Mistroke
.4907 .29406 L
.49256 .28942 L
.49442 .28478 L
.49628 .28014 L
.49814 .27551 L
.5 .24226 L
.50186 .43791 L
.50372 .43327 L
.50558 .40002 L
.50744 .39538 L
.5093 .39074 L
.51116 .3861 L
.51302 .38147 L
.51488 .37683 L
.51674 .37219 L
.5186 .36755 L
.52046 .36292 L
.52232 .35828 L
.52418 .35364 L
.52604 .349 L
.5279 .34436 L
.52976 .31111 L
.53162 .33509 L
.53348 .33045 L
.53534 .32581 L
.5372 .32117 L
.53906 .31654 L
.54092 .3119 L
.54278 .30726 L
.54464 .30262 L
.5465 .29799 L
.54836 .29335 L
.55022 .28871 L
.55208 .28407 L
.55394 .27943 L
.5558 .2748 L
.55766 .27016 L
.55952 .26552 L
.56138 .34672 L
.56324 .34208 L
.5651 .33744 L
.56696 .33281 L
.56882 .29956 L
.57068 .29492 L
.57254 .29028 L
.5744 .28564 L
.57626 .30962 L
.57813 .30498 L
.57999 .30034 L
.58185 .2957 L
Mistroke
.58371 .29107 L
.58557 .28643 L
.58743 .28179 L
.58929 .27715 L
.59115 .32974 L
.59301 .3251 L
.59487 .32046 L
.59673 .31583 L
.59859 .31119 L
.60045 .30655 L
.60231 .30191 L
.60417 .29728 L
.60603 .32125 L
.60789 .31661 L
.60975 .31197 L
.61161 .30734 L
.61347 .3027 L
.61533 .29806 L
.61719 .29342 L
.61905 .28878 L
.62091 .45582 L
.62277 .45119 L
.62463 .44655 L
.62649 .44191 L
.62835 .40866 L
.63021 .40402 L
.63207 .39938 L
.63393 .39475 L
.63579 .41872 L
.63765 .41408 L
.63951 .40944 L
.64137 .40481 L
.64323 .40017 L
.64509 .39553 L
.64695 .39089 L
.64881 .35764 L
.65067 .41023 L
.65253 .40559 L
.65439 .40095 L
.65625 .39632 L
.65811 .39168 L
.65997 .35843 L
.66183 .35379 L
.66369 .34915 L
.66555 .37313 L
.66741 .36849 L
.66927 .36385 L
.67113 .35921 L
.67299 .35458 L
.67485 .34994 L
Mistroke
.67671 .3453 L
.67857 .34066 L
.68043 .42186 L
.68229 .41722 L
.68415 .41259 L
.68601 .40795 L
.68787 .40331 L
.68973 .39867 L
.69159 .39404 L
.69345 .3894 L
.69531 .41337 L
.69717 .40873 L
.69903 .4041 L
.70089 .39946 L
.70275 .39482 L
.70461 .36157 L
.70647 .35693 L
.70833 .35229 L
.71019 .46211 L
.71205 .40024 L
.71391 .39561 L
.71577 .39097 L
.71763 .38633 L
.71949 .38169 L
.72135 .37705 L
.72321 .37242 L
.72507 .36778 L
.72693 .36314 L
.72879 .3585 L
.73065 .35387 L
.73251 .34923 L
.73438 .34459 L
.73624 .33995 L
.7381 .33531 L
.73996 .3879 L
.74182 .38326 L
.74368 .37863 L
.74554 .37399 L
.7474 .36935 L
.74926 .3361 L
.75112 .33146 L
.75298 .32682 L
.75484 .3508 L
.7567 .34616 L
.75856 .31291 L
.76042 .30827 L
.76228 .30363 L
.76414 .299 L
.766 .29436 L
.76786 .28972 L
Mistroke
.76972 .3137 L
.77158 .30906 L
.77344 .30442 L
.7753 .27117 L
.77716 .26653 L
.77902 .26189 L
.78088 .25726 L
.78274 .25262 L
.7846 .27659 L
.78646 .27195 L
.78832 .26732 L
.79018 .26268 L
.79204 .22943 L
.7939 .22479 L
.79576 .22015 L
.79762 .21551 L
.79948 .29671 L
.80134 .29208 L
.8032 .28744 L
.80506 .2828 L
.80692 .27816 L
.80878 .24491 L
.81064 .24028 L
.8125 .23564 L
.81436 .25961 L
.81622 .25497 L
.81808 .25034 L
.81994 .2457 L
.8218 .24106 L
.82366 .23642 L
.82552 .23178 L
.82738 .22715 L
.82924 .27973 L
.8311 .2751 L
.83296 .27046 L
.83482 .26582 L
.83668 .26118 L
.83854 .25655 L
.8404 .25191 L
.84226 .24727 L
.84412 .27124 L
.84598 .26661 L
.84784 .26197 L
.8497 .25733 L
.85156 .25269 L
.85342 .24805 L
.85528 .24342 L
.85714 .23878 L
.859 .40582 L
.86086 .40118 L
Mistroke
.86272 .39654 L
.86458 .3919 L
.86644 .35865 L
.8683 .35402 L
.87016 .34938 L
.87202 .34474 L
.87388 .36871 L
.87574 .36408 L
.8776 .35944 L
.87946 .3548 L
.88132 .32155 L
.88318 .31691 L
.88504 .31227 L
.8869 .30764 L
.88876 .36022 L
.89063 .35559 L
.89249 .35095 L
.89435 .34631 L
.89621 .34167 L
.89807 .33703 L
.89993 .3324 L
.90179 .29915 L
.90365 .32312 L
.90551 .31848 L
.90737 .31385 L
.90923 .30921 L
.91109 .30457 L
.91295 .29993 L
.91481 .29529 L
.91667 .29066 L
.91853 .37186 L
.92039 .36722 L
.92225 .36258 L
.92411 .35794 L
.92597 .35331 L
.92783 .34867 L
.92969 .34403 L
.93155 .33939 L
.93341 .36337 L
.93527 .35873 L
.93713 .35409 L
.93899 .34945 L
.94085 .3162 L
.94271 .31156 L
.94457 .30693 L
.94643 .30229 L
.94829 .35488 L
.95015 .35024 L
.95201 .3456 L
.95387 .34096 L
Mistroke
.95573 .33632 L
.95759 .33169 L
.95945 .29844 L
.96131 .2938 L
.96317 .31777 L
.96503 .31314 L
.96689 .3085 L
.96875 .30386 L
.97061 .29922 L
.97247 .29458 L
.97433 .28995 L
.97619 .28531 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{574.25, 354.938},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{57.1875, 515.563}, {437.063, 154.125}} -> {-186.237, \
0.00312883, 1.13512, 0.000409969}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot of Power Sweep", "Subtitle"],

Cell[CellGroupData[{

Cell["Insertion Loss as Function of Input Power", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"pwrdata", ",", "\[IndentingNewLine]", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
   RowBox[{
   "PlotLabel", "\[Rule]", 
    "\"\<Insertion Loss as Function of Input Power\>\""}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Input Power (dBm)\>\"", ",", "\"\<Insertion Loss (dB)\>\""}], 
     "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", 
      RowBox[{"RGBColor", " ", "[", 
       RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "}"}]}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.442868236193125*^9, 3.442868238099375*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.238431 0.0268276 0.934636 0.121362 [
[.10429 -0.0125 -10.0938 -16.375 ]
[.10429 -0.0125 10.0938 0 ]
[.23843 -0.0125 -5.59375 -16.375 ]
[.23843 -0.0125 5.59375 0 ]
[.37257 -0.0125 -5.59375 -16.375 ]
[.37257 -0.0125 5.59375 0 ]
[.50671 -0.0125 -9.1875 -16.375 ]
[.50671 -0.0125 9.1875 0 ]
[.64085 -0.0125 -9.1875 -16.375 ]
[.64085 -0.0125 9.1875 0 ]
[.77498 -0.0125 -9.1875 -16.375 ]
[.77498 -0.0125 9.1875 0 ]
[.90912 -0.0125 -9.1875 -16.375 ]
[.90912 -0.0125 9.1875 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -55.75 -32.75 ]
[.5 -0.0125 55.75 -16.375 ]
[-0.0125 .0851 -20.1875 -8.1875 ]
[-0.0125 .0851 0 8.1875 ]
[-0.0125 .20647 -20.1875 -8.1875 ]
[-0.0125 .20647 0 8.1875 ]
[-0.0125 .32783 -20.1875 -8.1875 ]
[-0.0125 .32783 0 8.1875 ]
[-0.0125 .44919 -20.1875 -8.1875 ]
[-0.0125 .44919 0 8.1875 ]
[-0.0125 .57055 -20.1875 -8.1875 ]
[-0.0125 .57055 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -56.0313 ]
[-0.01875 .30902 -20.1875 56.0313 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -120.969 0 ]
[.5 .63053 120.969 16.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.10429 0 m
.10429 .61803 L
s
.23843 0 m
.23843 .61803 L
s
.37257 0 m
.37257 .61803 L
s
.50671 0 m
.50671 .61803 L
s
.64085 0 m
.64085 .61803 L
s
.77498 0 m
.77498 .61803 L
s
.90912 0 m
.90912 .61803 L
s
0 .0851 m
1 .0851 L
s
0 .20647 m
1 .20647 L
s
0 .32783 m
1 .32783 L
s
0 .44919 m
1 .44919 L
s
0 .57055 m
1 .57055 L
s
0 g
.10429 0 m
.10429 .00625 L
s
gsave
.10429 -0.0125 -71.0938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.23843 0 m
.23843 .00625 L
s
gsave
.23843 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.37257 0 m
.37257 .00625 L
s
gsave
.37257 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.50671 0 m
.50671 .00625 L
s
gsave
.50671 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.64085 0 m
.64085 .00625 L
s
gsave
.64085 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.77498 0 m
.77498 .00625 L
s
gsave
.77498 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.90912 0 m
.90912 .00625 L
s
gsave
.90912 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
.13112 0 m
.13112 .00375 L
s
.15795 0 m
.15795 .00375 L
s
.18478 0 m
.18478 .00375 L
s
.2116 0 m
.2116 .00375 L
s
.26526 0 m
.26526 .00375 L
s
.29209 0 m
.29209 .00375 L
s
.31891 0 m
.31891 .00375 L
s
.34574 0 m
.34574 .00375 L
s
.3994 0 m
.3994 .00375 L
s
.42622 0 m
.42622 .00375 L
s
.45305 0 m
.45305 .00375 L
s
.47988 0 m
.47988 .00375 L
s
.53353 0 m
.53353 .00375 L
s
.56036 0 m
.56036 .00375 L
s
.58719 0 m
.58719 .00375 L
s
.61402 0 m
.61402 .00375 L
s
.66767 0 m
.66767 .00375 L
s
.6945 0 m
.6945 .00375 L
s
.72133 0 m
.72133 .00375 L
s
.74816 0 m
.74816 .00375 L
s
.80181 0 m
.80181 .00375 L
s
.82864 0 m
.82864 .00375 L
s
.85547 0 m
.85547 .00375 L
s
.88229 0 m
.88229 .00375 L
s
.07746 0 m
.07746 .00375 L
s
.05064 0 m
.05064 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93595 0 m
.93595 .00375 L
s
.96278 0 m
.96278 .00375 L
s
.9896 0 m
.9896 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -116.75 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Input) show
95.250 16.625 moveto
(Power) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.500 16.625 moveto
(H) show
139.688 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dBm) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
166.313 16.625 moveto
(L) show
170.500 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0851 m
.00625 .0851 L
s
gsave
-0.0125 .0851 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
0 .20647 m
.00625 .20647 L
s
gsave
-0.0125 .20647 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
0 .32783 m
.00625 .32783 L
s
gsave
-0.0125 .32783 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .44919 m
.00625 .44919 L
s
gsave
-0.0125 .44919 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .57055 m
.00625 .57055 L
s
gsave
-0.0125 .57055 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .10938 m
.00375 .10938 L
s
0 .13365 m
.00375 .13365 L
s
0 .15792 m
.00375 .15792 L
s
0 .18219 m
.00375 .18219 L
s
0 .23074 m
.00375 .23074 L
s
0 .25501 m
.00375 .25501 L
s
0 .27928 m
.00375 .27928 L
s
0 .30356 m
.00375 .30356 L
s
0 .3521 m
.00375 .3521 L
s
0 .37637 m
.00375 .37637 L
s
0 .40065 m
.00375 .40065 L
s
0 .42492 m
.00375 .42492 L
s
0 .47346 m
.00375 .47346 L
s
0 .49773 m
.00375 .49773 L
s
0 .52201 m
.00375 .52201 L
s
0 .54628 m
.00375 .54628 L
s
0 .06083 m
.00375 .06083 L
s
0 .03656 m
.00375 .03656 L
s
0 .01229 m
.00375 .01229 L
s
0 .59482 m
.00375 .59482 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -145.406 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
117.031 12.1875 translate
90 rotate
-117.031 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Insertion) show
116.063 16.625 moveto
(Loss) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
146.875 16.625 moveto
(H) show
151.063 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dB) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
166.875 16.625 moveto
(L) show
171.063 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.10429 .61178 m
.10429 .61803 L
s
.23843 .61178 m
.23843 .61803 L
s
.37257 .61178 m
.37257 .61803 L
s
.50671 .61178 m
.50671 .61803 L
s
.64085 .61178 m
.64085 .61803 L
s
.77498 .61178 m
.77498 .61803 L
s
.90912 .61178 m
.90912 .61803 L
s
.125 Mabswid
.13112 .61428 m
.13112 .61803 L
s
.15795 .61428 m
.15795 .61803 L
s
.18478 .61428 m
.18478 .61803 L
s
.2116 .61428 m
.2116 .61803 L
s
.26526 .61428 m
.26526 .61803 L
s
.29209 .61428 m
.29209 .61803 L
s
.31891 .61428 m
.31891 .61803 L
s
.34574 .61428 m
.34574 .61803 L
s
.3994 .61428 m
.3994 .61803 L
s
.42622 .61428 m
.42622 .61803 L
s
.45305 .61428 m
.45305 .61803 L
s
.47988 .61428 m
.47988 .61803 L
s
.53353 .61428 m
.53353 .61803 L
s
.56036 .61428 m
.56036 .61803 L
s
.58719 .61428 m
.58719 .61803 L
s
.61402 .61428 m
.61402 .61803 L
s
.66767 .61428 m
.66767 .61803 L
s
.6945 .61428 m
.6945 .61803 L
s
.72133 .61428 m
.72133 .61803 L
s
.74816 .61428 m
.74816 .61803 L
s
.80181 .61428 m
.80181 .61803 L
s
.82864 .61428 m
.82864 .61803 L
s
.85547 .61428 m
.85547 .61803 L
s
.88229 .61428 m
.88229 .61803 L
s
.07746 .61428 m
.07746 .61803 L
s
.05064 .61428 m
.05064 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.93595 .61428 m
.93595 .61803 L
s
.96278 .61428 m
.96278 .61803 L
s
.9896 .61428 m
.9896 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0851 m
1 .0851 L
s
.99375 .20647 m
1 .20647 L
s
.99375 .32783 m
1 .32783 L
s
.99375 .44919 m
1 .44919 L
s
.99375 .57055 m
1 .57055 L
s
.125 Mabswid
.99625 .10938 m
1 .10938 L
s
.99625 .13365 m
1 .13365 L
s
.99625 .15792 m
1 .15792 L
s
.99625 .18219 m
1 .18219 L
s
.99625 .23074 m
1 .23074 L
s
.99625 .25501 m
1 .25501 L
s
.99625 .27928 m
1 .27928 L
s
.99625 .30356 m
1 .30356 L
s
.99625 .3521 m
1 .3521 L
s
.99625 .37637 m
1 .37637 L
s
.99625 .40065 m
1 .40065 L
s
.99625 .42492 m
1 .42492 L
s
.99625 .47346 m
1 .47346 L
s
.99625 .49773 m
1 .49773 L
s
.99625 .52201 m
1 .52201 L
s
.99625 .54628 m
1 .54628 L
s
.99625 .06083 m
1 .06083 L
s
.99625 .03656 m
1 .03656 L
s
.99625 .01229 m
1 .01229 L
s
.99625 .59482 m
1 .59482 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .0851 m
1 .0851 L
s
.23843 0 m
.23843 .61803 L
s
gsave
.5 .63053 -181.969 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Insertion) show
116.063 16.625 moveto
(Loss) show
146.875 16.625 moveto
(as) show
164.063 16.625 moveto
(Function) show
217.188 16.625 moveto
(of) show
232.000 16.625 moveto
(Input) show
264.250 16.625 moveto
(Power) show
300.938 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 0 r
.007 w
.02381 .60332 m
.02649 .60332 L
.02918 .60211 L
.03186 .60332 L
.03454 .60211 L
.03722 .60332 L
.03991 .60211 L
.04259 .60211 L
.04527 .60211 L
.04795 .60211 L
.05064 .60211 L
.05332 .60211 L
.056 .60211 L
.05869 .60211 L
.06137 .60211 L
.06405 .60211 L
.06673 .60211 L
.06942 .60211 L
.0721 .60211 L
.07478 .60211 L
.07746 .60211 L
.08015 .60211 L
.08283 .60211 L
.08551 .60211 L
.0882 .60211 L
.09088 .60211 L
.09356 .60211 L
.09624 .60211 L
.09893 .60211 L
.10161 .60211 L
.10429 .60211 L
.10698 .60211 L
.10966 .60211 L
.11234 .60211 L
.11502 .60211 L
.11771 .60211 L
.12039 .60211 L
.12307 .60211 L
.12575 .60211 L
.12844 .60211 L
.13112 .60211 L
.1338 .60211 L
.13649 .60211 L
.13917 .60211 L
.14185 .60211 L
.14453 .60211 L
.14722 .60211 L
.1499 .60211 L
.15258 .60211 L
.15526 .60211 L
Mistroke
.15795 .60211 L
.16063 .60211 L
.16331 .60211 L
.166 .60211 L
.16868 .60211 L
.17136 .60211 L
.17404 .60211 L
.17673 .60211 L
.17941 .60211 L
.18209 .60211 L
.18478 .60211 L
.18746 .60211 L
.19014 .60211 L
.19282 .60211 L
.19551 .60211 L
.19819 .60211 L
.20087 .60211 L
.20355 .60211 L
.20624 .60211 L
.20892 .60211 L
.2116 .60211 L
.21429 .60211 L
.21697 .60211 L
.21965 .60211 L
.22233 .60211 L
.22502 .60211 L
.2277 .60211 L
.23038 .60211 L
.23307 .60211 L
.23575 .60211 L
.23843 .60211 L
.24111 .60211 L
.2438 .60211 L
.24648 .60211 L
.24916 .60089 L
.25184 .60211 L
.25453 .60211 L
.25721 .60089 L
.25989 .60089 L
.26258 .60089 L
.26526 .60089 L
.26794 .60089 L
.27062 .60089 L
.27331 .60089 L
.27599 .60089 L
.27867 .60089 L
.28135 .60089 L
.28404 .60089 L
.28672 .60089 L
.2894 .60089 L
Mistroke
.29209 .60089 L
.29477 .60089 L
.29745 .60089 L
.30013 .60089 L
.30282 .60089 L
.3055 .60089 L
.30818 .60089 L
.31087 .60089 L
.31355 .60089 L
.31623 .60089 L
.31891 .60089 L
.3216 .60089 L
.32428 .60089 L
.32696 .60089 L
.32964 .60089 L
.33233 .60089 L
.33501 .60089 L
.33769 .60089 L
.34038 .60089 L
.34306 .60089 L
.34574 .60089 L
.34842 .60089 L
.35111 .60089 L
.35379 .60089 L
.35647 .60089 L
.35915 .60089 L
.36184 .60089 L
.36452 .60089 L
.3672 .60089 L
.36989 .60089 L
.37257 .60089 L
.37525 .60089 L
.37793 .60089 L
.38062 .60089 L
.3833 .60089 L
.38598 .60089 L
.38867 .60089 L
.39135 .60089 L
.39403 .60089 L
.39671 .60089 L
.3994 .60089 L
.40208 .60089 L
.40476 .60089 L
.40744 .60089 L
.41013 .60089 L
.41281 .60089 L
.41549 .60089 L
.41818 .60089 L
.42086 .60089 L
.42354 .60089 L
Mistroke
.42622 .60089 L
.42891 .60089 L
.43159 .60089 L
.43427 .60089 L
.43696 .60089 L
.43964 .60089 L
.44232 .60089 L
.445 .60089 L
.44769 .60089 L
.45037 .60089 L
.45305 .60089 L
.45573 .60089 L
.45842 .60089 L
.4611 .60089 L
.46378 .60089 L
.46647 .60089 L
.46915 .60089 L
.47183 .60089 L
.47451 .60089 L
.4772 .60089 L
.47988 .60089 L
.48256 .60089 L
.48524 .60089 L
.48793 .60089 L
.49061 .60089 L
.49329 .60089 L
.49598 .60089 L
.49866 .60089 L
.50134 .60089 L
.50402 .60089 L
.50671 .60089 L
.50939 .59968 L
.51207 .59968 L
.51476 .59968 L
.51744 .59968 L
.52012 .59968 L
.5228 .59968 L
.52549 .59968 L
.52817 .59968 L
.53085 .59968 L
.53353 .59968 L
.53622 .59968 L
.5389 .59968 L
.54158 .59968 L
.54427 .59968 L
.54695 .59968 L
.54963 .59968 L
.55231 .59968 L
.555 .59968 L
.55768 .59968 L
Mistroke
.56036 .59968 L
.56304 .59968 L
.56573 .59968 L
.56841 .59968 L
.57109 .59968 L
.57378 .59968 L
.57646 .59968 L
.57914 .59968 L
.58182 .59968 L
.58451 .59968 L
.58719 .59968 L
.58987 .59968 L
.59256 .59968 L
.59524 .59968 L
.59792 .59968 L
.6006 .59968 L
.60329 .59968 L
.60597 .59968 L
.60865 .59968 L
.61133 .59968 L
.61402 .59968 L
.6167 .59968 L
.61938 .59968 L
.62207 .59968 L
.62475 .59968 L
.62743 .59968 L
.63011 .59968 L
.6328 .59968 L
.63548 .59968 L
.63816 .59968 L
.64085 .59968 L
.64353 .59968 L
.64621 .59968 L
.64889 .59968 L
.65158 .59968 L
.65426 .59968 L
.65694 .59968 L
.65962 .59968 L
.66231 .59968 L
.66499 .59968 L
.66767 .59968 L
.67036 .59968 L
.67304 .59968 L
.67572 .59968 L
.6784 .59968 L
.68109 .59968 L
.68377 .59968 L
.68645 .59968 L
.68913 .59968 L
.69182 .59968 L
Mistroke
.6945 .59968 L
.69718 .59968 L
.69987 .59968 L
.70255 .59968 L
.70523 .59968 L
.70791 .59968 L
.7106 .59968 L
.71328 .59968 L
.71596 .59968 L
.71865 .59968 L
.72133 .59968 L
.72401 .59968 L
.72669 .59968 L
.72938 .59968 L
.73206 .59968 L
.73474 .59968 L
.73742 .59968 L
.74011 .59968 L
.74279 .59968 L
.74547 .59968 L
.74816 .59968 L
.75084 .59968 L
.75352 .59968 L
.7562 .59846 L
.75889 .59846 L
.76157 .59846 L
.76425 .59846 L
.76693 .59846 L
.76962 .59846 L
.7723 .59846 L
.77498 .59846 L
.77767 .59846 L
.78035 .59846 L
.78303 .59725 L
.78571 .59725 L
.7884 .59604 L
.79108 .59482 L
.79376 .5924 L
.79645 .58754 L
.79913 .5839 L
.80181 .57905 L
.80449 .57419 L
.80718 .56812 L
.80986 .56206 L
.81254 .55477 L
.81522 .54871 L
.81791 .54264 L
.82059 .53536 L
.82327 .52807 L
.82596 .52079 L
Mistroke
.82864 .51351 L
.83132 .50623 L
.834 .49895 L
.83669 .49045 L
.83937 .48317 L
.84205 .47589 L
.84474 .46739 L
.84742 .4589 L
.8501 .4504 L
.85278 .44191 L
.85547 .4322 L
.85815 .4237 L
.86083 .41521 L
.86351 .4055 L
.8662 .397 L
.86888 .3873 L
.87156 .3788 L
.87425 .3703 L
.87693 .36181 L
.87961 .3521 L
.88229 .34361 L
.88498 .3339 L
.88766 .3254 L
.89034 .31569 L
.89302 .30598 L
.89571 .29749 L
.89839 .28778 L
.90107 .27686 L
.90376 .26836 L
.90644 .25865 L
.90912 .24894 L
.9118 .23923 L
.91449 .22831 L
.91717 .2186 L
.91985 .20889 L
.92254 .19797 L
.92522 .18826 L
.9279 .17977 L
.93058 .16884 L
.93327 .16035 L
.93595 .15064 L
.93863 .14093 L
.94131 .13001 L
.944 .12151 L
.94668 .11059 L
.94936 .1021 L
.95205 .09117 L
.95473 .08268 L
.95741 .07418 L
.96009 .06447 L
Mistroke
.96278 .05598 L
.96546 .04627 L
.96814 .03899 L
.97082 .03049 L
.97351 .02321 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{580.063, 358.5},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{57.1875, 520.188}, {513.125, 227.375}} -> {-20.0941, \
-3.47913, 0.0778063, 0.0171994}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"pwrdata", ",", "\[IndentingNewLine]", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
   RowBox[{
   "PlotLabel", "\[Rule]", 
    "\"\<Insertion Loss as Function of Input Power\>\""}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Input Power (dBm)\>\"", ",", "\"\<Insertion Loss (dB)\>\""}], 
     "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "3.0"}], ",", 
      RowBox[{"-", "2.6"}]}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", 
      RowBox[{"RGBColor", " ", "[", 
       RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "}"}]}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.442868242786875*^9, 3.442868244365*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.238431 0.0268276 4.63525 1.54508 [
[.10429 -0.0125 -10.0938 -16.375 ]
[.10429 -0.0125 10.0938 0 ]
[.23843 -0.0125 -5.59375 -16.375 ]
[.23843 -0.0125 5.59375 0 ]
[.37257 -0.0125 -5.59375 -16.375 ]
[.37257 -0.0125 5.59375 0 ]
[.50671 -0.0125 -9.1875 -16.375 ]
[.50671 -0.0125 9.1875 0 ]
[.64085 -0.0125 -9.1875 -16.375 ]
[.64085 -0.0125 9.1875 0 ]
[.77498 -0.0125 -9.1875 -16.375 ]
[.77498 -0.0125 9.1875 0 ]
[.90912 -0.0125 -9.1875 -16.375 ]
[.90912 -0.0125 9.1875 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -55.75 -32.75 ]
[.5 -0.0125 55.75 -16.375 ]
[-0.0125 .07725 -38.125 -8.1875 ]
[-0.0125 .07725 0 8.1875 ]
[-0.0125 .15451 -30.9375 -8.1875 ]
[-0.0125 .15451 0 8.1875 ]
[-0.0125 .23176 -38.125 -8.1875 ]
[-0.0125 .23176 0 8.1875 ]
[-0.0125 .30902 -30.9375 -8.1875 ]
[-0.0125 .30902 0 8.1875 ]
[-0.0125 .38627 -38.125 -8.1875 ]
[-0.0125 .38627 0 8.1875 ]
[-0.0125 .46353 -30.9375 -8.1875 ]
[-0.0125 .46353 0 8.1875 ]
[-0.0125 .54078 -38.125 -8.1875 ]
[-0.0125 .54078 0 8.1875 ]
[-0.0125 .61803 -30.9375 -8.1875 ]
[-0.0125 .61803 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -54.5 -56.0313 ]
[-0.01875 .30902 -38.125 56.0313 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -120.969 0 ]
[.5 .63053 120.969 16.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.10429 0 m
.10429 .61803 L
s
.23843 0 m
.23843 .61803 L
s
.37257 0 m
.37257 .61803 L
s
.50671 0 m
.50671 .61803 L
s
.64085 0 m
.64085 .61803 L
s
.77498 0 m
.77498 .61803 L
s
.90912 0 m
.90912 .61803 L
s
0 .07725 m
1 .07725 L
s
0 .15451 m
1 .15451 L
s
0 .23176 m
1 .23176 L
s
0 .30902 m
1 .30902 L
s
0 .38627 m
1 .38627 L
s
0 .46353 m
1 .46353 L
s
0 .54078 m
1 .54078 L
s
0 g
.10429 0 m
.10429 .00625 L
s
gsave
.10429 -0.0125 -71.0938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.23843 0 m
.23843 .00625 L
s
gsave
.23843 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.37257 0 m
.37257 .00625 L
s
gsave
.37257 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.50671 0 m
.50671 .00625 L
s
gsave
.50671 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.64085 0 m
.64085 .00625 L
s
gsave
.64085 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.77498 0 m
.77498 .00625 L
s
gsave
.77498 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.90912 0 m
.90912 .00625 L
s
gsave
.90912 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
.13112 0 m
.13112 .00375 L
s
.15795 0 m
.15795 .00375 L
s
.18478 0 m
.18478 .00375 L
s
.2116 0 m
.2116 .00375 L
s
.26526 0 m
.26526 .00375 L
s
.29209 0 m
.29209 .00375 L
s
.31891 0 m
.31891 .00375 L
s
.34574 0 m
.34574 .00375 L
s
.3994 0 m
.3994 .00375 L
s
.42622 0 m
.42622 .00375 L
s
.45305 0 m
.45305 .00375 L
s
.47988 0 m
.47988 .00375 L
s
.53353 0 m
.53353 .00375 L
s
.56036 0 m
.56036 .00375 L
s
.58719 0 m
.58719 .00375 L
s
.61402 0 m
.61402 .00375 L
s
.66767 0 m
.66767 .00375 L
s
.6945 0 m
.6945 .00375 L
s
.72133 0 m
.72133 .00375 L
s
.74816 0 m
.74816 .00375 L
s
.80181 0 m
.80181 .00375 L
s
.82864 0 m
.82864 .00375 L
s
.85547 0 m
.85547 .00375 L
s
.88229 0 m
.88229 .00375 L
s
.07746 0 m
.07746 .00375 L
s
.05064 0 m
.05064 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93595 0 m
.93595 .00375 L
s
.96278 0 m
.96278 .00375 L
s
.9896 0 m
.9896 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -116.75 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Input) show
95.250 16.625 moveto
(Power) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.500 16.625 moveto
(H) show
139.688 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dBm) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
166.313 16.625 moveto
(L) show
170.500 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
gsave
-0.0125 .07725 -99.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.95) show
1.000 setlinewidth
grestore
0 .15451 m
.00625 .15451 L
s
gsave
-0.0125 .15451 -91.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.9) show
1.000 setlinewidth
grestore
0 .23176 m
.00625 .23176 L
s
gsave
-0.0125 .23176 -99.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.85) show
1.000 setlinewidth
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -91.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
1.000 setlinewidth
grestore
0 .38627 m
.00625 .38627 L
s
gsave
-0.0125 .38627 -99.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.75) show
1.000 setlinewidth
grestore
0 .46353 m
.00625 .46353 L
s
gsave
-0.0125 .46353 -91.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.7) show
1.000 setlinewidth
grestore
0 .54078 m
.00625 .54078 L
s
gsave
-0.0125 .54078 -99.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.65) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -91.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -163.344 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
117.031 12.1875 translate
90 rotate
-117.031 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Insertion) show
116.063 16.625 moveto
(Loss) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
146.875 16.625 moveto
(H) show
151.063 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dB) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
166.875 16.625 moveto
(L) show
171.063 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.10429 .61178 m
.10429 .61803 L
s
.23843 .61178 m
.23843 .61803 L
s
.37257 .61178 m
.37257 .61803 L
s
.50671 .61178 m
.50671 .61803 L
s
.64085 .61178 m
.64085 .61803 L
s
.77498 .61178 m
.77498 .61803 L
s
.90912 .61178 m
.90912 .61803 L
s
.125 Mabswid
.13112 .61428 m
.13112 .61803 L
s
.15795 .61428 m
.15795 .61803 L
s
.18478 .61428 m
.18478 .61803 L
s
.2116 .61428 m
.2116 .61803 L
s
.26526 .61428 m
.26526 .61803 L
s
.29209 .61428 m
.29209 .61803 L
s
.31891 .61428 m
.31891 .61803 L
s
.34574 .61428 m
.34574 .61803 L
s
.3994 .61428 m
.3994 .61803 L
s
.42622 .61428 m
.42622 .61803 L
s
.45305 .61428 m
.45305 .61803 L
s
.47988 .61428 m
.47988 .61803 L
s
.53353 .61428 m
.53353 .61803 L
s
.56036 .61428 m
.56036 .61803 L
s
.58719 .61428 m
.58719 .61803 L
s
.61402 .61428 m
.61402 .61803 L
s
.66767 .61428 m
.66767 .61803 L
s
.6945 .61428 m
.6945 .61803 L
s
.72133 .61428 m
.72133 .61803 L
s
.74816 .61428 m
.74816 .61803 L
s
.80181 .61428 m
.80181 .61803 L
s
.82864 .61428 m
.82864 .61803 L
s
.85547 .61428 m
.85547 .61803 L
s
.88229 .61428 m
.88229 .61803 L
s
.07746 .61428 m
.07746 .61803 L
s
.05064 .61428 m
.05064 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.93595 .61428 m
.93595 .61803 L
s
.96278 .61428 m
.96278 .61803 L
s
.9896 .61428 m
.9896 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .07725 m
1 .07725 L
s
.99375 .15451 m
1 .15451 L
s
.99375 .23176 m
1 .23176 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .38627 m
1 .38627 L
s
.99375 .46353 m
1 .46353 L
s
.99375 .54078 m
1 .54078 L
s
.125 Mabswid
.99625 .01545 m
1 .01545 L
s
.99625 .0309 m
1 .0309 L
s
.99625 .04635 m
1 .04635 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .10816 m
1 .10816 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .13906 m
1 .13906 L
s
.99625 .16996 m
1 .16996 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .20086 m
1 .20086 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26266 m
1 .26266 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .29357 m
1 .29357 L
s
.99625 .32447 m
1 .32447 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .35537 m
1 .35537 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .41717 m
1 .41717 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .44807 m
1 .44807 L
s
.99625 .47898 m
1 .47898 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .50988 m
1 .50988 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57168 m
1 .57168 L
s
.99625 .58713 m
1 .58713 L
s
.99625 .60258 m
1 .60258 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.23843 0 m
.23843 .61803 L
s
gsave
.5 .63053 -181.969 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Insertion) show
116.063 16.625 moveto
(Loss) show
146.875 16.625 moveto
(as) show
164.063 16.625 moveto
(Function) show
217.188 16.625 moveto
(of) show
232.000 16.625 moveto
(Input) show
264.250 16.625 moveto
(Power) show
300.938 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.007 w
.02381 .41717 m
.02649 .41717 L
.02918 .40172 L
.03186 .41717 L
.03454 .40172 L
.03722 .41717 L
.03991 .40172 L
.04259 .40172 L
.04527 .40172 L
.04795 .40172 L
.05064 .40172 L
.05332 .40172 L
.056 .40172 L
.05869 .40172 L
.06137 .40172 L
.06405 .40172 L
.06673 .40172 L
.06942 .40172 L
.0721 .40172 L
.07478 .40172 L
.07746 .40172 L
.08015 .40172 L
.08283 .40172 L
.08551 .40172 L
.0882 .40172 L
.09088 .40172 L
.09356 .40172 L
.09624 .40172 L
.09893 .40172 L
.10161 .40172 L
.10429 .40172 L
.10698 .40172 L
.10966 .40172 L
.11234 .40172 L
.11502 .40172 L
.11771 .40172 L
.12039 .40172 L
.12307 .40172 L
.12575 .40172 L
.12844 .40172 L
.13112 .40172 L
.1338 .40172 L
.13649 .40172 L
.13917 .40172 L
.14185 .40172 L
.14453 .40172 L
.14722 .40172 L
.1499 .40172 L
.15258 .40172 L
.15526 .40172 L
Mistroke
.15795 .40172 L
.16063 .40172 L
.16331 .40172 L
.166 .40172 L
.16868 .40172 L
.17136 .40172 L
.17404 .40172 L
.17673 .40172 L
.17941 .40172 L
.18209 .40172 L
.18478 .40172 L
.18746 .40172 L
.19014 .40172 L
.19282 .40172 L
.19551 .40172 L
.19819 .40172 L
.20087 .40172 L
.20355 .40172 L
.20624 .40172 L
.20892 .40172 L
.2116 .40172 L
.21429 .40172 L
.21697 .40172 L
.21965 .40172 L
.22233 .40172 L
.22502 .40172 L
.2277 .40172 L
.23038 .40172 L
.23307 .40172 L
.23575 .40172 L
.23843 .40172 L
.24111 .40172 L
.2438 .40172 L
.24648 .40172 L
.24916 .38627 L
.25184 .40172 L
.25453 .40172 L
.25721 .38627 L
.25989 .38627 L
.26258 .38627 L
.26526 .38627 L
.26794 .38627 L
.27062 .38627 L
.27331 .38627 L
.27599 .38627 L
.27867 .38627 L
.28135 .38627 L
.28404 .38627 L
.28672 .38627 L
.2894 .38627 L
Mistroke
.29209 .38627 L
.29477 .38627 L
.29745 .38627 L
.30013 .38627 L
.30282 .38627 L
.3055 .38627 L
.30818 .38627 L
.31087 .38627 L
.31355 .38627 L
.31623 .38627 L
.31891 .38627 L
.3216 .38627 L
.32428 .38627 L
.32696 .38627 L
.32964 .38627 L
.33233 .38627 L
.33501 .38627 L
.33769 .38627 L
.34038 .38627 L
.34306 .38627 L
.34574 .38627 L
.34842 .38627 L
.35111 .38627 L
.35379 .38627 L
.35647 .38627 L
.35915 .38627 L
.36184 .38627 L
.36452 .38627 L
.3672 .38627 L
.36989 .38627 L
.37257 .38627 L
.37525 .38627 L
.37793 .38627 L
.38062 .38627 L
.3833 .38627 L
.38598 .38627 L
.38867 .38627 L
.39135 .38627 L
.39403 .38627 L
.39671 .38627 L
.3994 .38627 L
.40208 .38627 L
.40476 .38627 L
.40744 .38627 L
.41013 .38627 L
.41281 .38627 L
.41549 .38627 L
.41818 .38627 L
.42086 .38627 L
.42354 .38627 L
Mistroke
.42622 .38627 L
.42891 .38627 L
.43159 .38627 L
.43427 .38627 L
.43696 .38627 L
.43964 .38627 L
.44232 .38627 L
.445 .38627 L
.44769 .38627 L
.45037 .38627 L
.45305 .38627 L
.45573 .38627 L
.45842 .38627 L
.4611 .38627 L
.46378 .38627 L
.46647 .38627 L
.46915 .38627 L
.47183 .38627 L
.47451 .38627 L
.4772 .38627 L
.47988 .38627 L
.48256 .38627 L
.48524 .38627 L
.48793 .38627 L
.49061 .38627 L
.49329 .38627 L
.49598 .38627 L
.49866 .38627 L
.50134 .38627 L
.50402 .38627 L
.50671 .38627 L
.50939 .37082 L
.51207 .37082 L
.51476 .37082 L
.51744 .37082 L
.52012 .37082 L
.5228 .37082 L
.52549 .37082 L
.52817 .37082 L
.53085 .37082 L
.53353 .37082 L
.53622 .37082 L
.5389 .37082 L
.54158 .37082 L
.54427 .37082 L
.54695 .37082 L
.54963 .37082 L
.55231 .37082 L
.555 .37082 L
.55768 .37082 L
Mistroke
.56036 .37082 L
.56304 .37082 L
.56573 .37082 L
.56841 .37082 L
.57109 .37082 L
.57378 .37082 L
.57646 .37082 L
.57914 .37082 L
.58182 .37082 L
.58451 .37082 L
.58719 .37082 L
.58987 .37082 L
.59256 .37082 L
.59524 .37082 L
.59792 .37082 L
.6006 .37082 L
.60329 .37082 L
.60597 .37082 L
.60865 .37082 L
.61133 .37082 L
.61402 .37082 L
.6167 .37082 L
.61938 .37082 L
.62207 .37082 L
.62475 .37082 L
.62743 .37082 L
.63011 .37082 L
.6328 .37082 L
.63548 .37082 L
.63816 .37082 L
.64085 .37082 L
.64353 .37082 L
.64621 .37082 L
.64889 .37082 L
.65158 .37082 L
.65426 .37082 L
.65694 .37082 L
.65962 .37082 L
.66231 .37082 L
.66499 .37082 L
.66767 .37082 L
.67036 .37082 L
.67304 .37082 L
.67572 .37082 L
.6784 .37082 L
.68109 .37082 L
.68377 .37082 L
.68645 .37082 L
.68913 .37082 L
.69182 .37082 L
Mistroke
.6945 .37082 L
.69718 .37082 L
.69987 .37082 L
.70255 .37082 L
.70523 .37082 L
.70791 .37082 L
.7106 .37082 L
.71328 .37082 L
.71596 .37082 L
.71865 .37082 L
.72133 .37082 L
.72401 .37082 L
.72669 .37082 L
.72938 .37082 L
.73206 .37082 L
.73474 .37082 L
.73742 .37082 L
.74011 .37082 L
.74279 .37082 L
.74547 .37082 L
.74816 .37082 L
.75084 .37082 L
.75352 .37082 L
.7562 .35537 L
.75889 .35537 L
.76157 .35537 L
.76425 .35537 L
.76693 .35537 L
.76962 .35537 L
.7723 .35537 L
.77498 .35537 L
.77767 .35537 L
.78035 .35537 L
.78303 .33992 L
.78571 .33992 L
.7884 .32447 L
.79108 .30902 L
.79376 .27812 L
.79645 .21631 L
.79913 .16996 L
.80181 .10816 L
.80449 .04635 L
Mfstroke
.80449 .04635 m
.8061 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{579.938, 358.5},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{57.1875, 520.125}, {439.875, 154.125}} -> {-20.7889, \
-2.79207, 0.0778063, 0.00135097}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1017, 1036},
WindowMargins->{{84, Automatic}, {Automatic, 17}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
ShowSelection->True,
Magnification->1.25,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 41, 0, 103, "Title"],
Cell[634, 25, 112, 6, 108, "Subsubtitle"],
Cell[CellGroupData[{
Cell[771, 35, 40, 0, 62, "Subtitle"],
Cell[814, 37, 2389, 64, 262, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3240, 106, 34, 0, 62, "Subtitle"],
Cell[3277, 108, 2577, 78, 323, "Input"],
Cell[5857, 188, 45, 0, 58, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5939, 193, 25, 0, 62, "Subtitle"],
Cell[5967, 195, 405, 7, 102, "Input"],
Cell[6375, 204, 222, 6, 35, "Input"],
Cell[6600, 212, 1066, 29, 102, "Input"],
Cell[7669, 243, 528, 16, 102, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8234, 264, 31, 0, 62, "Subtitle"],
Cell[CellGroupData[{
Cell[8290, 268, 52, 0, 46, "Subsection"],
Cell[8345, 270, 4388, 142, 278, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12770, 417, 43, 0, 46, "Subsection"],
Cell[12816, 419, 368, 11, 80, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13221, 435, 43, 0, 46, "Subsection"],
Cell[13267, 437, 608, 18, 102, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13924, 461, 29, 0, 62, "Subtitle"],
Cell[13956, 463, 329, 11, 51, "Input"],
Cell[14288, 476, 1786, 48, 124, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16111, 529, 47, 0, 62, "Subtitle"],
Cell[16161, 531, 1129, 36, 140, "Input"],
Cell[17293, 569, 437, 12, 80, "Input"],
Cell[CellGroupData[{
Cell[17755, 585, 50, 0, 46, "Subsection"],
Cell[CellGroupData[{
Cell[17830, 589, 1072, 26, 146, "Input"],
Cell[18905, 617, 34376, 1474, 467, 27144, 1352, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[53330, 2097, 57, 0, 46, "Subsection"],
Cell[CellGroupData[{
Cell[53412, 2101, 4806, 124, 432, "Input"],
Cell[58221, 2227, 115050, 5781, 425, 96654, 5480, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[CellGroupData[{
Cell[173308, 8013, 3951, 103, 344, "Input"],
Cell[177262, 8118, 100787, 4976, 433, 82826, 4681, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[278098, 13100, 129, 3, 46, "Subsection"],
Cell[278230, 13105, 338, 11, 54, "Input"],
Cell[278571, 13118, 4097, 125, 314, "Input"],
Cell[CellGroupData[{
Cell[282693, 13247, 1971, 50, 212, "Input"],
Cell[284667, 13299, 228727, 6847, 423, 207511, 6498, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[513455, 20153, 38, 0, 62, "Subtitle"],
Cell[513496, 20155, 1010, 31, 136, "Input"],
Cell[514509, 20188, 437, 12, 80, "Input"],
Cell[CellGroupData[{
Cell[514971, 20204, 1338, 42, 142, "Input"],
Cell[516312, 20248, 324, 7, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[516673, 20260, 57, 0, 46, "Subsection"],
Cell[CellGroupData[{
Cell[516755, 20264, 1044, 26, 146, "Input"],
Cell[517802, 20292, 36263, 1700, 455, 30057, 1595, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[554114, 21998, 57, 0, 46, "Subsection"],
Cell[CellGroupData[{
Cell[554196, 22002, 4767, 123, 432, "Input"],
Cell[558966, 22127, 100345, 5696, 457, 94511, 5597, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[659372, 27830, 49, 0, 62, "Subtitle"],
Cell[CellGroupData[{
Cell[659446, 27834, 1826, 58, 184, "Input"],
Cell[661275, 27894, 48, 0, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[661360, 27899, 57, 0, 46, "Subsection"],
Cell[CellGroupData[{
Cell[661442, 27903, 952, 23, 146, "Input"],
Cell[662397, 27928, 41738, 1893, 458, 33728, 1758, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[704184, 29827, 54, 0, 46, "Subsection"],
Cell[CellGroupData[{
Cell[704263, 29831, 930, 22, 146, "Input"],
Cell[705196, 29855, 37613, 1739, 458, 31113, 1629, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[742858, 31600, 48, 0, 46, "Subsection"],
Cell[CellGroupData[{
Cell[742931, 31604, 928, 22, 146, "Input"],
Cell[743862, 31628, 37465, 1742, 457, 30762, 1629, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[781376, 33376, 48, 0, 46, "Subsection"],
Cell[CellGroupData[{
Cell[781449, 33380, 1010, 25, 146, "Input"],
Cell[782462, 33407, 38172, 1833, 455, 33042, 1746, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[CellGroupData[{
Cell[820671, 35245, 1025, 25, 146, "Input"],
Cell[821699, 35272, 40806, 1764, 454, 30735, 1596, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[862566, 37043, 39, 0, 62, "Subtitle"],
Cell[CellGroupData[{
Cell[862630, 37047, 63, 0, 46, "Subsection"],
Cell[CellGroupData[{
Cell[862718, 37051, 969, 24, 146, "Input"],
Cell[863690, 37077, 35044, 1624, 459, 29453, 1529, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[CellGroupData[{
Cell[898771, 38706, 1063, 28, 146, "Input"],
Cell[899837, 38736, 38177, 1777, 459, 32919, 1688, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
