(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     13502,        499]*)
(*NotebookOutlinePosition[     14211,        523]*)
(*  CellTagsIndexPosition[     14167,        519]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Board Parameters", "Section"],

Cell["All units in mils", "Text"],

Cell[BoxData[{
    \(\(Boardthickness = 125;\)\ \  (*\ mil\ *) \), "\[IndentingNewLine]", 
    \(\(Copper = 3;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      oz/sq\ inch; \ 1  oz\  = \ 1.4  mil\ *) \), "\[IndentingNewLine]", 
    \(\(Corethickness = 39\ ;\)\ \ \ \  (*\ 
      mil\ *) \), "\[IndentingNewLine]", 
    \(\(Prepregthickness = 37;\)\ \ \ \ \  (*\ 
      mil\ *) \), "\[IndentingNewLine]", 
    \(Er = 4.5; \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      dielectric\ constant*) \[IndentingNewLine]Layers = 
      4\ ; \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      top : \ signal; \ \(middle1\  &\)\ \(bottom : \ ground\); \ 
      middle2 : \ 
        RF\ *) \[IndentingNewLine]rule = {planethickness \[Rule] 
          Prepregthickness, 
        planeplane \[Rule] 
          Corethickness + Prepregthickness + 
            traceheight, \[IndentingNewLine]corethickness \[Rule] 
          Corethickness, 
        prepregthickness \[Rule] 
          Prepregthickness, \[IndentingNewLine]boardthickness \[Rule] 
          Boardthickness, er \[Rule] Er, layers \[Rule] Layers, 
        copper \[Rule] Copper, traceheight \[Rule] copper*1.4};\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Microline", "Section"],

Cell[BoxData[
    \(Zm[w_] := \(87\/\@\(er + 1.41\)\) 
        Log[\(5.98  planethickness\)\/\(0.8  w + traceheight\)]\)], "Input"],

Cell[BoxData[
    \(Speedm := \(\(1\/12\) \(1.017\) \(\@\( 0.475  er + 
              0.67\)\)\(\ \ \ \ \ \)\( (*\ in\ ns/inch\ *) \)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Zm[63] //. rule\)], "Input"],

Cell[BoxData[
    \(50.07693888112149`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Solve[Zm[w] \[Equal] Z0, w] // Simplify\), "\[IndentingNewLine]", 
    \(\(% /. Z0 \[Rule] 50\) //. rule\)}], "Input"],

Cell[BoxData[
    \({{w \[Rule] 
          7.4750000000000005`\ \[ExponentialE]\^\(\(-0.011494252873563218`\)\ \
\@\(\(\(1.41`\)\(\[InvisibleSpace]\)\) + 1.`\ er\)\ Z0\)\ planethickness - 
            1.25`\ traceheight}}\)], "Output"],

Cell[BoxData[
    \({{w \[Rule] 63.14688922538433`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Speedm //. rule\)], "Input"],

Cell[BoxData[
    \(0.14200367677898343`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stripline", "Section"],

Cell[BoxData[
    \(Z[w_] := \(60\/\@er\) 
        Log[\(4\ planeplane\)\/\(0.67  \[Pi]\ w \((0.8 + \
traceheight/w)\)\)]\)], "Input"],

Cell[BoxData[
    \(Speed := \(\(1/12\)\(\ \)\(1.017\) \(\@ Er\)\(\ \ \ \ \ \ \)\( (*\ 
          in\ ns/inch\ *) \)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Z[27] //. rule // N\)], "Input"],

Cell[BoxData[
    \(50.2382698644753`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Solve[Z[w] \[Equal] Z0, w] // Simplify\), "\[IndentingNewLine]", 
    \(\(% /. Z0 \[Rule] 50\) //. rule\)}], "Input"],

Cell[BoxData[
    \({{w \[Rule] 
          2.375446911819333`\ \[ExponentialE]\^\(\(-0.016666666666666666`\)\ \
\@er\ Z0\)\ planeplane - 1.25`\ traceheight}}\)], "Output"],

Cell[BoxData[
    \({{w \[Rule] 27.272825148387547`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Speed //. rule\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      ns/inch\ *) \), "\[IndentingNewLine]", 
    \(Table[2\^i, {i, \(-4\), 4}]\), "\n", 
    \(tracelen = \(\(1\/Speed\ Table[
            2\^i, {i, \(-4\), 4}]\)\(//.\)\(rule\)\(\ \ \)\( (*\ 
          trace\ length\ in\ inch\ *) \)\)\)}], "Input"],

Cell[BoxData[
    \(0.1797818991166797`\)], "Output"],

Cell[BoxData[
    \({1\/16, 1\/8, 1\/4, 1\/2, 1, 2, 4, 8, 16}\)], "Output"],

Cell[BoxData[
    \({0.3476434519107904`, 0.6952869038215808`, 1.3905738076431615`, 
      2.781147615286323`, 5.562295230572646`, 11.124590461145292`, 
      22.249180922290584`, 44.49836184458117`, 
      88.99672368916234`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(tracelen\  - 0.1\ \[Pi]\)\/2\)], "Input"],

Cell[BoxData[
    \({0.016742093275905534`, 0.19056381923130072`, 0.5382072711420911`, 
      1.2334941749636719`, 2.6240679826068334`, 5.405215597893156`, 
      10.967510828465802`, 22.092101289611094`, 
      44.34128221190168`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Asymmetric Stripline", "Section"],

Cell[BoxData[{
    \(Off[ReplaceAll::reps]\), "\[IndentingNewLine]", 
    \(Za[w_] := \(80\/\@er\) 
          Log[\(1.9 \((2*hhh + traceheight)\)\)\/\(0.8\ w + traceheight\)] \
\((1 - hhh\/\(4\ hhh1\))\) /. 
        If[prepregthickness > corethickness, {hhh \[Rule] corethickness, 
            hhh1 \[Rule] prepregthickness}, {hhh1 \[Rule] corethickness, 
            hhh \[Rule] prepregthickness}]\)}], "Input"],

Cell[BoxData[
    \(Speeda := \(\(1\/12\)\(\ \)\(1.017\) \(\@ Er\)\(\ \ \ \ \ \ \)\( (*\ 
          in\ ns/inch\ *) \)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Za[27] //. rule // N\)], "Input"],

Cell[BoxData[
    \(50.36513361831585`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Solve[\((Za[w] //. rule)\) \[Equal] Z0, w] // 
      Simplify\), "\[IndentingNewLine]", 
    \(\(% /. Z0 \[Rule] 50\) //. rule\)}], "Input"],

Cell[BoxData[
    \({{w \[Rule] \(-5.25`\) + 
            185.72500000000002`\ \[ExponentialE]\^\(\(-0.03476113168017902`\)\
\ Z0\)}}\)], "Output"],

Cell[BoxData[
    \({{w \[Rule] 27.411940502117794`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Speeda //. rule\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      ns/inch\ *) \), "\[IndentingNewLine]", 
    \(Table[2\^i, {i, \(-4\), 4}]\), "\n", 
    \(tracelen = \(\(1\/Speeda\ Table[
            2\^i, {i, \(-4\), 4}]\)\(//.\)\(rule\)\(\ \ \)\( (*\ 
          trace\ length\ in\ inch\ *) \)\)\)}], "Input"],

Cell[BoxData[
    \(0.1797818991166797`\)], "Output"],

Cell[BoxData[
    \({1\/16, 1\/8, 1\/4, 1\/2, 1, 2, 4, 8, 16}\)], "Output"],

Cell[BoxData[
    \({0.3476434519107904`, 0.6952869038215808`, 1.3905738076431615`, 
      2.781147615286323`, 5.562295230572646`, 11.124590461145292`, 
      22.249180922290584`, 44.49836184458117`, 
      88.99672368916234`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(tracelen\  - 0.1\ \[Pi]\)\/2\)], "Input"],

Cell[BoxData[
    \({0.016742093275905534`, 0.19056381923130072`, 0.5382072711420911`, 
      1.2334941749636719`, 2.6240679826068334`, 5.405215597893156`, 
      10.967510828465802`, 22.092101289611094`, 
      44.34128221190168`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell["Trace Lengths", "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`1\/16\)]],
  "ns"
}], "Subsubtitle"],

Cell[CellGroupData[{

Cell[BoxData[
    \(l[1] = \(-200\) + \[IndentingNewLine]2*\((4213 - 
              4100)\) + \[IndentingNewLine]\(\(100.\)\(\ \)\(\[Pi]\)\(\
\[IndentingNewLine]\)\)\)], "Input"],

Cell[BoxData[
    \(340.1592653589793`\)], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`1\/8\)]],
  "ns"
}], "Subsubtitle"],

Cell[CellGroupData[{

Cell[BoxData[
    \(l[2] = \(-200\) + \[IndentingNewLine]2*\((4483 - 
              4200)\) + \[IndentingNewLine]\(\(100.\)\(\ \)\(\[Pi]\)\(\
\[IndentingNewLine]\)\)\)], "Input"],

Cell[BoxData[
    \(680.1592653589794`\)], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`1\/4\)]],
  "ns"
}], "Subsubtitle"],

Cell[CellGroupData[{

Cell[BoxData[
    \(l[3] = \(-200\) + \[IndentingNewLine]2*\((4923 - 
              4300)\) + \[IndentingNewLine]\(\(100.\)\(\ \)\(\[Pi]\)\(\
\[IndentingNewLine]\)\)\)], "Input"],

Cell[BoxData[
    \(1360.1592653589794`\)], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  "ns"
}], "Subsubtitle"],

Cell[CellGroupData[{

Cell[BoxData[
    \(l[4] = \(-200\) + \[IndentingNewLine]2*\((5703 - 
              4400)\) + \[IndentingNewLine]\(\(100.\)\(\ \)\(\[Pi]\)\(\
\[IndentingNewLine]\)\)\)], "Input"],

Cell[BoxData[
    \(2720.159265358979`\)], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  "ns"
}], "Subsubtitle"],

Cell[CellGroupData[{

Cell[BoxData[
    \(l[5] = \(-200\) + \[IndentingNewLine]2*\((7164 - 
              4500)\) + \[IndentingNewLine]\(\(100.\)\(\ \)\(\[Pi]\)\(\
\[IndentingNewLine]\)\)\)], "Input"],

Cell[BoxData[
    \(5442.15926535898`\)], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`2\)]],
  "ns"
}], "Subsubtitle"],

Cell[CellGroupData[{

Cell[BoxData[
    \(l[6] = \(-200\) + \[IndentingNewLine]2*\((9986 - 
              4600)\) + \[IndentingNewLine]\(\(100.\)\(\ \)\(\[Pi]\)\(\
\[IndentingNewLine]\)\)\)], "Input"],

Cell[BoxData[
    \(10886.15926535898`\)], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4ns", "Subsubtitle"],

Cell[CellGroupData[{

Cell[BoxData[
    \(l[7] = \(-200\) + \[IndentingNewLine]2*\((10700 - 
              4700)\) + \[IndentingNewLine]100  \[Pi] + \
\[IndentingNewLine]300\ \[Pi] + \[IndentingNewLine]2*\((7200 - 
              6000)\) + \[IndentingNewLine]2*\((10700 - 
              7700)\) + \[IndentingNewLine]\(\(100.\)\(\ \)\(\[Pi]\)\(\
\[IndentingNewLine]\)\)\)], "Input"],

Cell[BoxData[
    \(21770.796326794898`\)], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["8ns", "Subsubtitle"],

Cell[CellGroupData[{

Cell[BoxData[
    \(l[8] = \(-200\) + \[IndentingNewLine]2*\((11300 - 
              4800)\) + \[IndentingNewLine]100  \[Pi] + \
\[IndentingNewLine]300\ \[Pi] + \[IndentingNewLine]2*\((8000 - 
              5200)\) + \[IndentingNewLine]2*\((11300 - 
              6500)\) + \[IndentingNewLine]100  \[Pi] + \
\[IndentingNewLine]300\ \[Pi] + \[IndentingNewLine]2*\((4800 - 
              4400)\) + \[IndentingNewLine]2*\((11300 - 
              6500)\) + \[IndentingNewLine]100  \[Pi]/
            2 + \[IndentingNewLine]300\ \[Pi]/
            2 + \[IndentingNewLine]2*\((4000 - 
              3157)\) + \[IndentingNewLine]\(\(100.\)\(\ \)\(\[Pi]\)\(\
\[IndentingNewLine]\)\)\)], "Input"],

Cell[BoxData[
    \(43541.75191894876`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["16ns", "Subsubtitle"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(l[
        9] = \(-200\) + \[IndentingNewLine]\((11800 - 
            4900)\) + \[IndentingNewLine]5*\((2*100  \[Pi] + 
              2*\((8800 - 2400)\))\) + \[IndentingNewLine]\((2*100  \[Pi] + 
            1*\((8800 - 7144)\))\) + \[IndentingNewLine]\((9000 - 
            7144)\) + \[IndentingNewLine]\((14000 - 
            4900)\) + \[IndentingNewLine]0. \)\(\[IndentingNewLine]\)
    \)\)], "Input"],

Cell[BoxData[
    \(87081.91118430774`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Error (in mils)", "Subsubtitle"],

Cell[CellGroupData[{

Cell[BoxData[
    \(1000\ tracelen - \((\ \(l[#] &\) /@ Range[9])\)\)], "Input"],

Cell[BoxData[
    \({0.007109282940007233`, 0.17348392485928343`, 0.5062332086979495`, 
      1.171731776375509`, 
      0.5027289117297187`, \(-0.8352768175609526`\), \
\(-0.14834971206073533`\), \(-0.4559647830828908`\), 
      0.6807240236084908`}\)], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1920}, {0, 1113}},
WindowSize->{840, 1057},
WindowMargins->{{195, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 35, 0, 73, "Section"],
Cell[1814, 55, 33, 0, 33, "Text"],
Cell[1850, 57, 1205, 22, 190, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3092, 84, 28, 0, 73, "Section"],
Cell[3123, 86, 131, 2, 48, "Input"],
Cell[3257, 90, 148, 2, 42, "Input"],

Cell[CellGroupData[{
Cell[3430, 96, 48, 1, 30, "Input"],
Cell[3481, 99, 52, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3570, 105, 139, 2, 50, "Input"],
Cell[3712, 109, 235, 4, 39, "Output"],
Cell[3950, 115, 66, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4053, 121, 48, 1, 30, "Input"],
Cell[4104, 124, 54, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4207, 131, 28, 0, 73, "Section"],
Cell[4238, 133, 134, 3, 48, "Input"],
Cell[4375, 138, 131, 2, 32, "Input"],

Cell[CellGroupData[{
Cell[4531, 144, 52, 1, 30, "Input"],
Cell[4586, 147, 51, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4674, 153, 138, 2, 50, "Input"],
Cell[4815, 157, 171, 3, 39, "Output"],
Cell[4989, 162, 67, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5093, 168, 337, 6, 86, "Input"],
Cell[5433, 176, 53, 1, 29, "Output"],
Cell[5489, 179, 75, 1, 42, "Output"],
Cell[5567, 182, 240, 4, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5844, 191, 63, 1, 42, "Input"],
Cell[5910, 194, 245, 4, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6204, 204, 39, 0, 73, "Section"],
Cell[6246, 206, 412, 7, 112, "Input"],
Cell[6661, 215, 133, 2, 42, "Input"],

Cell[CellGroupData[{
Cell[6819, 221, 53, 1, 30, "Input"],
Cell[6875, 224, 52, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6964, 230, 161, 3, 50, "Input"],
Cell[7128, 235, 147, 3, 29, "Output"],
Cell[7278, 240, 67, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7382, 246, 339, 6, 86, "Input"],
Cell[7724, 254, 53, 1, 29, "Output"],
Cell[7780, 257, 75, 1, 42, "Output"],
Cell[7858, 260, 240, 4, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8135, 269, 63, 1, 42, "Input"],
Cell[8201, 272, 245, 4, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[8473, 280, 32, 0, 73, "Section"],

Cell[CellGroupData[{
Cell[8530, 284, 93, 4, 34, "Subsubtitle"],

Cell[CellGroupData[{
Cell[8648, 292, 178, 3, 90, "Input"],
Cell[8829, 297, 52, 1, 29, "Output"]
}, Open  ]],
Cell[8896, 301, 26, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8959, 306, 92, 4, 34, "Subsubtitle"],

Cell[CellGroupData[{
Cell[9076, 314, 178, 3, 90, "Input"],
Cell[9257, 319, 52, 1, 29, "Output"]
}, Open  ]],
Cell[9324, 323, 26, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9387, 328, 92, 4, 34, "Subsubtitle"],

Cell[CellGroupData[{
Cell[9504, 336, 178, 3, 90, "Input"],
Cell[9685, 341, 53, 1, 29, "Output"]
}, Open  ]],
Cell[9753, 345, 26, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9816, 350, 92, 4, 34, "Subsubtitle"],

Cell[CellGroupData[{
Cell[9933, 358, 178, 3, 90, "Input"],
Cell[10114, 363, 52, 1, 29, "Output"]
}, Open  ]],
Cell[10181, 367, 26, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10244, 372, 89, 4, 30, "Subsubtitle"],

Cell[CellGroupData[{
Cell[10358, 380, 178, 3, 90, "Input"],
Cell[10539, 385, 51, 1, 29, "Output"]
}, Open  ]],
Cell[10605, 389, 26, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10668, 394, 89, 4, 30, "Subsubtitle"],

Cell[CellGroupData[{
Cell[10782, 402, 178, 3, 90, "Input"],
Cell[10963, 407, 52, 1, 29, "Output"]
}, Open  ]],
Cell[11030, 411, 26, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11093, 416, 26, 0, 30, "Subsubtitle"],

Cell[CellGroupData[{
Cell[11144, 420, 358, 6, 170, "Input"],
Cell[11505, 428, 53, 1, 29, "Output"]
}, Open  ]],
Cell[11573, 432, 26, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11636, 437, 26, 0, 30, "Subsubtitle"],

Cell[CellGroupData[{
Cell[11687, 441, 687, 12, 310, "Input"],
Cell[12377, 455, 52, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12478, 462, 27, 0, 30, "Subsubtitle"],

Cell[CellGroupData[{
Cell[12530, 466, 430, 8, 170, "Input"],
Cell[12963, 476, 52, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13064, 483, 38, 0, 30, "Subsubtitle"],

Cell[CellGroupData[{
Cell[13127, 487, 80, 1, 30, "Input"],
Cell[13210, 490, 264, 5, 29, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

